/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2022, */
/*    Rot127 <unisono@quyllur.org> 2022-2023 */
/* Automatically generated file by Capstone's LLVM TableGen Disassembler Backend. */

/* LLVM-commit: <commit> */
/* LLVM-tag: <tag> */

/* Do not edit. */

/* Capstone's LLVM TableGen Backends: */
/* https://github.com/capstone-engine/llvm-capstone */

{ TRICORE_FEATURE_HasV110, "HasV110" },
{ TRICORE_FEATURE_HasV120_UP, "HasV120_UP" },
{ TRICORE_FEATURE_HasV130_UP, "HasV130_UP" },
{ TRICORE_FEATURE_HasV161, "HasV161" },
{ TRICORE_FEATURE_HasV160_UP, "HasV160_UP" },
{ TRICORE_FEATURE_HasV131_UP, "HasV131_UP" },
{ TRICORE_FEATURE_HasV161_UP, "HasV161_UP" },
{ TRICORE_FEATURE_HasV162, "HasV162" },
{ TRICORE_FEATURE_HasV162_UP, "HasV162_UP" },
