
/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

/*===- TableGen'erated file -------------------------------------*- C++ -*-===*|*                                                                            *|
|* Subtarget Enumeration Source Fragment                                      *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/


enum {
  AArch64_FeatureAES = 0,
  AArch64_FeatureAM = 1,
  AArch64_FeatureAMVS = 2,
  AArch64_FeatureAggressiveFMA = 3,
  AArch64_FeatureAltFPCmp = 4,
  AArch64_FeatureAlternateSExtLoadCVTF32Pattern = 5,
  AArch64_FeatureAppleA7SysReg = 6,
  AArch64_FeatureArithmeticBccFusion = 7,
  AArch64_FeatureArithmeticCbzFusion = 8,
  AArch64_FeatureBF16 = 9,
  AArch64_FeatureBRBE = 10,
  AArch64_FeatureBalanceFPOps = 11,
  AArch64_FeatureBranchTargetId = 12,
  AArch64_FeatureCCIDX = 13,
  AArch64_FeatureCCPP = 14,
  AArch64_FeatureCONTEXTIDREL2 = 15,
  AArch64_FeatureCRC = 16,
  AArch64_FeatureCacheDeepPersist = 17,
  AArch64_FeatureCallSavedX8 = 18,
  AArch64_FeatureCallSavedX9 = 19,
  AArch64_FeatureCallSavedX10 = 20,
  AArch64_FeatureCallSavedX11 = 21,
  AArch64_FeatureCallSavedX12 = 22,
  AArch64_FeatureCallSavedX13 = 23,
  AArch64_FeatureCallSavedX14 = 24,
  AArch64_FeatureCallSavedX15 = 25,
  AArch64_FeatureCallSavedX18 = 26,
  AArch64_FeatureCmpBccFusion = 27,
  AArch64_FeatureComplxNum = 28,
  AArch64_FeatureCrypto = 29,
  AArch64_FeatureCustomCheapAsMoveHandling = 30,
  AArch64_FeatureDIT = 31,
  AArch64_FeatureDisableLatencySchedHeuristic = 32,
  AArch64_FeatureDotProd = 33,
  AArch64_FeatureEL2VMSA = 34,
  AArch64_FeatureEL3 = 35,
  AArch64_FeatureETE = 36,
  AArch64_FeatureEnhancedCounterVirtualization = 37,
  AArch64_FeatureExperimentalZeroingPseudos = 38,
  AArch64_FeatureExynosCheapAsMoveHandling = 39,
  AArch64_FeatureFP16FML = 40,
  AArch64_FeatureFPARMv8 = 41,
  AArch64_FeatureFRInt3264 = 42,
  AArch64_FeatureFineGrainedTraps = 43,
  AArch64_FeatureFixCortexA53_835769 = 44,
  AArch64_FeatureFlagM = 45,
  AArch64_FeatureForce32BitJumpTables = 46,
  AArch64_FeatureFullFP16 = 47,
  AArch64_FeatureFuseAES = 48,
  AArch64_FeatureFuseAddress = 49,
  AArch64_FeatureFuseArithmeticLogic = 50,
  AArch64_FeatureFuseCCSelect = 51,
  AArch64_FeatureFuseCryptoEOR = 52,
  AArch64_FeatureFuseLiterals = 53,
  AArch64_FeatureHBC = 54,
  AArch64_FeatureHCX = 55,
  AArch64_FeatureHardenSlsBlr = 56,
  AArch64_FeatureHardenSlsNoComdat = 57,
  AArch64_FeatureHardenSlsRetBr = 58,
  AArch64_FeatureJS = 59,
  AArch64_FeatureLOR = 60,
  AArch64_FeatureLS64 = 61,
  AArch64_FeatureLSE = 62,
  AArch64_FeatureLSE2 = 63,
  AArch64_FeatureLSLFast = 64,
  AArch64_FeatureMOPS = 65,
  AArch64_FeatureMPAM = 66,
  AArch64_FeatureMTE = 67,
  AArch64_FeatureMatMulFP32 = 68,
  AArch64_FeatureMatMulFP64 = 69,
  AArch64_FeatureMatMulInt8 = 70,
  AArch64_FeatureNEON = 71,
  AArch64_FeatureNV = 72,
  AArch64_FeatureNoBTIAtReturnTwice = 73,
  AArch64_FeatureNoNegativeImmediates = 74,
  AArch64_FeatureNoZCZeroingFP = 75,
  AArch64_FeatureOutlineAtomics = 76,
  AArch64_FeaturePAN = 77,
  AArch64_FeaturePAN_RWV = 78,
  AArch64_FeaturePAuth = 79,
  AArch64_FeaturePerfMon = 80,
  AArch64_FeaturePostRAScheduler = 81,
  AArch64_FeaturePredRes = 82,
  AArch64_FeaturePredictableSelectIsExpensive = 83,
  AArch64_FeaturePsUAO = 84,
  AArch64_FeatureRAS = 85,
  AArch64_FeatureRCPC = 86,
  AArch64_FeatureRCPC_IMMO = 87,
  AArch64_FeatureRDM = 88,
  AArch64_FeatureRME = 89,
  AArch64_FeatureRandGen = 90,
  AArch64_FeatureReserveX1 = 91,
  AArch64_FeatureReserveX2 = 92,
  AArch64_FeatureReserveX3 = 93,
  AArch64_FeatureReserveX4 = 94,
  AArch64_FeatureReserveX5 = 95,
  AArch64_FeatureReserveX6 = 96,
  AArch64_FeatureReserveX7 = 97,
  AArch64_FeatureReserveX9 = 98,
  AArch64_FeatureReserveX10 = 99,
  AArch64_FeatureReserveX11 = 100,
  AArch64_FeatureReserveX12 = 101,
  AArch64_FeatureReserveX13 = 102,
  AArch64_FeatureReserveX14 = 103,
  AArch64_FeatureReserveX15 = 104,
  AArch64_FeatureReserveX18 = 105,
  AArch64_FeatureReserveX20 = 106,
  AArch64_FeatureReserveX21 = 107,
  AArch64_FeatureReserveX22 = 108,
  AArch64_FeatureReserveX23 = 109,
  AArch64_FeatureReserveX24 = 110,
  AArch64_FeatureReserveX25 = 111,
  AArch64_FeatureReserveX26 = 112,
  AArch64_FeatureReserveX27 = 113,
  AArch64_FeatureReserveX28 = 114,
  AArch64_FeatureReserveX30 = 115,
  AArch64_FeatureSB = 116,
  AArch64_FeatureSEL2 = 117,
  AArch64_FeatureSHA2 = 118,
  AArch64_FeatureSHA3 = 119,
  AArch64_FeatureSM4 = 120,
  AArch64_FeatureSME = 121,
  AArch64_FeatureSMEF64 = 122,
  AArch64_FeatureSMEI64 = 123,
  AArch64_FeatureSPE = 124,
  AArch64_FeatureSPE_EEF = 125,
  AArch64_FeatureSSBS = 126,
  AArch64_FeatureSVE = 127,
  AArch64_FeatureSVE2 = 128,
  AArch64_FeatureSVE2AES = 129,
  AArch64_FeatureSVE2BitPerm = 130,
  AArch64_FeatureSVE2SHA3 = 131,
  AArch64_FeatureSVE2SM4 = 132,
  AArch64_FeatureSlowMisaligned128Store = 133,
  AArch64_FeatureSlowPaired128 = 134,
  AArch64_FeatureSlowSTRQro = 135,
  AArch64_FeatureSpecRestrict = 136,
  AArch64_FeatureStreamingSVE = 137,
  AArch64_FeatureStrictAlign = 138,
  AArch64_FeatureTLB_RMI = 139,
  AArch64_FeatureTME = 140,
  AArch64_FeatureTRACEV8_4 = 141,
  AArch64_FeatureTRBE = 142,
  AArch64_FeatureTaggedGlobals = 143,
  AArch64_FeatureUseEL1ForTP = 144,
  AArch64_FeatureUseEL2ForTP = 145,
  AArch64_FeatureUseEL3ForTP = 146,
  AArch64_FeatureUseRSqrt = 147,
  AArch64_FeatureUseScalarIncVL = 148,
  AArch64_FeatureVH = 149,
  AArch64_FeatureWFxT = 150,
  AArch64_FeatureXS = 151,
  AArch64_FeatureZCRegMove = 152,
  AArch64_FeatureZCZeroing = 153,
  AArch64_FeatureZCZeroingFPWorkaround = 154,
  AArch64_FeatureZCZeroingGP = 155,
  AArch64_HasV8_0aOps = 156,
  AArch64_HasV8_0rOps = 157,
  AArch64_HasV8_1aOps = 158,
  AArch64_HasV8_2aOps = 159,
  AArch64_HasV8_3aOps = 160,
  AArch64_HasV8_4aOps = 161,
  AArch64_HasV8_5aOps = 162,
  AArch64_HasV8_6aOps = 163,
  AArch64_HasV8_7aOps = 164,
  AArch64_HasV8_8aOps = 165,
  AArch64_HasV9_0aOps = 166,
  AArch64_HasV9_1aOps = 167,
  AArch64_HasV9_2aOps = 168,
  AArch64_HasV9_3aOps = 169,
  AArch64_TuneA35 = 170,
  AArch64_TuneA53 = 171,
  AArch64_TuneA55 = 172,
  AArch64_TuneA57 = 173,
  AArch64_TuneA64FX = 174,
  AArch64_TuneA65 = 175,
  AArch64_TuneA72 = 176,
  AArch64_TuneA73 = 177,
  AArch64_TuneA75 = 178,
  AArch64_TuneA76 = 179,
  AArch64_TuneA77 = 180,
  AArch64_TuneA78 = 181,
  AArch64_TuneA78C = 182,
  AArch64_TuneA510 = 183,
  AArch64_TuneA710 = 184,
  AArch64_TuneAmpere1 = 185,
  AArch64_TuneAppleA7 = 186,
  AArch64_TuneAppleA10 = 187,
  AArch64_TuneAppleA11 = 188,
  AArch64_TuneAppleA12 = 189,
  AArch64_TuneAppleA13 = 190,
  AArch64_TuneAppleA14 = 191,
  AArch64_TuneCarmel = 192,
  AArch64_TuneExynosM3 = 193,
  AArch64_TuneExynosM4 = 194,
  AArch64_TuneFalkor = 195,
  AArch64_TuneKryo = 196,
  AArch64_TuneNeoverse512TVB = 197,
  AArch64_TuneNeoverseE1 = 198,
  AArch64_TuneNeoverseN1 = 199,
  AArch64_TuneNeoverseN2 = 200,
  AArch64_TuneNeoverseV1 = 201,
  AArch64_TuneR82 = 202,
  AArch64_TuneSaphira = 203,
  AArch64_TuneTSV110 = 204,
  AArch64_TuneThunderX = 205,
  AArch64_TuneThunderX2T99 = 206,
  AArch64_TuneThunderX3T110 = 207,
  AArch64_TuneThunderXT81 = 208,
  AArch64_TuneThunderXT83 = 209,
  AArch64_TuneThunderXT88 = 210,
  AArch64_TuneX1 = 211,
  AArch64_TuneX2 = 212,
  AArch64_NumSubtargetFeatures = 213
};

