// For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT
package capstone;

public class Ppc_const {

	public static final int PPC_BC_INVALID = 0;
	public static final int PPC_BC_LT = (0<<5)|12;
	public static final int PPC_BC_LE = (1<<5)|4;
	public static final int PPC_BC_EQ = (2<<5)|12;
	public static final int PPC_BC_GE = (0<<5)|4;
	public static final int PPC_BC_GT = (1<<5)|12;
	public static final int PPC_BC_NE = (2<<5)|4;
	public static final int PPC_BC_UN = (3<<5)|12;
	public static final int PPC_BC_NU = (3<<5)|4;
	public static final int PPC_BC_SO = (4<<5)|12;
	public static final int PPC_BC_NS = (4<<5)|4;

	public static final int PPC_BH_INVALID = 0;
	public static final int PPC_BH_PLUS = 1;
	public static final int PPC_BH_MINUS = 2;

	public static final int PPC_OP_INVALID = 0;
	public static final int PPC_OP_REG = 1;
	public static final int PPC_OP_IMM = 2;
	public static final int PPC_OP_MEM = 3;
	public static final int PPC_OP_CRX = 64;

	public static final int PPC_REG_INVALID = 0;
	public static final int PPC_REG_CARRY = 2;
	public static final int PPC_REG_CTR = 3;
	public static final int PPC_REG_LR = 5;
	public static final int PPC_REG_RM = 6;
	public static final int PPC_REG_VRSAVE = 8;
	public static final int PPC_REG_XER = 9;
	public static final int PPC_REG_ZERO = 10;
	public static final int PPC_REG_CR0 = 12;
	public static final int PPC_REG_CR1 = 13;
	public static final int PPC_REG_CR2 = 14;
	public static final int PPC_REG_CR3 = 15;
	public static final int PPC_REG_CR4 = 16;
	public static final int PPC_REG_CR5 = 17;
	public static final int PPC_REG_CR6 = 18;
	public static final int PPC_REG_CR7 = 19;
	public static final int PPC_REG_CTR8 = 20;
	public static final int PPC_REG_F0 = 21;
	public static final int PPC_REG_F1 = 22;
	public static final int PPC_REG_F2 = 23;
	public static final int PPC_REG_F3 = 24;
	public static final int PPC_REG_F4 = 25;
	public static final int PPC_REG_F5 = 26;
	public static final int PPC_REG_F6 = 27;
	public static final int PPC_REG_F7 = 28;
	public static final int PPC_REG_F8 = 29;
	public static final int PPC_REG_F9 = 30;
	public static final int PPC_REG_F10 = 31;
	public static final int PPC_REG_F11 = 32;
	public static final int PPC_REG_F12 = 33;
	public static final int PPC_REG_F13 = 34;
	public static final int PPC_REG_F14 = 35;
	public static final int PPC_REG_F15 = 36;
	public static final int PPC_REG_F16 = 37;
	public static final int PPC_REG_F17 = 38;
	public static final int PPC_REG_F18 = 39;
	public static final int PPC_REG_F19 = 40;
	public static final int PPC_REG_F20 = 41;
	public static final int PPC_REG_F21 = 42;
	public static final int PPC_REG_F22 = 43;
	public static final int PPC_REG_F23 = 44;
	public static final int PPC_REG_F24 = 45;
	public static final int PPC_REG_F25 = 46;
	public static final int PPC_REG_F26 = 47;
	public static final int PPC_REG_F27 = 48;
	public static final int PPC_REG_F28 = 49;
	public static final int PPC_REG_F29 = 50;
	public static final int PPC_REG_F30 = 51;
	public static final int PPC_REG_F31 = 52;
	public static final int PPC_REG_LR8 = 54;
	public static final int PPC_REG_Q0 = 55;
	public static final int PPC_REG_Q1 = 56;
	public static final int PPC_REG_Q2 = 57;
	public static final int PPC_REG_Q3 = 58;
	public static final int PPC_REG_Q4 = 59;
	public static final int PPC_REG_Q5 = 60;
	public static final int PPC_REG_Q6 = 61;
	public static final int PPC_REG_Q7 = 62;
	public static final int PPC_REG_Q8 = 63;
	public static final int PPC_REG_Q9 = 64;
	public static final int PPC_REG_Q10 = 65;
	public static final int PPC_REG_Q11 = 66;
	public static final int PPC_REG_Q12 = 67;
	public static final int PPC_REG_Q13 = 68;
	public static final int PPC_REG_Q14 = 69;
	public static final int PPC_REG_Q15 = 70;
	public static final int PPC_REG_Q16 = 71;
	public static final int PPC_REG_Q17 = 72;
	public static final int PPC_REG_Q18 = 73;
	public static final int PPC_REG_Q19 = 74;
	public static final int PPC_REG_Q20 = 75;
	public static final int PPC_REG_Q21 = 76;
	public static final int PPC_REG_Q22 = 77;
	public static final int PPC_REG_Q23 = 78;
	public static final int PPC_REG_Q24 = 79;
	public static final int PPC_REG_Q25 = 80;
	public static final int PPC_REG_Q26 = 81;
	public static final int PPC_REG_Q27 = 82;
	public static final int PPC_REG_Q28 = 83;
	public static final int PPC_REG_Q29 = 84;
	public static final int PPC_REG_Q30 = 85;
	public static final int PPC_REG_Q31 = 86;
	public static final int PPC_REG_R0 = 87;
	public static final int PPC_REG_R1 = 88;
	public static final int PPC_REG_R2 = 89;
	public static final int PPC_REG_R3 = 90;
	public static final int PPC_REG_R4 = 91;
	public static final int PPC_REG_R5 = 92;
	public static final int PPC_REG_R6 = 93;
	public static final int PPC_REG_R7 = 94;
	public static final int PPC_REG_R8 = 95;
	public static final int PPC_REG_R9 = 96;
	public static final int PPC_REG_R10 = 97;
	public static final int PPC_REG_R11 = 98;
	public static final int PPC_REG_R12 = 99;
	public static final int PPC_REG_R13 = 100;
	public static final int PPC_REG_R14 = 101;
	public static final int PPC_REG_R15 = 102;
	public static final int PPC_REG_R16 = 103;
	public static final int PPC_REG_R17 = 104;
	public static final int PPC_REG_R18 = 105;
	public static final int PPC_REG_R19 = 106;
	public static final int PPC_REG_R20 = 107;
	public static final int PPC_REG_R21 = 108;
	public static final int PPC_REG_R22 = 109;
	public static final int PPC_REG_R23 = 110;
	public static final int PPC_REG_R24 = 111;
	public static final int PPC_REG_R25 = 112;
	public static final int PPC_REG_R26 = 113;
	public static final int PPC_REG_R27 = 114;
	public static final int PPC_REG_R28 = 115;
	public static final int PPC_REG_R29 = 116;
	public static final int PPC_REG_R30 = 117;
	public static final int PPC_REG_R31 = 118;
	public static final int PPC_REG_V0 = 151;
	public static final int PPC_REG_V1 = 152;
	public static final int PPC_REG_V2 = 153;
	public static final int PPC_REG_V3 = 154;
	public static final int PPC_REG_V4 = 155;
	public static final int PPC_REG_V5 = 156;
	public static final int PPC_REG_V6 = 157;
	public static final int PPC_REG_V7 = 158;
	public static final int PPC_REG_V8 = 159;
	public static final int PPC_REG_V9 = 160;
	public static final int PPC_REG_V10 = 161;
	public static final int PPC_REG_V11 = 162;
	public static final int PPC_REG_V12 = 163;
	public static final int PPC_REG_V13 = 164;
	public static final int PPC_REG_V14 = 165;
	public static final int PPC_REG_V15 = 166;
	public static final int PPC_REG_V16 = 167;
	public static final int PPC_REG_V17 = 168;
	public static final int PPC_REG_V18 = 169;
	public static final int PPC_REG_V19 = 170;
	public static final int PPC_REG_V20 = 171;
	public static final int PPC_REG_V21 = 172;
	public static final int PPC_REG_V22 = 173;
	public static final int PPC_REG_V23 = 174;
	public static final int PPC_REG_V24 = 175;
	public static final int PPC_REG_V25 = 176;
	public static final int PPC_REG_V26 = 177;
	public static final int PPC_REG_V27 = 178;
	public static final int PPC_REG_V28 = 179;
	public static final int PPC_REG_V29 = 180;
	public static final int PPC_REG_V30 = 181;
	public static final int PPC_REG_V31 = 182;
	public static final int PPC_REG_VS0 = 215;
	public static final int PPC_REG_VS1 = 216;
	public static final int PPC_REG_VS2 = 217;
	public static final int PPC_REG_VS3 = 218;
	public static final int PPC_REG_VS4 = 219;
	public static final int PPC_REG_VS5 = 220;
	public static final int PPC_REG_VS6 = 221;
	public static final int PPC_REG_VS7 = 222;
	public static final int PPC_REG_VS8 = 223;
	public static final int PPC_REG_VS9 = 224;
	public static final int PPC_REG_VS10 = 225;
	public static final int PPC_REG_VS11 = 226;
	public static final int PPC_REG_VS12 = 227;
	public static final int PPC_REG_VS13 = 228;
	public static final int PPC_REG_VS14 = 229;
	public static final int PPC_REG_VS15 = 230;
	public static final int PPC_REG_VS16 = 231;
	public static final int PPC_REG_VS17 = 232;
	public static final int PPC_REG_VS18 = 233;
	public static final int PPC_REG_VS19 = 234;
	public static final int PPC_REG_VS20 = 235;
	public static final int PPC_REG_VS21 = 236;
	public static final int PPC_REG_VS22 = 237;
	public static final int PPC_REG_VS23 = 238;
	public static final int PPC_REG_VS24 = 239;
	public static final int PPC_REG_VS25 = 240;
	public static final int PPC_REG_VS26 = 241;
	public static final int PPC_REG_VS27 = 242;
	public static final int PPC_REG_VS28 = 243;
	public static final int PPC_REG_VS29 = 244;
	public static final int PPC_REG_VS30 = 245;
	public static final int PPC_REG_VS31 = 246;
	public static final int PPC_REG_VS32 = 247;
	public static final int PPC_REG_VS33 = 248;
	public static final int PPC_REG_VS34 = 249;
	public static final int PPC_REG_VS35 = 250;
	public static final int PPC_REG_VS36 = 251;
	public static final int PPC_REG_VS37 = 252;
	public static final int PPC_REG_VS38 = 253;
	public static final int PPC_REG_VS39 = 254;
	public static final int PPC_REG_VS40 = 255;
	public static final int PPC_REG_VS41 = 256;
	public static final int PPC_REG_VS42 = 257;
	public static final int PPC_REG_VS43 = 258;
	public static final int PPC_REG_VS44 = 259;
	public static final int PPC_REG_VS45 = 260;
	public static final int PPC_REG_VS46 = 261;
	public static final int PPC_REG_VS47 = 262;
	public static final int PPC_REG_VS48 = 263;
	public static final int PPC_REG_VS49 = 264;
	public static final int PPC_REG_VS50 = 265;
	public static final int PPC_REG_VS51 = 266;
	public static final int PPC_REG_VS52 = 267;
	public static final int PPC_REG_VS53 = 268;
	public static final int PPC_REG_VS54 = 269;
	public static final int PPC_REG_VS55 = 270;
	public static final int PPC_REG_VS56 = 271;
	public static final int PPC_REG_VS57 = 272;
	public static final int PPC_REG_VS58 = 273;
	public static final int PPC_REG_VS59 = 274;
	public static final int PPC_REG_VS60 = 275;
	public static final int PPC_REG_VS61 = 276;
	public static final int PPC_REG_VS62 = 277;
	public static final int PPC_REG_VS63 = 278;
	public static final int PPC_REG_CR0EQ = 312;
	public static final int PPC_REG_CR1EQ = 313;
	public static final int PPC_REG_CR2EQ = 314;
	public static final int PPC_REG_CR3EQ = 315;
	public static final int PPC_REG_CR4EQ = 316;
	public static final int PPC_REG_CR5EQ = 317;
	public static final int PPC_REG_CR6EQ = 318;
	public static final int PPC_REG_CR7EQ = 319;
	public static final int PPC_REG_CR0GT = 320;
	public static final int PPC_REG_CR1GT = 321;
	public static final int PPC_REG_CR2GT = 322;
	public static final int PPC_REG_CR3GT = 323;
	public static final int PPC_REG_CR4GT = 324;
	public static final int PPC_REG_CR5GT = 325;
	public static final int PPC_REG_CR6GT = 326;
	public static final int PPC_REG_CR7GT = 327;
	public static final int PPC_REG_CR0LT = 328;
	public static final int PPC_REG_CR1LT = 329;
	public static final int PPC_REG_CR2LT = 330;
	public static final int PPC_REG_CR3LT = 331;
	public static final int PPC_REG_CR4LT = 332;
	public static final int PPC_REG_CR5LT = 333;
	public static final int PPC_REG_CR6LT = 334;
	public static final int PPC_REG_CR7LT = 335;
	public static final int PPC_REG_CR0UN = 336;
	public static final int PPC_REG_CR1UN = 337;
	public static final int PPC_REG_CR2UN = 338;
	public static final int PPC_REG_CR3UN = 339;
	public static final int PPC_REG_CR4UN = 340;
	public static final int PPC_REG_CR5UN = 341;
	public static final int PPC_REG_CR6UN = 342;
	public static final int PPC_REG_CR7UN = 343;
	public static final int PPC_REG_ENDING = 344;

	public static final int PPC_INS_INVALID = 0;
	public static final int PPC_INS_ADD = 1;
	public static final int PPC_INS_ADDC = 2;
	public static final int PPC_INS_ADDE = 3;
	public static final int PPC_INS_ADDI = 4;
	public static final int PPC_INS_ADDIC = 5;
	public static final int PPC_INS_ADDIS = 6;
	public static final int PPC_INS_ADDME = 7;
	public static final int PPC_INS_ADDPCIS = 8;
	public static final int PPC_INS_ADDZE = 9;
	public static final int PPC_INS_AND = 10;
	public static final int PPC_INS_ANDC = 11;
	public static final int PPC_INS_ANDI = 12;
	public static final int PPC_INS_ANDIS = 13;
	public static final int PPC_INS_ATTN = 14;
	public static final int PPC_INS_B = 15;
	public static final int PPC_INS_BA = 16;
	public static final int PPC_INS_BC = 17;
	public static final int PPC_INS_BCA = 18;
	public static final int PPC_INS_BCCTR = 19;
	public static final int PPC_INS_BCCTRL = 20;
	public static final int PPC_INS_BCDCFN = 21;
	public static final int PPC_INS_BCDCFSQ = 22;
	public static final int PPC_INS_BCDCFZ = 23;
	public static final int PPC_INS_BCDCPSGN = 24;
	public static final int PPC_INS_BCDCTN = 25;
	public static final int PPC_INS_BCDCTSQ = 26;
	public static final int PPC_INS_BCDCTZ = 27;
	public static final int PPC_INS_BCDS = 28;
	public static final int PPC_INS_BCDSETSGN = 29;
	public static final int PPC_INS_BCDSR = 30;
	public static final int PPC_INS_BCDTRUNC = 31;
	public static final int PPC_INS_BCDUS = 32;
	public static final int PPC_INS_BCDUTRUNC = 33;
	public static final int PPC_INS_BCL = 34;
	public static final int PPC_INS_BCLA = 35;
	public static final int PPC_INS_BCLR = 36;
	public static final int PPC_INS_BCLRL = 37;
	public static final int PPC_INS_BCTR = 38;
	public static final int PPC_INS_BCTRL = 39;
	public static final int PPC_INS_BDNZ = 40;
	public static final int PPC_INS_BDNZA = 41;
	public static final int PPC_INS_BDNZF = 42;
	public static final int PPC_INS_BDNZFA = 43;
	public static final int PPC_INS_BDNZFL = 44;
	public static final int PPC_INS_BDNZFLA = 45;
	public static final int PPC_INS_BDNZFLR = 46;
	public static final int PPC_INS_BDNZFLRL = 47;
	public static final int PPC_INS_BDNZL = 48;
	public static final int PPC_INS_BDNZLA = 49;
	public static final int PPC_INS_BDNZLR = 50;
	public static final int PPC_INS_BDNZLRL = 51;
	public static final int PPC_INS_BDNZT = 52;
	public static final int PPC_INS_BDNZTA = 53;
	public static final int PPC_INS_BDNZTL = 54;
	public static final int PPC_INS_BDNZTLA = 55;
	public static final int PPC_INS_BDNZTLR = 56;
	public static final int PPC_INS_BDNZTLRL = 57;
	public static final int PPC_INS_BDZ = 58;
	public static final int PPC_INS_BDZA = 59;
	public static final int PPC_INS_BDZF = 60;
	public static final int PPC_INS_BDZFA = 61;
	public static final int PPC_INS_BDZFL = 62;
	public static final int PPC_INS_BDZFLA = 63;
	public static final int PPC_INS_BDZFLR = 64;
	public static final int PPC_INS_BDZFLRL = 65;
	public static final int PPC_INS_BDZL = 66;
	public static final int PPC_INS_BDZLA = 67;
	public static final int PPC_INS_BDZLR = 68;
	public static final int PPC_INS_BDZLRL = 69;
	public static final int PPC_INS_BDZT = 70;
	public static final int PPC_INS_BDZTA = 71;
	public static final int PPC_INS_BDZTL = 72;
	public static final int PPC_INS_BDZTLA = 73;
	public static final int PPC_INS_BDZTLR = 74;
	public static final int PPC_INS_BDZTLRL = 75;
	public static final int PPC_INS_BEQ = 76;
	public static final int PPC_INS_BEQA = 77;
	public static final int PPC_INS_BEQCTR = 78;
	public static final int PPC_INS_BEQCTRL = 79;
	public static final int PPC_INS_BEQL = 80;
	public static final int PPC_INS_BEQLA = 81;
	public static final int PPC_INS_BEQLR = 82;
	public static final int PPC_INS_BEQLRL = 83;
	public static final int PPC_INS_BF = 84;
	public static final int PPC_INS_BFA = 85;
	public static final int PPC_INS_BFCTR = 86;
	public static final int PPC_INS_BFCTRL = 87;
	public static final int PPC_INS_BFL = 88;
	public static final int PPC_INS_BFLA = 89;
	public static final int PPC_INS_BFLR = 90;
	public static final int PPC_INS_BFLRL = 91;
	public static final int PPC_INS_BGE = 92;
	public static final int PPC_INS_BGEA = 93;
	public static final int PPC_INS_BGECTR = 94;
	public static final int PPC_INS_BGECTRL = 95;
	public static final int PPC_INS_BGEL = 96;
	public static final int PPC_INS_BGELA = 97;
	public static final int PPC_INS_BGELR = 98;
	public static final int PPC_INS_BGELRL = 99;
	public static final int PPC_INS_BGT = 100;
	public static final int PPC_INS_BGTA = 101;
	public static final int PPC_INS_BGTCTR = 102;
	public static final int PPC_INS_BGTCTRL = 103;
	public static final int PPC_INS_BGTL = 104;
	public static final int PPC_INS_BGTLA = 105;
	public static final int PPC_INS_BGTLR = 106;
	public static final int PPC_INS_BGTLRL = 107;
	public static final int PPC_INS_BL = 108;
	public static final int PPC_INS_BLA = 109;
	public static final int PPC_INS_BLE = 110;
	public static final int PPC_INS_BLEA = 111;
	public static final int PPC_INS_BLECTR = 112;
	public static final int PPC_INS_BLECTRL = 113;
	public static final int PPC_INS_BLEL = 114;
	public static final int PPC_INS_BLELA = 115;
	public static final int PPC_INS_BLELR = 116;
	public static final int PPC_INS_BLELRL = 117;
	public static final int PPC_INS_BLR = 118;
	public static final int PPC_INS_BLRL = 119;
	public static final int PPC_INS_BLT = 120;
	public static final int PPC_INS_BLTA = 121;
	public static final int PPC_INS_BLTCTR = 122;
	public static final int PPC_INS_BLTCTRL = 123;
	public static final int PPC_INS_BLTL = 124;
	public static final int PPC_INS_BLTLA = 125;
	public static final int PPC_INS_BLTLR = 126;
	public static final int PPC_INS_BLTLRL = 127;
	public static final int PPC_INS_BNE = 128;
	public static final int PPC_INS_BNEA = 129;
	public static final int PPC_INS_BNECTR = 130;
	public static final int PPC_INS_BNECTRL = 131;
	public static final int PPC_INS_BNEL = 132;
	public static final int PPC_INS_BNELA = 133;
	public static final int PPC_INS_BNELR = 134;
	public static final int PPC_INS_BNELRL = 135;
	public static final int PPC_INS_BNG = 136;
	public static final int PPC_INS_BNGA = 137;
	public static final int PPC_INS_BNGCTR = 138;
	public static final int PPC_INS_BNGCTRL = 139;
	public static final int PPC_INS_BNGL = 140;
	public static final int PPC_INS_BNGLA = 141;
	public static final int PPC_INS_BNGLR = 142;
	public static final int PPC_INS_BNGLRL = 143;
	public static final int PPC_INS_BNL = 144;
	public static final int PPC_INS_BNLA = 145;
	public static final int PPC_INS_BNLCTR = 146;
	public static final int PPC_INS_BNLCTRL = 147;
	public static final int PPC_INS_BNLL = 148;
	public static final int PPC_INS_BNLLA = 149;
	public static final int PPC_INS_BNLLR = 150;
	public static final int PPC_INS_BNLLRL = 151;
	public static final int PPC_INS_BNS = 152;
	public static final int PPC_INS_BNSA = 153;
	public static final int PPC_INS_BNSCTR = 154;
	public static final int PPC_INS_BNSCTRL = 155;
	public static final int PPC_INS_BNSL = 156;
	public static final int PPC_INS_BNSLA = 157;
	public static final int PPC_INS_BNSLR = 158;
	public static final int PPC_INS_BNSLRL = 159;
	public static final int PPC_INS_BNU = 160;
	public static final int PPC_INS_BNUA = 161;
	public static final int PPC_INS_BNUCTR = 162;
	public static final int PPC_INS_BNUCTRL = 163;
	public static final int PPC_INS_BNUL = 164;
	public static final int PPC_INS_BNULA = 165;
	public static final int PPC_INS_BNULR = 166;
	public static final int PPC_INS_BNULRL = 167;
	public static final int PPC_INS_BPERMD = 168;
	public static final int PPC_INS_BRINC = 169;
	public static final int PPC_INS_BSO = 170;
	public static final int PPC_INS_BSOA = 171;
	public static final int PPC_INS_BSOCTR = 172;
	public static final int PPC_INS_BSOCTRL = 173;
	public static final int PPC_INS_BSOL = 174;
	public static final int PPC_INS_BSOLA = 175;
	public static final int PPC_INS_BSOLR = 176;
	public static final int PPC_INS_BSOLRL = 177;
	public static final int PPC_INS_BT = 178;
	public static final int PPC_INS_BTA = 179;
	public static final int PPC_INS_BTCTR = 180;
	public static final int PPC_INS_BTCTRL = 181;
	public static final int PPC_INS_BTL = 182;
	public static final int PPC_INS_BTLA = 183;
	public static final int PPC_INS_BTLR = 184;
	public static final int PPC_INS_BTLRL = 185;
	public static final int PPC_INS_BUN = 186;
	public static final int PPC_INS_BUNA = 187;
	public static final int PPC_INS_BUNCTR = 188;
	public static final int PPC_INS_BUNCTRL = 189;
	public static final int PPC_INS_BUNL = 190;
	public static final int PPC_INS_BUNLA = 191;
	public static final int PPC_INS_BUNLR = 192;
	public static final int PPC_INS_BUNLRL = 193;
	public static final int PPC_INS_CLRBHRB = 194;
	public static final int PPC_INS_CLRLDI = 195;
	public static final int PPC_INS_CLRLSLDI = 196;
	public static final int PPC_INS_CLRLSLWI = 197;
	public static final int PPC_INS_CLRLWI = 198;
	public static final int PPC_INS_CLRRDI = 199;
	public static final int PPC_INS_CLRRWI = 200;
	public static final int PPC_INS_CMP = 201;
	public static final int PPC_INS_CMPB = 202;
	public static final int PPC_INS_CMPD = 203;
	public static final int PPC_INS_CMPDI = 204;
	public static final int PPC_INS_CMPEQB = 205;
	public static final int PPC_INS_CMPI = 206;
	public static final int PPC_INS_CMPL = 207;
	public static final int PPC_INS_CMPLD = 208;
	public static final int PPC_INS_CMPLDI = 209;
	public static final int PPC_INS_CMPLI = 210;
	public static final int PPC_INS_CMPLW = 211;
	public static final int PPC_INS_CMPLWI = 212;
	public static final int PPC_INS_CMPRB = 213;
	public static final int PPC_INS_CMPW = 214;
	public static final int PPC_INS_CMPWI = 215;
	public static final int PPC_INS_CNTLZD = 216;
	public static final int PPC_INS_CNTLZW = 217;
	public static final int PPC_INS_CNTTZD = 218;
	public static final int PPC_INS_CNTTZW = 219;
	public static final int PPC_INS_COPY = 220;
	public static final int PPC_INS_COPY_FIRST = 221;
	public static final int PPC_INS_CP_ABORT = 222;
	public static final int PPC_INS_CRAND = 223;
	public static final int PPC_INS_CRANDC = 224;
	public static final int PPC_INS_CRCLR = 225;
	public static final int PPC_INS_CREQV = 226;
	public static final int PPC_INS_CRMOVE = 227;
	public static final int PPC_INS_CRNAND = 228;
	public static final int PPC_INS_CRNOR = 229;
	public static final int PPC_INS_CRNOT = 230;
	public static final int PPC_INS_CROR = 231;
	public static final int PPC_INS_CRORC = 232;
	public static final int PPC_INS_CRSET = 233;
	public static final int PPC_INS_CRXOR = 234;
	public static final int PPC_INS_DARN = 235;
	public static final int PPC_INS_DCBA = 236;
	public static final int PPC_INS_DCBF = 237;
	public static final int PPC_INS_DCBFEP = 238;
	public static final int PPC_INS_DCBFL = 239;
	public static final int PPC_INS_DCBFLP = 240;
	public static final int PPC_INS_DCBI = 241;
	public static final int PPC_INS_DCBST = 242;
	public static final int PPC_INS_DCBSTEP = 243;
	public static final int PPC_INS_DCBT = 244;
	public static final int PPC_INS_DCBTCT = 245;
	public static final int PPC_INS_DCBTDS = 246;
	public static final int PPC_INS_DCBTEP = 247;
	public static final int PPC_INS_DCBTST = 248;
	public static final int PPC_INS_DCBTSTCT = 249;
	public static final int PPC_INS_DCBTSTDS = 250;
	public static final int PPC_INS_DCBTSTEP = 251;
	public static final int PPC_INS_DCBTSTT = 252;
	public static final int PPC_INS_DCBTT = 253;
	public static final int PPC_INS_DCBZ = 254;
	public static final int PPC_INS_DCBZEP = 255;
	public static final int PPC_INS_DCBZL = 256;
	public static final int PPC_INS_DCBZLEP = 257;
	public static final int PPC_INS_DCCCI = 258;
	public static final int PPC_INS_DCI = 259;
	public static final int PPC_INS_DIVD = 260;
	public static final int PPC_INS_DIVDE = 261;
	public static final int PPC_INS_DIVDEU = 262;
	public static final int PPC_INS_DIVDU = 263;
	public static final int PPC_INS_DIVW = 264;
	public static final int PPC_INS_DIVWE = 265;
	public static final int PPC_INS_DIVWEU = 266;
	public static final int PPC_INS_DIVWU = 267;
	public static final int PPC_INS_DSS = 268;
	public static final int PPC_INS_DSSALL = 269;
	public static final int PPC_INS_DST = 270;
	public static final int PPC_INS_DSTST = 271;
	public static final int PPC_INS_DSTSTT = 272;
	public static final int PPC_INS_DSTT = 273;
	public static final int PPC_INS_EFDABS = 274;
	public static final int PPC_INS_EFDADD = 275;
	public static final int PPC_INS_EFDCFS = 276;
	public static final int PPC_INS_EFDCFSF = 277;
	public static final int PPC_INS_EFDCFSI = 278;
	public static final int PPC_INS_EFDCFSID = 279;
	public static final int PPC_INS_EFDCFUF = 280;
	public static final int PPC_INS_EFDCFUI = 281;
	public static final int PPC_INS_EFDCFUID = 282;
	public static final int PPC_INS_EFDCMPEQ = 283;
	public static final int PPC_INS_EFDCMPGT = 284;
	public static final int PPC_INS_EFDCMPLT = 285;
	public static final int PPC_INS_EFDCTSF = 286;
	public static final int PPC_INS_EFDCTSI = 287;
	public static final int PPC_INS_EFDCTSIDZ = 288;
	public static final int PPC_INS_EFDCTSIZ = 289;
	public static final int PPC_INS_EFDCTUF = 290;
	public static final int PPC_INS_EFDCTUI = 291;
	public static final int PPC_INS_EFDCTUIDZ = 292;
	public static final int PPC_INS_EFDCTUIZ = 293;
	public static final int PPC_INS_EFDDIV = 294;
	public static final int PPC_INS_EFDMUL = 295;
	public static final int PPC_INS_EFDNABS = 296;
	public static final int PPC_INS_EFDNEG = 297;
	public static final int PPC_INS_EFDSUB = 298;
	public static final int PPC_INS_EFDTSTEQ = 299;
	public static final int PPC_INS_EFDTSTGT = 300;
	public static final int PPC_INS_EFDTSTLT = 301;
	public static final int PPC_INS_EFSABS = 302;
	public static final int PPC_INS_EFSADD = 303;
	public static final int PPC_INS_EFSCFD = 304;
	public static final int PPC_INS_EFSCFSF = 305;
	public static final int PPC_INS_EFSCFSI = 306;
	public static final int PPC_INS_EFSCFUF = 307;
	public static final int PPC_INS_EFSCFUI = 308;
	public static final int PPC_INS_EFSCMPEQ = 309;
	public static final int PPC_INS_EFSCMPGT = 310;
	public static final int PPC_INS_EFSCMPLT = 311;
	public static final int PPC_INS_EFSCTSF = 312;
	public static final int PPC_INS_EFSCTSI = 313;
	public static final int PPC_INS_EFSCTSIZ = 314;
	public static final int PPC_INS_EFSCTUF = 315;
	public static final int PPC_INS_EFSCTUI = 316;
	public static final int PPC_INS_EFSCTUIZ = 317;
	public static final int PPC_INS_EFSDIV = 318;
	public static final int PPC_INS_EFSMUL = 319;
	public static final int PPC_INS_EFSNABS = 320;
	public static final int PPC_INS_EFSNEG = 321;
	public static final int PPC_INS_EFSSUB = 322;
	public static final int PPC_INS_EFSTSTEQ = 323;
	public static final int PPC_INS_EFSTSTGT = 324;
	public static final int PPC_INS_EFSTSTLT = 325;
	public static final int PPC_INS_EIEIO = 326;
	public static final int PPC_INS_EQV = 327;
	public static final int PPC_INS_EVABS = 328;
	public static final int PPC_INS_EVADDIW = 329;
	public static final int PPC_INS_EVADDSMIAAW = 330;
	public static final int PPC_INS_EVADDSSIAAW = 331;
	public static final int PPC_INS_EVADDUMIAAW = 332;
	public static final int PPC_INS_EVADDUSIAAW = 333;
	public static final int PPC_INS_EVADDW = 334;
	public static final int PPC_INS_EVAND = 335;
	public static final int PPC_INS_EVANDC = 336;
	public static final int PPC_INS_EVCMPEQ = 337;
	public static final int PPC_INS_EVCMPGTS = 338;
	public static final int PPC_INS_EVCMPGTU = 339;
	public static final int PPC_INS_EVCMPLTS = 340;
	public static final int PPC_INS_EVCMPLTU = 341;
	public static final int PPC_INS_EVCNTLSW = 342;
	public static final int PPC_INS_EVCNTLZW = 343;
	public static final int PPC_INS_EVDIVWS = 344;
	public static final int PPC_INS_EVDIVWU = 345;
	public static final int PPC_INS_EVEQV = 346;
	public static final int PPC_INS_EVEXTSB = 347;
	public static final int PPC_INS_EVEXTSH = 348;
	public static final int PPC_INS_EVFSABS = 349;
	public static final int PPC_INS_EVFSADD = 350;
	public static final int PPC_INS_EVFSCFSF = 351;
	public static final int PPC_INS_EVFSCFSI = 352;
	public static final int PPC_INS_EVFSCFUF = 353;
	public static final int PPC_INS_EVFSCFUI = 354;
	public static final int PPC_INS_EVFSCMPEQ = 355;
	public static final int PPC_INS_EVFSCMPGT = 356;
	public static final int PPC_INS_EVFSCMPLT = 357;
	public static final int PPC_INS_EVFSCTSF = 358;
	public static final int PPC_INS_EVFSCTSI = 359;
	public static final int PPC_INS_EVFSCTSIZ = 360;
	public static final int PPC_INS_EVFSCTUI = 361;
	public static final int PPC_INS_EVFSDIV = 362;
	public static final int PPC_INS_EVFSMUL = 363;
	public static final int PPC_INS_EVFSNABS = 364;
	public static final int PPC_INS_EVFSNEG = 365;
	public static final int PPC_INS_EVFSSUB = 366;
	public static final int PPC_INS_EVFSTSTEQ = 367;
	public static final int PPC_INS_EVFSTSTGT = 368;
	public static final int PPC_INS_EVFSTSTLT = 369;
	public static final int PPC_INS_EVLDD = 370;
	public static final int PPC_INS_EVLDDX = 371;
	public static final int PPC_INS_EVLDH = 372;
	public static final int PPC_INS_EVLDHX = 373;
	public static final int PPC_INS_EVLDW = 374;
	public static final int PPC_INS_EVLDWX = 375;
	public static final int PPC_INS_EVLHHESPLAT = 376;
	public static final int PPC_INS_EVLHHESPLATX = 377;
	public static final int PPC_INS_EVLHHOSSPLAT = 378;
	public static final int PPC_INS_EVLHHOSSPLATX = 379;
	public static final int PPC_INS_EVLHHOUSPLAT = 380;
	public static final int PPC_INS_EVLHHOUSPLATX = 381;
	public static final int PPC_INS_EVLWHE = 382;
	public static final int PPC_INS_EVLWHEX = 383;
	public static final int PPC_INS_EVLWHOS = 384;
	public static final int PPC_INS_EVLWHOSX = 385;
	public static final int PPC_INS_EVLWHOU = 386;
	public static final int PPC_INS_EVLWHOUX = 387;
	public static final int PPC_INS_EVLWHSPLAT = 388;
	public static final int PPC_INS_EVLWHSPLATX = 389;
	public static final int PPC_INS_EVLWWSPLAT = 390;
	public static final int PPC_INS_EVLWWSPLATX = 391;
	public static final int PPC_INS_EVMERGEHI = 392;
	public static final int PPC_INS_EVMERGEHILO = 393;
	public static final int PPC_INS_EVMERGELO = 394;
	public static final int PPC_INS_EVMERGELOHI = 395;
	public static final int PPC_INS_EVMHEGSMFAA = 396;
	public static final int PPC_INS_EVMHEGSMFAN = 397;
	public static final int PPC_INS_EVMHEGSMIAA = 398;
	public static final int PPC_INS_EVMHEGSMIAN = 399;
	public static final int PPC_INS_EVMHEGUMIAA = 400;
	public static final int PPC_INS_EVMHEGUMIAN = 401;
	public static final int PPC_INS_EVMHESMF = 402;
	public static final int PPC_INS_EVMHESMFA = 403;
	public static final int PPC_INS_EVMHESMFAAW = 404;
	public static final int PPC_INS_EVMHESMFANW = 405;
	public static final int PPC_INS_EVMHESMI = 406;
	public static final int PPC_INS_EVMHESMIA = 407;
	public static final int PPC_INS_EVMHESMIAAW = 408;
	public static final int PPC_INS_EVMHESMIANW = 409;
	public static final int PPC_INS_EVMHESSF = 410;
	public static final int PPC_INS_EVMHESSFA = 411;
	public static final int PPC_INS_EVMHESSFAAW = 412;
	public static final int PPC_INS_EVMHESSFANW = 413;
	public static final int PPC_INS_EVMHESSIAAW = 414;
	public static final int PPC_INS_EVMHESSIANW = 415;
	public static final int PPC_INS_EVMHEUMI = 416;
	public static final int PPC_INS_EVMHEUMIA = 417;
	public static final int PPC_INS_EVMHEUMIAAW = 418;
	public static final int PPC_INS_EVMHEUMIANW = 419;
	public static final int PPC_INS_EVMHEUSIAAW = 420;
	public static final int PPC_INS_EVMHEUSIANW = 421;
	public static final int PPC_INS_EVMHOGSMFAA = 422;
	public static final int PPC_INS_EVMHOGSMFAN = 423;
	public static final int PPC_INS_EVMHOGSMIAA = 424;
	public static final int PPC_INS_EVMHOGSMIAN = 425;
	public static final int PPC_INS_EVMHOGUMIAA = 426;
	public static final int PPC_INS_EVMHOGUMIAN = 427;
	public static final int PPC_INS_EVMHOSMF = 428;
	public static final int PPC_INS_EVMHOSMFA = 429;
	public static final int PPC_INS_EVMHOSMFAAW = 430;
	public static final int PPC_INS_EVMHOSMFANW = 431;
	public static final int PPC_INS_EVMHOSMI = 432;
	public static final int PPC_INS_EVMHOSMIA = 433;
	public static final int PPC_INS_EVMHOSMIAAW = 434;
	public static final int PPC_INS_EVMHOSMIANW = 435;
	public static final int PPC_INS_EVMHOSSF = 436;
	public static final int PPC_INS_EVMHOSSFA = 437;
	public static final int PPC_INS_EVMHOSSFAAW = 438;
	public static final int PPC_INS_EVMHOSSFANW = 439;
	public static final int PPC_INS_EVMHOSSIAAW = 440;
	public static final int PPC_INS_EVMHOSSIANW = 441;
	public static final int PPC_INS_EVMHOUMI = 442;
	public static final int PPC_INS_EVMHOUMIA = 443;
	public static final int PPC_INS_EVMHOUMIAAW = 444;
	public static final int PPC_INS_EVMHOUMIANW = 445;
	public static final int PPC_INS_EVMHOUSIAAW = 446;
	public static final int PPC_INS_EVMHOUSIANW = 447;
	public static final int PPC_INS_EVMRA = 448;
	public static final int PPC_INS_EVMWHSMF = 449;
	public static final int PPC_INS_EVMWHSMFA = 450;
	public static final int PPC_INS_EVMWHSMI = 451;
	public static final int PPC_INS_EVMWHSMIA = 452;
	public static final int PPC_INS_EVMWHSSF = 453;
	public static final int PPC_INS_EVMWHSSFA = 454;
	public static final int PPC_INS_EVMWHUMI = 455;
	public static final int PPC_INS_EVMWHUMIA = 456;
	public static final int PPC_INS_EVMWLSMIAAW = 457;
	public static final int PPC_INS_EVMWLSMIANW = 458;
	public static final int PPC_INS_EVMWLSSIAAW = 459;
	public static final int PPC_INS_EVMWLSSIANW = 460;
	public static final int PPC_INS_EVMWLUMI = 461;
	public static final int PPC_INS_EVMWLUMIA = 462;
	public static final int PPC_INS_EVMWLUMIAAW = 463;
	public static final int PPC_INS_EVMWLUMIANW = 464;
	public static final int PPC_INS_EVMWLUSIAAW = 465;
	public static final int PPC_INS_EVMWLUSIANW = 466;
	public static final int PPC_INS_EVMWSMF = 467;
	public static final int PPC_INS_EVMWSMFA = 468;
	public static final int PPC_INS_EVMWSMFAA = 469;
	public static final int PPC_INS_EVMWSMFAN = 470;
	public static final int PPC_INS_EVMWSMI = 471;
	public static final int PPC_INS_EVMWSMIA = 472;
	public static final int PPC_INS_EVMWSMIAA = 473;
	public static final int PPC_INS_EVMWSMIAN = 474;
	public static final int PPC_INS_EVMWSSF = 475;
	public static final int PPC_INS_EVMWSSFA = 476;
	public static final int PPC_INS_EVMWSSFAA = 477;
	public static final int PPC_INS_EVMWSSFAN = 478;
	public static final int PPC_INS_EVMWUMI = 479;
	public static final int PPC_INS_EVMWUMIA = 480;
	public static final int PPC_INS_EVMWUMIAA = 481;
	public static final int PPC_INS_EVMWUMIAN = 482;
	public static final int PPC_INS_EVNAND = 483;
	public static final int PPC_INS_EVNEG = 484;
	public static final int PPC_INS_EVNOR = 485;
	public static final int PPC_INS_EVOR = 486;
	public static final int PPC_INS_EVORC = 487;
	public static final int PPC_INS_EVRLW = 488;
	public static final int PPC_INS_EVRLWI = 489;
	public static final int PPC_INS_EVRNDW = 490;
	public static final int PPC_INS_EVSEL = 491;
	public static final int PPC_INS_EVSLW = 492;
	public static final int PPC_INS_EVSLWI = 493;
	public static final int PPC_INS_EVSPLATFI = 494;
	public static final int PPC_INS_EVSPLATI = 495;
	public static final int PPC_INS_EVSRWIS = 496;
	public static final int PPC_INS_EVSRWIU = 497;
	public static final int PPC_INS_EVSRWS = 498;
	public static final int PPC_INS_EVSRWU = 499;
	public static final int PPC_INS_EVSTDD = 500;
	public static final int PPC_INS_EVSTDDX = 501;
	public static final int PPC_INS_EVSTDH = 502;
	public static final int PPC_INS_EVSTDHX = 503;
	public static final int PPC_INS_EVSTDW = 504;
	public static final int PPC_INS_EVSTDWX = 505;
	public static final int PPC_INS_EVSTWHE = 506;
	public static final int PPC_INS_EVSTWHEX = 507;
	public static final int PPC_INS_EVSTWHO = 508;
	public static final int PPC_INS_EVSTWHOX = 509;
	public static final int PPC_INS_EVSTWWE = 510;
	public static final int PPC_INS_EVSTWWEX = 511;
	public static final int PPC_INS_EVSTWWO = 512;
	public static final int PPC_INS_EVSTWWOX = 513;
	public static final int PPC_INS_EVSUBFSMIAAW = 514;
	public static final int PPC_INS_EVSUBFSSIAAW = 515;
	public static final int PPC_INS_EVSUBFUMIAAW = 516;
	public static final int PPC_INS_EVSUBFUSIAAW = 517;
	public static final int PPC_INS_EVSUBFW = 518;
	public static final int PPC_INS_EVSUBIFW = 519;
	public static final int PPC_INS_EVXOR = 520;
	public static final int PPC_INS_EXTLDI = 521;
	public static final int PPC_INS_EXTLWI = 522;
	public static final int PPC_INS_EXTRDI = 523;
	public static final int PPC_INS_EXTRWI = 524;
	public static final int PPC_INS_EXTSB = 525;
	public static final int PPC_INS_EXTSH = 526;
	public static final int PPC_INS_EXTSW = 527;
	public static final int PPC_INS_EXTSWSLI = 528;
	public static final int PPC_INS_FABS = 529;
	public static final int PPC_INS_FADD = 530;
	public static final int PPC_INS_FADDS = 531;
	public static final int PPC_INS_FCFID = 532;
	public static final int PPC_INS_FCFIDS = 533;
	public static final int PPC_INS_FCFIDU = 534;
	public static final int PPC_INS_FCFIDUS = 535;
	public static final int PPC_INS_FCMPU = 536;
	public static final int PPC_INS_FCPSGN = 537;
	public static final int PPC_INS_FCTID = 538;
	public static final int PPC_INS_FCTIDU = 539;
	public static final int PPC_INS_FCTIDUZ = 540;
	public static final int PPC_INS_FCTIDZ = 541;
	public static final int PPC_INS_FCTIW = 542;
	public static final int PPC_INS_FCTIWU = 543;
	public static final int PPC_INS_FCTIWUZ = 544;
	public static final int PPC_INS_FCTIWZ = 545;
	public static final int PPC_INS_FDIV = 546;
	public static final int PPC_INS_FDIVS = 547;
	public static final int PPC_INS_FMADD = 548;
	public static final int PPC_INS_FMADDS = 549;
	public static final int PPC_INS_FMR = 550;
	public static final int PPC_INS_FMSUB = 551;
	public static final int PPC_INS_FMSUBS = 552;
	public static final int PPC_INS_FMUL = 553;
	public static final int PPC_INS_FMULS = 554;
	public static final int PPC_INS_FNABS = 555;
	public static final int PPC_INS_FNEG = 556;
	public static final int PPC_INS_FNMADD = 557;
	public static final int PPC_INS_FNMADDS = 558;
	public static final int PPC_INS_FNMSUB = 559;
	public static final int PPC_INS_FNMSUBS = 560;
	public static final int PPC_INS_FRE = 561;
	public static final int PPC_INS_FRES = 562;
	public static final int PPC_INS_FRIM = 563;
	public static final int PPC_INS_FRIN = 564;
	public static final int PPC_INS_FRIP = 565;
	public static final int PPC_INS_FRIZ = 566;
	public static final int PPC_INS_FRSP = 567;
	public static final int PPC_INS_FRSQRTE = 568;
	public static final int PPC_INS_FRSQRTES = 569;
	public static final int PPC_INS_FSEL = 570;
	public static final int PPC_INS_FSQRT = 571;
	public static final int PPC_INS_FSQRTS = 572;
	public static final int PPC_INS_FSUB = 573;
	public static final int PPC_INS_FSUBS = 574;
	public static final int PPC_INS_FTDIV = 575;
	public static final int PPC_INS_FTSQRT = 576;
	public static final int PPC_INS_HRFID = 577;
	public static final int PPC_INS_ICBI = 578;
	public static final int PPC_INS_ICBIEP = 579;
	public static final int PPC_INS_ICBLC = 580;
	public static final int PPC_INS_ICBLQ = 581;
	public static final int PPC_INS_ICBT = 582;
	public static final int PPC_INS_ICBTLS = 583;
	public static final int PPC_INS_ICCCI = 584;
	public static final int PPC_INS_ICI = 585;
	public static final int PPC_INS_INSLWI = 586;
	public static final int PPC_INS_INSRDI = 587;
	public static final int PPC_INS_INSRWI = 588;
	public static final int PPC_INS_ISEL = 589;
	public static final int PPC_INS_ISYNC = 590;
	public static final int PPC_INS_LA = 591;
	public static final int PPC_INS_LBARX = 592;
	public static final int PPC_INS_LBEPX = 593;
	public static final int PPC_INS_LBZ = 594;
	public static final int PPC_INS_LBZCIX = 595;
	public static final int PPC_INS_LBZU = 596;
	public static final int PPC_INS_LBZUX = 597;
	public static final int PPC_INS_LBZX = 598;
	public static final int PPC_INS_LD = 599;
	public static final int PPC_INS_LDARX = 600;
	public static final int PPC_INS_LDAT = 601;
	public static final int PPC_INS_LDBRX = 602;
	public static final int PPC_INS_LDCIX = 603;
	public static final int PPC_INS_LDMX = 604;
	public static final int PPC_INS_LDU = 605;
	public static final int PPC_INS_LDUX = 606;
	public static final int PPC_INS_LDX = 607;
	public static final int PPC_INS_LFD = 608;
	public static final int PPC_INS_LFDEPX = 609;
	public static final int PPC_INS_LFDU = 610;
	public static final int PPC_INS_LFDUX = 611;
	public static final int PPC_INS_LFDX = 612;
	public static final int PPC_INS_LFIWAX = 613;
	public static final int PPC_INS_LFIWZX = 614;
	public static final int PPC_INS_LFS = 615;
	public static final int PPC_INS_LFSU = 616;
	public static final int PPC_INS_LFSUX = 617;
	public static final int PPC_INS_LFSX = 618;
	public static final int PPC_INS_LHA = 619;
	public static final int PPC_INS_LHARX = 620;
	public static final int PPC_INS_LHAU = 621;
	public static final int PPC_INS_LHAUX = 622;
	public static final int PPC_INS_LHAX = 623;
	public static final int PPC_INS_LHBRX = 624;
	public static final int PPC_INS_LHEPX = 625;
	public static final int PPC_INS_LHZ = 626;
	public static final int PPC_INS_LHZCIX = 627;
	public static final int PPC_INS_LHZU = 628;
	public static final int PPC_INS_LHZUX = 629;
	public static final int PPC_INS_LHZX = 630;
	public static final int PPC_INS_LI = 631;
	public static final int PPC_INS_LIS = 632;
	public static final int PPC_INS_LMW = 633;
	public static final int PPC_INS_LNIA = 634;
	public static final int PPC_INS_LSWI = 635;
	public static final int PPC_INS_LVEBX = 636;
	public static final int PPC_INS_LVEHX = 637;
	public static final int PPC_INS_LVEWX = 638;
	public static final int PPC_INS_LVSL = 639;
	public static final int PPC_INS_LVSR = 640;
	public static final int PPC_INS_LVX = 641;
	public static final int PPC_INS_LVXL = 642;
	public static final int PPC_INS_LWA = 643;
	public static final int PPC_INS_LWARX = 644;
	public static final int PPC_INS_LWAT = 645;
	public static final int PPC_INS_LWAUX = 646;
	public static final int PPC_INS_LWAX = 647;
	public static final int PPC_INS_LWBRX = 648;
	public static final int PPC_INS_LWEPX = 649;
	public static final int PPC_INS_LWSYNC = 650;
	public static final int PPC_INS_LWZ = 651;
	public static final int PPC_INS_LWZCIX = 652;
	public static final int PPC_INS_LWZU = 653;
	public static final int PPC_INS_LWZUX = 654;
	public static final int PPC_INS_LWZX = 655;
	public static final int PPC_INS_LXSD = 656;
	public static final int PPC_INS_LXSDX = 657;
	public static final int PPC_INS_LXSIBZX = 658;
	public static final int PPC_INS_LXSIHZX = 659;
	public static final int PPC_INS_LXSIWAX = 660;
	public static final int PPC_INS_LXSIWZX = 661;
	public static final int PPC_INS_LXSSP = 662;
	public static final int PPC_INS_LXSSPX = 663;
	public static final int PPC_INS_LXV = 664;
	public static final int PPC_INS_LXVB16X = 665;
	public static final int PPC_INS_LXVD2X = 666;
	public static final int PPC_INS_LXVDSX = 667;
	public static final int PPC_INS_LXVH8X = 668;
	public static final int PPC_INS_LXVL = 669;
	public static final int PPC_INS_LXVLL = 670;
	public static final int PPC_INS_LXVW4X = 671;
	public static final int PPC_INS_LXVWSX = 672;
	public static final int PPC_INS_LXVX = 673;
	public static final int PPC_INS_MADDHD = 674;
	public static final int PPC_INS_MADDHDU = 675;
	public static final int PPC_INS_MADDLD = 676;
	public static final int PPC_INS_MBAR = 677;
	public static final int PPC_INS_MCRF = 678;
	public static final int PPC_INS_MCRFS = 679;
	public static final int PPC_INS_MCRXRX = 680;
	public static final int PPC_INS_MFAMR = 681;
	public static final int PPC_INS_MFASR = 682;
	public static final int PPC_INS_MFBHRBE = 683;
	public static final int PPC_INS_MFBR0 = 684;
	public static final int PPC_INS_MFBR1 = 685;
	public static final int PPC_INS_MFBR2 = 686;
	public static final int PPC_INS_MFBR3 = 687;
	public static final int PPC_INS_MFBR4 = 688;
	public static final int PPC_INS_MFBR5 = 689;
	public static final int PPC_INS_MFBR6 = 690;
	public static final int PPC_INS_MFBR7 = 691;
	public static final int PPC_INS_MFCFAR = 692;
	public static final int PPC_INS_MFCR = 693;
	public static final int PPC_INS_MFCTR = 694;
	public static final int PPC_INS_MFDAR = 695;
	public static final int PPC_INS_MFDBATL = 696;
	public static final int PPC_INS_MFDBATU = 697;
	public static final int PPC_INS_MFDCCR = 698;
	public static final int PPC_INS_MFDCR = 699;
	public static final int PPC_INS_MFDEAR = 700;
	public static final int PPC_INS_MFDEC = 701;
	public static final int PPC_INS_MFDSCR = 702;
	public static final int PPC_INS_MFDSISR = 703;
	public static final int PPC_INS_MFESR = 704;
	public static final int PPC_INS_MFFPRD = 705;
	public static final int PPC_INS_MFFS = 706;
	public static final int PPC_INS_MFFSCDRN = 707;
	public static final int PPC_INS_MFFSCDRNI = 708;
	public static final int PPC_INS_MFFSCE = 709;
	public static final int PPC_INS_MFFSCRN = 710;
	public static final int PPC_INS_MFFSCRNI = 711;
	public static final int PPC_INS_MFFSL = 712;
	public static final int PPC_INS_MFIBATL = 713;
	public static final int PPC_INS_MFIBATU = 714;
	public static final int PPC_INS_MFICCR = 715;
	public static final int PPC_INS_MFLR = 716;
	public static final int PPC_INS_MFMSR = 717;
	public static final int PPC_INS_MFOCRF = 718;
	public static final int PPC_INS_MFPID = 719;
	public static final int PPC_INS_MFPMR = 720;
	public static final int PPC_INS_MFPVR = 721;
	public static final int PPC_INS_MFRTCL = 722;
	public static final int PPC_INS_MFRTCU = 723;
	public static final int PPC_INS_MFSDR1 = 724;
	public static final int PPC_INS_MFSPEFSCR = 725;
	public static final int PPC_INS_MFSPR = 726;
	public static final int PPC_INS_MFSPRG = 727;
	public static final int PPC_INS_MFSPRG0 = 728;
	public static final int PPC_INS_MFSPRG1 = 729;
	public static final int PPC_INS_MFSPRG2 = 730;
	public static final int PPC_INS_MFSPRG3 = 731;
	public static final int PPC_INS_MFSPRG4 = 732;
	public static final int PPC_INS_MFSPRG5 = 733;
	public static final int PPC_INS_MFSPRG6 = 734;
	public static final int PPC_INS_MFSPRG7 = 735;
	public static final int PPC_INS_MFSR = 736;
	public static final int PPC_INS_MFSRIN = 737;
	public static final int PPC_INS_MFSRR0 = 738;
	public static final int PPC_INS_MFSRR1 = 739;
	public static final int PPC_INS_MFSRR2 = 740;
	public static final int PPC_INS_MFSRR3 = 741;
	public static final int PPC_INS_MFTB = 742;
	public static final int PPC_INS_MFTBHI = 743;
	public static final int PPC_INS_MFTBL = 744;
	public static final int PPC_INS_MFTBLO = 745;
	public static final int PPC_INS_MFTBU = 746;
	public static final int PPC_INS_MFTCR = 747;
	public static final int PPC_INS_MFVRD = 748;
	public static final int PPC_INS_MFVRSAVE = 749;
	public static final int PPC_INS_MFVSCR = 750;
	public static final int PPC_INS_MFVSRD = 751;
	public static final int PPC_INS_MFVSRLD = 752;
	public static final int PPC_INS_MFVSRWZ = 753;
	public static final int PPC_INS_MFXER = 754;
	public static final int PPC_INS_MODSD = 755;
	public static final int PPC_INS_MODSW = 756;
	public static final int PPC_INS_MODUD = 757;
	public static final int PPC_INS_MODUW = 758;
	public static final int PPC_INS_MR = 759;
	public static final int PPC_INS_MSGSYNC = 760;
	public static final int PPC_INS_MSYNC = 761;
	public static final int PPC_INS_MTAMR = 762;
	public static final int PPC_INS_MTASR = 763;
	public static final int PPC_INS_MTBR0 = 764;
	public static final int PPC_INS_MTBR1 = 765;
	public static final int PPC_INS_MTBR2 = 766;
	public static final int PPC_INS_MTBR3 = 767;
	public static final int PPC_INS_MTBR4 = 768;
	public static final int PPC_INS_MTBR5 = 769;
	public static final int PPC_INS_MTBR6 = 770;
	public static final int PPC_INS_MTBR7 = 771;
	public static final int PPC_INS_MTCFAR = 772;
	public static final int PPC_INS_MTCR = 773;
	public static final int PPC_INS_MTCRF = 774;
	public static final int PPC_INS_MTCTR = 775;
	public static final int PPC_INS_MTDAR = 776;
	public static final int PPC_INS_MTDBATL = 777;
	public static final int PPC_INS_MTDBATU = 778;
	public static final int PPC_INS_MTDCCR = 779;
	public static final int PPC_INS_MTDCR = 780;
	public static final int PPC_INS_MTDEAR = 781;
	public static final int PPC_INS_MTDEC = 782;
	public static final int PPC_INS_MTDSCR = 783;
	public static final int PPC_INS_MTDSISR = 784;
	public static final int PPC_INS_MTESR = 785;
	public static final int PPC_INS_MTFSB0 = 786;
	public static final int PPC_INS_MTFSB1 = 787;
	public static final int PPC_INS_MTFSF = 788;
	public static final int PPC_INS_MTFSFI = 789;
	public static final int PPC_INS_MTIBATL = 790;
	public static final int PPC_INS_MTIBATU = 791;
	public static final int PPC_INS_MTICCR = 792;
	public static final int PPC_INS_MTLR = 793;
	public static final int PPC_INS_MTMSR = 794;
	public static final int PPC_INS_MTMSRD = 795;
	public static final int PPC_INS_MTOCRF = 796;
	public static final int PPC_INS_MTPID = 797;
	public static final int PPC_INS_MTPMR = 798;
	public static final int PPC_INS_MTSDR1 = 799;
	public static final int PPC_INS_MTSPEFSCR = 800;
	public static final int PPC_INS_MTSPR = 801;
	public static final int PPC_INS_MTSPRG = 802;
	public static final int PPC_INS_MTSPRG0 = 803;
	public static final int PPC_INS_MTSPRG1 = 804;
	public static final int PPC_INS_MTSPRG2 = 805;
	public static final int PPC_INS_MTSPRG3 = 806;
	public static final int PPC_INS_MTSPRG4 = 807;
	public static final int PPC_INS_MTSPRG5 = 808;
	public static final int PPC_INS_MTSPRG6 = 809;
	public static final int PPC_INS_MTSPRG7 = 810;
	public static final int PPC_INS_MTSR = 811;
	public static final int PPC_INS_MTSRIN = 812;
	public static final int PPC_INS_MTSRR0 = 813;
	public static final int PPC_INS_MTSRR1 = 814;
	public static final int PPC_INS_MTSRR2 = 815;
	public static final int PPC_INS_MTSRR3 = 816;
	public static final int PPC_INS_MTTBHI = 817;
	public static final int PPC_INS_MTTBL = 818;
	public static final int PPC_INS_MTTBLO = 819;
	public static final int PPC_INS_MTTBU = 820;
	public static final int PPC_INS_MTTCR = 821;
	public static final int PPC_INS_MTVRSAVE = 822;
	public static final int PPC_INS_MTVSCR = 823;
	public static final int PPC_INS_MTVSRD = 824;
	public static final int PPC_INS_MTVSRDD = 825;
	public static final int PPC_INS_MTVSRWA = 826;
	public static final int PPC_INS_MTVSRWS = 827;
	public static final int PPC_INS_MTVSRWZ = 828;
	public static final int PPC_INS_MTXER = 829;
	public static final int PPC_INS_MULHD = 830;
	public static final int PPC_INS_MULHDU = 831;
	public static final int PPC_INS_MULHW = 832;
	public static final int PPC_INS_MULHWU = 833;
	public static final int PPC_INS_MULLD = 834;
	public static final int PPC_INS_MULLI = 835;
	public static final int PPC_INS_MULLW = 836;
	public static final int PPC_INS_NAND = 837;
	public static final int PPC_INS_NAP = 838;
	public static final int PPC_INS_NEG = 839;
	public static final int PPC_INS_NOP = 840;
	public static final int PPC_INS_NOR = 841;
	public static final int PPC_INS_NOT = 842;
	public static final int PPC_INS_OR = 843;
	public static final int PPC_INS_ORC = 844;
	public static final int PPC_INS_ORI = 845;
	public static final int PPC_INS_ORIS = 846;
	public static final int PPC_INS_PASTE = 847;
	public static final int PPC_INS_PASTE_LAST = 848;
	public static final int PPC_INS_POPCNTB = 849;
	public static final int PPC_INS_POPCNTD = 850;
	public static final int PPC_INS_POPCNTW = 851;
	public static final int PPC_INS_PTESYNC = 852;
	public static final int PPC_INS_QVALIGNI = 853;
	public static final int PPC_INS_QVESPLATI = 854;
	public static final int PPC_INS_QVFABS = 855;
	public static final int PPC_INS_QVFADD = 856;
	public static final int PPC_INS_QVFADDS = 857;
	public static final int PPC_INS_QVFAND = 858;
	public static final int PPC_INS_QVFANDC = 859;
	public static final int PPC_INS_QVFCFID = 860;
	public static final int PPC_INS_QVFCFIDS = 861;
	public static final int PPC_INS_QVFCFIDU = 862;
	public static final int PPC_INS_QVFCFIDUS = 863;
	public static final int PPC_INS_QVFCLR = 864;
	public static final int PPC_INS_QVFCMPEQ = 865;
	public static final int PPC_INS_QVFCMPGT = 866;
	public static final int PPC_INS_QVFCMPLT = 867;
	public static final int PPC_INS_QVFCPSGN = 868;
	public static final int PPC_INS_QVFCTFB = 869;
	public static final int PPC_INS_QVFCTID = 870;
	public static final int PPC_INS_QVFCTIDU = 871;
	public static final int PPC_INS_QVFCTIDUZ = 872;
	public static final int PPC_INS_QVFCTIDZ = 873;
	public static final int PPC_INS_QVFCTIW = 874;
	public static final int PPC_INS_QVFCTIWU = 875;
	public static final int PPC_INS_QVFCTIWUZ = 876;
	public static final int PPC_INS_QVFCTIWZ = 877;
	public static final int PPC_INS_QVFEQU = 878;
	public static final int PPC_INS_QVFLOGICAL = 879;
	public static final int PPC_INS_QVFMADD = 880;
	public static final int PPC_INS_QVFMADDS = 881;
	public static final int PPC_INS_QVFMR = 882;
	public static final int PPC_INS_QVFMSUB = 883;
	public static final int PPC_INS_QVFMSUBS = 884;
	public static final int PPC_INS_QVFMUL = 885;
	public static final int PPC_INS_QVFMULS = 886;
	public static final int PPC_INS_QVFNABS = 887;
	public static final int PPC_INS_QVFNAND = 888;
	public static final int PPC_INS_QVFNEG = 889;
	public static final int PPC_INS_QVFNMADD = 890;
	public static final int PPC_INS_QVFNMADDS = 891;
	public static final int PPC_INS_QVFNMSUB = 892;
	public static final int PPC_INS_QVFNMSUBS = 893;
	public static final int PPC_INS_QVFNOR = 894;
	public static final int PPC_INS_QVFNOT = 895;
	public static final int PPC_INS_QVFOR = 896;
	public static final int PPC_INS_QVFORC = 897;
	public static final int PPC_INS_QVFPERM = 898;
	public static final int PPC_INS_QVFRE = 899;
	public static final int PPC_INS_QVFRES = 900;
	public static final int PPC_INS_QVFRIM = 901;
	public static final int PPC_INS_QVFRIN = 902;
	public static final int PPC_INS_QVFRIP = 903;
	public static final int PPC_INS_QVFRIZ = 904;
	public static final int PPC_INS_QVFRSP = 905;
	public static final int PPC_INS_QVFRSQRTE = 906;
	public static final int PPC_INS_QVFRSQRTES = 907;
	public static final int PPC_INS_QVFSEL = 908;
	public static final int PPC_INS_QVFSET = 909;
	public static final int PPC_INS_QVFSUB = 910;
	public static final int PPC_INS_QVFSUBS = 911;
	public static final int PPC_INS_QVFTSTNAN = 912;
	public static final int PPC_INS_QVFXMADD = 913;
	public static final int PPC_INS_QVFXMADDS = 914;
	public static final int PPC_INS_QVFXMUL = 915;
	public static final int PPC_INS_QVFXMULS = 916;
	public static final int PPC_INS_QVFXOR = 917;
	public static final int PPC_INS_QVFXXCPNMADD = 918;
	public static final int PPC_INS_QVFXXCPNMADDS = 919;
	public static final int PPC_INS_QVFXXMADD = 920;
	public static final int PPC_INS_QVFXXMADDS = 921;
	public static final int PPC_INS_QVFXXNPMADD = 922;
	public static final int PPC_INS_QVFXXNPMADDS = 923;
	public static final int PPC_INS_QVGPCI = 924;
	public static final int PPC_INS_QVLFCDUX = 925;
	public static final int PPC_INS_QVLFCDUXA = 926;
	public static final int PPC_INS_QVLFCDX = 927;
	public static final int PPC_INS_QVLFCDXA = 928;
	public static final int PPC_INS_QVLFCSUX = 929;
	public static final int PPC_INS_QVLFCSUXA = 930;
	public static final int PPC_INS_QVLFCSX = 931;
	public static final int PPC_INS_QVLFCSXA = 932;
	public static final int PPC_INS_QVLFDUX = 933;
	public static final int PPC_INS_QVLFDUXA = 934;
	public static final int PPC_INS_QVLFDX = 935;
	public static final int PPC_INS_QVLFDXA = 936;
	public static final int PPC_INS_QVLFIWAX = 937;
	public static final int PPC_INS_QVLFIWAXA = 938;
	public static final int PPC_INS_QVLFIWZX = 939;
	public static final int PPC_INS_QVLFIWZXA = 940;
	public static final int PPC_INS_QVLFSUX = 941;
	public static final int PPC_INS_QVLFSUXA = 942;
	public static final int PPC_INS_QVLFSX = 943;
	public static final int PPC_INS_QVLFSXA = 944;
	public static final int PPC_INS_QVLPCLDX = 945;
	public static final int PPC_INS_QVLPCLSX = 946;
	public static final int PPC_INS_QVLPCRDX = 947;
	public static final int PPC_INS_QVLPCRSX = 948;
	public static final int PPC_INS_QVSTFCDUX = 949;
	public static final int PPC_INS_QVSTFCDUXA = 950;
	public static final int PPC_INS_QVSTFCDUXI = 951;
	public static final int PPC_INS_QVSTFCDUXIA = 952;
	public static final int PPC_INS_QVSTFCDX = 953;
	public static final int PPC_INS_QVSTFCDXA = 954;
	public static final int PPC_INS_QVSTFCDXI = 955;
	public static final int PPC_INS_QVSTFCDXIA = 956;
	public static final int PPC_INS_QVSTFCSUX = 957;
	public static final int PPC_INS_QVSTFCSUXA = 958;
	public static final int PPC_INS_QVSTFCSUXI = 959;
	public static final int PPC_INS_QVSTFCSUXIA = 960;
	public static final int PPC_INS_QVSTFCSX = 961;
	public static final int PPC_INS_QVSTFCSXA = 962;
	public static final int PPC_INS_QVSTFCSXI = 963;
	public static final int PPC_INS_QVSTFCSXIA = 964;
	public static final int PPC_INS_QVSTFDUX = 965;
	public static final int PPC_INS_QVSTFDUXA = 966;
	public static final int PPC_INS_QVSTFDUXI = 967;
	public static final int PPC_INS_QVSTFDUXIA = 968;
	public static final int PPC_INS_QVSTFDX = 969;
	public static final int PPC_INS_QVSTFDXA = 970;
	public static final int PPC_INS_QVSTFDXI = 971;
	public static final int PPC_INS_QVSTFDXIA = 972;
	public static final int PPC_INS_QVSTFIWX = 973;
	public static final int PPC_INS_QVSTFIWXA = 974;
	public static final int PPC_INS_QVSTFSUX = 975;
	public static final int PPC_INS_QVSTFSUXA = 976;
	public static final int PPC_INS_QVSTFSUXI = 977;
	public static final int PPC_INS_QVSTFSUXIA = 978;
	public static final int PPC_INS_QVSTFSX = 979;
	public static final int PPC_INS_QVSTFSXA = 980;
	public static final int PPC_INS_QVSTFSXI = 981;
	public static final int PPC_INS_QVSTFSXIA = 982;
	public static final int PPC_INS_RFCI = 983;
	public static final int PPC_INS_RFDI = 984;
	public static final int PPC_INS_RFEBB = 985;
	public static final int PPC_INS_RFI = 986;
	public static final int PPC_INS_RFID = 987;
	public static final int PPC_INS_RFMCI = 988;
	public static final int PPC_INS_RLDCL = 989;
	public static final int PPC_INS_RLDCR = 990;
	public static final int PPC_INS_RLDIC = 991;
	public static final int PPC_INS_RLDICL = 992;
	public static final int PPC_INS_RLDICR = 993;
	public static final int PPC_INS_RLDIMI = 994;
	public static final int PPC_INS_RLWIMI = 995;
	public static final int PPC_INS_RLWINM = 996;
	public static final int PPC_INS_RLWNM = 997;
	public static final int PPC_INS_ROTLD = 998;
	public static final int PPC_INS_ROTLDI = 999;
	public static final int PPC_INS_ROTLW = 1000;
	public static final int PPC_INS_ROTLWI = 1001;
	public static final int PPC_INS_ROTRDI = 1002;
	public static final int PPC_INS_ROTRWI = 1003;
	public static final int PPC_INS_SC = 1004;
	public static final int PPC_INS_SETB = 1005;
	public static final int PPC_INS_SLBIA = 1006;
	public static final int PPC_INS_SLBIE = 1007;
	public static final int PPC_INS_SLBIEG = 1008;
	public static final int PPC_INS_SLBMFEE = 1009;
	public static final int PPC_INS_SLBMFEV = 1010;
	public static final int PPC_INS_SLBMTE = 1011;
	public static final int PPC_INS_SLBSYNC = 1012;
	public static final int PPC_INS_SLD = 1013;
	public static final int PPC_INS_SLDI = 1014;
	public static final int PPC_INS_SLW = 1015;
	public static final int PPC_INS_SLWI = 1016;
	public static final int PPC_INS_SRAD = 1017;
	public static final int PPC_INS_SRADI = 1018;
	public static final int PPC_INS_SRAW = 1019;
	public static final int PPC_INS_SRAWI = 1020;
	public static final int PPC_INS_SRD = 1021;
	public static final int PPC_INS_SRDI = 1022;
	public static final int PPC_INS_SRW = 1023;
	public static final int PPC_INS_SRWI = 1024;
	public static final int PPC_INS_STB = 1025;
	public static final int PPC_INS_STBCIX = 1026;
	public static final int PPC_INS_STBCX = 1027;
	public static final int PPC_INS_STBEPX = 1028;
	public static final int PPC_INS_STBU = 1029;
	public static final int PPC_INS_STBUX = 1030;
	public static final int PPC_INS_STBX = 1031;
	public static final int PPC_INS_STD = 1032;
	public static final int PPC_INS_STDAT = 1033;
	public static final int PPC_INS_STDBRX = 1034;
	public static final int PPC_INS_STDCIX = 1035;
	public static final int PPC_INS_STDCX = 1036;
	public static final int PPC_INS_STDU = 1037;
	public static final int PPC_INS_STDUX = 1038;
	public static final int PPC_INS_STDX = 1039;
	public static final int PPC_INS_STFD = 1040;
	public static final int PPC_INS_STFDEPX = 1041;
	public static final int PPC_INS_STFDU = 1042;
	public static final int PPC_INS_STFDUX = 1043;
	public static final int PPC_INS_STFDX = 1044;
	public static final int PPC_INS_STFIWX = 1045;
	public static final int PPC_INS_STFS = 1046;
	public static final int PPC_INS_STFSU = 1047;
	public static final int PPC_INS_STFSUX = 1048;
	public static final int PPC_INS_STFSX = 1049;
	public static final int PPC_INS_STH = 1050;
	public static final int PPC_INS_STHBRX = 1051;
	public static final int PPC_INS_STHCIX = 1052;
	public static final int PPC_INS_STHCX = 1053;
	public static final int PPC_INS_STHEPX = 1054;
	public static final int PPC_INS_STHU = 1055;
	public static final int PPC_INS_STHUX = 1056;
	public static final int PPC_INS_STHX = 1057;
	public static final int PPC_INS_STMW = 1058;
	public static final int PPC_INS_STOP = 1059;
	public static final int PPC_INS_STSWI = 1060;
	public static final int PPC_INS_STVEBX = 1061;
	public static final int PPC_INS_STVEHX = 1062;
	public static final int PPC_INS_STVEWX = 1063;
	public static final int PPC_INS_STVX = 1064;
	public static final int PPC_INS_STVXL = 1065;
	public static final int PPC_INS_STW = 1066;
	public static final int PPC_INS_STWAT = 1067;
	public static final int PPC_INS_STWBRX = 1068;
	public static final int PPC_INS_STWCIX = 1069;
	public static final int PPC_INS_STWCX = 1070;
	public static final int PPC_INS_STWEPX = 1071;
	public static final int PPC_INS_STWU = 1072;
	public static final int PPC_INS_STWUX = 1073;
	public static final int PPC_INS_STWX = 1074;
	public static final int PPC_INS_STXSD = 1075;
	public static final int PPC_INS_STXSDX = 1076;
	public static final int PPC_INS_STXSIBX = 1077;
	public static final int PPC_INS_STXSIHX = 1078;
	public static final int PPC_INS_STXSIWX = 1079;
	public static final int PPC_INS_STXSSP = 1080;
	public static final int PPC_INS_STXSSPX = 1081;
	public static final int PPC_INS_STXV = 1082;
	public static final int PPC_INS_STXVB16X = 1083;
	public static final int PPC_INS_STXVD2X = 1084;
	public static final int PPC_INS_STXVH8X = 1085;
	public static final int PPC_INS_STXVL = 1086;
	public static final int PPC_INS_STXVLL = 1087;
	public static final int PPC_INS_STXVW4X = 1088;
	public static final int PPC_INS_STXVX = 1089;
	public static final int PPC_INS_SUB = 1090;
	public static final int PPC_INS_SUBC = 1091;
	public static final int PPC_INS_SUBF = 1092;
	public static final int PPC_INS_SUBFC = 1093;
	public static final int PPC_INS_SUBFE = 1094;
	public static final int PPC_INS_SUBFIC = 1095;
	public static final int PPC_INS_SUBFME = 1096;
	public static final int PPC_INS_SUBFZE = 1097;
	public static final int PPC_INS_SUBI = 1098;
	public static final int PPC_INS_SUBIC = 1099;
	public static final int PPC_INS_SUBIS = 1100;
	public static final int PPC_INS_SUBPCIS = 1101;
	public static final int PPC_INS_SYNC = 1102;
	public static final int PPC_INS_TABORT = 1103;
	public static final int PPC_INS_TABORTDC = 1104;
	public static final int PPC_INS_TABORTDCI = 1105;
	public static final int PPC_INS_TABORTWC = 1106;
	public static final int PPC_INS_TABORTWCI = 1107;
	public static final int PPC_INS_TBEGIN = 1108;
	public static final int PPC_INS_TCHECK = 1109;
	public static final int PPC_INS_TD = 1110;
	public static final int PPC_INS_TDEQ = 1111;
	public static final int PPC_INS_TDEQI = 1112;
	public static final int PPC_INS_TDGE = 1113;
	public static final int PPC_INS_TDGEI = 1114;
	public static final int PPC_INS_TDGT = 1115;
	public static final int PPC_INS_TDGTI = 1116;
	public static final int PPC_INS_TDI = 1117;
	public static final int PPC_INS_TDLE = 1118;
	public static final int PPC_INS_TDLEI = 1119;
	public static final int PPC_INS_TDLGE = 1120;
	public static final int PPC_INS_TDLGEI = 1121;
	public static final int PPC_INS_TDLGT = 1122;
	public static final int PPC_INS_TDLGTI = 1123;
	public static final int PPC_INS_TDLLE = 1124;
	public static final int PPC_INS_TDLLEI = 1125;
	public static final int PPC_INS_TDLLT = 1126;
	public static final int PPC_INS_TDLLTI = 1127;
	public static final int PPC_INS_TDLNG = 1128;
	public static final int PPC_INS_TDLNGI = 1129;
	public static final int PPC_INS_TDLNL = 1130;
	public static final int PPC_INS_TDLNLI = 1131;
	public static final int PPC_INS_TDLT = 1132;
	public static final int PPC_INS_TDLTI = 1133;
	public static final int PPC_INS_TDNE = 1134;
	public static final int PPC_INS_TDNEI = 1135;
	public static final int PPC_INS_TDNG = 1136;
	public static final int PPC_INS_TDNGI = 1137;
	public static final int PPC_INS_TDNL = 1138;
	public static final int PPC_INS_TDNLI = 1139;
	public static final int PPC_INS_TDU = 1140;
	public static final int PPC_INS_TDUI = 1141;
	public static final int PPC_INS_TEND = 1142;
	public static final int PPC_INS_TLBIA = 1143;
	public static final int PPC_INS_TLBIE = 1144;
	public static final int PPC_INS_TLBIEL = 1145;
	public static final int PPC_INS_TLBIVAX = 1146;
	public static final int PPC_INS_TLBLD = 1147;
	public static final int PPC_INS_TLBLI = 1148;
	public static final int PPC_INS_TLBRE = 1149;
	public static final int PPC_INS_TLBREHI = 1150;
	public static final int PPC_INS_TLBRELO = 1151;
	public static final int PPC_INS_TLBSX = 1152;
	public static final int PPC_INS_TLBSYNC = 1153;
	public static final int PPC_INS_TLBWE = 1154;
	public static final int PPC_INS_TLBWEHI = 1155;
	public static final int PPC_INS_TLBWELO = 1156;
	public static final int PPC_INS_TRAP = 1157;
	public static final int PPC_INS_TRECHKPT = 1158;
	public static final int PPC_INS_TRECLAIM = 1159;
	public static final int PPC_INS_TSR = 1160;
	public static final int PPC_INS_TW = 1161;
	public static final int PPC_INS_TWEQ = 1162;
	public static final int PPC_INS_TWEQI = 1163;
	public static final int PPC_INS_TWGE = 1164;
	public static final int PPC_INS_TWGEI = 1165;
	public static final int PPC_INS_TWGT = 1166;
	public static final int PPC_INS_TWGTI = 1167;
	public static final int PPC_INS_TWI = 1168;
	public static final int PPC_INS_TWLE = 1169;
	public static final int PPC_INS_TWLEI = 1170;
	public static final int PPC_INS_TWLGE = 1171;
	public static final int PPC_INS_TWLGEI = 1172;
	public static final int PPC_INS_TWLGT = 1173;
	public static final int PPC_INS_TWLGTI = 1174;
	public static final int PPC_INS_TWLLE = 1175;
	public static final int PPC_INS_TWLLEI = 1176;
	public static final int PPC_INS_TWLLT = 1177;
	public static final int PPC_INS_TWLLTI = 1178;
	public static final int PPC_INS_TWLNG = 1179;
	public static final int PPC_INS_TWLNGI = 1180;
	public static final int PPC_INS_TWLNL = 1181;
	public static final int PPC_INS_TWLNLI = 1182;
	public static final int PPC_INS_TWLT = 1183;
	public static final int PPC_INS_TWLTI = 1184;
	public static final int PPC_INS_TWNE = 1185;
	public static final int PPC_INS_TWNEI = 1186;
	public static final int PPC_INS_TWNG = 1187;
	public static final int PPC_INS_TWNGI = 1188;
	public static final int PPC_INS_TWNL = 1189;
	public static final int PPC_INS_TWNLI = 1190;
	public static final int PPC_INS_TWU = 1191;
	public static final int PPC_INS_TWUI = 1192;
	public static final int PPC_INS_VABSDUB = 1193;
	public static final int PPC_INS_VABSDUH = 1194;
	public static final int PPC_INS_VABSDUW = 1195;
	public static final int PPC_INS_VADDCUQ = 1196;
	public static final int PPC_INS_VADDCUW = 1197;
	public static final int PPC_INS_VADDECUQ = 1198;
	public static final int PPC_INS_VADDEUQM = 1199;
	public static final int PPC_INS_VADDFP = 1200;
	public static final int PPC_INS_VADDSBS = 1201;
	public static final int PPC_INS_VADDSHS = 1202;
	public static final int PPC_INS_VADDSWS = 1203;
	public static final int PPC_INS_VADDUBM = 1204;
	public static final int PPC_INS_VADDUBS = 1205;
	public static final int PPC_INS_VADDUDM = 1206;
	public static final int PPC_INS_VADDUHM = 1207;
	public static final int PPC_INS_VADDUHS = 1208;
	public static final int PPC_INS_VADDUQM = 1209;
	public static final int PPC_INS_VADDUWM = 1210;
	public static final int PPC_INS_VADDUWS = 1211;
	public static final int PPC_INS_VAND = 1212;
	public static final int PPC_INS_VANDC = 1213;
	public static final int PPC_INS_VAVGSB = 1214;
	public static final int PPC_INS_VAVGSH = 1215;
	public static final int PPC_INS_VAVGSW = 1216;
	public static final int PPC_INS_VAVGUB = 1217;
	public static final int PPC_INS_VAVGUH = 1218;
	public static final int PPC_INS_VAVGUW = 1219;
	public static final int PPC_INS_VBPERMD = 1220;
	public static final int PPC_INS_VBPERMQ = 1221;
	public static final int PPC_INS_VCFSX = 1222;
	public static final int PPC_INS_VCFUX = 1223;
	public static final int PPC_INS_VCIPHER = 1224;
	public static final int PPC_INS_VCIPHERLAST = 1225;
	public static final int PPC_INS_VCLZB = 1226;
	public static final int PPC_INS_VCLZD = 1227;
	public static final int PPC_INS_VCLZH = 1228;
	public static final int PPC_INS_VCLZLSBB = 1229;
	public static final int PPC_INS_VCLZW = 1230;
	public static final int PPC_INS_VCMPBFP = 1231;
	public static final int PPC_INS_VCMPEQFP = 1232;
	public static final int PPC_INS_VCMPEQUB = 1233;
	public static final int PPC_INS_VCMPEQUD = 1234;
	public static final int PPC_INS_VCMPEQUH = 1235;
	public static final int PPC_INS_VCMPEQUW = 1236;
	public static final int PPC_INS_VCMPGEFP = 1237;
	public static final int PPC_INS_VCMPGTFP = 1238;
	public static final int PPC_INS_VCMPGTSB = 1239;
	public static final int PPC_INS_VCMPGTSD = 1240;
	public static final int PPC_INS_VCMPGTSH = 1241;
	public static final int PPC_INS_VCMPGTSW = 1242;
	public static final int PPC_INS_VCMPGTUB = 1243;
	public static final int PPC_INS_VCMPGTUD = 1244;
	public static final int PPC_INS_VCMPGTUH = 1245;
	public static final int PPC_INS_VCMPGTUW = 1246;
	public static final int PPC_INS_VCMPNEB = 1247;
	public static final int PPC_INS_VCMPNEH = 1248;
	public static final int PPC_INS_VCMPNEW = 1249;
	public static final int PPC_INS_VCMPNEZB = 1250;
	public static final int PPC_INS_VCMPNEZH = 1251;
	public static final int PPC_INS_VCMPNEZW = 1252;
	public static final int PPC_INS_VCTSXS = 1253;
	public static final int PPC_INS_VCTUXS = 1254;
	public static final int PPC_INS_VCTZB = 1255;
	public static final int PPC_INS_VCTZD = 1256;
	public static final int PPC_INS_VCTZH = 1257;
	public static final int PPC_INS_VCTZLSBB = 1258;
	public static final int PPC_INS_VCTZW = 1259;
	public static final int PPC_INS_VEQV = 1260;
	public static final int PPC_INS_VEXPTEFP = 1261;
	public static final int PPC_INS_VEXTRACTD = 1262;
	public static final int PPC_INS_VEXTRACTUB = 1263;
	public static final int PPC_INS_VEXTRACTUH = 1264;
	public static final int PPC_INS_VEXTRACTUW = 1265;
	public static final int PPC_INS_VEXTSB2D = 1266;
	public static final int PPC_INS_VEXTSB2W = 1267;
	public static final int PPC_INS_VEXTSH2D = 1268;
	public static final int PPC_INS_VEXTSH2W = 1269;
	public static final int PPC_INS_VEXTSW2D = 1270;
	public static final int PPC_INS_VEXTUBLX = 1271;
	public static final int PPC_INS_VEXTUBRX = 1272;
	public static final int PPC_INS_VEXTUHLX = 1273;
	public static final int PPC_INS_VEXTUHRX = 1274;
	public static final int PPC_INS_VEXTUWLX = 1275;
	public static final int PPC_INS_VEXTUWRX = 1276;
	public static final int PPC_INS_VGBBD = 1277;
	public static final int PPC_INS_VINSERTB = 1278;
	public static final int PPC_INS_VINSERTD = 1279;
	public static final int PPC_INS_VINSERTH = 1280;
	public static final int PPC_INS_VINSERTW = 1281;
	public static final int PPC_INS_VLOGEFP = 1282;
	public static final int PPC_INS_VMADDFP = 1283;
	public static final int PPC_INS_VMAXFP = 1284;
	public static final int PPC_INS_VMAXSB = 1285;
	public static final int PPC_INS_VMAXSD = 1286;
	public static final int PPC_INS_VMAXSH = 1287;
	public static final int PPC_INS_VMAXSW = 1288;
	public static final int PPC_INS_VMAXUB = 1289;
	public static final int PPC_INS_VMAXUD = 1290;
	public static final int PPC_INS_VMAXUH = 1291;
	public static final int PPC_INS_VMAXUW = 1292;
	public static final int PPC_INS_VMHADDSHS = 1293;
	public static final int PPC_INS_VMHRADDSHS = 1294;
	public static final int PPC_INS_VMINFP = 1295;
	public static final int PPC_INS_VMINSB = 1296;
	public static final int PPC_INS_VMINSD = 1297;
	public static final int PPC_INS_VMINSH = 1298;
	public static final int PPC_INS_VMINSW = 1299;
	public static final int PPC_INS_VMINUB = 1300;
	public static final int PPC_INS_VMINUD = 1301;
	public static final int PPC_INS_VMINUH = 1302;
	public static final int PPC_INS_VMINUW = 1303;
	public static final int PPC_INS_VMLADDUHM = 1304;
	public static final int PPC_INS_VMR = 1305;
	public static final int PPC_INS_VMRGEW = 1306;
	public static final int PPC_INS_VMRGHB = 1307;
	public static final int PPC_INS_VMRGHH = 1308;
	public static final int PPC_INS_VMRGHW = 1309;
	public static final int PPC_INS_VMRGLB = 1310;
	public static final int PPC_INS_VMRGLH = 1311;
	public static final int PPC_INS_VMRGLW = 1312;
	public static final int PPC_INS_VMRGOW = 1313;
	public static final int PPC_INS_VMSUMMBM = 1314;
	public static final int PPC_INS_VMSUMSHM = 1315;
	public static final int PPC_INS_VMSUMSHS = 1316;
	public static final int PPC_INS_VMSUMUBM = 1317;
	public static final int PPC_INS_VMSUMUHM = 1318;
	public static final int PPC_INS_VMSUMUHS = 1319;
	public static final int PPC_INS_VMUL10CUQ = 1320;
	public static final int PPC_INS_VMUL10ECUQ = 1321;
	public static final int PPC_INS_VMUL10EUQ = 1322;
	public static final int PPC_INS_VMUL10UQ = 1323;
	public static final int PPC_INS_VMULESB = 1324;
	public static final int PPC_INS_VMULESH = 1325;
	public static final int PPC_INS_VMULESW = 1326;
	public static final int PPC_INS_VMULEUB = 1327;
	public static final int PPC_INS_VMULEUH = 1328;
	public static final int PPC_INS_VMULEUW = 1329;
	public static final int PPC_INS_VMULOSB = 1330;
	public static final int PPC_INS_VMULOSH = 1331;
	public static final int PPC_INS_VMULOSW = 1332;
	public static final int PPC_INS_VMULOUB = 1333;
	public static final int PPC_INS_VMULOUH = 1334;
	public static final int PPC_INS_VMULOUW = 1335;
	public static final int PPC_INS_VMULUWM = 1336;
	public static final int PPC_INS_VNAND = 1337;
	public static final int PPC_INS_VNCIPHER = 1338;
	public static final int PPC_INS_VNCIPHERLAST = 1339;
	public static final int PPC_INS_VNEGD = 1340;
	public static final int PPC_INS_VNEGW = 1341;
	public static final int PPC_INS_VNMSUBFP = 1342;
	public static final int PPC_INS_VNOR = 1343;
	public static final int PPC_INS_VNOT = 1344;
	public static final int PPC_INS_VOR = 1345;
	public static final int PPC_INS_VORC = 1346;
	public static final int PPC_INS_VPERM = 1347;
	public static final int PPC_INS_VPERMR = 1348;
	public static final int PPC_INS_VPERMXOR = 1349;
	public static final int PPC_INS_VPKPX = 1350;
	public static final int PPC_INS_VPKSDSS = 1351;
	public static final int PPC_INS_VPKSDUS = 1352;
	public static final int PPC_INS_VPKSHSS = 1353;
	public static final int PPC_INS_VPKSHUS = 1354;
	public static final int PPC_INS_VPKSWSS = 1355;
	public static final int PPC_INS_VPKSWUS = 1356;
	public static final int PPC_INS_VPKUDUM = 1357;
	public static final int PPC_INS_VPKUDUS = 1358;
	public static final int PPC_INS_VPKUHUM = 1359;
	public static final int PPC_INS_VPKUHUS = 1360;
	public static final int PPC_INS_VPKUWUM = 1361;
	public static final int PPC_INS_VPKUWUS = 1362;
	public static final int PPC_INS_VPMSUMB = 1363;
	public static final int PPC_INS_VPMSUMD = 1364;
	public static final int PPC_INS_VPMSUMH = 1365;
	public static final int PPC_INS_VPMSUMW = 1366;
	public static final int PPC_INS_VPOPCNTB = 1367;
	public static final int PPC_INS_VPOPCNTD = 1368;
	public static final int PPC_INS_VPOPCNTH = 1369;
	public static final int PPC_INS_VPOPCNTW = 1370;
	public static final int PPC_INS_VPRTYBD = 1371;
	public static final int PPC_INS_VPRTYBQ = 1372;
	public static final int PPC_INS_VPRTYBW = 1373;
	public static final int PPC_INS_VREFP = 1374;
	public static final int PPC_INS_VRFIM = 1375;
	public static final int PPC_INS_VRFIN = 1376;
	public static final int PPC_INS_VRFIP = 1377;
	public static final int PPC_INS_VRFIZ = 1378;
	public static final int PPC_INS_VRLB = 1379;
	public static final int PPC_INS_VRLD = 1380;
	public static final int PPC_INS_VRLDMI = 1381;
	public static final int PPC_INS_VRLDNM = 1382;
	public static final int PPC_INS_VRLH = 1383;
	public static final int PPC_INS_VRLW = 1384;
	public static final int PPC_INS_VRLWMI = 1385;
	public static final int PPC_INS_VRLWNM = 1386;
	public static final int PPC_INS_VRSQRTEFP = 1387;
	public static final int PPC_INS_VSBOX = 1388;
	public static final int PPC_INS_VSEL = 1389;
	public static final int PPC_INS_VSHASIGMAD = 1390;
	public static final int PPC_INS_VSHASIGMAW = 1391;
	public static final int PPC_INS_VSL = 1392;
	public static final int PPC_INS_VSLB = 1393;
	public static final int PPC_INS_VSLD = 1394;
	public static final int PPC_INS_VSLDOI = 1395;
	public static final int PPC_INS_VSLH = 1396;
	public static final int PPC_INS_VSLO = 1397;
	public static final int PPC_INS_VSLV = 1398;
	public static final int PPC_INS_VSLW = 1399;
	public static final int PPC_INS_VSPLTB = 1400;
	public static final int PPC_INS_VSPLTH = 1401;
	public static final int PPC_INS_VSPLTISB = 1402;
	public static final int PPC_INS_VSPLTISH = 1403;
	public static final int PPC_INS_VSPLTISW = 1404;
	public static final int PPC_INS_VSPLTW = 1405;
	public static final int PPC_INS_VSR = 1406;
	public static final int PPC_INS_VSRAB = 1407;
	public static final int PPC_INS_VSRAD = 1408;
	public static final int PPC_INS_VSRAH = 1409;
	public static final int PPC_INS_VSRAW = 1410;
	public static final int PPC_INS_VSRB = 1411;
	public static final int PPC_INS_VSRD = 1412;
	public static final int PPC_INS_VSRH = 1413;
	public static final int PPC_INS_VSRO = 1414;
	public static final int PPC_INS_VSRV = 1415;
	public static final int PPC_INS_VSRW = 1416;
	public static final int PPC_INS_VSUBCUQ = 1417;
	public static final int PPC_INS_VSUBCUW = 1418;
	public static final int PPC_INS_VSUBECUQ = 1419;
	public static final int PPC_INS_VSUBEUQM = 1420;
	public static final int PPC_INS_VSUBFP = 1421;
	public static final int PPC_INS_VSUBSBS = 1422;
	public static final int PPC_INS_VSUBSHS = 1423;
	public static final int PPC_INS_VSUBSWS = 1424;
	public static final int PPC_INS_VSUBUBM = 1425;
	public static final int PPC_INS_VSUBUBS = 1426;
	public static final int PPC_INS_VSUBUDM = 1427;
	public static final int PPC_INS_VSUBUHM = 1428;
	public static final int PPC_INS_VSUBUHS = 1429;
	public static final int PPC_INS_VSUBUQM = 1430;
	public static final int PPC_INS_VSUBUWM = 1431;
	public static final int PPC_INS_VSUBUWS = 1432;
	public static final int PPC_INS_VSUM2SWS = 1433;
	public static final int PPC_INS_VSUM4SBS = 1434;
	public static final int PPC_INS_VSUM4SHS = 1435;
	public static final int PPC_INS_VSUM4UBS = 1436;
	public static final int PPC_INS_VSUMSWS = 1437;
	public static final int PPC_INS_VUPKHPX = 1438;
	public static final int PPC_INS_VUPKHSB = 1439;
	public static final int PPC_INS_VUPKHSH = 1440;
	public static final int PPC_INS_VUPKHSW = 1441;
	public static final int PPC_INS_VUPKLPX = 1442;
	public static final int PPC_INS_VUPKLSB = 1443;
	public static final int PPC_INS_VUPKLSH = 1444;
	public static final int PPC_INS_VUPKLSW = 1445;
	public static final int PPC_INS_VXOR = 1446;
	public static final int PPC_INS_WAIT = 1447;
	public static final int PPC_INS_WAITIMPL = 1448;
	public static final int PPC_INS_WAITRSV = 1449;
	public static final int PPC_INS_WRTEE = 1450;
	public static final int PPC_INS_WRTEEI = 1451;
	public static final int PPC_INS_XNOP = 1452;
	public static final int PPC_INS_XOR = 1453;
	public static final int PPC_INS_XORI = 1454;
	public static final int PPC_INS_XORIS = 1455;
	public static final int PPC_INS_XSABSDP = 1456;
	public static final int PPC_INS_XSABSQP = 1457;
	public static final int PPC_INS_XSADDDP = 1458;
	public static final int PPC_INS_XSADDQP = 1459;
	public static final int PPC_INS_XSADDQPO = 1460;
	public static final int PPC_INS_XSADDSP = 1461;
	public static final int PPC_INS_XSCMPEQDP = 1462;
	public static final int PPC_INS_XSCMPEXPDP = 1463;
	public static final int PPC_INS_XSCMPEXPQP = 1464;
	public static final int PPC_INS_XSCMPGEDP = 1465;
	public static final int PPC_INS_XSCMPGTDP = 1466;
	public static final int PPC_INS_XSCMPODP = 1467;
	public static final int PPC_INS_XSCMPOQP = 1468;
	public static final int PPC_INS_XSCMPUDP = 1469;
	public static final int PPC_INS_XSCMPUQP = 1470;
	public static final int PPC_INS_XSCPSGNDP = 1471;
	public static final int PPC_INS_XSCPSGNQP = 1472;
	public static final int PPC_INS_XSCVDPHP = 1473;
	public static final int PPC_INS_XSCVDPQP = 1474;
	public static final int PPC_INS_XSCVDPSP = 1475;
	public static final int PPC_INS_XSCVDPSPN = 1476;
	public static final int PPC_INS_XSCVDPSXDS = 1477;
	public static final int PPC_INS_XSCVDPSXWS = 1478;
	public static final int PPC_INS_XSCVDPUXDS = 1479;
	public static final int PPC_INS_XSCVDPUXWS = 1480;
	public static final int PPC_INS_XSCVHPDP = 1481;
	public static final int PPC_INS_XSCVQPDP = 1482;
	public static final int PPC_INS_XSCVQPDPO = 1483;
	public static final int PPC_INS_XSCVQPSDZ = 1484;
	public static final int PPC_INS_XSCVQPSWZ = 1485;
	public static final int PPC_INS_XSCVQPUDZ = 1486;
	public static final int PPC_INS_XSCVQPUWZ = 1487;
	public static final int PPC_INS_XSCVSDQP = 1488;
	public static final int PPC_INS_XSCVSPDP = 1489;
	public static final int PPC_INS_XSCVSPDPN = 1490;
	public static final int PPC_INS_XSCVSXDDP = 1491;
	public static final int PPC_INS_XSCVSXDSP = 1492;
	public static final int PPC_INS_XSCVUDQP = 1493;
	public static final int PPC_INS_XSCVUXDDP = 1494;
	public static final int PPC_INS_XSCVUXDSP = 1495;
	public static final int PPC_INS_XSDIVDP = 1496;
	public static final int PPC_INS_XSDIVQP = 1497;
	public static final int PPC_INS_XSDIVQPO = 1498;
	public static final int PPC_INS_XSDIVSP = 1499;
	public static final int PPC_INS_XSIEXPDP = 1500;
	public static final int PPC_INS_XSIEXPQP = 1501;
	public static final int PPC_INS_XSMADDADP = 1502;
	public static final int PPC_INS_XSMADDASP = 1503;
	public static final int PPC_INS_XSMADDMDP = 1504;
	public static final int PPC_INS_XSMADDMSP = 1505;
	public static final int PPC_INS_XSMADDQP = 1506;
	public static final int PPC_INS_XSMADDQPO = 1507;
	public static final int PPC_INS_XSMAXCDP = 1508;
	public static final int PPC_INS_XSMAXDP = 1509;
	public static final int PPC_INS_XSMAXJDP = 1510;
	public static final int PPC_INS_XSMINCDP = 1511;
	public static final int PPC_INS_XSMINDP = 1512;
	public static final int PPC_INS_XSMINJDP = 1513;
	public static final int PPC_INS_XSMSUBADP = 1514;
	public static final int PPC_INS_XSMSUBASP = 1515;
	public static final int PPC_INS_XSMSUBMDP = 1516;
	public static final int PPC_INS_XSMSUBMSP = 1517;
	public static final int PPC_INS_XSMSUBQP = 1518;
	public static final int PPC_INS_XSMSUBQPO = 1519;
	public static final int PPC_INS_XSMULDP = 1520;
	public static final int PPC_INS_XSMULQP = 1521;
	public static final int PPC_INS_XSMULQPO = 1522;
	public static final int PPC_INS_XSMULSP = 1523;
	public static final int PPC_INS_XSNABSDP = 1524;
	public static final int PPC_INS_XSNABSQP = 1525;
	public static final int PPC_INS_XSNEGDP = 1526;
	public static final int PPC_INS_XSNEGQP = 1527;
	public static final int PPC_INS_XSNMADDADP = 1528;
	public static final int PPC_INS_XSNMADDASP = 1529;
	public static final int PPC_INS_XSNMADDMDP = 1530;
	public static final int PPC_INS_XSNMADDMSP = 1531;
	public static final int PPC_INS_XSNMADDQP = 1532;
	public static final int PPC_INS_XSNMADDQPO = 1533;
	public static final int PPC_INS_XSNMSUBADP = 1534;
	public static final int PPC_INS_XSNMSUBASP = 1535;
	public static final int PPC_INS_XSNMSUBMDP = 1536;
	public static final int PPC_INS_XSNMSUBMSP = 1537;
	public static final int PPC_INS_XSNMSUBQP = 1538;
	public static final int PPC_INS_XSNMSUBQPO = 1539;
	public static final int PPC_INS_XSRDPI = 1540;
	public static final int PPC_INS_XSRDPIC = 1541;
	public static final int PPC_INS_XSRDPIM = 1542;
	public static final int PPC_INS_XSRDPIP = 1543;
	public static final int PPC_INS_XSRDPIZ = 1544;
	public static final int PPC_INS_XSREDP = 1545;
	public static final int PPC_INS_XSRESP = 1546;
	public static final int PPC_INS_XSRQPI = 1547;
	public static final int PPC_INS_XSRQPIX = 1548;
	public static final int PPC_INS_XSRQPXP = 1549;
	public static final int PPC_INS_XSRSP = 1550;
	public static final int PPC_INS_XSRSQRTEDP = 1551;
	public static final int PPC_INS_XSRSQRTESP = 1552;
	public static final int PPC_INS_XSSQRTDP = 1553;
	public static final int PPC_INS_XSSQRTQP = 1554;
	public static final int PPC_INS_XSSQRTQPO = 1555;
	public static final int PPC_INS_XSSQRTSP = 1556;
	public static final int PPC_INS_XSSUBDP = 1557;
	public static final int PPC_INS_XSSUBQP = 1558;
	public static final int PPC_INS_XSSUBQPO = 1559;
	public static final int PPC_INS_XSSUBSP = 1560;
	public static final int PPC_INS_XSTDIVDP = 1561;
	public static final int PPC_INS_XSTSQRTDP = 1562;
	public static final int PPC_INS_XSTSTDCDP = 1563;
	public static final int PPC_INS_XSTSTDCQP = 1564;
	public static final int PPC_INS_XSTSTDCSP = 1565;
	public static final int PPC_INS_XSXEXPDP = 1566;
	public static final int PPC_INS_XSXEXPQP = 1567;
	public static final int PPC_INS_XSXSIGDP = 1568;
	public static final int PPC_INS_XSXSIGQP = 1569;
	public static final int PPC_INS_XVABSDP = 1570;
	public static final int PPC_INS_XVABSSP = 1571;
	public static final int PPC_INS_XVADDDP = 1572;
	public static final int PPC_INS_XVADDSP = 1573;
	public static final int PPC_INS_XVCMPEQDP = 1574;
	public static final int PPC_INS_XVCMPEQSP = 1575;
	public static final int PPC_INS_XVCMPGEDP = 1576;
	public static final int PPC_INS_XVCMPGESP = 1577;
	public static final int PPC_INS_XVCMPGTDP = 1578;
	public static final int PPC_INS_XVCMPGTSP = 1579;
	public static final int PPC_INS_XVCPSGNDP = 1580;
	public static final int PPC_INS_XVCPSGNSP = 1581;
	public static final int PPC_INS_XVCVDPSP = 1582;
	public static final int PPC_INS_XVCVDPSXDS = 1583;
	public static final int PPC_INS_XVCVDPSXWS = 1584;
	public static final int PPC_INS_XVCVDPUXDS = 1585;
	public static final int PPC_INS_XVCVDPUXWS = 1586;
	public static final int PPC_INS_XVCVHPSP = 1587;
	public static final int PPC_INS_XVCVSPDP = 1588;
	public static final int PPC_INS_XVCVSPHP = 1589;
	public static final int PPC_INS_XVCVSPSXDS = 1590;
	public static final int PPC_INS_XVCVSPSXWS = 1591;
	public static final int PPC_INS_XVCVSPUXDS = 1592;
	public static final int PPC_INS_XVCVSPUXWS = 1593;
	public static final int PPC_INS_XVCVSXDDP = 1594;
	public static final int PPC_INS_XVCVSXDSP = 1595;
	public static final int PPC_INS_XVCVSXWDP = 1596;
	public static final int PPC_INS_XVCVSXWSP = 1597;
	public static final int PPC_INS_XVCVUXDDP = 1598;
	public static final int PPC_INS_XVCVUXDSP = 1599;
	public static final int PPC_INS_XVCVUXWDP = 1600;
	public static final int PPC_INS_XVCVUXWSP = 1601;
	public static final int PPC_INS_XVDIVDP = 1602;
	public static final int PPC_INS_XVDIVSP = 1603;
	public static final int PPC_INS_XVIEXPDP = 1604;
	public static final int PPC_INS_XVIEXPSP = 1605;
	public static final int PPC_INS_XVMADDADP = 1606;
	public static final int PPC_INS_XVMADDASP = 1607;
	public static final int PPC_INS_XVMADDMDP = 1608;
	public static final int PPC_INS_XVMADDMSP = 1609;
	public static final int PPC_INS_XVMAXDP = 1610;
	public static final int PPC_INS_XVMAXSP = 1611;
	public static final int PPC_INS_XVMINDP = 1612;
	public static final int PPC_INS_XVMINSP = 1613;
	public static final int PPC_INS_XVMOVDP = 1614;
	public static final int PPC_INS_XVMOVSP = 1615;
	public static final int PPC_INS_XVMSUBADP = 1616;
	public static final int PPC_INS_XVMSUBASP = 1617;
	public static final int PPC_INS_XVMSUBMDP = 1618;
	public static final int PPC_INS_XVMSUBMSP = 1619;
	public static final int PPC_INS_XVMULDP = 1620;
	public static final int PPC_INS_XVMULSP = 1621;
	public static final int PPC_INS_XVNABSDP = 1622;
	public static final int PPC_INS_XVNABSSP = 1623;
	public static final int PPC_INS_XVNEGDP = 1624;
	public static final int PPC_INS_XVNEGSP = 1625;
	public static final int PPC_INS_XVNMADDADP = 1626;
	public static final int PPC_INS_XVNMADDASP = 1627;
	public static final int PPC_INS_XVNMADDMDP = 1628;
	public static final int PPC_INS_XVNMADDMSP = 1629;
	public static final int PPC_INS_XVNMSUBADP = 1630;
	public static final int PPC_INS_XVNMSUBASP = 1631;
	public static final int PPC_INS_XVNMSUBMDP = 1632;
	public static final int PPC_INS_XVNMSUBMSP = 1633;
	public static final int PPC_INS_XVRDPI = 1634;
	public static final int PPC_INS_XVRDPIC = 1635;
	public static final int PPC_INS_XVRDPIM = 1636;
	public static final int PPC_INS_XVRDPIP = 1637;
	public static final int PPC_INS_XVRDPIZ = 1638;
	public static final int PPC_INS_XVREDP = 1639;
	public static final int PPC_INS_XVRESP = 1640;
	public static final int PPC_INS_XVRSPI = 1641;
	public static final int PPC_INS_XVRSPIC = 1642;
	public static final int PPC_INS_XVRSPIM = 1643;
	public static final int PPC_INS_XVRSPIP = 1644;
	public static final int PPC_INS_XVRSPIZ = 1645;
	public static final int PPC_INS_XVRSQRTEDP = 1646;
	public static final int PPC_INS_XVRSQRTESP = 1647;
	public static final int PPC_INS_XVSQRTDP = 1648;
	public static final int PPC_INS_XVSQRTSP = 1649;
	public static final int PPC_INS_XVSUBDP = 1650;
	public static final int PPC_INS_XVSUBSP = 1651;
	public static final int PPC_INS_XVTDIVDP = 1652;
	public static final int PPC_INS_XVTDIVSP = 1653;
	public static final int PPC_INS_XVTSQRTDP = 1654;
	public static final int PPC_INS_XVTSQRTSP = 1655;
	public static final int PPC_INS_XVTSTDCDP = 1656;
	public static final int PPC_INS_XVTSTDCSP = 1657;
	public static final int PPC_INS_XVXEXPDP = 1658;
	public static final int PPC_INS_XVXEXPSP = 1659;
	public static final int PPC_INS_XVXSIGDP = 1660;
	public static final int PPC_INS_XVXSIGSP = 1661;
	public static final int PPC_INS_XXBRD = 1662;
	public static final int PPC_INS_XXBRH = 1663;
	public static final int PPC_INS_XXBRQ = 1664;
	public static final int PPC_INS_XXBRW = 1665;
	public static final int PPC_INS_XXEXTRACTUW = 1666;
	public static final int PPC_INS_XXINSERTW = 1667;
	public static final int PPC_INS_XXLAND = 1668;
	public static final int PPC_INS_XXLANDC = 1669;
	public static final int PPC_INS_XXLEQV = 1670;
	public static final int PPC_INS_XXLNAND = 1671;
	public static final int PPC_INS_XXLNOR = 1672;
	public static final int PPC_INS_XXLOR = 1673;
	public static final int PPC_INS_XXLORC = 1674;
	public static final int PPC_INS_XXLXOR = 1675;
	public static final int PPC_INS_XXMRGHD = 1676;
	public static final int PPC_INS_XXMRGHW = 1677;
	public static final int PPC_INS_XXMRGLD = 1678;
	public static final int PPC_INS_XXMRGLW = 1679;
	public static final int PPC_INS_XXPERM = 1680;
	public static final int PPC_INS_XXPERMDI = 1681;
	public static final int PPC_INS_XXPERMR = 1682;
	public static final int PPC_INS_XXSEL = 1683;
	public static final int PPC_INS_XXSLDWI = 1684;
	public static final int PPC_INS_XXSPLTD = 1685;
	public static final int PPC_INS_XXSPLTIB = 1686;
	public static final int PPC_INS_XXSPLTW = 1687;
	public static final int PPC_INS_XXSWAPD = 1688;
	public static final int PPC_INS_DCBZ_L = 1689;
	public static final int PPC_INS_PSQ_L = 1690;
	public static final int PPC_INS_PSQ_LU = 1691;
	public static final int PPC_INS_PSQ_LUX = 1692;
	public static final int PPC_INS_PSQ_LX = 1693;
	public static final int PPC_INS_PSQ_ST = 1694;
	public static final int PPC_INS_PSQ_STU = 1695;
	public static final int PPC_INS_PSQ_STUX = 1696;
	public static final int PPC_INS_PSQ_STX = 1697;
	public static final int PPC_INS_PS_ABS = 1698;
	public static final int PPC_INS_PS_ADD = 1699;
	public static final int PPC_INS_PS_CMPO0 = 1700;
	public static final int PPC_INS_PS_CMPO1 = 1701;
	public static final int PPC_INS_PS_CMPU0 = 1702;
	public static final int PPC_INS_PS_CMPU1 = 1703;
	public static final int PPC_INS_PS_DIV = 1704;
	public static final int PPC_INS_PS_MADD = 1705;
	public static final int PPC_INS_PS_MADDS0 = 1706;
	public static final int PPC_INS_PS_MADDS1 = 1707;
	public static final int PPC_INS_PS_MERGE00 = 1708;
	public static final int PPC_INS_PS_MERGE01 = 1709;
	public static final int PPC_INS_PS_MERGE10 = 1710;
	public static final int PPC_INS_PS_MERGE11 = 1711;
	public static final int PPC_INS_PS_MR = 1712;
	public static final int PPC_INS_PS_MSUB = 1713;
	public static final int PPC_INS_PS_MUL = 1714;
	public static final int PPC_INS_PS_MULS0 = 1715;
	public static final int PPC_INS_PS_MULS1 = 1716;
	public static final int PPC_INS_PS_NABS = 1717;
	public static final int PPC_INS_PS_NEG = 1718;
	public static final int PPC_INS_PS_NMADD = 1719;
	public static final int PPC_INS_PS_NMSUB = 1720;
	public static final int PPC_INS_PS_RES = 1721;
	public static final int PPC_INS_PS_RSQRTE = 1722;
	public static final int PPC_INS_PS_SEL = 1723;
	public static final int PPC_INS_PS_SUB = 1724;
	public static final int PPC_INS_PS_SUM0 = 1725;
	public static final int PPC_INS_PS_SUM1 = 1726;
	public static final int PPC_INS_ENDING = 1727;

	public static final int PPC_GRP_INVALID = 0;
	public static final int PPC_GRP_JUMP = 1;
	public static final int PPC_GRP_ALTIVEC = 128;
	public static final int PPC_GRP_MODE32 = 129;
	public static final int PPC_GRP_MODE64 = 130;
	public static final int PPC_GRP_BOOKE = 131;
	public static final int PPC_GRP_NOTBOOKE = 132;
	public static final int PPC_GRP_SPE = 133;
	public static final int PPC_GRP_VSX = 134;
	public static final int PPC_GRP_E500 = 135;
	public static final int PPC_GRP_PPC4XX = 136;
	public static final int PPC_GRP_PPC6XX = 137;
	public static final int PPC_GRP_ICBT = 138;
	public static final int PPC_GRP_P8ALTIVEC = 139;
	public static final int PPC_GRP_P8VECTOR = 140;
	public static final int PPC_GRP_QPX = 141;
	public static final int PPC_GRP_PS = 142;
	public static final int PPC_GRP_ENDING = 143;
}