/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* This is auto-gen data for Capstone disassembly engine (www.capstone-engine.org) */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

	"abs", // ARM64_INS_ABS,
	"adc", // ARM64_INS_ADC,
	"adclb", // ARM64_INS_ADCLB,
	"adclt", // ARM64_INS_ADCLT,
	"adcs", // ARM64_INS_ADCS,
	"add", // ARM64_INS_ADD,
	"addg", // ARM64_INS_ADDG,
	"addha", // ARM64_INS_ADDHA,
	"addhn", // ARM64_INS_ADDHN,
	"addhn2", // ARM64_INS_ADDHN2,
	"addhnb", // ARM64_INS_ADDHNB,
	"addhnt", // ARM64_INS_ADDHNT,
	"addp", // ARM64_INS_ADDP,
	"addpl", // ARM64_INS_ADDPL,
	"adds", // ARM64_INS_ADDS,
	"addv", // ARM64_INS_ADDV,
	"addva", // ARM64_INS_ADDVA,
	"addvl", // ARM64_INS_ADDVL,
	"adr", // ARM64_INS_ADR,
	"adrp", // ARM64_INS_ADRP,
	"aesd", // ARM64_INS_AESD,
	"aese", // ARM64_INS_AESE,
	"aesimc", // ARM64_INS_AESIMC,
	"aesmc", // ARM64_INS_AESMC,
	"and", // ARM64_INS_AND,
	"ands", // ARM64_INS_ANDS,
	"andv", // ARM64_INS_ANDV,
	"asr", // ARM64_INS_ASR,
	"asrd", // ARM64_INS_ASRD,
	"asrr", // ARM64_INS_ASRR,
	"asrv", // ARM64_INS_ASRV,
	"autda", // ARM64_INS_AUTDA,
	"autdb", // ARM64_INS_AUTDB,
	"autdza", // ARM64_INS_AUTDZA,
	"autdzb", // ARM64_INS_AUTDZB,
	"autia", // ARM64_INS_AUTIA,
	"autia1716", // ARM64_INS_AUTIA1716,
	"autiasp", // ARM64_INS_AUTIASP,
	"autiaz", // ARM64_INS_AUTIAZ,
	"autib", // ARM64_INS_AUTIB,
	"autib1716", // ARM64_INS_AUTIB1716,
	"autibsp", // ARM64_INS_AUTIBSP,
	"autibz", // ARM64_INS_AUTIBZ,
	"autiza", // ARM64_INS_AUTIZA,
	"autizb", // ARM64_INS_AUTIZB,
	"axflag", // ARM64_INS_AXFLAG,
	"b", // ARM64_INS_B,
	"bc", // ARM64_INS_BC,
	"bcax", // ARM64_INS_BCAX,
	"bdep", // ARM64_INS_BDEP,
	"bext", // ARM64_INS_BEXT,
	"bfcvt", // ARM64_INS_BFCVT,
	"bfcvtn", // ARM64_INS_BFCVTN,
	"bfcvtn2", // ARM64_INS_BFCVTN2,
	"bfcvtnt", // ARM64_INS_BFCVTNT,
	"bfdot", // ARM64_INS_BFDOT,
	"bfm", // ARM64_INS_BFM,
	"bfmlalb", // ARM64_INS_BFMLALB,
	"bfmlalt", // ARM64_INS_BFMLALT,
	"bfmmla", // ARM64_INS_BFMMLA,
	"bfmopa", // ARM64_INS_BFMOPA,
	"bfmops", // ARM64_INS_BFMOPS,
	"bgrp", // ARM64_INS_BGRP,
	"bic", // ARM64_INS_BIC,
	"bics", // ARM64_INS_BICS,
	"bif", // ARM64_INS_BIF,
	"bit", // ARM64_INS_BIT,
	"bl", // ARM64_INS_BL,
	"blr", // ARM64_INS_BLR,
	"blraa", // ARM64_INS_BLRAA,
	"blraaz", // ARM64_INS_BLRAAZ,
	"blrab", // ARM64_INS_BLRAB,
	"blrabz", // ARM64_INS_BLRABZ,
	"br", // ARM64_INS_BR,
	"braa", // ARM64_INS_BRAA,
	"braaz", // ARM64_INS_BRAAZ,
	"brab", // ARM64_INS_BRAB,
	"brabz", // ARM64_INS_BRABZ,
	"brb", // ARM64_INS_BRB,
	"brk", // ARM64_INS_BRK,
	"brka", // ARM64_INS_BRKA,
	"brkas", // ARM64_INS_BRKAS,
	"brkb", // ARM64_INS_BRKB,
	"brkbs", // ARM64_INS_BRKBS,
	"brkn", // ARM64_INS_BRKN,
	"brkns", // ARM64_INS_BRKNS,
	"brkpa", // ARM64_INS_BRKPA,
	"brkpas", // ARM64_INS_BRKPAS,
	"brkpb", // ARM64_INS_BRKPB,
	"brkpbs", // ARM64_INS_BRKPBS,
	"bsl", // ARM64_INS_BSL,
	"bsl1n", // ARM64_INS_BSL1N,
	"bsl2n", // ARM64_INS_BSL2N,
	"bti", // ARM64_INS_BTI,
	"cadd", // ARM64_INS_CADD,
	"cas", // ARM64_INS_CAS,
	"casa", // ARM64_INS_CASA,
	"casab", // ARM64_INS_CASAB,
	"casah", // ARM64_INS_CASAH,
	"casal", // ARM64_INS_CASAL,
	"casalb", // ARM64_INS_CASALB,
	"casalh", // ARM64_INS_CASALH,
	"casb", // ARM64_INS_CASB,
	"cash", // ARM64_INS_CASH,
	"casl", // ARM64_INS_CASL,
	"caslb", // ARM64_INS_CASLB,
	"caslh", // ARM64_INS_CASLH,
	"casp", // ARM64_INS_CASP,
	"caspa", // ARM64_INS_CASPA,
	"caspal", // ARM64_INS_CASPAL,
	"caspl", // ARM64_INS_CASPL,
	"cbnz", // ARM64_INS_CBNZ,
	"cbz", // ARM64_INS_CBZ,
	"ccmn", // ARM64_INS_CCMN,
	"ccmp", // ARM64_INS_CCMP,
	"cdot", // ARM64_INS_CDOT,
	"cfinv", // ARM64_INS_CFINV,
	"cinc", // ARM64_INS_CINC,
	"cinv", // ARM64_INS_CINV,
	"clasta", // ARM64_INS_CLASTA,
	"clastb", // ARM64_INS_CLASTB,
	"clrex", // ARM64_INS_CLREX,
	"cls", // ARM64_INS_CLS,
	"clz", // ARM64_INS_CLZ,
	"cmeq", // ARM64_INS_CMEQ,
	"cmge", // ARM64_INS_CMGE,
	"cmgt", // ARM64_INS_CMGT,
	"cmhi", // ARM64_INS_CMHI,
	"cmhs", // ARM64_INS_CMHS,
	"cmla", // ARM64_INS_CMLA,
	"cmle", // ARM64_INS_CMLE,
	"cmlo", // ARM64_INS_CMLO,
	"cmls", // ARM64_INS_CMLS,
	"cmlt", // ARM64_INS_CMLT,
	"cmn", // ARM64_INS_CMN,
	"cmp", // ARM64_INS_CMP,
	"cmpeq", // ARM64_INS_CMPEQ,
	"cmpge", // ARM64_INS_CMPGE,
	"cmpgt", // ARM64_INS_CMPGT,
	"cmphi", // ARM64_INS_CMPHI,
	"cmphs", // ARM64_INS_CMPHS,
	"cmple", // ARM64_INS_CMPLE,
	"cmplo", // ARM64_INS_CMPLO,
	"cmpls", // ARM64_INS_CMPLS,
	"cmplt", // ARM64_INS_CMPLT,
	"cmpne", // ARM64_INS_CMPNE,
	"cmpp", // ARM64_INS_CMPP,
	"cmtst", // ARM64_INS_CMTST,
	"cneg", // ARM64_INS_CNEG,
	"cnot", // ARM64_INS_CNOT,
	"cnt", // ARM64_INS_CNT,
	"cntb", // ARM64_INS_CNTB,
	"cntd", // ARM64_INS_CNTD,
	"cnth", // ARM64_INS_CNTH,
	"cntp", // ARM64_INS_CNTP,
	"cntw", // ARM64_INS_CNTW,
	"compact", // ARM64_INS_COMPACT,
	"cpy", // ARM64_INS_CPY,
	"cpye", // ARM64_INS_CPYE,
	"cpyen", // ARM64_INS_CPYEN,
	"cpyern", // ARM64_INS_CPYERN,
	"cpyert", // ARM64_INS_CPYERT,
	"cpyertn", // ARM64_INS_CPYERTN,
	"cpyertrn", // ARM64_INS_CPYERTRN,
	"cpyertwn", // ARM64_INS_CPYERTWN,
	"cpyet", // ARM64_INS_CPYET,
	"cpyetn", // ARM64_INS_CPYETN,
	"cpyetrn", // ARM64_INS_CPYETRN,
	"cpyetwn", // ARM64_INS_CPYETWN,
	"cpyewn", // ARM64_INS_CPYEWN,
	"cpyewt", // ARM64_INS_CPYEWT,
	"cpyewtn", // ARM64_INS_CPYEWTN,
	"cpyewtrn", // ARM64_INS_CPYEWTRN,
	"cpyewtwn", // ARM64_INS_CPYEWTWN,
	"cpyfe", // ARM64_INS_CPYFE,
	"cpyfen", // ARM64_INS_CPYFEN,
	"cpyfern", // ARM64_INS_CPYFERN,
	"cpyfert", // ARM64_INS_CPYFERT,
	"cpyfertn", // ARM64_INS_CPYFERTN,
	"cpyfertrn", // ARM64_INS_CPYFERTRN,
	"cpyfertwn", // ARM64_INS_CPYFERTWN,
	"cpyfet", // ARM64_INS_CPYFET,
	"cpyfetn", // ARM64_INS_CPYFETN,
	"cpyfetrn", // ARM64_INS_CPYFETRN,
	"cpyfetwn", // ARM64_INS_CPYFETWN,
	"cpyfewn", // ARM64_INS_CPYFEWN,
	"cpyfewt", // ARM64_INS_CPYFEWT,
	"cpyfewtn", // ARM64_INS_CPYFEWTN,
	"cpyfewtrn", // ARM64_INS_CPYFEWTRN,
	"cpyfewtwn", // ARM64_INS_CPYFEWTWN,
	"cpyfm", // ARM64_INS_CPYFM,
	"cpyfmn", // ARM64_INS_CPYFMN,
	"cpyfmrn", // ARM64_INS_CPYFMRN,
	"cpyfmrt", // ARM64_INS_CPYFMRT,
	"cpyfmrtn", // ARM64_INS_CPYFMRTN,
	"cpyfmrtrn", // ARM64_INS_CPYFMRTRN,
	"cpyfmrtwn", // ARM64_INS_CPYFMRTWN,
	"cpyfmt", // ARM64_INS_CPYFMT,
	"cpyfmtn", // ARM64_INS_CPYFMTN,
	"cpyfmtrn", // ARM64_INS_CPYFMTRN,
	"cpyfmtwn", // ARM64_INS_CPYFMTWN,
	"cpyfmwn", // ARM64_INS_CPYFMWN,
	"cpyfmwt", // ARM64_INS_CPYFMWT,
	"cpyfmwtn", // ARM64_INS_CPYFMWTN,
	"cpyfmwtrn", // ARM64_INS_CPYFMWTRN,
	"cpyfmwtwn", // ARM64_INS_CPYFMWTWN,
	"cpyfp", // ARM64_INS_CPYFP,
	"cpyfpn", // ARM64_INS_CPYFPN,
	"cpyfprn", // ARM64_INS_CPYFPRN,
	"cpyfprt", // ARM64_INS_CPYFPRT,
	"cpyfprtn", // ARM64_INS_CPYFPRTN,
	"cpyfprtrn", // ARM64_INS_CPYFPRTRN,
	"cpyfprtwn", // ARM64_INS_CPYFPRTWN,
	"cpyfpt", // ARM64_INS_CPYFPT,
	"cpyfptn", // ARM64_INS_CPYFPTN,
	"cpyfptrn", // ARM64_INS_CPYFPTRN,
	"cpyfptwn", // ARM64_INS_CPYFPTWN,
	"cpyfpwn", // ARM64_INS_CPYFPWN,
	"cpyfpwt", // ARM64_INS_CPYFPWT,
	"cpyfpwtn", // ARM64_INS_CPYFPWTN,
	"cpyfpwtrn", // ARM64_INS_CPYFPWTRN,
	"cpyfpwtwn", // ARM64_INS_CPYFPWTWN,
	"cpym", // ARM64_INS_CPYM,
	"cpymn", // ARM64_INS_CPYMN,
	"cpymrn", // ARM64_INS_CPYMRN,
	"cpymrt", // ARM64_INS_CPYMRT,
	"cpymrtn", // ARM64_INS_CPYMRTN,
	"cpymrtrn", // ARM64_INS_CPYMRTRN,
	"cpymrtwn", // ARM64_INS_CPYMRTWN,
	"cpymt", // ARM64_INS_CPYMT,
	"cpymtn", // ARM64_INS_CPYMTN,
	"cpymtrn", // ARM64_INS_CPYMTRN,
	"cpymtwn", // ARM64_INS_CPYMTWN,
	"cpymwn", // ARM64_INS_CPYMWN,
	"cpymwt", // ARM64_INS_CPYMWT,
	"cpymwtn", // ARM64_INS_CPYMWTN,
	"cpymwtrn", // ARM64_INS_CPYMWTRN,
	"cpymwtwn", // ARM64_INS_CPYMWTWN,
	"cpyp", // ARM64_INS_CPYP,
	"cpypn", // ARM64_INS_CPYPN,
	"cpyprn", // ARM64_INS_CPYPRN,
	"cpyprt", // ARM64_INS_CPYPRT,
	"cpyprtn", // ARM64_INS_CPYPRTN,
	"cpyprtrn", // ARM64_INS_CPYPRTRN,
	"cpyprtwn", // ARM64_INS_CPYPRTWN,
	"cpypt", // ARM64_INS_CPYPT,
	"cpyptn", // ARM64_INS_CPYPTN,
	"cpyptrn", // ARM64_INS_CPYPTRN,
	"cpyptwn", // ARM64_INS_CPYPTWN,
	"cpypwn", // ARM64_INS_CPYPWN,
	"cpypwt", // ARM64_INS_CPYPWT,
	"cpypwtn", // ARM64_INS_CPYPWTN,
	"cpypwtrn", // ARM64_INS_CPYPWTRN,
	"cpypwtwn", // ARM64_INS_CPYPWTWN,
	"crc32b", // ARM64_INS_CRC32B,
	"crc32cb", // ARM64_INS_CRC32CB,
	"crc32ch", // ARM64_INS_CRC32CH,
	"crc32cw", // ARM64_INS_CRC32CW,
	"crc32cx", // ARM64_INS_CRC32CX,
	"crc32h", // ARM64_INS_CRC32H,
	"crc32w", // ARM64_INS_CRC32W,
	"crc32x", // ARM64_INS_CRC32X,
	"csdb", // ARM64_INS_CSDB,
	"csel", // ARM64_INS_CSEL,
	"cset", // ARM64_INS_CSET,
	"csetm", // ARM64_INS_CSETM,
	"csinc", // ARM64_INS_CSINC,
	"csinv", // ARM64_INS_CSINV,
	"csneg", // ARM64_INS_CSNEG,
	"ctermeq", // ARM64_INS_CTERMEQ,
	"ctermne", // ARM64_INS_CTERMNE,
	"dcps1", // ARM64_INS_DCPS1,
	"dcps2", // ARM64_INS_DCPS2,
	"dcps3", // ARM64_INS_DCPS3,
	"decb", // ARM64_INS_DECB,
	"decd", // ARM64_INS_DECD,
	"dech", // ARM64_INS_DECH,
	"decp", // ARM64_INS_DECP,
	"decw", // ARM64_INS_DECW,
	"dfb", // ARM64_INS_DFB,
	"dgh", // ARM64_INS_DGH,
	"dmb", // ARM64_INS_DMB,
	"drps", // ARM64_INS_DRPS,
	"dsb", // ARM64_INS_DSB,
	"dup", // ARM64_INS_DUP,
	"dupm", // ARM64_INS_DUPM,
	"eon", // ARM64_INS_EON,
	"eor", // ARM64_INS_EOR,
	"eor3", // ARM64_INS_EOR3,
	"eorbt", // ARM64_INS_EORBT,
	"eors", // ARM64_INS_EORS,
	"eortb", // ARM64_INS_EORTB,
	"eorv", // ARM64_INS_EORV,
	"eret", // ARM64_INS_ERET,
	"eretaa", // ARM64_INS_ERETAA,
	"eretab", // ARM64_INS_ERETAB,
	"esb", // ARM64_INS_ESB,
	"ext", // ARM64_INS_EXT,
	"extr", // ARM64_INS_EXTR,
	"fabd", // ARM64_INS_FABD,
	"fabs", // ARM64_INS_FABS,
	"facge", // ARM64_INS_FACGE,
	"facgt", // ARM64_INS_FACGT,
	"facle", // ARM64_INS_FACLE,
	"faclt", // ARM64_INS_FACLT,
	"fadd", // ARM64_INS_FADD,
	"fadda", // ARM64_INS_FADDA,
	"faddp", // ARM64_INS_FADDP,
	"faddv", // ARM64_INS_FADDV,
	"fcadd", // ARM64_INS_FCADD,
	"fccmp", // ARM64_INS_FCCMP,
	"fccmpe", // ARM64_INS_FCCMPE,
	"fcmeq", // ARM64_INS_FCMEQ,
	"fcmge", // ARM64_INS_FCMGE,
	"fcmgt", // ARM64_INS_FCMGT,
	"fcmla", // ARM64_INS_FCMLA,
	"fcmle", // ARM64_INS_FCMLE,
	"fcmlt", // ARM64_INS_FCMLT,
	"fcmne", // ARM64_INS_FCMNE,
	"fcmp", // ARM64_INS_FCMP,
	"fcmpe", // ARM64_INS_FCMPE,
	"fcmuo", // ARM64_INS_FCMUO,
	"fcpy", // ARM64_INS_FCPY,
	"fcsel", // ARM64_INS_FCSEL,
	"fcvt", // ARM64_INS_FCVT,
	"fcvtas", // ARM64_INS_FCVTAS,
	"fcvtau", // ARM64_INS_FCVTAU,
	"fcvtl", // ARM64_INS_FCVTL,
	"fcvtl2", // ARM64_INS_FCVTL2,
	"fcvtlt", // ARM64_INS_FCVTLT,
	"fcvtms", // ARM64_INS_FCVTMS,
	"fcvtmu", // ARM64_INS_FCVTMU,
	"fcvtn", // ARM64_INS_FCVTN,
	"fcvtn2", // ARM64_INS_FCVTN2,
	"fcvtns", // ARM64_INS_FCVTNS,
	"fcvtnt", // ARM64_INS_FCVTNT,
	"fcvtnu", // ARM64_INS_FCVTNU,
	"fcvtps", // ARM64_INS_FCVTPS,
	"fcvtpu", // ARM64_INS_FCVTPU,
	"fcvtx", // ARM64_INS_FCVTX,
	"fcvtxn", // ARM64_INS_FCVTXN,
	"fcvtxn2", // ARM64_INS_FCVTXN2,
	"fcvtxnt", // ARM64_INS_FCVTXNT,
	"fcvtzs", // ARM64_INS_FCVTZS,
	"fcvtzu", // ARM64_INS_FCVTZU,
	"fdiv", // ARM64_INS_FDIV,
	"fdivr", // ARM64_INS_FDIVR,
	"fdup", // ARM64_INS_FDUP,
	"fexpa", // ARM64_INS_FEXPA,
	"fjcvtzs", // ARM64_INS_FJCVTZS,
	"flogb", // ARM64_INS_FLOGB,
	"fmad", // ARM64_INS_FMAD,
	"fmadd", // ARM64_INS_FMADD,
	"fmax", // ARM64_INS_FMAX,
	"fmaxnm", // ARM64_INS_FMAXNM,
	"fmaxnmp", // ARM64_INS_FMAXNMP,
	"fmaxnmv", // ARM64_INS_FMAXNMV,
	"fmaxp", // ARM64_INS_FMAXP,
	"fmaxv", // ARM64_INS_FMAXV,
	"fmin", // ARM64_INS_FMIN,
	"fminnm", // ARM64_INS_FMINNM,
	"fminnmp", // ARM64_INS_FMINNMP,
	"fminnmv", // ARM64_INS_FMINNMV,
	"fminp", // ARM64_INS_FMINP,
	"fminv", // ARM64_INS_FMINV,
	"fmla", // ARM64_INS_FMLA,
	"fmlal", // ARM64_INS_FMLAL,
	"fmlal2", // ARM64_INS_FMLAL2,
	"fmlalb", // ARM64_INS_FMLALB,
	"fmlalt", // ARM64_INS_FMLALT,
	"fmls", // ARM64_INS_FMLS,
	"fmlsl", // ARM64_INS_FMLSL,
	"fmlsl2", // ARM64_INS_FMLSL2,
	"fmlslb", // ARM64_INS_FMLSLB,
	"fmlslt", // ARM64_INS_FMLSLT,
	"fmmla", // ARM64_INS_FMMLA,
	"fmopa", // ARM64_INS_FMOPA,
	"fmops", // ARM64_INS_FMOPS,
	"fmov", // ARM64_INS_FMOV,
	"fmsb", // ARM64_INS_FMSB,
	"fmsub", // ARM64_INS_FMSUB,
	"fmul", // ARM64_INS_FMUL,
	"fmulx", // ARM64_INS_FMULX,
	"fneg", // ARM64_INS_FNEG,
	"fnmad", // ARM64_INS_FNMAD,
	"fnmadd", // ARM64_INS_FNMADD,
	"fnmla", // ARM64_INS_FNMLA,
	"fnmls", // ARM64_INS_FNMLS,
	"fnmsb", // ARM64_INS_FNMSB,
	"fnmsub", // ARM64_INS_FNMSUB,
	"fnmul", // ARM64_INS_FNMUL,
	"frecpe", // ARM64_INS_FRECPE,
	"frecps", // ARM64_INS_FRECPS,
	"frecpx", // ARM64_INS_FRECPX,
	"frint32x", // ARM64_INS_FRINT32X,
	"frint32z", // ARM64_INS_FRINT32Z,
	"frint64x", // ARM64_INS_FRINT64X,
	"frint64z", // ARM64_INS_FRINT64Z,
	"frinta", // ARM64_INS_FRINTA,
	"frinti", // ARM64_INS_FRINTI,
	"frintm", // ARM64_INS_FRINTM,
	"frintn", // ARM64_INS_FRINTN,
	"frintp", // ARM64_INS_FRINTP,
	"frintx", // ARM64_INS_FRINTX,
	"frintz", // ARM64_INS_FRINTZ,
	"frsqrte", // ARM64_INS_FRSQRTE,
	"frsqrts", // ARM64_INS_FRSQRTS,
	"fscale", // ARM64_INS_FSCALE,
	"fsqrt", // ARM64_INS_FSQRT,
	"fsub", // ARM64_INS_FSUB,
	"fsubr", // ARM64_INS_FSUBR,
	"ftmad", // ARM64_INS_FTMAD,
	"ftsmul", // ARM64_INS_FTSMUL,
	"ftssel", // ARM64_INS_FTSSEL,
	"gmi", // ARM64_INS_GMI,
	"hint", // ARM64_INS_HINT,
	"histcnt", // ARM64_INS_HISTCNT,
	"histseg", // ARM64_INS_HISTSEG,
	"hlt", // ARM64_INS_HLT,
	"hvc", // ARM64_INS_HVC,
	"incb", // ARM64_INS_INCB,
	"incd", // ARM64_INS_INCD,
	"inch", // ARM64_INS_INCH,
	"incp", // ARM64_INS_INCP,
	"incw", // ARM64_INS_INCW,
	"index", // ARM64_INS_INDEX,
	"ins", // ARM64_INS_INS,
	"insr", // ARM64_INS_INSR,
	"irg", // ARM64_INS_IRG,
	"isb", // ARM64_INS_ISB,
	"lasta", // ARM64_INS_LASTA,
	"lastb", // ARM64_INS_LASTB,
	"ld1", // ARM64_INS_LD1,
	"ld1b", // ARM64_INS_LD1B,
	"ld1d", // ARM64_INS_LD1D,
	"ld1h", // ARM64_INS_LD1H,
	"ld1q", // ARM64_INS_LD1Q,
	"ld1r", // ARM64_INS_LD1R,
	"ld1rb", // ARM64_INS_LD1RB,
	"ld1rd", // ARM64_INS_LD1RD,
	"ld1rh", // ARM64_INS_LD1RH,
	"ld1rob", // ARM64_INS_LD1ROB,
	"ld1rod", // ARM64_INS_LD1ROD,
	"ld1roh", // ARM64_INS_LD1ROH,
	"ld1row", // ARM64_INS_LD1ROW,
	"ld1rqb", // ARM64_INS_LD1RQB,
	"ld1rqd", // ARM64_INS_LD1RQD,
	"ld1rqh", // ARM64_INS_LD1RQH,
	"ld1rqw", // ARM64_INS_LD1RQW,
	"ld1rsb", // ARM64_INS_LD1RSB,
	"ld1rsh", // ARM64_INS_LD1RSH,
	"ld1rsw", // ARM64_INS_LD1RSW,
	"ld1rw", // ARM64_INS_LD1RW,
	"ld1sb", // ARM64_INS_LD1SB,
	"ld1sh", // ARM64_INS_LD1SH,
	"ld1sw", // ARM64_INS_LD1SW,
	"ld1w", // ARM64_INS_LD1W,
	"ld2", // ARM64_INS_LD2,
	"ld2b", // ARM64_INS_LD2B,
	"ld2d", // ARM64_INS_LD2D,
	"ld2h", // ARM64_INS_LD2H,
	"ld2r", // ARM64_INS_LD2R,
	"ld2w", // ARM64_INS_LD2W,
	"ld3", // ARM64_INS_LD3,
	"ld3b", // ARM64_INS_LD3B,
	"ld3d", // ARM64_INS_LD3D,
	"ld3h", // ARM64_INS_LD3H,
	"ld3r", // ARM64_INS_LD3R,
	"ld3w", // ARM64_INS_LD3W,
	"ld4", // ARM64_INS_LD4,
	"ld4b", // ARM64_INS_LD4B,
	"ld4d", // ARM64_INS_LD4D,
	"ld4h", // ARM64_INS_LD4H,
	"ld4r", // ARM64_INS_LD4R,
	"ld4w", // ARM64_INS_LD4W,
	"ld64b", // ARM64_INS_LD64B,
	"ldadd", // ARM64_INS_LDADD,
	"ldadda", // ARM64_INS_LDADDA,
	"ldaddab", // ARM64_INS_LDADDAB,
	"ldaddah", // ARM64_INS_LDADDAH,
	"ldaddal", // ARM64_INS_LDADDAL,
	"ldaddalb", // ARM64_INS_LDADDALB,
	"ldaddalh", // ARM64_INS_LDADDALH,
	"ldaddb", // ARM64_INS_LDADDB,
	"ldaddh", // ARM64_INS_LDADDH,
	"ldaddl", // ARM64_INS_LDADDL,
	"ldaddlb", // ARM64_INS_LDADDLB,
	"ldaddlh", // ARM64_INS_LDADDLH,
	"ldapr", // ARM64_INS_LDAPR,
	"ldaprb", // ARM64_INS_LDAPRB,
	"ldaprh", // ARM64_INS_LDAPRH,
	"ldapur", // ARM64_INS_LDAPUR,
	"ldapurb", // ARM64_INS_LDAPURB,
	"ldapurh", // ARM64_INS_LDAPURH,
	"ldapursb", // ARM64_INS_LDAPURSB,
	"ldapursh", // ARM64_INS_LDAPURSH,
	"ldapursw", // ARM64_INS_LDAPURSW,
	"ldar", // ARM64_INS_LDAR,
	"ldarb", // ARM64_INS_LDARB,
	"ldarh", // ARM64_INS_LDARH,
	"ldaxp", // ARM64_INS_LDAXP,
	"ldaxr", // ARM64_INS_LDAXR,
	"ldaxrb", // ARM64_INS_LDAXRB,
	"ldaxrh", // ARM64_INS_LDAXRH,
	"ldclr", // ARM64_INS_LDCLR,
	"ldclra", // ARM64_INS_LDCLRA,
	"ldclrab", // ARM64_INS_LDCLRAB,
	"ldclrah", // ARM64_INS_LDCLRAH,
	"ldclral", // ARM64_INS_LDCLRAL,
	"ldclralb", // ARM64_INS_LDCLRALB,
	"ldclralh", // ARM64_INS_LDCLRALH,
	"ldclrb", // ARM64_INS_LDCLRB,
	"ldclrh", // ARM64_INS_LDCLRH,
	"ldclrl", // ARM64_INS_LDCLRL,
	"ldclrlb", // ARM64_INS_LDCLRLB,
	"ldclrlh", // ARM64_INS_LDCLRLH,
	"ldeor", // ARM64_INS_LDEOR,
	"ldeora", // ARM64_INS_LDEORA,
	"ldeorab", // ARM64_INS_LDEORAB,
	"ldeorah", // ARM64_INS_LDEORAH,
	"ldeoral", // ARM64_INS_LDEORAL,
	"ldeoralb", // ARM64_INS_LDEORALB,
	"ldeoralh", // ARM64_INS_LDEORALH,
	"ldeorb", // ARM64_INS_LDEORB,
	"ldeorh", // ARM64_INS_LDEORH,
	"ldeorl", // ARM64_INS_LDEORL,
	"ldeorlb", // ARM64_INS_LDEORLB,
	"ldeorlh", // ARM64_INS_LDEORLH,
	"ldff1b", // ARM64_INS_LDFF1B,
	"ldff1d", // ARM64_INS_LDFF1D,
	"ldff1h", // ARM64_INS_LDFF1H,
	"ldff1sb", // ARM64_INS_LDFF1SB,
	"ldff1sh", // ARM64_INS_LDFF1SH,
	"ldff1sw", // ARM64_INS_LDFF1SW,
	"ldff1w", // ARM64_INS_LDFF1W,
	"ldg", // ARM64_INS_LDG,
	"ldgm", // ARM64_INS_LDGM,
	"ldlar", // ARM64_INS_LDLAR,
	"ldlarb", // ARM64_INS_LDLARB,
	"ldlarh", // ARM64_INS_LDLARH,
	"ldnf1b", // ARM64_INS_LDNF1B,
	"ldnf1d", // ARM64_INS_LDNF1D,
	"ldnf1h", // ARM64_INS_LDNF1H,
	"ldnf1sb", // ARM64_INS_LDNF1SB,
	"ldnf1sh", // ARM64_INS_LDNF1SH,
	"ldnf1sw", // ARM64_INS_LDNF1SW,
	"ldnf1w", // ARM64_INS_LDNF1W,
	"ldnp", // ARM64_INS_LDNP,
	"ldnt1b", // ARM64_INS_LDNT1B,
	"ldnt1d", // ARM64_INS_LDNT1D,
	"ldnt1h", // ARM64_INS_LDNT1H,
	"ldnt1sb", // ARM64_INS_LDNT1SB,
	"ldnt1sh", // ARM64_INS_LDNT1SH,
	"ldnt1sw", // ARM64_INS_LDNT1SW,
	"ldnt1w", // ARM64_INS_LDNT1W,
	"ldp", // ARM64_INS_LDP,
	"ldpsw", // ARM64_INS_LDPSW,
	"ldr", // ARM64_INS_LDR,
	"ldraa", // ARM64_INS_LDRAA,
	"ldrab", // ARM64_INS_LDRAB,
	"ldrb", // ARM64_INS_LDRB,
	"ldrh", // ARM64_INS_LDRH,
	"ldrsb", // ARM64_INS_LDRSB,
	"ldrsh", // ARM64_INS_LDRSH,
	"ldrsw", // ARM64_INS_LDRSW,
	"ldset", // ARM64_INS_LDSET,
	"ldseta", // ARM64_INS_LDSETA,
	"ldsetab", // ARM64_INS_LDSETAB,
	"ldsetah", // ARM64_INS_LDSETAH,
	"ldsetal", // ARM64_INS_LDSETAL,
	"ldsetalb", // ARM64_INS_LDSETALB,
	"ldsetalh", // ARM64_INS_LDSETALH,
	"ldsetb", // ARM64_INS_LDSETB,
	"ldseth", // ARM64_INS_LDSETH,
	"ldsetl", // ARM64_INS_LDSETL,
	"ldsetlb", // ARM64_INS_LDSETLB,
	"ldsetlh", // ARM64_INS_LDSETLH,
	"ldsmax", // ARM64_INS_LDSMAX,
	"ldsmaxa", // ARM64_INS_LDSMAXA,
	"ldsmaxab", // ARM64_INS_LDSMAXAB,
	"ldsmaxah", // ARM64_INS_LDSMAXAH,
	"ldsmaxal", // ARM64_INS_LDSMAXAL,
	"ldsmaxalb", // ARM64_INS_LDSMAXALB,
	"ldsmaxalh", // ARM64_INS_LDSMAXALH,
	"ldsmaxb", // ARM64_INS_LDSMAXB,
	"ldsmaxh", // ARM64_INS_LDSMAXH,
	"ldsmaxl", // ARM64_INS_LDSMAXL,
	"ldsmaxlb", // ARM64_INS_LDSMAXLB,
	"ldsmaxlh", // ARM64_INS_LDSMAXLH,
	"ldsmin", // ARM64_INS_LDSMIN,
	"ldsmina", // ARM64_INS_LDSMINA,
	"ldsminab", // ARM64_INS_LDSMINAB,
	"ldsminah", // ARM64_INS_LDSMINAH,
	"ldsminal", // ARM64_INS_LDSMINAL,
	"ldsminalb", // ARM64_INS_LDSMINALB,
	"ldsminalh", // ARM64_INS_LDSMINALH,
	"ldsminb", // ARM64_INS_LDSMINB,
	"ldsminh", // ARM64_INS_LDSMINH,
	"ldsminl", // ARM64_INS_LDSMINL,
	"ldsminlb", // ARM64_INS_LDSMINLB,
	"ldsminlh", // ARM64_INS_LDSMINLH,
	"ldtr", // ARM64_INS_LDTR,
	"ldtrb", // ARM64_INS_LDTRB,
	"ldtrh", // ARM64_INS_LDTRH,
	"ldtrsb", // ARM64_INS_LDTRSB,
	"ldtrsh", // ARM64_INS_LDTRSH,
	"ldtrsw", // ARM64_INS_LDTRSW,
	"ldumax", // ARM64_INS_LDUMAX,
	"ldumaxa", // ARM64_INS_LDUMAXA,
	"ldumaxab", // ARM64_INS_LDUMAXAB,
	"ldumaxah", // ARM64_INS_LDUMAXAH,
	"ldumaxal", // ARM64_INS_LDUMAXAL,
	"ldumaxalb", // ARM64_INS_LDUMAXALB,
	"ldumaxalh", // ARM64_INS_LDUMAXALH,
	"ldumaxb", // ARM64_INS_LDUMAXB,
	"ldumaxh", // ARM64_INS_LDUMAXH,
	"ldumaxl", // ARM64_INS_LDUMAXL,
	"ldumaxlb", // ARM64_INS_LDUMAXLB,
	"ldumaxlh", // ARM64_INS_LDUMAXLH,
	"ldumin", // ARM64_INS_LDUMIN,
	"ldumina", // ARM64_INS_LDUMINA,
	"lduminab", // ARM64_INS_LDUMINAB,
	"lduminah", // ARM64_INS_LDUMINAH,
	"lduminal", // ARM64_INS_LDUMINAL,
	"lduminalb", // ARM64_INS_LDUMINALB,
	"lduminalh", // ARM64_INS_LDUMINALH,
	"lduminb", // ARM64_INS_LDUMINB,
	"lduminh", // ARM64_INS_LDUMINH,
	"lduminl", // ARM64_INS_LDUMINL,
	"lduminlb", // ARM64_INS_LDUMINLB,
	"lduminlh", // ARM64_INS_LDUMINLH,
	"ldur", // ARM64_INS_LDUR,
	"ldurb", // ARM64_INS_LDURB,
	"ldurh", // ARM64_INS_LDURH,
	"ldursb", // ARM64_INS_LDURSB,
	"ldursh", // ARM64_INS_LDURSH,
	"ldursw", // ARM64_INS_LDURSW,
	"ldxp", // ARM64_INS_LDXP,
	"ldxr", // ARM64_INS_LDXR,
	"ldxrb", // ARM64_INS_LDXRB,
	"ldxrh", // ARM64_INS_LDXRH,
	"lsl", // ARM64_INS_LSL,
	"lslr", // ARM64_INS_LSLR,
	"lslv", // ARM64_INS_LSLV,
	"lsr", // ARM64_INS_LSR,
	"lsrr", // ARM64_INS_LSRR,
	"lsrv", // ARM64_INS_LSRV,
	"mad", // ARM64_INS_MAD,
	"madd", // ARM64_INS_MADD,
	"match", // ARM64_INS_MATCH,
	"mla", // ARM64_INS_MLA,
	"mls", // ARM64_INS_MLS,
	"mneg", // ARM64_INS_MNEG,
	"mov", // ARM64_INS_MOV,
	"mova", // ARM64_INS_MOVA,
	"movi", // ARM64_INS_MOVI,
	"movk", // ARM64_INS_MOVK,
	"movn", // ARM64_INS_MOVN,
	"movprfx", // ARM64_INS_MOVPRFX,
	"movs", // ARM64_INS_MOVS,
	"movz", // ARM64_INS_MOVZ,
	"mrs", // ARM64_INS_MRS,
	"msb", // ARM64_INS_MSB,
	"msr", // ARM64_INS_MSR,
	"msub", // ARM64_INS_MSUB,
	"mul", // ARM64_INS_MUL,
	"mvn", // ARM64_INS_MVN,
	"mvni", // ARM64_INS_MVNI,
	"nand", // ARM64_INS_NAND,
	"nands", // ARM64_INS_NANDS,
	"nbsl", // ARM64_INS_NBSL,
	"neg", // ARM64_INS_NEG,
	"negs", // ARM64_INS_NEGS,
	"ngc", // ARM64_INS_NGC,
	"ngcs", // ARM64_INS_NGCS,
	"nmatch", // ARM64_INS_NMATCH,
	"nop", // ARM64_INS_NOP,
	"nor", // ARM64_INS_NOR,
	"nors", // ARM64_INS_NORS,
	"not", // ARM64_INS_NOT,
	"nots", // ARM64_INS_NOTS,
	"orn", // ARM64_INS_ORN,
	"orns", // ARM64_INS_ORNS,
	"orr", // ARM64_INS_ORR,
	"orrs", // ARM64_INS_ORRS,
	"orv", // ARM64_INS_ORV,
	"pacda", // ARM64_INS_PACDA,
	"pacdb", // ARM64_INS_PACDB,
	"pacdza", // ARM64_INS_PACDZA,
	"pacdzb", // ARM64_INS_PACDZB,
	"pacga", // ARM64_INS_PACGA,
	"pacia", // ARM64_INS_PACIA,
	"pacia1716", // ARM64_INS_PACIA1716,
	"paciasp", // ARM64_INS_PACIASP,
	"paciaz", // ARM64_INS_PACIAZ,
	"pacib", // ARM64_INS_PACIB,
	"pacib1716", // ARM64_INS_PACIB1716,
	"pacibsp", // ARM64_INS_PACIBSP,
	"pacibz", // ARM64_INS_PACIBZ,
	"paciza", // ARM64_INS_PACIZA,
	"pacizb", // ARM64_INS_PACIZB,
	"pfalse", // ARM64_INS_PFALSE,
	"pfirst", // ARM64_INS_PFIRST,
	"pmul", // ARM64_INS_PMUL,
	"pmull", // ARM64_INS_PMULL,
	"pmull2", // ARM64_INS_PMULL2,
	"pmullb", // ARM64_INS_PMULLB,
	"pmullt", // ARM64_INS_PMULLT,
	"pnext", // ARM64_INS_PNEXT,
	"prfb", // ARM64_INS_PRFB,
	"prfd", // ARM64_INS_PRFD,
	"prfh", // ARM64_INS_PRFH,
	"prfm", // ARM64_INS_PRFM,
	"prfum", // ARM64_INS_PRFUM,
	"prfw", // ARM64_INS_PRFW,
	"psb", // ARM64_INS_PSB,
	"psel", // ARM64_INS_PSEL,
	"pssbb", // ARM64_INS_PSSBB,
	"ptest", // ARM64_INS_PTEST,
	"ptrue", // ARM64_INS_PTRUE,
	"ptrues", // ARM64_INS_PTRUES,
	"punpkhi", // ARM64_INS_PUNPKHI,
	"punpklo", // ARM64_INS_PUNPKLO,
	"raddhn", // ARM64_INS_RADDHN,
	"raddhn2", // ARM64_INS_RADDHN2,
	"raddhnb", // ARM64_INS_RADDHNB,
	"raddhnt", // ARM64_INS_RADDHNT,
	"rax1", // ARM64_INS_RAX1,
	"rbit", // ARM64_INS_RBIT,
	"rdffr", // ARM64_INS_RDFFR,
	"rdffrs", // ARM64_INS_RDFFRS,
	"rdvl", // ARM64_INS_RDVL,
	"ret", // ARM64_INS_RET,
	"retaa", // ARM64_INS_RETAA,
	"retab", // ARM64_INS_RETAB,
	"rev", // ARM64_INS_REV,
	"rev16", // ARM64_INS_REV16,
	"rev32", // ARM64_INS_REV32,
	"rev64", // ARM64_INS_REV64,
	"revb", // ARM64_INS_REVB,
	"revd", // ARM64_INS_REVD,
	"revh", // ARM64_INS_REVH,
	"revw", // ARM64_INS_REVW,
	"rmif", // ARM64_INS_RMIF,
	"ror", // ARM64_INS_ROR,
	"rorv", // ARM64_INS_RORV,
	"rshrn", // ARM64_INS_RSHRN,
	"rshrn2", // ARM64_INS_RSHRN2,
	"rshrnb", // ARM64_INS_RSHRNB,
	"rshrnt", // ARM64_INS_RSHRNT,
	"rsubhn", // ARM64_INS_RSUBHN,
	"rsubhn2", // ARM64_INS_RSUBHN2,
	"rsubhnb", // ARM64_INS_RSUBHNB,
	"rsubhnt", // ARM64_INS_RSUBHNT,
	"saba", // ARM64_INS_SABA,
	"sabal", // ARM64_INS_SABAL,
	"sabal2", // ARM64_INS_SABAL2,
	"sabalb", // ARM64_INS_SABALB,
	"sabalt", // ARM64_INS_SABALT,
	"sabd", // ARM64_INS_SABD,
	"sabdl", // ARM64_INS_SABDL,
	"sabdl2", // ARM64_INS_SABDL2,
	"sabdlb", // ARM64_INS_SABDLB,
	"sabdlt", // ARM64_INS_SABDLT,
	"sadalp", // ARM64_INS_SADALP,
	"saddl", // ARM64_INS_SADDL,
	"saddl2", // ARM64_INS_SADDL2,
	"saddlb", // ARM64_INS_SADDLB,
	"saddlbt", // ARM64_INS_SADDLBT,
	"saddlp", // ARM64_INS_SADDLP,
	"saddlt", // ARM64_INS_SADDLT,
	"saddlv", // ARM64_INS_SADDLV,
	"saddv", // ARM64_INS_SADDV,
	"saddw", // ARM64_INS_SADDW,
	"saddw2", // ARM64_INS_SADDW2,
	"saddwb", // ARM64_INS_SADDWB,
	"saddwt", // ARM64_INS_SADDWT,
	"sb", // ARM64_INS_SB,
	"sbc", // ARM64_INS_SBC,
	"sbclb", // ARM64_INS_SBCLB,
	"sbclt", // ARM64_INS_SBCLT,
	"sbcs", // ARM64_INS_SBCS,
	"sbfm", // ARM64_INS_SBFM,
	"sclamp", // ARM64_INS_SCLAMP,
	"scvtf", // ARM64_INS_SCVTF,
	"sdiv", // ARM64_INS_SDIV,
	"sdivr", // ARM64_INS_SDIVR,
	"sdot", // ARM64_INS_SDOT,
	"sel", // ARM64_INS_SEL,
	"sete", // ARM64_INS_SETE,
	"seten", // ARM64_INS_SETEN,
	"setet", // ARM64_INS_SETET,
	"setetn", // ARM64_INS_SETETN,
	"setf16", // ARM64_INS_SETF16,
	"setf8", // ARM64_INS_SETF8,
	"setffr", // ARM64_INS_SETFFR,
	"setge", // ARM64_INS_SETGE,
	"setgen", // ARM64_INS_SETGEN,
	"setget", // ARM64_INS_SETGET,
	"setgetn", // ARM64_INS_SETGETN,
	"setgm", // ARM64_INS_SETGM,
	"setgmn", // ARM64_INS_SETGMN,
	"setgmt", // ARM64_INS_SETGMT,
	"setgmtn", // ARM64_INS_SETGMTN,
	"setgp", // ARM64_INS_SETGP,
	"setgpn", // ARM64_INS_SETGPN,
	"setgpt", // ARM64_INS_SETGPT,
	"setgptn", // ARM64_INS_SETGPTN,
	"setm", // ARM64_INS_SETM,
	"setmn", // ARM64_INS_SETMN,
	"setmt", // ARM64_INS_SETMT,
	"setmtn", // ARM64_INS_SETMTN,
	"setp", // ARM64_INS_SETP,
	"setpn", // ARM64_INS_SETPN,
	"setpt", // ARM64_INS_SETPT,
	"setptn", // ARM64_INS_SETPTN,
	"sev", // ARM64_INS_SEV,
	"sevl", // ARM64_INS_SEVL,
	"sha1c", // ARM64_INS_SHA1C,
	"sha1h", // ARM64_INS_SHA1H,
	"sha1m", // ARM64_INS_SHA1M,
	"sha1p", // ARM64_INS_SHA1P,
	"sha1su0", // ARM64_INS_SHA1SU0,
	"sha1su1", // ARM64_INS_SHA1SU1,
	"sha256h", // ARM64_INS_SHA256H,
	"sha256h2", // ARM64_INS_SHA256H2,
	"sha256su0", // ARM64_INS_SHA256SU0,
	"sha256su1", // ARM64_INS_SHA256SU1,
	"sha512h", // ARM64_INS_SHA512H,
	"sha512h2", // ARM64_INS_SHA512H2,
	"sha512su0", // ARM64_INS_SHA512SU0,
	"sha512su1", // ARM64_INS_SHA512SU1,
	"shadd", // ARM64_INS_SHADD,
	"shl", // ARM64_INS_SHL,
	"shll", // ARM64_INS_SHLL,
	"shll2", // ARM64_INS_SHLL2,
	"shrn", // ARM64_INS_SHRN,
	"shrn2", // ARM64_INS_SHRN2,
	"shrnb", // ARM64_INS_SHRNB,
	"shrnt", // ARM64_INS_SHRNT,
	"shsub", // ARM64_INS_SHSUB,
	"shsubr", // ARM64_INS_SHSUBR,
	"sli", // ARM64_INS_SLI,
	"sm3partw1", // ARM64_INS_SM3PARTW1,
	"sm3partw2", // ARM64_INS_SM3PARTW2,
	"sm3ss1", // ARM64_INS_SM3SS1,
	"sm3tt1a", // ARM64_INS_SM3TT1A,
	"sm3tt1b", // ARM64_INS_SM3TT1B,
	"sm3tt2a", // ARM64_INS_SM3TT2A,
	"sm3tt2b", // ARM64_INS_SM3TT2B,
	"sm4e", // ARM64_INS_SM4E,
	"sm4ekey", // ARM64_INS_SM4EKEY,
	"smaddl", // ARM64_INS_SMADDL,
	"smax", // ARM64_INS_SMAX,
	"smaxp", // ARM64_INS_SMAXP,
	"smaxv", // ARM64_INS_SMAXV,
	"smc", // ARM64_INS_SMC,
	"smin", // ARM64_INS_SMIN,
	"sminp", // ARM64_INS_SMINP,
	"sminv", // ARM64_INS_SMINV,
	"smlal", // ARM64_INS_SMLAL,
	"smlal2", // ARM64_INS_SMLAL2,
	"smlalb", // ARM64_INS_SMLALB,
	"smlalt", // ARM64_INS_SMLALT,
	"smlsl", // ARM64_INS_SMLSL,
	"smlsl2", // ARM64_INS_SMLSL2,
	"smlslb", // ARM64_INS_SMLSLB,
	"smlslt", // ARM64_INS_SMLSLT,
	"smmla", // ARM64_INS_SMMLA,
	"smnegl", // ARM64_INS_SMNEGL,
	"smopa", // ARM64_INS_SMOPA,
	"smops", // ARM64_INS_SMOPS,
	"smov", // ARM64_INS_SMOV,
	"smstart", // ARM64_INS_SMSTART,
	"smstop", // ARM64_INS_SMSTOP,
	"smsubl", // ARM64_INS_SMSUBL,
	"smulh", // ARM64_INS_SMULH,
	"smull", // ARM64_INS_SMULL,
	"smull2", // ARM64_INS_SMULL2,
	"smullb", // ARM64_INS_SMULLB,
	"smullt", // ARM64_INS_SMULLT,
	"splice", // ARM64_INS_SPLICE,
	"sqabs", // ARM64_INS_SQABS,
	"sqadd", // ARM64_INS_SQADD,
	"sqcadd", // ARM64_INS_SQCADD,
	"sqdecb", // ARM64_INS_SQDECB,
	"sqdecd", // ARM64_INS_SQDECD,
	"sqdech", // ARM64_INS_SQDECH,
	"sqdecp", // ARM64_INS_SQDECP,
	"sqdecw", // ARM64_INS_SQDECW,
	"sqdmlal", // ARM64_INS_SQDMLAL,
	"sqdmlal2", // ARM64_INS_SQDMLAL2,
	"sqdmlalb", // ARM64_INS_SQDMLALB,
	"sqdmlalbt", // ARM64_INS_SQDMLALBT,
	"sqdmlalt", // ARM64_INS_SQDMLALT,
	"sqdmlsl", // ARM64_INS_SQDMLSL,
	"sqdmlsl2", // ARM64_INS_SQDMLSL2,
	"sqdmlslb", // ARM64_INS_SQDMLSLB,
	"sqdmlslbt", // ARM64_INS_SQDMLSLBT,
	"sqdmlslt", // ARM64_INS_SQDMLSLT,
	"sqdmulh", // ARM64_INS_SQDMULH,
	"sqdmull", // ARM64_INS_SQDMULL,
	"sqdmull2", // ARM64_INS_SQDMULL2,
	"sqdmullb", // ARM64_INS_SQDMULLB,
	"sqdmullt", // ARM64_INS_SQDMULLT,
	"sqincb", // ARM64_INS_SQINCB,
	"sqincd", // ARM64_INS_SQINCD,
	"sqinch", // ARM64_INS_SQINCH,
	"sqincp", // ARM64_INS_SQINCP,
	"sqincw", // ARM64_INS_SQINCW,
	"sqneg", // ARM64_INS_SQNEG,
	"sqrdcmlah", // ARM64_INS_SQRDCMLAH,
	"sqrdmlah", // ARM64_INS_SQRDMLAH,
	"sqrdmlsh", // ARM64_INS_SQRDMLSH,
	"sqrdmulh", // ARM64_INS_SQRDMULH,
	"sqrshl", // ARM64_INS_SQRSHL,
	"sqrshlr", // ARM64_INS_SQRSHLR,
	"sqrshrn", // ARM64_INS_SQRSHRN,
	"sqrshrn2", // ARM64_INS_SQRSHRN2,
	"sqrshrnb", // ARM64_INS_SQRSHRNB,
	"sqrshrnt", // ARM64_INS_SQRSHRNT,
	"sqrshrun", // ARM64_INS_SQRSHRUN,
	"sqrshrun2", // ARM64_INS_SQRSHRUN2,
	"sqrshrunb", // ARM64_INS_SQRSHRUNB,
	"sqrshrunt", // ARM64_INS_SQRSHRUNT,
	"sqshl", // ARM64_INS_SQSHL,
	"sqshlr", // ARM64_INS_SQSHLR,
	"sqshlu", // ARM64_INS_SQSHLU,
	"sqshrn", // ARM64_INS_SQSHRN,
	"sqshrn2", // ARM64_INS_SQSHRN2,
	"sqshrnb", // ARM64_INS_SQSHRNB,
	"sqshrnt", // ARM64_INS_SQSHRNT,
	"sqshrun", // ARM64_INS_SQSHRUN,
	"sqshrun2", // ARM64_INS_SQSHRUN2,
	"sqshrunb", // ARM64_INS_SQSHRUNB,
	"sqshrunt", // ARM64_INS_SQSHRUNT,
	"sqsub", // ARM64_INS_SQSUB,
	"sqsubr", // ARM64_INS_SQSUBR,
	"sqxtn", // ARM64_INS_SQXTN,
	"sqxtn2", // ARM64_INS_SQXTN2,
	"sqxtnb", // ARM64_INS_SQXTNB,
	"sqxtnt", // ARM64_INS_SQXTNT,
	"sqxtun", // ARM64_INS_SQXTUN,
	"sqxtun2", // ARM64_INS_SQXTUN2,
	"sqxtunb", // ARM64_INS_SQXTUNB,
	"sqxtunt", // ARM64_INS_SQXTUNT,
	"srhadd", // ARM64_INS_SRHADD,
	"sri", // ARM64_INS_SRI,
	"srshl", // ARM64_INS_SRSHL,
	"srshlr", // ARM64_INS_SRSHLR,
	"srshr", // ARM64_INS_SRSHR,
	"srsra", // ARM64_INS_SRSRA,
	"ssbb", // ARM64_INS_SSBB,
	"sshl", // ARM64_INS_SSHL,
	"sshll", // ARM64_INS_SSHLL,
	"sshll2", // ARM64_INS_SSHLL2,
	"sshllb", // ARM64_INS_SSHLLB,
	"sshllt", // ARM64_INS_SSHLLT,
	"sshr", // ARM64_INS_SSHR,
	"ssra", // ARM64_INS_SSRA,
	"ssubl", // ARM64_INS_SSUBL,
	"ssubl2", // ARM64_INS_SSUBL2,
	"ssublb", // ARM64_INS_SSUBLB,
	"ssublbt", // ARM64_INS_SSUBLBT,
	"ssublt", // ARM64_INS_SSUBLT,
	"ssubltb", // ARM64_INS_SSUBLTB,
	"ssubw", // ARM64_INS_SSUBW,
	"ssubw2", // ARM64_INS_SSUBW2,
	"ssubwb", // ARM64_INS_SSUBWB,
	"ssubwt", // ARM64_INS_SSUBWT,
	"st1", // ARM64_INS_ST1,
	"st1b", // ARM64_INS_ST1B,
	"st1d", // ARM64_INS_ST1D,
	"st1h", // ARM64_INS_ST1H,
	"st1q", // ARM64_INS_ST1Q,
	"st1w", // ARM64_INS_ST1W,
	"st2", // ARM64_INS_ST2,
	"st2b", // ARM64_INS_ST2B,
	"st2d", // ARM64_INS_ST2D,
	"st2g", // ARM64_INS_ST2G,
	"st2h", // ARM64_INS_ST2H,
	"st2w", // ARM64_INS_ST2W,
	"st3", // ARM64_INS_ST3,
	"st3b", // ARM64_INS_ST3B,
	"st3d", // ARM64_INS_ST3D,
	"st3h", // ARM64_INS_ST3H,
	"st3w", // ARM64_INS_ST3W,
	"st4", // ARM64_INS_ST4,
	"st4b", // ARM64_INS_ST4B,
	"st4d", // ARM64_INS_ST4D,
	"st4h", // ARM64_INS_ST4H,
	"st4w", // ARM64_INS_ST4W,
	"st64b", // ARM64_INS_ST64B,
	"st64bv", // ARM64_INS_ST64BV,
	"st64bv0", // ARM64_INS_ST64BV0,
	"stadd", // ARM64_INS_STADD,
	"staddb", // ARM64_INS_STADDB,
	"staddh", // ARM64_INS_STADDH,
	"staddl", // ARM64_INS_STADDL,
	"staddlb", // ARM64_INS_STADDLB,
	"staddlh", // ARM64_INS_STADDLH,
	"stclr", // ARM64_INS_STCLR,
	"stclrb", // ARM64_INS_STCLRB,
	"stclrh", // ARM64_INS_STCLRH,
	"stclrl", // ARM64_INS_STCLRL,
	"stclrlb", // ARM64_INS_STCLRLB,
	"stclrlh", // ARM64_INS_STCLRLH,
	"steor", // ARM64_INS_STEOR,
	"steorb", // ARM64_INS_STEORB,
	"steorh", // ARM64_INS_STEORH,
	"steorl", // ARM64_INS_STEORL,
	"steorlb", // ARM64_INS_STEORLB,
	"steorlh", // ARM64_INS_STEORLH,
	"stg", // ARM64_INS_STG,
	"stgm", // ARM64_INS_STGM,
	"stgp", // ARM64_INS_STGP,
	"stllr", // ARM64_INS_STLLR,
	"stllrb", // ARM64_INS_STLLRB,
	"stllrh", // ARM64_INS_STLLRH,
	"stlr", // ARM64_INS_STLR,
	"stlrb", // ARM64_INS_STLRB,
	"stlrh", // ARM64_INS_STLRH,
	"stlur", // ARM64_INS_STLUR,
	"stlurb", // ARM64_INS_STLURB,
	"stlurh", // ARM64_INS_STLURH,
	"stlxp", // ARM64_INS_STLXP,
	"stlxr", // ARM64_INS_STLXR,
	"stlxrb", // ARM64_INS_STLXRB,
	"stlxrh", // ARM64_INS_STLXRH,
	"stnp", // ARM64_INS_STNP,
	"stnt1b", // ARM64_INS_STNT1B,
	"stnt1d", // ARM64_INS_STNT1D,
	"stnt1h", // ARM64_INS_STNT1H,
	"stnt1w", // ARM64_INS_STNT1W,
	"stp", // ARM64_INS_STP,
	"str", // ARM64_INS_STR,
	"strb", // ARM64_INS_STRB,
	"strh", // ARM64_INS_STRH,
	"stset", // ARM64_INS_STSET,
	"stsetb", // ARM64_INS_STSETB,
	"stseth", // ARM64_INS_STSETH,
	"stsetl", // ARM64_INS_STSETL,
	"stsetlb", // ARM64_INS_STSETLB,
	"stsetlh", // ARM64_INS_STSETLH,
	"stsmax", // ARM64_INS_STSMAX,
	"stsmaxb", // ARM64_INS_STSMAXB,
	"stsmaxh", // ARM64_INS_STSMAXH,
	"stsmaxl", // ARM64_INS_STSMAXL,
	"stsmaxlb", // ARM64_INS_STSMAXLB,
	"stsmaxlh", // ARM64_INS_STSMAXLH,
	"stsmin", // ARM64_INS_STSMIN,
	"stsminb", // ARM64_INS_STSMINB,
	"stsminh", // ARM64_INS_STSMINH,
	"stsminl", // ARM64_INS_STSMINL,
	"stsminlb", // ARM64_INS_STSMINLB,
	"stsminlh", // ARM64_INS_STSMINLH,
	"sttr", // ARM64_INS_STTR,
	"sttrb", // ARM64_INS_STTRB,
	"sttrh", // ARM64_INS_STTRH,
	"stumax", // ARM64_INS_STUMAX,
	"stumaxb", // ARM64_INS_STUMAXB,
	"stumaxh", // ARM64_INS_STUMAXH,
	"stumaxl", // ARM64_INS_STUMAXL,
	"stumaxlb", // ARM64_INS_STUMAXLB,
	"stumaxlh", // ARM64_INS_STUMAXLH,
	"stumin", // ARM64_INS_STUMIN,
	"stuminb", // ARM64_INS_STUMINB,
	"stuminh", // ARM64_INS_STUMINH,
	"stuminl", // ARM64_INS_STUMINL,
	"stuminlb", // ARM64_INS_STUMINLB,
	"stuminlh", // ARM64_INS_STUMINLH,
	"stur", // ARM64_INS_STUR,
	"sturb", // ARM64_INS_STURB,
	"sturh", // ARM64_INS_STURH,
	"stxp", // ARM64_INS_STXP,
	"stxr", // ARM64_INS_STXR,
	"stxrb", // ARM64_INS_STXRB,
	"stxrh", // ARM64_INS_STXRH,
	"stz2g", // ARM64_INS_STZ2G,
	"stzg", // ARM64_INS_STZG,
	"stzgm", // ARM64_INS_STZGM,
	"sub", // ARM64_INS_SUB,
	"subg", // ARM64_INS_SUBG,
	"subhn", // ARM64_INS_SUBHN,
	"subhn2", // ARM64_INS_SUBHN2,
	"subhnb", // ARM64_INS_SUBHNB,
	"subhnt", // ARM64_INS_SUBHNT,
	"subp", // ARM64_INS_SUBP,
	"subps", // ARM64_INS_SUBPS,
	"subr", // ARM64_INS_SUBR,
	"subs", // ARM64_INS_SUBS,
	"sudot", // ARM64_INS_SUDOT,
	"sumopa", // ARM64_INS_SUMOPA,
	"sumops", // ARM64_INS_SUMOPS,
	"sunpkhi", // ARM64_INS_SUNPKHI,
	"sunpklo", // ARM64_INS_SUNPKLO,
	"suqadd", // ARM64_INS_SUQADD,
	"svc", // ARM64_INS_SVC,
	"swp", // ARM64_INS_SWP,
	"swpa", // ARM64_INS_SWPA,
	"swpab", // ARM64_INS_SWPAB,
	"swpah", // ARM64_INS_SWPAH,
	"swpal", // ARM64_INS_SWPAL,
	"swpalb", // ARM64_INS_SWPALB,
	"swpalh", // ARM64_INS_SWPALH,
	"swpb", // ARM64_INS_SWPB,
	"swph", // ARM64_INS_SWPH,
	"swpl", // ARM64_INS_SWPL,
	"swplb", // ARM64_INS_SWPLB,
	"swplh", // ARM64_INS_SWPLH,
	"sxtb", // ARM64_INS_SXTB,
	"sxth", // ARM64_INS_SXTH,
	"sxtl", // ARM64_INS_SXTL,
	"sxtl2", // ARM64_INS_SXTL2,
	"sxtw", // ARM64_INS_SXTW,
	"sys", // ARM64_INS_SYS,
	"sysl", // ARM64_INS_SYSL,
	"tbl", // ARM64_INS_TBL,
	"tbnz", // ARM64_INS_TBNZ,
	"tbx", // ARM64_INS_TBX,
	"tbz", // ARM64_INS_TBZ,
	"tcancel", // ARM64_INS_TCANCEL,
	"tcommit", // ARM64_INS_TCOMMIT,
	"trn1", // ARM64_INS_TRN1,
	"trn2", // ARM64_INS_TRN2,
	"tsb", // ARM64_INS_TSB,
	"tst", // ARM64_INS_TST,
	"tstart", // ARM64_INS_TSTART,
	"ttest", // ARM64_INS_TTEST,
	"uaba", // ARM64_INS_UABA,
	"uabal", // ARM64_INS_UABAL,
	"uabal2", // ARM64_INS_UABAL2,
	"uabalb", // ARM64_INS_UABALB,
	"uabalt", // ARM64_INS_UABALT,
	"uabd", // ARM64_INS_UABD,
	"uabdl", // ARM64_INS_UABDL,
	"uabdl2", // ARM64_INS_UABDL2,
	"uabdlb", // ARM64_INS_UABDLB,
	"uabdlt", // ARM64_INS_UABDLT,
	"uadalp", // ARM64_INS_UADALP,
	"uaddl", // ARM64_INS_UADDL,
	"uaddl2", // ARM64_INS_UADDL2,
	"uaddlb", // ARM64_INS_UADDLB,
	"uaddlp", // ARM64_INS_UADDLP,
	"uaddlt", // ARM64_INS_UADDLT,
	"uaddlv", // ARM64_INS_UADDLV,
	"uaddv", // ARM64_INS_UADDV,
	"uaddw", // ARM64_INS_UADDW,
	"uaddw2", // ARM64_INS_UADDW2,
	"uaddwb", // ARM64_INS_UADDWB,
	"uaddwt", // ARM64_INS_UADDWT,
	"ubfm", // ARM64_INS_UBFM,
	"uclamp", // ARM64_INS_UCLAMP,
	"ucvtf", // ARM64_INS_UCVTF,
	"udf", // ARM64_INS_UDF,
	"udiv", // ARM64_INS_UDIV,
	"udivr", // ARM64_INS_UDIVR,
	"udot", // ARM64_INS_UDOT,
	"uhadd", // ARM64_INS_UHADD,
	"uhsub", // ARM64_INS_UHSUB,
	"uhsubr", // ARM64_INS_UHSUBR,
	"umaddl", // ARM64_INS_UMADDL,
	"umax", // ARM64_INS_UMAX,
	"umaxp", // ARM64_INS_UMAXP,
	"umaxv", // ARM64_INS_UMAXV,
	"umin", // ARM64_INS_UMIN,
	"uminp", // ARM64_INS_UMINP,
	"uminv", // ARM64_INS_UMINV,
	"umlal", // ARM64_INS_UMLAL,
	"umlal2", // ARM64_INS_UMLAL2,
	"umlalb", // ARM64_INS_UMLALB,
	"umlalt", // ARM64_INS_UMLALT,
	"umlsl", // ARM64_INS_UMLSL,
	"umlsl2", // ARM64_INS_UMLSL2,
	"umlslb", // ARM64_INS_UMLSLB,
	"umlslt", // ARM64_INS_UMLSLT,
	"ummla", // ARM64_INS_UMMLA,
	"umnegl", // ARM64_INS_UMNEGL,
	"umopa", // ARM64_INS_UMOPA,
	"umops", // ARM64_INS_UMOPS,
	"umov", // ARM64_INS_UMOV,
	"umsubl", // ARM64_INS_UMSUBL,
	"umulh", // ARM64_INS_UMULH,
	"umull", // ARM64_INS_UMULL,
	"umull2", // ARM64_INS_UMULL2,
	"umullb", // ARM64_INS_UMULLB,
	"umullt", // ARM64_INS_UMULLT,
	"uqadd", // ARM64_INS_UQADD,
	"uqdecb", // ARM64_INS_UQDECB,
	"uqdecd", // ARM64_INS_UQDECD,
	"uqdech", // ARM64_INS_UQDECH,
	"uqdecp", // ARM64_INS_UQDECP,
	"uqdecw", // ARM64_INS_UQDECW,
	"uqincb", // ARM64_INS_UQINCB,
	"uqincd", // ARM64_INS_UQINCD,
	"uqinch", // ARM64_INS_UQINCH,
	"uqincp", // ARM64_INS_UQINCP,
	"uqincw", // ARM64_INS_UQINCW,
	"uqrshl", // ARM64_INS_UQRSHL,
	"uqrshlr", // ARM64_INS_UQRSHLR,
	"uqrshrn", // ARM64_INS_UQRSHRN,
	"uqrshrn2", // ARM64_INS_UQRSHRN2,
	"uqrshrnb", // ARM64_INS_UQRSHRNB,
	"uqrshrnt", // ARM64_INS_UQRSHRNT,
	"uqshl", // ARM64_INS_UQSHL,
	"uqshlr", // ARM64_INS_UQSHLR,
	"uqshrn", // ARM64_INS_UQSHRN,
	"uqshrn2", // ARM64_INS_UQSHRN2,
	"uqshrnb", // ARM64_INS_UQSHRNB,
	"uqshrnt", // ARM64_INS_UQSHRNT,
	"uqsub", // ARM64_INS_UQSUB,
	"uqsubr", // ARM64_INS_UQSUBR,
	"uqxtn", // ARM64_INS_UQXTN,
	"uqxtn2", // ARM64_INS_UQXTN2,
	"uqxtnb", // ARM64_INS_UQXTNB,
	"uqxtnt", // ARM64_INS_UQXTNT,
	"urecpe", // ARM64_INS_URECPE,
	"urhadd", // ARM64_INS_URHADD,
	"urshl", // ARM64_INS_URSHL,
	"urshlr", // ARM64_INS_URSHLR,
	"urshr", // ARM64_INS_URSHR,
	"ursqrte", // ARM64_INS_URSQRTE,
	"ursra", // ARM64_INS_URSRA,
	"usdot", // ARM64_INS_USDOT,
	"ushl", // ARM64_INS_USHL,
	"ushll", // ARM64_INS_USHLL,
	"ushll2", // ARM64_INS_USHLL2,
	"ushllb", // ARM64_INS_USHLLB,
	"ushllt", // ARM64_INS_USHLLT,
	"ushr", // ARM64_INS_USHR,
	"usmmla", // ARM64_INS_USMMLA,
	"usmopa", // ARM64_INS_USMOPA,
	"usmops", // ARM64_INS_USMOPS,
	"usqadd", // ARM64_INS_USQADD,
	"usra", // ARM64_INS_USRA,
	"usubl", // ARM64_INS_USUBL,
	"usubl2", // ARM64_INS_USUBL2,
	"usublb", // ARM64_INS_USUBLB,
	"usublt", // ARM64_INS_USUBLT,
	"usubw", // ARM64_INS_USUBW,
	"usubw2", // ARM64_INS_USUBW2,
	"usubwb", // ARM64_INS_USUBWB,
	"usubwt", // ARM64_INS_USUBWT,
	"uunpkhi", // ARM64_INS_UUNPKHI,
	"uunpklo", // ARM64_INS_UUNPKLO,
	"uxtb", // ARM64_INS_UXTB,
	"uxth", // ARM64_INS_UXTH,
	"uxtl", // ARM64_INS_UXTL,
	"uxtl2", // ARM64_INS_UXTL2,
	"uxtw", // ARM64_INS_UXTW,
	"uzp1", // ARM64_INS_UZP1,
	"uzp2", // ARM64_INS_UZP2,
	"wfe", // ARM64_INS_WFE,
	"wfet", // ARM64_INS_WFET,
	"wfi", // ARM64_INS_WFI,
	"wfit", // ARM64_INS_WFIT,
	"whilege", // ARM64_INS_WHILEGE,
	"whilegt", // ARM64_INS_WHILEGT,
	"whilehi", // ARM64_INS_WHILEHI,
	"whilehs", // ARM64_INS_WHILEHS,
	"whilele", // ARM64_INS_WHILELE,
	"whilelo", // ARM64_INS_WHILELO,
	"whilels", // ARM64_INS_WHILELS,
	"whilelt", // ARM64_INS_WHILELT,
	"whilerw", // ARM64_INS_WHILERW,
	"whilewr", // ARM64_INS_WHILEWR,
	"wrffr", // ARM64_INS_WRFFR,
	"xaflag", // ARM64_INS_XAFLAG,
	"xar", // ARM64_INS_XAR,
	"xpacd", // ARM64_INS_XPACD,
	"xpaci", // ARM64_INS_XPACI,
	"xpaclri", // ARM64_INS_XPACLRI,
	"xtn", // ARM64_INS_XTN,
	"xtn2", // ARM64_INS_XTN2,
	"yield", // ARM64_INS_YIELD,
	"zero", // ARM64_INS_ZERO,
	"zip1", // ARM64_INS_ZIP1,
	"zip2", // ARM64_INS_ZIP2,
