/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2022, */
/*    Rot127 <unisono@quyllur.org> 2022-2023 */
/* Automatically generated file by Capstone's LLVM TableGen Disassembler Backend. */

/* LLVM-commit: <commit> */
/* LLVM-tag: <tag> */

/* Do not edit. */

/* Capstone's LLVM TableGen Backends: */
/* https://github.com/capstone-engine/llvm-capstone */

  TRICORE_OP_GROUP_RegImmShift = 0,
  TRICORE_OP_GROUP_LdStmModeOperand = 1,
  TRICORE_OP_GROUP_MandatoryInvertedPredicateOperand = 2,
  TRICORE_OP_GROUP_Operand = 3,
  TRICORE_OP_GROUP_SExtImm_9 = 4,
  TRICORE_OP_GROUP_ZExtImm_16 = 5,
  TRICORE_OP_GROUP_SExtImm_16 = 6,
  TRICORE_OP_GROUP_ZExtImm_2 = 7,
  TRICORE_OP_GROUP_SExtImm_4 = 8,
  TRICORE_OP_GROUP_ZExtImm_4 = 9,
  TRICORE_OP_GROUP_ZExtImm_8 = 10,
  TRICORE_OP_GROUP_SExtImm_10 = 11,
  TRICORE_OP_GROUP_Disp24Imm = 12,
  TRICORE_OP_GROUP_Disp8Imm = 13,
  TRICORE_OP_GROUP_Disp15Imm = 14,
  TRICORE_OP_GROUP_Disp4Imm = 15,
  TRICORE_OP_GROUP_Off18Imm = 16,
  TRICORE_OP_GROUP_OExtImm_4 = 17,
  TRICORE_OP_GROUP_ZExtImm_9 = 18,
