(* For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [x86_const.ml] *)

let _X86_REG_INVALID = 0;;
let _X86_REG_AH = 1;;
let _X86_REG_AL = 2;;
let _X86_REG_AX = 3;;
let _X86_REG_BH = 4;;
let _X86_REG_BL = 5;;
let _X86_REG_BP = 6;;
let _X86_REG_BPL = 7;;
let _X86_REG_BX = 8;;
let _X86_REG_CH = 9;;
let _X86_REG_CL = 10;;
let _X86_REG_CS = 11;;
let _X86_REG_CX = 12;;
let _X86_REG_DH = 13;;
let _X86_REG_DI = 14;;
let _X86_REG_DIL = 15;;
let _X86_REG_DL = 16;;
let _X86_REG_DS = 17;;
let _X86_REG_DX = 18;;
let _X86_REG_EAX = 19;;
let _X86_REG_EBP = 20;;
let _X86_REG_EBX = 21;;
let _X86_REG_ECX = 22;;
let _X86_REG_EDI = 23;;
let _X86_REG_EDX = 24;;
let _X86_REG_EFLAGS = 25;;
let _X86_REG_EIP = 26;;
let _X86_REG_EIZ = 27;;
let _X86_REG_ES = 28;;
let _X86_REG_ESI = 29;;
let _X86_REG_ESP = 30;;
let _X86_REG_FPSW = 31;;
let _X86_REG_FS = 32;;
let _X86_REG_GS = 33;;
let _X86_REG_IP = 34;;
let _X86_REG_RAX = 35;;
let _X86_REG_RBP = 36;;
let _X86_REG_RBX = 37;;
let _X86_REG_RCX = 38;;
let _X86_REG_RDI = 39;;
let _X86_REG_RDX = 40;;
let _X86_REG_RIP = 41;;
let _X86_REG_RIZ = 42;;
let _X86_REG_RSI = 43;;
let _X86_REG_RSP = 44;;
let _X86_REG_SI = 45;;
let _X86_REG_SIL = 46;;
let _X86_REG_SP = 47;;
let _X86_REG_SPL = 48;;
let _X86_REG_SS = 49;;
let _X86_REG_CR0 = 50;;
let _X86_REG_CR1 = 51;;
let _X86_REG_CR2 = 52;;
let _X86_REG_CR3 = 53;;
let _X86_REG_CR4 = 54;;
let _X86_REG_CR5 = 55;;
let _X86_REG_CR6 = 56;;
let _X86_REG_CR7 = 57;;
let _X86_REG_CR8 = 58;;
let _X86_REG_CR9 = 59;;
let _X86_REG_CR10 = 60;;
let _X86_REG_CR11 = 61;;
let _X86_REG_CR12 = 62;;
let _X86_REG_CR13 = 63;;
let _X86_REG_CR14 = 64;;
let _X86_REG_CR15 = 65;;
let _X86_REG_DR0 = 66;;
let _X86_REG_DR1 = 67;;
let _X86_REG_DR2 = 68;;
let _X86_REG_DR3 = 69;;
let _X86_REG_DR4 = 70;;
let _X86_REG_DR5 = 71;;
let _X86_REG_DR6 = 72;;
let _X86_REG_DR7 = 73;;
let _X86_REG_DR8 = 74;;
let _X86_REG_DR9 = 75;;
let _X86_REG_DR10 = 76;;
let _X86_REG_DR11 = 77;;
let _X86_REG_DR12 = 78;;
let _X86_REG_DR13 = 79;;
let _X86_REG_DR14 = 80;;
let _X86_REG_DR15 = 81;;
let _X86_REG_FP0 = 82;;
let _X86_REG_FP1 = 83;;
let _X86_REG_FP2 = 84;;
let _X86_REG_FP3 = 85;;
let _X86_REG_FP4 = 86;;
let _X86_REG_FP5 = 87;;
let _X86_REG_FP6 = 88;;
let _X86_REG_FP7 = 89;;
let _X86_REG_K0 = 90;;
let _X86_REG_K1 = 91;;
let _X86_REG_K2 = 92;;
let _X86_REG_K3 = 93;;
let _X86_REG_K4 = 94;;
let _X86_REG_K5 = 95;;
let _X86_REG_K6 = 96;;
let _X86_REG_K7 = 97;;
let _X86_REG_MM0 = 98;;
let _X86_REG_MM1 = 99;;
let _X86_REG_MM2 = 100;;
let _X86_REG_MM3 = 101;;
let _X86_REG_MM4 = 102;;
let _X86_REG_MM5 = 103;;
let _X86_REG_MM6 = 104;;
let _X86_REG_MM7 = 105;;
let _X86_REG_R8 = 106;;
let _X86_REG_R9 = 107;;
let _X86_REG_R10 = 108;;
let _X86_REG_R11 = 109;;
let _X86_REG_R12 = 110;;
let _X86_REG_R13 = 111;;
let _X86_REG_R14 = 112;;
let _X86_REG_R15 = 113;;
let _X86_REG_ST0 = 114;;
let _X86_REG_ST1 = 115;;
let _X86_REG_ST2 = 116;;
let _X86_REG_ST3 = 117;;
let _X86_REG_ST4 = 118;;
let _X86_REG_ST5 = 119;;
let _X86_REG_ST6 = 120;;
let _X86_REG_ST7 = 121;;
let _X86_REG_XMM0 = 122;;
let _X86_REG_XMM1 = 123;;
let _X86_REG_XMM2 = 124;;
let _X86_REG_XMM3 = 125;;
let _X86_REG_XMM4 = 126;;
let _X86_REG_XMM5 = 127;;
let _X86_REG_XMM6 = 128;;
let _X86_REG_XMM7 = 129;;
let _X86_REG_XMM8 = 130;;
let _X86_REG_XMM9 = 131;;
let _X86_REG_XMM10 = 132;;
let _X86_REG_XMM11 = 133;;
let _X86_REG_XMM12 = 134;;
let _X86_REG_XMM13 = 135;;
let _X86_REG_XMM14 = 136;;
let _X86_REG_XMM15 = 137;;
let _X86_REG_XMM16 = 138;;
let _X86_REG_XMM17 = 139;;
let _X86_REG_XMM18 = 140;;
let _X86_REG_XMM19 = 141;;
let _X86_REG_XMM20 = 142;;
let _X86_REG_XMM21 = 143;;
let _X86_REG_XMM22 = 144;;
let _X86_REG_XMM23 = 145;;
let _X86_REG_XMM24 = 146;;
let _X86_REG_XMM25 = 147;;
let _X86_REG_XMM26 = 148;;
let _X86_REG_XMM27 = 149;;
let _X86_REG_XMM28 = 150;;
let _X86_REG_XMM29 = 151;;
let _X86_REG_XMM30 = 152;;
let _X86_REG_XMM31 = 153;;
let _X86_REG_YMM0 = 154;;
let _X86_REG_YMM1 = 155;;
let _X86_REG_YMM2 = 156;;
let _X86_REG_YMM3 = 157;;
let _X86_REG_YMM4 = 158;;
let _X86_REG_YMM5 = 159;;
let _X86_REG_YMM6 = 160;;
let _X86_REG_YMM7 = 161;;
let _X86_REG_YMM8 = 162;;
let _X86_REG_YMM9 = 163;;
let _X86_REG_YMM10 = 164;;
let _X86_REG_YMM11 = 165;;
let _X86_REG_YMM12 = 166;;
let _X86_REG_YMM13 = 167;;
let _X86_REG_YMM14 = 168;;
let _X86_REG_YMM15 = 169;;
let _X86_REG_YMM16 = 170;;
let _X86_REG_YMM17 = 171;;
let _X86_REG_YMM18 = 172;;
let _X86_REG_YMM19 = 173;;
let _X86_REG_YMM20 = 174;;
let _X86_REG_YMM21 = 175;;
let _X86_REG_YMM22 = 176;;
let _X86_REG_YMM23 = 177;;
let _X86_REG_YMM24 = 178;;
let _X86_REG_YMM25 = 179;;
let _X86_REG_YMM26 = 180;;
let _X86_REG_YMM27 = 181;;
let _X86_REG_YMM28 = 182;;
let _X86_REG_YMM29 = 183;;
let _X86_REG_YMM30 = 184;;
let _X86_REG_YMM31 = 185;;
let _X86_REG_ZMM0 = 186;;
let _X86_REG_ZMM1 = 187;;
let _X86_REG_ZMM2 = 188;;
let _X86_REG_ZMM3 = 189;;
let _X86_REG_ZMM4 = 190;;
let _X86_REG_ZMM5 = 191;;
let _X86_REG_ZMM6 = 192;;
let _X86_REG_ZMM7 = 193;;
let _X86_REG_ZMM8 = 194;;
let _X86_REG_ZMM9 = 195;;
let _X86_REG_ZMM10 = 196;;
let _X86_REG_ZMM11 = 197;;
let _X86_REG_ZMM12 = 198;;
let _X86_REG_ZMM13 = 199;;
let _X86_REG_ZMM14 = 200;;
let _X86_REG_ZMM15 = 201;;
let _X86_REG_ZMM16 = 202;;
let _X86_REG_ZMM17 = 203;;
let _X86_REG_ZMM18 = 204;;
let _X86_REG_ZMM19 = 205;;
let _X86_REG_ZMM20 = 206;;
let _X86_REG_ZMM21 = 207;;
let _X86_REG_ZMM22 = 208;;
let _X86_REG_ZMM23 = 209;;
let _X86_REG_ZMM24 = 210;;
let _X86_REG_ZMM25 = 211;;
let _X86_REG_ZMM26 = 212;;
let _X86_REG_ZMM27 = 213;;
let _X86_REG_ZMM28 = 214;;
let _X86_REG_ZMM29 = 215;;
let _X86_REG_ZMM30 = 216;;
let _X86_REG_ZMM31 = 217;;
let _X86_REG_R8B = 218;;
let _X86_REG_R9B = 219;;
let _X86_REG_R10B = 220;;
let _X86_REG_R11B = 221;;
let _X86_REG_R12B = 222;;
let _X86_REG_R13B = 223;;
let _X86_REG_R14B = 224;;
let _X86_REG_R15B = 225;;
let _X86_REG_R8D = 226;;
let _X86_REG_R9D = 227;;
let _X86_REG_R10D = 228;;
let _X86_REG_R11D = 229;;
let _X86_REG_R12D = 230;;
let _X86_REG_R13D = 231;;
let _X86_REG_R14D = 232;;
let _X86_REG_R15D = 233;;
let _X86_REG_R8W = 234;;
let _X86_REG_R9W = 235;;
let _X86_REG_R10W = 236;;
let _X86_REG_R11W = 237;;
let _X86_REG_R12W = 238;;
let _X86_REG_R13W = 239;;
let _X86_REG_R14W = 240;;
let _X86_REG_R15W = 241;;
let _X86_REG_BND0 = 242;;
let _X86_REG_BND1 = 243;;
let _X86_REG_BND2 = 244;;
let _X86_REG_BND3 = 245;;
let _X86_REG_ENDING = 246;;
let _X86_EFLAGS_MODIFY_AF = 1 lsl 0;;
let _X86_EFLAGS_MODIFY_CF = 1 lsl 1;;
let _X86_EFLAGS_MODIFY_SF = 1 lsl 2;;
let _X86_EFLAGS_MODIFY_ZF = 1 lsl 3;;
let _X86_EFLAGS_MODIFY_PF = 1 lsl 4;;
let _X86_EFLAGS_MODIFY_OF = 1 lsl 5;;
let _X86_EFLAGS_MODIFY_TF = 1 lsl 6;;
let _X86_EFLAGS_MODIFY_IF = 1 lsl 7;;
let _X86_EFLAGS_MODIFY_DF = 1 lsl 8;;
let _X86_EFLAGS_MODIFY_NT = 1 lsl 9;;
let _X86_EFLAGS_MODIFY_RF = 1 lsl 10;;
let _X86_EFLAGS_PRIOR_OF = 1 lsl 11;;
let _X86_EFLAGS_PRIOR_SF = 1 lsl 12;;
let _X86_EFLAGS_PRIOR_ZF = 1 lsl 13;;
let _X86_EFLAGS_PRIOR_AF = 1 lsl 14;;
let _X86_EFLAGS_PRIOR_PF = 1 lsl 15;;
let _X86_EFLAGS_PRIOR_CF = 1 lsl 16;;
let _X86_EFLAGS_PRIOR_TF = 1 lsl 17;;
let _X86_EFLAGS_PRIOR_IF = 1 lsl 18;;
let _X86_EFLAGS_PRIOR_DF = 1 lsl 19;;
let _X86_EFLAGS_PRIOR_NT = 1 lsl 20;;
let _X86_EFLAGS_RESET_OF = 1 lsl 21;;
let _X86_EFLAGS_RESET_CF = 1 lsl 22;;
let _X86_EFLAGS_RESET_DF = 1 lsl 23;;
let _X86_EFLAGS_RESET_IF = 1 lsl 24;;
let _X86_EFLAGS_RESET_SF = 1 lsl 25;;
let _X86_EFLAGS_RESET_AF = 1 lsl 26;;
let _X86_EFLAGS_RESET_TF = 1 lsl 27;;
let _X86_EFLAGS_RESET_NT = 1 lsl 28;;
let _X86_EFLAGS_RESET_PF = 1 lsl 29;;
let _X86_EFLAGS_SET_CF = 1 lsl 30;;
let _X86_EFLAGS_SET_DF = 1 lsl 31;;
let _X86_EFLAGS_SET_IF = 1 lsl 32;;
let _X86_EFLAGS_TEST_OF = 1 lsl 33;;
let _X86_EFLAGS_TEST_SF = 1 lsl 34;;
let _X86_EFLAGS_TEST_ZF = 1 lsl 35;;
let _X86_EFLAGS_TEST_PF = 1 lsl 36;;
let _X86_EFLAGS_TEST_CF = 1 lsl 37;;
let _X86_EFLAGS_TEST_NT = 1 lsl 38;;
let _X86_EFLAGS_TEST_DF = 1 lsl 39;;
let _X86_EFLAGS_UNDEFINED_OF = 1 lsl 40;;
let _X86_EFLAGS_UNDEFINED_SF = 1 lsl 41;;
let _X86_EFLAGS_UNDEFINED_ZF = 1 lsl 42;;
let _X86_EFLAGS_UNDEFINED_PF = 1 lsl 43;;
let _X86_EFLAGS_UNDEFINED_AF = 1 lsl 44;;
let _X86_EFLAGS_UNDEFINED_CF = 1 lsl 45;;
let _X86_EFLAGS_RESET_RF = 1 lsl 46;;
let _X86_EFLAGS_TEST_RF = 1 lsl 47;;
let _X86_EFLAGS_TEST_IF = 1 lsl 48;;
let _X86_EFLAGS_TEST_TF = 1 lsl 49;;
let _X86_EFLAGS_TEST_AF = 1 lsl 50;;
let _X86_EFLAGS_RESET_ZF = 1 lsl 51;;
let _X86_EFLAGS_SET_OF = 1 lsl 52;;
let _X86_EFLAGS_SET_SF = 1 lsl 53;;
let _X86_EFLAGS_SET_ZF = 1 lsl 54;;
let _X86_EFLAGS_SET_AF = 1 lsl 55;;
let _X86_EFLAGS_SET_PF = 1 lsl 56;;
let _X86_EFLAGS_RESET_0F = 1 lsl 57;;
let _X86_EFLAGS_RESET_AC = 1 lsl 58;;
let _X86_FPU_FLAGS_MODIFY_C0 = 1 lsl 0;;
let _X86_FPU_FLAGS_MODIFY_C1 = 1 lsl 1;;
let _X86_FPU_FLAGS_MODIFY_C2 = 1 lsl 2;;
let _X86_FPU_FLAGS_MODIFY_C3 = 1 lsl 3;;
let _X86_FPU_FLAGS_RESET_C0 = 1 lsl 4;;
let _X86_FPU_FLAGS_RESET_C1 = 1 lsl 5;;
let _X86_FPU_FLAGS_RESET_C2 = 1 lsl 6;;
let _X86_FPU_FLAGS_RESET_C3 = 1 lsl 7;;
let _X86_FPU_FLAGS_SET_C0 = 1 lsl 8;;
let _X86_FPU_FLAGS_SET_C1 = 1 lsl 9;;
let _X86_FPU_FLAGS_SET_C2 = 1 lsl 10;;
let _X86_FPU_FLAGS_SET_C3 = 1 lsl 11;;
let _X86_FPU_FLAGS_UNDEFINED_C0 = 1 lsl 12;;
let _X86_FPU_FLAGS_UNDEFINED_C1 = 1 lsl 13;;
let _X86_FPU_FLAGS_UNDEFINED_C2 = 1 lsl 14;;
let _X86_FPU_FLAGS_UNDEFINED_C3 = 1 lsl 15;;
let _X86_FPU_FLAGS_TEST_C0 = 1 lsl 16;;
let _X86_FPU_FLAGS_TEST_C1 = 1 lsl 17;;
let _X86_FPU_FLAGS_TEST_C2 = 1 lsl 18;;
let _X86_FPU_FLAGS_TEST_C3 = 1 lsl 19;;

let _X86_OP_INVALID = 0;;
let _X86_OP_REG = 1;;
let _X86_OP_IMM = 2;;
let _X86_OP_MEM = 3;;

let _X86_XOP_CC_INVALID = 0;;
let _X86_XOP_CC_LT = 1;;
let _X86_XOP_CC_LE = 2;;
let _X86_XOP_CC_GT = 3;;
let _X86_XOP_CC_GE = 4;;
let _X86_XOP_CC_EQ = 5;;
let _X86_XOP_CC_NEQ = 6;;
let _X86_XOP_CC_FALSE = 7;;
let _X86_XOP_CC_TRUE = 8;;

let _X86_AVX_BCAST_INVALID = 0;;
let _X86_AVX_BCAST_2 = 1;;
let _X86_AVX_BCAST_4 = 2;;
let _X86_AVX_BCAST_8 = 3;;
let _X86_AVX_BCAST_16 = 4;;

let _X86_SSE_CC_INVALID = 0;;
let _X86_SSE_CC_EQ = 1;;
let _X86_SSE_CC_LT = 2;;
let _X86_SSE_CC_LE = 3;;
let _X86_SSE_CC_UNORD = 4;;
let _X86_SSE_CC_NEQ = 5;;
let _X86_SSE_CC_NLT = 6;;
let _X86_SSE_CC_NLE = 7;;
let _X86_SSE_CC_ORD = 8;;

let _X86_AVX_CC_INVALID = 0;;
let _X86_AVX_CC_EQ = 1;;
let _X86_AVX_CC_LT = 2;;
let _X86_AVX_CC_LE = 3;;
let _X86_AVX_CC_UNORD = 4;;
let _X86_AVX_CC_NEQ = 5;;
let _X86_AVX_CC_NLT = 6;;
let _X86_AVX_CC_NLE = 7;;
let _X86_AVX_CC_ORD = 8;;
let _X86_AVX_CC_EQ_UQ = 9;;
let _X86_AVX_CC_NGE = 10;;
let _X86_AVX_CC_NGT = 11;;
let _X86_AVX_CC_FALSE = 12;;
let _X86_AVX_CC_NEQ_OQ = 13;;
let _X86_AVX_CC_GE = 14;;
let _X86_AVX_CC_GT = 15;;
let _X86_AVX_CC_TRUE = 16;;
let _X86_AVX_CC_EQ_OS = 17;;
let _X86_AVX_CC_LT_OQ = 18;;
let _X86_AVX_CC_LE_OQ = 19;;
let _X86_AVX_CC_UNORD_S = 20;;
let _X86_AVX_CC_NEQ_US = 21;;
let _X86_AVX_CC_NLT_UQ = 22;;
let _X86_AVX_CC_NLE_UQ = 23;;
let _X86_AVX_CC_ORD_S = 24;;
let _X86_AVX_CC_EQ_US = 25;;
let _X86_AVX_CC_NGE_UQ = 26;;
let _X86_AVX_CC_NGT_UQ = 27;;
let _X86_AVX_CC_FALSE_OS = 28;;
let _X86_AVX_CC_NEQ_OS = 29;;
let _X86_AVX_CC_GE_OQ = 30;;
let _X86_AVX_CC_GT_OQ = 31;;
let _X86_AVX_CC_TRUE_US = 32;;

let _X86_AVX_RM_INVALID = 0;;
let _X86_AVX_RM_RN = 1;;
let _X86_AVX_RM_RD = 2;;
let _X86_AVX_RM_RU = 3;;
let _X86_AVX_RM_RZ = 4;;
let _X86_PREFIX_LOCK = 0xf0;;
let _X86_PREFIX_REP = 0xf3;;
let _X86_PREFIX_REPE = 0xf3;;
let _X86_PREFIX_REPNE = 0xf2;;
let _X86_PREFIX_CS = 0x2e;;
let _X86_PREFIX_SS = 0x36;;
let _X86_PREFIX_DS = 0x3e;;
let _X86_PREFIX_ES = 0x26;;
let _X86_PREFIX_FS = 0x64;;
let _X86_PREFIX_GS = 0x65;;
let _X86_PREFIX_OPSIZE = 0x66;;
let _X86_PREFIX_ADDRSIZE = 0x67;;

let _X86_INS_INVALID = 0;;
let _X86_INS_AAA = 1;;
let _X86_INS_AAD = 2;;
let _X86_INS_AAM = 3;;
let _X86_INS_AAS = 4;;
let _X86_INS_FABS = 5;;
let _X86_INS_ADC = 6;;
let _X86_INS_ADCX = 7;;
let _X86_INS_ADD = 8;;
let _X86_INS_ADDPD = 9;;
let _X86_INS_ADDPS = 10;;
let _X86_INS_ADDSD = 11;;
let _X86_INS_ADDSS = 12;;
let _X86_INS_ADDSUBPD = 13;;
let _X86_INS_ADDSUBPS = 14;;
let _X86_INS_FADD = 15;;
let _X86_INS_FIADD = 16;;
let _X86_INS_ADOX = 17;;
let _X86_INS_AESDECLAST = 18;;
let _X86_INS_AESDEC = 19;;
let _X86_INS_AESENCLAST = 20;;
let _X86_INS_AESENC = 21;;
let _X86_INS_AESIMC = 22;;
let _X86_INS_AESKEYGENASSIST = 23;;
let _X86_INS_AND = 24;;
let _X86_INS_ANDN = 25;;
let _X86_INS_ANDNPD = 26;;
let _X86_INS_ANDNPS = 27;;
let _X86_INS_ANDPD = 28;;
let _X86_INS_ANDPS = 29;;
let _X86_INS_ARPL = 30;;
let _X86_INS_BEXTR = 31;;
let _X86_INS_BLCFILL = 32;;
let _X86_INS_BLCI = 33;;
let _X86_INS_BLCIC = 34;;
let _X86_INS_BLCMSK = 35;;
let _X86_INS_BLCS = 36;;
let _X86_INS_BLENDPD = 37;;
let _X86_INS_BLENDPS = 38;;
let _X86_INS_BLENDVPD = 39;;
let _X86_INS_BLENDVPS = 40;;
let _X86_INS_BLSFILL = 41;;
let _X86_INS_BLSI = 42;;
let _X86_INS_BLSIC = 43;;
let _X86_INS_BLSMSK = 44;;
let _X86_INS_BLSR = 45;;
let _X86_INS_BNDCL = 46;;
let _X86_INS_BNDCN = 47;;
let _X86_INS_BNDCU = 48;;
let _X86_INS_BNDLDX = 49;;
let _X86_INS_BNDMK = 50;;
let _X86_INS_BNDMOV = 51;;
let _X86_INS_BNDSTX = 52;;
let _X86_INS_BOUND = 53;;
let _X86_INS_BSF = 54;;
let _X86_INS_BSR = 55;;
let _X86_INS_BSWAP = 56;;
let _X86_INS_BT = 57;;
let _X86_INS_BTC = 58;;
let _X86_INS_BTR = 59;;
let _X86_INS_BTS = 60;;
let _X86_INS_BZHI = 61;;
let _X86_INS_CALL = 62;;
let _X86_INS_CBW = 63;;
let _X86_INS_CDQ = 64;;
let _X86_INS_CDQE = 65;;
let _X86_INS_FCHS = 66;;
let _X86_INS_CLAC = 67;;
let _X86_INS_CLC = 68;;
let _X86_INS_CLD = 69;;
let _X86_INS_CLDEMOTE = 70;;
let _X86_INS_CLFLUSH = 71;;
let _X86_INS_CLFLUSHOPT = 72;;
let _X86_INS_CLGI = 73;;
let _X86_INS_CLI = 74;;
let _X86_INS_CLRSSBSY = 75;;
let _X86_INS_CLTS = 76;;
let _X86_INS_CLWB = 77;;
let _X86_INS_CLZERO = 78;;
let _X86_INS_CMC = 79;;
let _X86_INS_CMOVA = 80;;
let _X86_INS_CMOVAE = 81;;
let _X86_INS_CMOVB = 82;;
let _X86_INS_CMOVBE = 83;;
let _X86_INS_FCMOVBE = 84;;
let _X86_INS_FCMOVB = 85;;
let _X86_INS_CMOVE = 86;;
let _X86_INS_FCMOVE = 87;;
let _X86_INS_CMOVG = 88;;
let _X86_INS_CMOVGE = 89;;
let _X86_INS_CMOVL = 90;;
let _X86_INS_CMOVLE = 91;;
let _X86_INS_FCMOVNBE = 92;;
let _X86_INS_FCMOVNB = 93;;
let _X86_INS_CMOVNE = 94;;
let _X86_INS_FCMOVNE = 95;;
let _X86_INS_CMOVNO = 96;;
let _X86_INS_CMOVNP = 97;;
let _X86_INS_FCMOVNU = 98;;
let _X86_INS_FCMOVNP = 99;;
let _X86_INS_CMOVNS = 100;;
let _X86_INS_CMOVO = 101;;
let _X86_INS_CMOVP = 102;;
let _X86_INS_FCMOVU = 103;;
let _X86_INS_CMOVS = 104;;
let _X86_INS_CMP = 105;;
let _X86_INS_CMPPD = 106;;
let _X86_INS_CMPPS = 107;;
let _X86_INS_CMPSB = 108;;
let _X86_INS_CMPSD = 109;;
let _X86_INS_CMPSQ = 110;;
let _X86_INS_CMPSS = 111;;
let _X86_INS_CMPSW = 112;;
let _X86_INS_CMPXCHG16B = 113;;
let _X86_INS_CMPXCHG = 114;;
let _X86_INS_CMPXCHG8B = 115;;
let _X86_INS_COMISD = 116;;
let _X86_INS_COMISS = 117;;
let _X86_INS_FCOMP = 118;;
let _X86_INS_FCOMPI = 119;;
let _X86_INS_FCOMI = 120;;
let _X86_INS_FCOM = 121;;
let _X86_INS_FCOS = 122;;
let _X86_INS_CPUID = 123;;
let _X86_INS_CQO = 124;;
let _X86_INS_CRC32 = 125;;
let _X86_INS_CVTDQ2PD = 126;;
let _X86_INS_CVTDQ2PS = 127;;
let _X86_INS_CVTPD2DQ = 128;;
let _X86_INS_CVTPD2PS = 129;;
let _X86_INS_CVTPS2DQ = 130;;
let _X86_INS_CVTPS2PD = 131;;
let _X86_INS_CVTSD2SI = 132;;
let _X86_INS_CVTSD2SS = 133;;
let _X86_INS_CVTSI2SD = 134;;
let _X86_INS_CVTSI2SS = 135;;
let _X86_INS_CVTSS2SD = 136;;
let _X86_INS_CVTSS2SI = 137;;
let _X86_INS_CVTTPD2DQ = 138;;
let _X86_INS_CVTTPS2DQ = 139;;
let _X86_INS_CVTTSD2SI = 140;;
let _X86_INS_CVTTSS2SI = 141;;
let _X86_INS_CWD = 142;;
let _X86_INS_CWDE = 143;;
let _X86_INS_DAA = 144;;
let _X86_INS_DAS = 145;;
let _X86_INS_DATA16 = 146;;
let _X86_INS_DEC = 147;;
let _X86_INS_DIV = 148;;
let _X86_INS_DIVPD = 149;;
let _X86_INS_DIVPS = 150;;
let _X86_INS_FDIVR = 151;;
let _X86_INS_FIDIVR = 152;;
let _X86_INS_FDIVRP = 153;;
let _X86_INS_DIVSD = 154;;
let _X86_INS_DIVSS = 155;;
let _X86_INS_FDIV = 156;;
let _X86_INS_FIDIV = 157;;
let _X86_INS_FDIVP = 158;;
let _X86_INS_DPPD = 159;;
let _X86_INS_DPPS = 160;;
let _X86_INS_ENCLS = 161;;
let _X86_INS_ENCLU = 162;;
let _X86_INS_ENCLV = 163;;
let _X86_INS_ENDBR32 = 164;;
let _X86_INS_ENDBR64 = 165;;
let _X86_INS_ENTER = 166;;
let _X86_INS_EXTRACTPS = 167;;
let _X86_INS_EXTRQ = 168;;
let _X86_INS_F2XM1 = 169;;
let _X86_INS_LCALL = 170;;
let _X86_INS_LJMP = 171;;
let _X86_INS_JMP = 172;;
let _X86_INS_FBLD = 173;;
let _X86_INS_FBSTP = 174;;
let _X86_INS_FCOMPP = 175;;
let _X86_INS_FDECSTP = 176;;
let _X86_INS_FDISI8087_NOP = 177;;
let _X86_INS_FEMMS = 178;;
let _X86_INS_FENI8087_NOP = 179;;
let _X86_INS_FFREE = 180;;
let _X86_INS_FFREEP = 181;;
let _X86_INS_FICOM = 182;;
let _X86_INS_FICOMP = 183;;
let _X86_INS_FINCSTP = 184;;
let _X86_INS_FLDCW = 185;;
let _X86_INS_FLDENV = 186;;
let _X86_INS_FLDL2E = 187;;
let _X86_INS_FLDL2T = 188;;
let _X86_INS_FLDLG2 = 189;;
let _X86_INS_FLDLN2 = 190;;
let _X86_INS_FLDPI = 191;;
let _X86_INS_FNCLEX = 192;;
let _X86_INS_FNINIT = 193;;
let _X86_INS_FNOP = 194;;
let _X86_INS_FNSTCW = 195;;
let _X86_INS_FNSTSW = 196;;
let _X86_INS_FPATAN = 197;;
let _X86_INS_FSTPNCE = 198;;
let _X86_INS_FPREM = 199;;
let _X86_INS_FPREM1 = 200;;
let _X86_INS_FPTAN = 201;;
let _X86_INS_FRNDINT = 202;;
let _X86_INS_FRSTOR = 203;;
let _X86_INS_FNSAVE = 204;;
let _X86_INS_FSCALE = 205;;
let _X86_INS_FSETPM = 206;;
let _X86_INS_FSINCOS = 207;;
let _X86_INS_FNSTENV = 208;;
let _X86_INS_FXAM = 209;;
let _X86_INS_FXRSTOR = 210;;
let _X86_INS_FXRSTOR64 = 211;;
let _X86_INS_FXSAVE = 212;;
let _X86_INS_FXSAVE64 = 213;;
let _X86_INS_FXTRACT = 214;;
let _X86_INS_FYL2X = 215;;
let _X86_INS_FYL2XP1 = 216;;
let _X86_INS_GETSEC = 217;;
let _X86_INS_GF2P8AFFINEINVQB = 218;;
let _X86_INS_GF2P8AFFINEQB = 219;;
let _X86_INS_GF2P8MULB = 220;;
let _X86_INS_HADDPD = 221;;
let _X86_INS_HADDPS = 222;;
let _X86_INS_HLT = 223;;
let _X86_INS_HSUBPD = 224;;
let _X86_INS_HSUBPS = 225;;
let _X86_INS_IDIV = 226;;
let _X86_INS_FILD = 227;;
let _X86_INS_IMUL = 228;;
let _X86_INS_IN = 229;;
let _X86_INS_INC = 230;;
let _X86_INS_INCSSPD = 231;;
let _X86_INS_INCSSPQ = 232;;
let _X86_INS_INSB = 233;;
let _X86_INS_INSERTPS = 234;;
let _X86_INS_INSERTQ = 235;;
let _X86_INS_INSD = 236;;
let _X86_INS_INSW = 237;;
let _X86_INS_INT = 238;;
let _X86_INS_INT1 = 239;;
let _X86_INS_INT3 = 240;;
let _X86_INS_INTO = 241;;
let _X86_INS_INVD = 242;;
let _X86_INS_INVEPT = 243;;
let _X86_INS_INVLPG = 244;;
let _X86_INS_INVLPGA = 245;;
let _X86_INS_INVPCID = 246;;
let _X86_INS_INVVPID = 247;;
let _X86_INS_IRET = 248;;
let _X86_INS_IRETD = 249;;
let _X86_INS_IRETQ = 250;;
let _X86_INS_FISTTP = 251;;
let _X86_INS_FIST = 252;;
let _X86_INS_FISTP = 253;;
let _X86_INS_JAE = 254;;
let _X86_INS_JA = 255;;
let _X86_INS_JBE = 256;;
let _X86_INS_JB = 257;;
let _X86_INS_JCXZ = 258;;
let _X86_INS_JECXZ = 259;;
let _X86_INS_JE = 260;;
let _X86_INS_JGE = 261;;
let _X86_INS_JG = 262;;
let _X86_INS_JLE = 263;;
let _X86_INS_JL = 264;;
let _X86_INS_JNE = 265;;
let _X86_INS_JNO = 266;;
let _X86_INS_JNP = 267;;
let _X86_INS_JNS = 268;;
let _X86_INS_JO = 269;;
let _X86_INS_JP = 270;;
let _X86_INS_JRCXZ = 271;;
let _X86_INS_JS = 272;;
let _X86_INS_KADDB = 273;;
let _X86_INS_KADDD = 274;;
let _X86_INS_KADDQ = 275;;
let _X86_INS_KADDW = 276;;
let _X86_INS_KANDB = 277;;
let _X86_INS_KANDD = 278;;
let _X86_INS_KANDNB = 279;;
let _X86_INS_KANDND = 280;;
let _X86_INS_KANDNQ = 281;;
let _X86_INS_KANDNW = 282;;
let _X86_INS_KANDQ = 283;;
let _X86_INS_KANDW = 284;;
let _X86_INS_KMOVB = 285;;
let _X86_INS_KMOVD = 286;;
let _X86_INS_KMOVQ = 287;;
let _X86_INS_KMOVW = 288;;
let _X86_INS_KNOTB = 289;;
let _X86_INS_KNOTD = 290;;
let _X86_INS_KNOTQ = 291;;
let _X86_INS_KNOTW = 292;;
let _X86_INS_KORB = 293;;
let _X86_INS_KORD = 294;;
let _X86_INS_KORQ = 295;;
let _X86_INS_KORTESTB = 296;;
let _X86_INS_KORTESTD = 297;;
let _X86_INS_KORTESTQ = 298;;
let _X86_INS_KORTESTW = 299;;
let _X86_INS_KORW = 300;;
let _X86_INS_KSHIFTLB = 301;;
let _X86_INS_KSHIFTLD = 302;;
let _X86_INS_KSHIFTLQ = 303;;
let _X86_INS_KSHIFTLW = 304;;
let _X86_INS_KSHIFTRB = 305;;
let _X86_INS_KSHIFTRD = 306;;
let _X86_INS_KSHIFTRQ = 307;;
let _X86_INS_KSHIFTRW = 308;;
let _X86_INS_KTESTB = 309;;
let _X86_INS_KTESTD = 310;;
let _X86_INS_KTESTQ = 311;;
let _X86_INS_KTESTW = 312;;
let _X86_INS_KUNPCKBW = 313;;
let _X86_INS_KUNPCKDQ = 314;;
let _X86_INS_KUNPCKWD = 315;;
let _X86_INS_KXNORB = 316;;
let _X86_INS_KXNORD = 317;;
let _X86_INS_KXNORQ = 318;;
let _X86_INS_KXNORW = 319;;
let _X86_INS_KXORB = 320;;
let _X86_INS_KXORD = 321;;
let _X86_INS_KXORQ = 322;;
let _X86_INS_KXORW = 323;;
let _X86_INS_LAHF = 324;;
let _X86_INS_LAR = 325;;
let _X86_INS_LDDQU = 326;;
let _X86_INS_LDMXCSR = 327;;
let _X86_INS_LDS = 328;;
let _X86_INS_FLDZ = 329;;
let _X86_INS_FLD1 = 330;;
let _X86_INS_FLD = 331;;
let _X86_INS_LEA = 332;;
let _X86_INS_LEAVE = 333;;
let _X86_INS_LES = 334;;
let _X86_INS_LFENCE = 335;;
let _X86_INS_LFS = 336;;
let _X86_INS_LGDT = 337;;
let _X86_INS_LGS = 338;;
let _X86_INS_LIDT = 339;;
let _X86_INS_LLDT = 340;;
let _X86_INS_LLWPCB = 341;;
let _X86_INS_LMSW = 342;;
let _X86_INS_LOCK = 343;;
let _X86_INS_LODSB = 344;;
let _X86_INS_LODSD = 345;;
let _X86_INS_LODSQ = 346;;
let _X86_INS_LODSW = 347;;
let _X86_INS_LOOP = 348;;
let _X86_INS_LOOPE = 349;;
let _X86_INS_LOOPNE = 350;;
let _X86_INS_RETF = 351;;
let _X86_INS_RETFQ = 352;;
let _X86_INS_LSL = 353;;
let _X86_INS_LSS = 354;;
let _X86_INS_LTR = 355;;
let _X86_INS_LWPINS = 356;;
let _X86_INS_LWPVAL = 357;;
let _X86_INS_LZCNT = 358;;
let _X86_INS_MASKMOVDQU = 359;;
let _X86_INS_MAXPD = 360;;
let _X86_INS_MAXPS = 361;;
let _X86_INS_MAXSD = 362;;
let _X86_INS_MAXSS = 363;;
let _X86_INS_MFENCE = 364;;
let _X86_INS_MINPD = 365;;
let _X86_INS_MINPS = 366;;
let _X86_INS_MINSD = 367;;
let _X86_INS_MINSS = 368;;
let _X86_INS_CVTPD2PI = 369;;
let _X86_INS_CVTPI2PD = 370;;
let _X86_INS_CVTPI2PS = 371;;
let _X86_INS_CVTPS2PI = 372;;
let _X86_INS_CVTTPD2PI = 373;;
let _X86_INS_CVTTPS2PI = 374;;
let _X86_INS_EMMS = 375;;
let _X86_INS_MASKMOVQ = 376;;
let _X86_INS_MOVD = 377;;
let _X86_INS_MOVQ = 378;;
let _X86_INS_MOVDQ2Q = 379;;
let _X86_INS_MOVNTQ = 380;;
let _X86_INS_MOVQ2DQ = 381;;
let _X86_INS_PABSB = 382;;
let _X86_INS_PABSD = 383;;
let _X86_INS_PABSW = 384;;
let _X86_INS_PACKSSDW = 385;;
let _X86_INS_PACKSSWB = 386;;
let _X86_INS_PACKUSWB = 387;;
let _X86_INS_PADDB = 388;;
let _X86_INS_PADDD = 389;;
let _X86_INS_PADDQ = 390;;
let _X86_INS_PADDSB = 391;;
let _X86_INS_PADDSW = 392;;
let _X86_INS_PADDUSB = 393;;
let _X86_INS_PADDUSW = 394;;
let _X86_INS_PADDW = 395;;
let _X86_INS_PALIGNR = 396;;
let _X86_INS_PANDN = 397;;
let _X86_INS_PAND = 398;;
let _X86_INS_PAVGB = 399;;
let _X86_INS_PAVGW = 400;;
let _X86_INS_PCMPEQB = 401;;
let _X86_INS_PCMPEQD = 402;;
let _X86_INS_PCMPEQW = 403;;
let _X86_INS_PCMPGTB = 404;;
let _X86_INS_PCMPGTD = 405;;
let _X86_INS_PCMPGTW = 406;;
let _X86_INS_PEXTRW = 407;;
let _X86_INS_PHADDD = 408;;
let _X86_INS_PHADDSW = 409;;
let _X86_INS_PHADDW = 410;;
let _X86_INS_PHSUBD = 411;;
let _X86_INS_PHSUBSW = 412;;
let _X86_INS_PHSUBW = 413;;
let _X86_INS_PINSRW = 414;;
let _X86_INS_PMADDUBSW = 415;;
let _X86_INS_PMADDWD = 416;;
let _X86_INS_PMAXSW = 417;;
let _X86_INS_PMAXUB = 418;;
let _X86_INS_PMINSW = 419;;
let _X86_INS_PMINUB = 420;;
let _X86_INS_PMOVMSKB = 421;;
let _X86_INS_PMULHRSW = 422;;
let _X86_INS_PMULHUW = 423;;
let _X86_INS_PMULHW = 424;;
let _X86_INS_PMULLW = 425;;
let _X86_INS_PMULUDQ = 426;;
let _X86_INS_POR = 427;;
let _X86_INS_PSADBW = 428;;
let _X86_INS_PSHUFB = 429;;
let _X86_INS_PSHUFW = 430;;
let _X86_INS_PSIGNB = 431;;
let _X86_INS_PSIGND = 432;;
let _X86_INS_PSIGNW = 433;;
let _X86_INS_PSLLD = 434;;
let _X86_INS_PSLLQ = 435;;
let _X86_INS_PSLLW = 436;;
let _X86_INS_PSRAD = 437;;
let _X86_INS_PSRAW = 438;;
let _X86_INS_PSRLD = 439;;
let _X86_INS_PSRLQ = 440;;
let _X86_INS_PSRLW = 441;;
let _X86_INS_PSUBB = 442;;
let _X86_INS_PSUBD = 443;;
let _X86_INS_PSUBQ = 444;;
let _X86_INS_PSUBSB = 445;;
let _X86_INS_PSUBSW = 446;;
let _X86_INS_PSUBUSB = 447;;
let _X86_INS_PSUBUSW = 448;;
let _X86_INS_PSUBW = 449;;
let _X86_INS_PUNPCKHBW = 450;;
let _X86_INS_PUNPCKHDQ = 451;;
let _X86_INS_PUNPCKHWD = 452;;
let _X86_INS_PUNPCKLBW = 453;;
let _X86_INS_PUNPCKLDQ = 454;;
let _X86_INS_PUNPCKLWD = 455;;
let _X86_INS_PXOR = 456;;
let _X86_INS_MONITORX = 457;;
let _X86_INS_MONITOR = 458;;
let _X86_INS_MONTMUL = 459;;
let _X86_INS_MOV = 460;;
let _X86_INS_MOVABS = 461;;
let _X86_INS_MOVAPD = 462;;
let _X86_INS_MOVAPS = 463;;
let _X86_INS_MOVBE = 464;;
let _X86_INS_MOVDDUP = 465;;
let _X86_INS_MOVDIR64B = 466;;
let _X86_INS_MOVDIRI = 467;;
let _X86_INS_MOVDQA = 468;;
let _X86_INS_MOVDQU = 469;;
let _X86_INS_MOVHLPS = 470;;
let _X86_INS_MOVHPD = 471;;
let _X86_INS_MOVHPS = 472;;
let _X86_INS_MOVLHPS = 473;;
let _X86_INS_MOVLPD = 474;;
let _X86_INS_MOVLPS = 475;;
let _X86_INS_MOVMSKPD = 476;;
let _X86_INS_MOVMSKPS = 477;;
let _X86_INS_MOVNTDQA = 478;;
let _X86_INS_MOVNTDQ = 479;;
let _X86_INS_MOVNTI = 480;;
let _X86_INS_MOVNTPD = 481;;
let _X86_INS_MOVNTPS = 482;;
let _X86_INS_MOVNTSD = 483;;
let _X86_INS_MOVNTSS = 484;;
let _X86_INS_MOVSB = 485;;
let _X86_INS_MOVSD = 486;;
let _X86_INS_MOVSHDUP = 487;;
let _X86_INS_MOVSLDUP = 488;;
let _X86_INS_MOVSQ = 489;;
let _X86_INS_MOVSS = 490;;
let _X86_INS_MOVSW = 491;;
let _X86_INS_MOVSX = 492;;
let _X86_INS_MOVSXD = 493;;
let _X86_INS_MOVUPD = 494;;
let _X86_INS_MOVUPS = 495;;
let _X86_INS_MOVZX = 496;;
let _X86_INS_MPSADBW = 497;;
let _X86_INS_MUL = 498;;
let _X86_INS_MULPD = 499;;
let _X86_INS_MULPS = 500;;
let _X86_INS_MULSD = 501;;
let _X86_INS_MULSS = 502;;
let _X86_INS_MULX = 503;;
let _X86_INS_FMUL = 504;;
let _X86_INS_FIMUL = 505;;
let _X86_INS_FMULP = 506;;
let _X86_INS_MWAITX = 507;;
let _X86_INS_MWAIT = 508;;
let _X86_INS_NEG = 509;;
let _X86_INS_NOP = 510;;
let _X86_INS_NOT = 511;;
let _X86_INS_OR = 512;;
let _X86_INS_ORPD = 513;;
let _X86_INS_ORPS = 514;;
let _X86_INS_OUT = 515;;
let _X86_INS_OUTSB = 516;;
let _X86_INS_OUTSD = 517;;
let _X86_INS_OUTSW = 518;;
let _X86_INS_PACKUSDW = 519;;
let _X86_INS_PAUSE = 520;;
let _X86_INS_PAVGUSB = 521;;
let _X86_INS_PBLENDVB = 522;;
let _X86_INS_PBLENDW = 523;;
let _X86_INS_PCLMULQDQ = 524;;
let _X86_INS_PCMPEQQ = 525;;
let _X86_INS_PCMPESTRI = 526;;
let _X86_INS_PCMPESTRM = 527;;
let _X86_INS_PCMPGTQ = 528;;
let _X86_INS_PCMPISTRI = 529;;
let _X86_INS_PCMPISTRM = 530;;
let _X86_INS_PCONFIG = 531;;
let _X86_INS_PDEP = 532;;
let _X86_INS_PEXT = 533;;
let _X86_INS_PEXTRB = 534;;
let _X86_INS_PEXTRD = 535;;
let _X86_INS_PEXTRQ = 536;;
let _X86_INS_PF2ID = 537;;
let _X86_INS_PF2IW = 538;;
let _X86_INS_PFACC = 539;;
let _X86_INS_PFADD = 540;;
let _X86_INS_PFCMPEQ = 541;;
let _X86_INS_PFCMPGE = 542;;
let _X86_INS_PFCMPGT = 543;;
let _X86_INS_PFMAX = 544;;
let _X86_INS_PFMIN = 545;;
let _X86_INS_PFMUL = 546;;
let _X86_INS_PFNACC = 547;;
let _X86_INS_PFPNACC = 548;;
let _X86_INS_PFRCPIT1 = 549;;
let _X86_INS_PFRCPIT2 = 550;;
let _X86_INS_PFRCP = 551;;
let _X86_INS_PFRSQIT1 = 552;;
let _X86_INS_PFRSQRT = 553;;
let _X86_INS_PFSUBR = 554;;
let _X86_INS_PFSUB = 555;;
let _X86_INS_PHMINPOSUW = 556;;
let _X86_INS_PI2FD = 557;;
let _X86_INS_PI2FW = 558;;
let _X86_INS_PINSRB = 559;;
let _X86_INS_PINSRD = 560;;
let _X86_INS_PINSRQ = 561;;
let _X86_INS_PMAXSB = 562;;
let _X86_INS_PMAXSD = 563;;
let _X86_INS_PMAXUD = 564;;
let _X86_INS_PMAXUW = 565;;
let _X86_INS_PMINSB = 566;;
let _X86_INS_PMINSD = 567;;
let _X86_INS_PMINUD = 568;;
let _X86_INS_PMINUW = 569;;
let _X86_INS_PMOVSXBD = 570;;
let _X86_INS_PMOVSXBQ = 571;;
let _X86_INS_PMOVSXBW = 572;;
let _X86_INS_PMOVSXDQ = 573;;
let _X86_INS_PMOVSXWD = 574;;
let _X86_INS_PMOVSXWQ = 575;;
let _X86_INS_PMOVZXBD = 576;;
let _X86_INS_PMOVZXBQ = 577;;
let _X86_INS_PMOVZXBW = 578;;
let _X86_INS_PMOVZXDQ = 579;;
let _X86_INS_PMOVZXWD = 580;;
let _X86_INS_PMOVZXWQ = 581;;
let _X86_INS_PMULDQ = 582;;
let _X86_INS_PMULHRW = 583;;
let _X86_INS_PMULLD = 584;;
let _X86_INS_POP = 585;;
let _X86_INS_POPAW = 586;;
let _X86_INS_POPAL = 587;;
let _X86_INS_POPCNT = 588;;
let _X86_INS_POPF = 589;;
let _X86_INS_POPFD = 590;;
let _X86_INS_POPFQ = 591;;
let _X86_INS_PREFETCH = 592;;
let _X86_INS_PREFETCHNTA = 593;;
let _X86_INS_PREFETCHT0 = 594;;
let _X86_INS_PREFETCHT1 = 595;;
let _X86_INS_PREFETCHT2 = 596;;
let _X86_INS_PREFETCHW = 597;;
let _X86_INS_PREFETCHWT1 = 598;;
let _X86_INS_PSHUFD = 599;;
let _X86_INS_PSHUFHW = 600;;
let _X86_INS_PSHUFLW = 601;;
let _X86_INS_PSLLDQ = 602;;
let _X86_INS_PSRLDQ = 603;;
let _X86_INS_PSWAPD = 604;;
let _X86_INS_PTEST = 605;;
let _X86_INS_PTWRITE = 606;;
let _X86_INS_PUNPCKHQDQ = 607;;
let _X86_INS_PUNPCKLQDQ = 608;;
let _X86_INS_PUSH = 609;;
let _X86_INS_PUSHAW = 610;;
let _X86_INS_PUSHAL = 611;;
let _X86_INS_PUSHF = 612;;
let _X86_INS_PUSHFD = 613;;
let _X86_INS_PUSHFQ = 614;;
let _X86_INS_RCL = 615;;
let _X86_INS_RCPPS = 616;;
let _X86_INS_RCPSS = 617;;
let _X86_INS_RCR = 618;;
let _X86_INS_RDFSBASE = 619;;
let _X86_INS_RDGSBASE = 620;;
let _X86_INS_RDMSR = 621;;
let _X86_INS_RDPID = 622;;
let _X86_INS_RDPKRU = 623;;
let _X86_INS_RDPMC = 624;;
let _X86_INS_RDRAND = 625;;
let _X86_INS_RDSEED = 626;;
let _X86_INS_RDSSPD = 627;;
let _X86_INS_RDSSPQ = 628;;
let _X86_INS_RDTSC = 629;;
let _X86_INS_RDTSCP = 630;;
let _X86_INS_REPNE = 631;;
let _X86_INS_REP = 632;;
let _X86_INS_RET = 633;;
let _X86_INS_REX64 = 634;;
let _X86_INS_ROL = 635;;
let _X86_INS_ROR = 636;;
let _X86_INS_RORX = 637;;
let _X86_INS_ROUNDPD = 638;;
let _X86_INS_ROUNDPS = 639;;
let _X86_INS_ROUNDSD = 640;;
let _X86_INS_ROUNDSS = 641;;
let _X86_INS_RSM = 642;;
let _X86_INS_RSQRTPS = 643;;
let _X86_INS_RSQRTSS = 644;;
let _X86_INS_RSTORSSP = 645;;
let _X86_INS_SAHF = 646;;
let _X86_INS_SAL = 647;;
let _X86_INS_SALC = 648;;
let _X86_INS_SAR = 649;;
let _X86_INS_SARX = 650;;
let _X86_INS_SAVEPREVSSP = 651;;
let _X86_INS_SBB = 652;;
let _X86_INS_SCASB = 653;;
let _X86_INS_SCASD = 654;;
let _X86_INS_SCASQ = 655;;
let _X86_INS_SCASW = 656;;
let _X86_INS_SETAE = 657;;
let _X86_INS_SETA = 658;;
let _X86_INS_SETBE = 659;;
let _X86_INS_SETB = 660;;
let _X86_INS_SETE = 661;;
let _X86_INS_SETGE = 662;;
let _X86_INS_SETG = 663;;
let _X86_INS_SETLE = 664;;
let _X86_INS_SETL = 665;;
let _X86_INS_SETNE = 666;;
let _X86_INS_SETNO = 667;;
let _X86_INS_SETNP = 668;;
let _X86_INS_SETNS = 669;;
let _X86_INS_SETO = 670;;
let _X86_INS_SETP = 671;;
let _X86_INS_SETSSBSY = 672;;
let _X86_INS_SETS = 673;;
let _X86_INS_SFENCE = 674;;
let _X86_INS_SGDT = 675;;
let _X86_INS_SHA1MSG1 = 676;;
let _X86_INS_SHA1MSG2 = 677;;
let _X86_INS_SHA1NEXTE = 678;;
let _X86_INS_SHA1RNDS4 = 679;;
let _X86_INS_SHA256MSG1 = 680;;
let _X86_INS_SHA256MSG2 = 681;;
let _X86_INS_SHA256RNDS2 = 682;;
let _X86_INS_SHL = 683;;
let _X86_INS_SHLD = 684;;
let _X86_INS_SHLX = 685;;
let _X86_INS_SHR = 686;;
let _X86_INS_SHRD = 687;;
let _X86_INS_SHRX = 688;;
let _X86_INS_SHUFPD = 689;;
let _X86_INS_SHUFPS = 690;;
let _X86_INS_SIDT = 691;;
let _X86_INS_FSIN = 692;;
let _X86_INS_SKINIT = 693;;
let _X86_INS_SLDT = 694;;
let _X86_INS_SLWPCB = 695;;
let _X86_INS_SMSW = 696;;
let _X86_INS_SQRTPD = 697;;
let _X86_INS_SQRTPS = 698;;
let _X86_INS_SQRTSD = 699;;
let _X86_INS_SQRTSS = 700;;
let _X86_INS_FSQRT = 701;;
let _X86_INS_STAC = 702;;
let _X86_INS_STC = 703;;
let _X86_INS_STD = 704;;
let _X86_INS_STGI = 705;;
let _X86_INS_STI = 706;;
let _X86_INS_STMXCSR = 707;;
let _X86_INS_STOSB = 708;;
let _X86_INS_STOSD = 709;;
let _X86_INS_STOSQ = 710;;
let _X86_INS_STOSW = 711;;
let _X86_INS_STR = 712;;
let _X86_INS_FST = 713;;
let _X86_INS_FSTP = 714;;
let _X86_INS_SUB = 715;;
let _X86_INS_SUBPD = 716;;
let _X86_INS_SUBPS = 717;;
let _X86_INS_FSUBR = 718;;
let _X86_INS_FISUBR = 719;;
let _X86_INS_FSUBRP = 720;;
let _X86_INS_SUBSD = 721;;
let _X86_INS_SUBSS = 722;;
let _X86_INS_FSUB = 723;;
let _X86_INS_FISUB = 724;;
let _X86_INS_FSUBP = 725;;
let _X86_INS_SWAPGS = 726;;
let _X86_INS_SYSCALL = 727;;
let _X86_INS_SYSENTER = 728;;
let _X86_INS_SYSEXIT = 729;;
let _X86_INS_SYSEXITQ = 730;;
let _X86_INS_SYSRET = 731;;
let _X86_INS_SYSRETQ = 732;;
let _X86_INS_T1MSKC = 733;;
let _X86_INS_TEST = 734;;
let _X86_INS_TPAUSE = 735;;
let _X86_INS_FTST = 736;;
let _X86_INS_TZCNT = 737;;
let _X86_INS_TZMSK = 738;;
let _X86_INS_UCOMISD = 739;;
let _X86_INS_UCOMISS = 740;;
let _X86_INS_FUCOMPI = 741;;
let _X86_INS_FUCOMI = 742;;
let _X86_INS_FUCOMPP = 743;;
let _X86_INS_FUCOMP = 744;;
let _X86_INS_FUCOM = 745;;
let _X86_INS_UD0 = 746;;
let _X86_INS_UD1 = 747;;
let _X86_INS_UD2 = 748;;
let _X86_INS_UMONITOR = 749;;
let _X86_INS_UMWAIT = 750;;
let _X86_INS_UNPCKHPD = 751;;
let _X86_INS_UNPCKHPS = 752;;
let _X86_INS_UNPCKLPD = 753;;
let _X86_INS_UNPCKLPS = 754;;
let _X86_INS_V4FMADDPS = 755;;
let _X86_INS_V4FMADDSS = 756;;
let _X86_INS_V4FNMADDPS = 757;;
let _X86_INS_V4FNMADDSS = 758;;
let _X86_INS_VADDPD = 759;;
let _X86_INS_VADDPS = 760;;
let _X86_INS_VADDSD = 761;;
let _X86_INS_VADDSS = 762;;
let _X86_INS_VADDSUBPD = 763;;
let _X86_INS_VADDSUBPS = 764;;
let _X86_INS_VAESDECLAST = 765;;
let _X86_INS_VAESDEC = 766;;
let _X86_INS_VAESENCLAST = 767;;
let _X86_INS_VAESENC = 768;;
let _X86_INS_VAESIMC = 769;;
let _X86_INS_VAESKEYGENASSIST = 770;;
let _X86_INS_VALIGND = 771;;
let _X86_INS_VALIGNQ = 772;;
let _X86_INS_VANDNPD = 773;;
let _X86_INS_VANDNPS = 774;;
let _X86_INS_VANDPD = 775;;
let _X86_INS_VANDPS = 776;;
let _X86_INS_VBLENDMPD = 777;;
let _X86_INS_VBLENDMPS = 778;;
let _X86_INS_VBLENDPD = 779;;
let _X86_INS_VBLENDPS = 780;;
let _X86_INS_VBLENDVPD = 781;;
let _X86_INS_VBLENDVPS = 782;;
let _X86_INS_VBROADCASTF128 = 783;;
let _X86_INS_VBROADCASTF32X2 = 784;;
let _X86_INS_VBROADCASTF32X4 = 785;;
let _X86_INS_VBROADCASTF32X8 = 786;;
let _X86_INS_VBROADCASTF64X2 = 787;;
let _X86_INS_VBROADCASTF64X4 = 788;;
let _X86_INS_VBROADCASTI128 = 789;;
let _X86_INS_VBROADCASTI32X2 = 790;;
let _X86_INS_VBROADCASTI32X4 = 791;;
let _X86_INS_VBROADCASTI32X8 = 792;;
let _X86_INS_VBROADCASTI64X2 = 793;;
let _X86_INS_VBROADCASTI64X4 = 794;;
let _X86_INS_VBROADCASTSD = 795;;
let _X86_INS_VBROADCASTSS = 796;;
let _X86_INS_VCMP = 797;;
let _X86_INS_VCMPPD = 798;;
let _X86_INS_VCMPPS = 799;;
let _X86_INS_VCMPSD = 800;;
let _X86_INS_VCMPSS = 801;;
let _X86_INS_VCOMISD = 802;;
let _X86_INS_VCOMISS = 803;;
let _X86_INS_VCOMPRESSPD = 804;;
let _X86_INS_VCOMPRESSPS = 805;;
let _X86_INS_VCVTDQ2PD = 806;;
let _X86_INS_VCVTDQ2PS = 807;;
let _X86_INS_VCVTPD2DQ = 808;;
let _X86_INS_VCVTPD2PS = 809;;
let _X86_INS_VCVTPD2QQ = 810;;
let _X86_INS_VCVTPD2UDQ = 811;;
let _X86_INS_VCVTPD2UQQ = 812;;
let _X86_INS_VCVTPH2PS = 813;;
let _X86_INS_VCVTPS2DQ = 814;;
let _X86_INS_VCVTPS2PD = 815;;
let _X86_INS_VCVTPS2PH = 816;;
let _X86_INS_VCVTPS2QQ = 817;;
let _X86_INS_VCVTPS2UDQ = 818;;
let _X86_INS_VCVTPS2UQQ = 819;;
let _X86_INS_VCVTQQ2PD = 820;;
let _X86_INS_VCVTQQ2PS = 821;;
let _X86_INS_VCVTSD2SI = 822;;
let _X86_INS_VCVTSD2SS = 823;;
let _X86_INS_VCVTSD2USI = 824;;
let _X86_INS_VCVTSI2SD = 825;;
let _X86_INS_VCVTSI2SS = 826;;
let _X86_INS_VCVTSS2SD = 827;;
let _X86_INS_VCVTSS2SI = 828;;
let _X86_INS_VCVTSS2USI = 829;;
let _X86_INS_VCVTTPD2DQ = 830;;
let _X86_INS_VCVTTPD2QQ = 831;;
let _X86_INS_VCVTTPD2UDQ = 832;;
let _X86_INS_VCVTTPD2UQQ = 833;;
let _X86_INS_VCVTTPS2DQ = 834;;
let _X86_INS_VCVTTPS2QQ = 835;;
let _X86_INS_VCVTTPS2UDQ = 836;;
let _X86_INS_VCVTTPS2UQQ = 837;;
let _X86_INS_VCVTTSD2SI = 838;;
let _X86_INS_VCVTTSD2USI = 839;;
let _X86_INS_VCVTTSS2SI = 840;;
let _X86_INS_VCVTTSS2USI = 841;;
let _X86_INS_VCVTUDQ2PD = 842;;
let _X86_INS_VCVTUDQ2PS = 843;;
let _X86_INS_VCVTUQQ2PD = 844;;
let _X86_INS_VCVTUQQ2PS = 845;;
let _X86_INS_VCVTUSI2SD = 846;;
let _X86_INS_VCVTUSI2SS = 847;;
let _X86_INS_VDBPSADBW = 848;;
let _X86_INS_VDIVPD = 849;;
let _X86_INS_VDIVPS = 850;;
let _X86_INS_VDIVSD = 851;;
let _X86_INS_VDIVSS = 852;;
let _X86_INS_VDPPD = 853;;
let _X86_INS_VDPPS = 854;;
let _X86_INS_VERR = 855;;
let _X86_INS_VERW = 856;;
let _X86_INS_VEXP2PD = 857;;
let _X86_INS_VEXP2PS = 858;;
let _X86_INS_VEXPANDPD = 859;;
let _X86_INS_VEXPANDPS = 860;;
let _X86_INS_VEXTRACTF128 = 861;;
let _X86_INS_VEXTRACTF32X4 = 862;;
let _X86_INS_VEXTRACTF32X8 = 863;;
let _X86_INS_VEXTRACTF64X2 = 864;;
let _X86_INS_VEXTRACTF64X4 = 865;;
let _X86_INS_VEXTRACTI128 = 866;;
let _X86_INS_VEXTRACTI32X4 = 867;;
let _X86_INS_VEXTRACTI32X8 = 868;;
let _X86_INS_VEXTRACTI64X2 = 869;;
let _X86_INS_VEXTRACTI64X4 = 870;;
let _X86_INS_VEXTRACTPS = 871;;
let _X86_INS_VFIXUPIMMPD = 872;;
let _X86_INS_VFIXUPIMMPS = 873;;
let _X86_INS_VFIXUPIMMSD = 874;;
let _X86_INS_VFIXUPIMMSS = 875;;
let _X86_INS_VFMADD132PD = 876;;
let _X86_INS_VFMADD132PS = 877;;
let _X86_INS_VFMADD132SD = 878;;
let _X86_INS_VFMADD132SS = 879;;
let _X86_INS_VFMADD213PD = 880;;
let _X86_INS_VFMADD213PS = 881;;
let _X86_INS_VFMADD213SD = 882;;
let _X86_INS_VFMADD213SS = 883;;
let _X86_INS_VFMADD231PD = 884;;
let _X86_INS_VFMADD231PS = 885;;
let _X86_INS_VFMADD231SD = 886;;
let _X86_INS_VFMADD231SS = 887;;
let _X86_INS_VFMADDPD = 888;;
let _X86_INS_VFMADDPS = 889;;
let _X86_INS_VFMADDSD = 890;;
let _X86_INS_VFMADDSS = 891;;
let _X86_INS_VFMADDSUB132PD = 892;;
let _X86_INS_VFMADDSUB132PS = 893;;
let _X86_INS_VFMADDSUB213PD = 894;;
let _X86_INS_VFMADDSUB213PS = 895;;
let _X86_INS_VFMADDSUB231PD = 896;;
let _X86_INS_VFMADDSUB231PS = 897;;
let _X86_INS_VFMADDSUBPD = 898;;
let _X86_INS_VFMADDSUBPS = 899;;
let _X86_INS_VFMSUB132PD = 900;;
let _X86_INS_VFMSUB132PS = 901;;
let _X86_INS_VFMSUB132SD = 902;;
let _X86_INS_VFMSUB132SS = 903;;
let _X86_INS_VFMSUB213PD = 904;;
let _X86_INS_VFMSUB213PS = 905;;
let _X86_INS_VFMSUB213SD = 906;;
let _X86_INS_VFMSUB213SS = 907;;
let _X86_INS_VFMSUB231PD = 908;;
let _X86_INS_VFMSUB231PS = 909;;
let _X86_INS_VFMSUB231SD = 910;;
let _X86_INS_VFMSUB231SS = 911;;
let _X86_INS_VFMSUBADD132PD = 912;;
let _X86_INS_VFMSUBADD132PS = 913;;
let _X86_INS_VFMSUBADD213PD = 914;;
let _X86_INS_VFMSUBADD213PS = 915;;
let _X86_INS_VFMSUBADD231PD = 916;;
let _X86_INS_VFMSUBADD231PS = 917;;
let _X86_INS_VFMSUBADDPD = 918;;
let _X86_INS_VFMSUBADDPS = 919;;
let _X86_INS_VFMSUBPD = 920;;
let _X86_INS_VFMSUBPS = 921;;
let _X86_INS_VFMSUBSD = 922;;
let _X86_INS_VFMSUBSS = 923;;
let _X86_INS_VFNMADD132PD = 924;;
let _X86_INS_VFNMADD132PS = 925;;
let _X86_INS_VFNMADD132SD = 926;;
let _X86_INS_VFNMADD132SS = 927;;
let _X86_INS_VFNMADD213PD = 928;;
let _X86_INS_VFNMADD213PS = 929;;
let _X86_INS_VFNMADD213SD = 930;;
let _X86_INS_VFNMADD213SS = 931;;
let _X86_INS_VFNMADD231PD = 932;;
let _X86_INS_VFNMADD231PS = 933;;
let _X86_INS_VFNMADD231SD = 934;;
let _X86_INS_VFNMADD231SS = 935;;
let _X86_INS_VFNMADDPD = 936;;
let _X86_INS_VFNMADDPS = 937;;
let _X86_INS_VFNMADDSD = 938;;
let _X86_INS_VFNMADDSS = 939;;
let _X86_INS_VFNMSUB132PD = 940;;
let _X86_INS_VFNMSUB132PS = 941;;
let _X86_INS_VFNMSUB132SD = 942;;
let _X86_INS_VFNMSUB132SS = 943;;
let _X86_INS_VFNMSUB213PD = 944;;
let _X86_INS_VFNMSUB213PS = 945;;
let _X86_INS_VFNMSUB213SD = 946;;
let _X86_INS_VFNMSUB213SS = 947;;
let _X86_INS_VFNMSUB231PD = 948;;
let _X86_INS_VFNMSUB231PS = 949;;
let _X86_INS_VFNMSUB231SD = 950;;
let _X86_INS_VFNMSUB231SS = 951;;
let _X86_INS_VFNMSUBPD = 952;;
let _X86_INS_VFNMSUBPS = 953;;
let _X86_INS_VFNMSUBSD = 954;;
let _X86_INS_VFNMSUBSS = 955;;
let _X86_INS_VFPCLASSPD = 956;;
let _X86_INS_VFPCLASSPS = 957;;
let _X86_INS_VFPCLASSSD = 958;;
let _X86_INS_VFPCLASSSS = 959;;
let _X86_INS_VFRCZPD = 960;;
let _X86_INS_VFRCZPS = 961;;
let _X86_INS_VFRCZSD = 962;;
let _X86_INS_VFRCZSS = 963;;
let _X86_INS_VGATHERDPD = 964;;
let _X86_INS_VGATHERDPS = 965;;
let _X86_INS_VGATHERPF0DPD = 966;;
let _X86_INS_VGATHERPF0DPS = 967;;
let _X86_INS_VGATHERPF0QPD = 968;;
let _X86_INS_VGATHERPF0QPS = 969;;
let _X86_INS_VGATHERPF1DPD = 970;;
let _X86_INS_VGATHERPF1DPS = 971;;
let _X86_INS_VGATHERPF1QPD = 972;;
let _X86_INS_VGATHERPF1QPS = 973;;
let _X86_INS_VGATHERQPD = 974;;
let _X86_INS_VGATHERQPS = 975;;
let _X86_INS_VGETEXPPD = 976;;
let _X86_INS_VGETEXPPS = 977;;
let _X86_INS_VGETEXPSD = 978;;
let _X86_INS_VGETEXPSS = 979;;
let _X86_INS_VGETMANTPD = 980;;
let _X86_INS_VGETMANTPS = 981;;
let _X86_INS_VGETMANTSD = 982;;
let _X86_INS_VGETMANTSS = 983;;
let _X86_INS_VGF2P8AFFINEINVQB = 984;;
let _X86_INS_VGF2P8AFFINEQB = 985;;
let _X86_INS_VGF2P8MULB = 986;;
let _X86_INS_VHADDPD = 987;;
let _X86_INS_VHADDPS = 988;;
let _X86_INS_VHSUBPD = 989;;
let _X86_INS_VHSUBPS = 990;;
let _X86_INS_VINSERTF128 = 991;;
let _X86_INS_VINSERTF32X4 = 992;;
let _X86_INS_VINSERTF32X8 = 993;;
let _X86_INS_VINSERTF64X2 = 994;;
let _X86_INS_VINSERTF64X4 = 995;;
let _X86_INS_VINSERTI128 = 996;;
let _X86_INS_VINSERTI32X4 = 997;;
let _X86_INS_VINSERTI32X8 = 998;;
let _X86_INS_VINSERTI64X2 = 999;;
let _X86_INS_VINSERTI64X4 = 1000;;
let _X86_INS_VINSERTPS = 1001;;
let _X86_INS_VLDDQU = 1002;;
let _X86_INS_VLDMXCSR = 1003;;
let _X86_INS_VMASKMOVDQU = 1004;;
let _X86_INS_VMASKMOVPD = 1005;;
let _X86_INS_VMASKMOVPS = 1006;;
let _X86_INS_VMAXPD = 1007;;
let _X86_INS_VMAXPS = 1008;;
let _X86_INS_VMAXSD = 1009;;
let _X86_INS_VMAXSS = 1010;;
let _X86_INS_VMCALL = 1011;;
let _X86_INS_VMCLEAR = 1012;;
let _X86_INS_VMFUNC = 1013;;
let _X86_INS_VMINPD = 1014;;
let _X86_INS_VMINPS = 1015;;
let _X86_INS_VMINSD = 1016;;
let _X86_INS_VMINSS = 1017;;
let _X86_INS_VMLAUNCH = 1018;;
let _X86_INS_VMLOAD = 1019;;
let _X86_INS_VMMCALL = 1020;;
let _X86_INS_VMOVQ = 1021;;
let _X86_INS_VMOVAPD = 1022;;
let _X86_INS_VMOVAPS = 1023;;
let _X86_INS_VMOVDDUP = 1024;;
let _X86_INS_VMOVD = 1025;;
let _X86_INS_VMOVDQA32 = 1026;;
let _X86_INS_VMOVDQA64 = 1027;;
let _X86_INS_VMOVDQA = 1028;;
let _X86_INS_VMOVDQU16 = 1029;;
let _X86_INS_VMOVDQU32 = 1030;;
let _X86_INS_VMOVDQU64 = 1031;;
let _X86_INS_VMOVDQU8 = 1032;;
let _X86_INS_VMOVDQU = 1033;;
let _X86_INS_VMOVHLPS = 1034;;
let _X86_INS_VMOVHPD = 1035;;
let _X86_INS_VMOVHPS = 1036;;
let _X86_INS_VMOVLHPS = 1037;;
let _X86_INS_VMOVLPD = 1038;;
let _X86_INS_VMOVLPS = 1039;;
let _X86_INS_VMOVMSKPD = 1040;;
let _X86_INS_VMOVMSKPS = 1041;;
let _X86_INS_VMOVNTDQA = 1042;;
let _X86_INS_VMOVNTDQ = 1043;;
let _X86_INS_VMOVNTPD = 1044;;
let _X86_INS_VMOVNTPS = 1045;;
let _X86_INS_VMOVSD = 1046;;
let _X86_INS_VMOVSHDUP = 1047;;
let _X86_INS_VMOVSLDUP = 1048;;
let _X86_INS_VMOVSS = 1049;;
let _X86_INS_VMOVUPD = 1050;;
let _X86_INS_VMOVUPS = 1051;;
let _X86_INS_VMPSADBW = 1052;;
let _X86_INS_VMPTRLD = 1053;;
let _X86_INS_VMPTRST = 1054;;
let _X86_INS_VMREAD = 1055;;
let _X86_INS_VMRESUME = 1056;;
let _X86_INS_VMRUN = 1057;;
let _X86_INS_VMSAVE = 1058;;
let _X86_INS_VMULPD = 1059;;
let _X86_INS_VMULPS = 1060;;
let _X86_INS_VMULSD = 1061;;
let _X86_INS_VMULSS = 1062;;
let _X86_INS_VMWRITE = 1063;;
let _X86_INS_VMXOFF = 1064;;
let _X86_INS_VMXON = 1065;;
let _X86_INS_VORPD = 1066;;
let _X86_INS_VORPS = 1067;;
let _X86_INS_VP4DPWSSDS = 1068;;
let _X86_INS_VP4DPWSSD = 1069;;
let _X86_INS_VPABSB = 1070;;
let _X86_INS_VPABSD = 1071;;
let _X86_INS_VPABSQ = 1072;;
let _X86_INS_VPABSW = 1073;;
let _X86_INS_VPACKSSDW = 1074;;
let _X86_INS_VPACKSSWB = 1075;;
let _X86_INS_VPACKUSDW = 1076;;
let _X86_INS_VPACKUSWB = 1077;;
let _X86_INS_VPADDB = 1078;;
let _X86_INS_VPADDD = 1079;;
let _X86_INS_VPADDQ = 1080;;
let _X86_INS_VPADDSB = 1081;;
let _X86_INS_VPADDSW = 1082;;
let _X86_INS_VPADDUSB = 1083;;
let _X86_INS_VPADDUSW = 1084;;
let _X86_INS_VPADDW = 1085;;
let _X86_INS_VPALIGNR = 1086;;
let _X86_INS_VPANDD = 1087;;
let _X86_INS_VPANDND = 1088;;
let _X86_INS_VPANDNQ = 1089;;
let _X86_INS_VPANDN = 1090;;
let _X86_INS_VPANDQ = 1091;;
let _X86_INS_VPAND = 1092;;
let _X86_INS_VPAVGB = 1093;;
let _X86_INS_VPAVGW = 1094;;
let _X86_INS_VPBLENDD = 1095;;
let _X86_INS_VPBLENDMB = 1096;;
let _X86_INS_VPBLENDMD = 1097;;
let _X86_INS_VPBLENDMQ = 1098;;
let _X86_INS_VPBLENDMW = 1099;;
let _X86_INS_VPBLENDVB = 1100;;
let _X86_INS_VPBLENDW = 1101;;
let _X86_INS_VPBROADCASTB = 1102;;
let _X86_INS_VPBROADCASTD = 1103;;
let _X86_INS_VPBROADCASTMB2Q = 1104;;
let _X86_INS_VPBROADCASTMW2D = 1105;;
let _X86_INS_VPBROADCASTQ = 1106;;
let _X86_INS_VPBROADCASTW = 1107;;
let _X86_INS_VPCLMULQDQ = 1108;;
let _X86_INS_VPCMOV = 1109;;
let _X86_INS_VPCMP = 1110;;
let _X86_INS_VPCMPB = 1111;;
let _X86_INS_VPCMPD = 1112;;
let _X86_INS_VPCMPEQB = 1113;;
let _X86_INS_VPCMPEQD = 1114;;
let _X86_INS_VPCMPEQQ = 1115;;
let _X86_INS_VPCMPEQW = 1116;;
let _X86_INS_VPCMPESTRI = 1117;;
let _X86_INS_VPCMPESTRM = 1118;;
let _X86_INS_VPCMPGTB = 1119;;
let _X86_INS_VPCMPGTD = 1120;;
let _X86_INS_VPCMPGTQ = 1121;;
let _X86_INS_VPCMPGTW = 1122;;
let _X86_INS_VPCMPISTRI = 1123;;
let _X86_INS_VPCMPISTRM = 1124;;
let _X86_INS_VPCMPQ = 1125;;
let _X86_INS_VPCMPUB = 1126;;
let _X86_INS_VPCMPUD = 1127;;
let _X86_INS_VPCMPUQ = 1128;;
let _X86_INS_VPCMPUW = 1129;;
let _X86_INS_VPCMPW = 1130;;
let _X86_INS_VPCOM = 1131;;
let _X86_INS_VPCOMB = 1132;;
let _X86_INS_VPCOMD = 1133;;
let _X86_INS_VPCOMPRESSB = 1134;;
let _X86_INS_VPCOMPRESSD = 1135;;
let _X86_INS_VPCOMPRESSQ = 1136;;
let _X86_INS_VPCOMPRESSW = 1137;;
let _X86_INS_VPCOMQ = 1138;;
let _X86_INS_VPCOMUB = 1139;;
let _X86_INS_VPCOMUD = 1140;;
let _X86_INS_VPCOMUQ = 1141;;
let _X86_INS_VPCOMUW = 1142;;
let _X86_INS_VPCOMW = 1143;;
let _X86_INS_VPCONFLICTD = 1144;;
let _X86_INS_VPCONFLICTQ = 1145;;
let _X86_INS_VPDPBUSDS = 1146;;
let _X86_INS_VPDPBUSD = 1147;;
let _X86_INS_VPDPWSSDS = 1148;;
let _X86_INS_VPDPWSSD = 1149;;
let _X86_INS_VPERM2F128 = 1150;;
let _X86_INS_VPERM2I128 = 1151;;
let _X86_INS_VPERMB = 1152;;
let _X86_INS_VPERMD = 1153;;
let _X86_INS_VPERMI2B = 1154;;
let _X86_INS_VPERMI2D = 1155;;
let _X86_INS_VPERMI2PD = 1156;;
let _X86_INS_VPERMI2PS = 1157;;
let _X86_INS_VPERMI2Q = 1158;;
let _X86_INS_VPERMI2W = 1159;;
let _X86_INS_VPERMIL2PD = 1160;;
let _X86_INS_VPERMILPD = 1161;;
let _X86_INS_VPERMIL2PS = 1162;;
let _X86_INS_VPERMILPS = 1163;;
let _X86_INS_VPERMPD = 1164;;
let _X86_INS_VPERMPS = 1165;;
let _X86_INS_VPERMQ = 1166;;
let _X86_INS_VPERMT2B = 1167;;
let _X86_INS_VPERMT2D = 1168;;
let _X86_INS_VPERMT2PD = 1169;;
let _X86_INS_VPERMT2PS = 1170;;
let _X86_INS_VPERMT2Q = 1171;;
let _X86_INS_VPERMT2W = 1172;;
let _X86_INS_VPERMW = 1173;;
let _X86_INS_VPEXPANDB = 1174;;
let _X86_INS_VPEXPANDD = 1175;;
let _X86_INS_VPEXPANDQ = 1176;;
let _X86_INS_VPEXPANDW = 1177;;
let _X86_INS_VPEXTRB = 1178;;
let _X86_INS_VPEXTRD = 1179;;
let _X86_INS_VPEXTRQ = 1180;;
let _X86_INS_VPEXTRW = 1181;;
let _X86_INS_VPGATHERDD = 1182;;
let _X86_INS_VPGATHERDQ = 1183;;
let _X86_INS_VPGATHERQD = 1184;;
let _X86_INS_VPGATHERQQ = 1185;;
let _X86_INS_VPHADDBD = 1186;;
let _X86_INS_VPHADDBQ = 1187;;
let _X86_INS_VPHADDBW = 1188;;
let _X86_INS_VPHADDDQ = 1189;;
let _X86_INS_VPHADDD = 1190;;
let _X86_INS_VPHADDSW = 1191;;
let _X86_INS_VPHADDUBD = 1192;;
let _X86_INS_VPHADDUBQ = 1193;;
let _X86_INS_VPHADDUBW = 1194;;
let _X86_INS_VPHADDUDQ = 1195;;
let _X86_INS_VPHADDUWD = 1196;;
let _X86_INS_VPHADDUWQ = 1197;;
let _X86_INS_VPHADDWD = 1198;;
let _X86_INS_VPHADDWQ = 1199;;
let _X86_INS_VPHADDW = 1200;;
let _X86_INS_VPHMINPOSUW = 1201;;
let _X86_INS_VPHSUBBW = 1202;;
let _X86_INS_VPHSUBDQ = 1203;;
let _X86_INS_VPHSUBD = 1204;;
let _X86_INS_VPHSUBSW = 1205;;
let _X86_INS_VPHSUBWD = 1206;;
let _X86_INS_VPHSUBW = 1207;;
let _X86_INS_VPINSRB = 1208;;
let _X86_INS_VPINSRD = 1209;;
let _X86_INS_VPINSRQ = 1210;;
let _X86_INS_VPINSRW = 1211;;
let _X86_INS_VPLZCNTD = 1212;;
let _X86_INS_VPLZCNTQ = 1213;;
let _X86_INS_VPMACSDD = 1214;;
let _X86_INS_VPMACSDQH = 1215;;
let _X86_INS_VPMACSDQL = 1216;;
let _X86_INS_VPMACSSDD = 1217;;
let _X86_INS_VPMACSSDQH = 1218;;
let _X86_INS_VPMACSSDQL = 1219;;
let _X86_INS_VPMACSSWD = 1220;;
let _X86_INS_VPMACSSWW = 1221;;
let _X86_INS_VPMACSWD = 1222;;
let _X86_INS_VPMACSWW = 1223;;
let _X86_INS_VPMADCSSWD = 1224;;
let _X86_INS_VPMADCSWD = 1225;;
let _X86_INS_VPMADD52HUQ = 1226;;
let _X86_INS_VPMADD52LUQ = 1227;;
let _X86_INS_VPMADDUBSW = 1228;;
let _X86_INS_VPMADDWD = 1229;;
let _X86_INS_VPMASKMOVD = 1230;;
let _X86_INS_VPMASKMOVQ = 1231;;
let _X86_INS_VPMAXSB = 1232;;
let _X86_INS_VPMAXSD = 1233;;
let _X86_INS_VPMAXSQ = 1234;;
let _X86_INS_VPMAXSW = 1235;;
let _X86_INS_VPMAXUB = 1236;;
let _X86_INS_VPMAXUD = 1237;;
let _X86_INS_VPMAXUQ = 1238;;
let _X86_INS_VPMAXUW = 1239;;
let _X86_INS_VPMINSB = 1240;;
let _X86_INS_VPMINSD = 1241;;
let _X86_INS_VPMINSQ = 1242;;
let _X86_INS_VPMINSW = 1243;;
let _X86_INS_VPMINUB = 1244;;
let _X86_INS_VPMINUD = 1245;;
let _X86_INS_VPMINUQ = 1246;;
let _X86_INS_VPMINUW = 1247;;
let _X86_INS_VPMOVB2M = 1248;;
let _X86_INS_VPMOVD2M = 1249;;
let _X86_INS_VPMOVDB = 1250;;
let _X86_INS_VPMOVDW = 1251;;
let _X86_INS_VPMOVM2B = 1252;;
let _X86_INS_VPMOVM2D = 1253;;
let _X86_INS_VPMOVM2Q = 1254;;
let _X86_INS_VPMOVM2W = 1255;;
let _X86_INS_VPMOVMSKB = 1256;;
let _X86_INS_VPMOVQ2M = 1257;;
let _X86_INS_VPMOVQB = 1258;;
let _X86_INS_VPMOVQD = 1259;;
let _X86_INS_VPMOVQW = 1260;;
let _X86_INS_VPMOVSDB = 1261;;
let _X86_INS_VPMOVSDW = 1262;;
let _X86_INS_VPMOVSQB = 1263;;
let _X86_INS_VPMOVSQD = 1264;;
let _X86_INS_VPMOVSQW = 1265;;
let _X86_INS_VPMOVSWB = 1266;;
let _X86_INS_VPMOVSXBD = 1267;;
let _X86_INS_VPMOVSXBQ = 1268;;
let _X86_INS_VPMOVSXBW = 1269;;
let _X86_INS_VPMOVSXDQ = 1270;;
let _X86_INS_VPMOVSXWD = 1271;;
let _X86_INS_VPMOVSXWQ = 1272;;
let _X86_INS_VPMOVUSDB = 1273;;
let _X86_INS_VPMOVUSDW = 1274;;
let _X86_INS_VPMOVUSQB = 1275;;
let _X86_INS_VPMOVUSQD = 1276;;
let _X86_INS_VPMOVUSQW = 1277;;
let _X86_INS_VPMOVUSWB = 1278;;
let _X86_INS_VPMOVW2M = 1279;;
let _X86_INS_VPMOVWB = 1280;;
let _X86_INS_VPMOVZXBD = 1281;;
let _X86_INS_VPMOVZXBQ = 1282;;
let _X86_INS_VPMOVZXBW = 1283;;
let _X86_INS_VPMOVZXDQ = 1284;;
let _X86_INS_VPMOVZXWD = 1285;;
let _X86_INS_VPMOVZXWQ = 1286;;
let _X86_INS_VPMULDQ = 1287;;
let _X86_INS_VPMULHRSW = 1288;;
let _X86_INS_VPMULHUW = 1289;;
let _X86_INS_VPMULHW = 1290;;
let _X86_INS_VPMULLD = 1291;;
let _X86_INS_VPMULLQ = 1292;;
let _X86_INS_VPMULLW = 1293;;
let _X86_INS_VPMULTISHIFTQB = 1294;;
let _X86_INS_VPMULUDQ = 1295;;
let _X86_INS_VPOPCNTB = 1296;;
let _X86_INS_VPOPCNTD = 1297;;
let _X86_INS_VPOPCNTQ = 1298;;
let _X86_INS_VPOPCNTW = 1299;;
let _X86_INS_VPORD = 1300;;
let _X86_INS_VPORQ = 1301;;
let _X86_INS_VPOR = 1302;;
let _X86_INS_VPPERM = 1303;;
let _X86_INS_VPROLD = 1304;;
let _X86_INS_VPROLQ = 1305;;
let _X86_INS_VPROLVD = 1306;;
let _X86_INS_VPROLVQ = 1307;;
let _X86_INS_VPRORD = 1308;;
let _X86_INS_VPRORQ = 1309;;
let _X86_INS_VPRORVD = 1310;;
let _X86_INS_VPRORVQ = 1311;;
let _X86_INS_VPROTB = 1312;;
let _X86_INS_VPROTD = 1313;;
let _X86_INS_VPROTQ = 1314;;
let _X86_INS_VPROTW = 1315;;
let _X86_INS_VPSADBW = 1316;;
let _X86_INS_VPSCATTERDD = 1317;;
let _X86_INS_VPSCATTERDQ = 1318;;
let _X86_INS_VPSCATTERQD = 1319;;
let _X86_INS_VPSCATTERQQ = 1320;;
let _X86_INS_VPSHAB = 1321;;
let _X86_INS_VPSHAD = 1322;;
let _X86_INS_VPSHAQ = 1323;;
let _X86_INS_VPSHAW = 1324;;
let _X86_INS_VPSHLB = 1325;;
let _X86_INS_VPSHLDD = 1326;;
let _X86_INS_VPSHLDQ = 1327;;
let _X86_INS_VPSHLDVD = 1328;;
let _X86_INS_VPSHLDVQ = 1329;;
let _X86_INS_VPSHLDVW = 1330;;
let _X86_INS_VPSHLDW = 1331;;
let _X86_INS_VPSHLD = 1332;;
let _X86_INS_VPSHLQ = 1333;;
let _X86_INS_VPSHLW = 1334;;
let _X86_INS_VPSHRDD = 1335;;
let _X86_INS_VPSHRDQ = 1336;;
let _X86_INS_VPSHRDVD = 1337;;
let _X86_INS_VPSHRDVQ = 1338;;
let _X86_INS_VPSHRDVW = 1339;;
let _X86_INS_VPSHRDW = 1340;;
let _X86_INS_VPSHUFBITQMB = 1341;;
let _X86_INS_VPSHUFB = 1342;;
let _X86_INS_VPSHUFD = 1343;;
let _X86_INS_VPSHUFHW = 1344;;
let _X86_INS_VPSHUFLW = 1345;;
let _X86_INS_VPSIGNB = 1346;;
let _X86_INS_VPSIGND = 1347;;
let _X86_INS_VPSIGNW = 1348;;
let _X86_INS_VPSLLDQ = 1349;;
let _X86_INS_VPSLLD = 1350;;
let _X86_INS_VPSLLQ = 1351;;
let _X86_INS_VPSLLVD = 1352;;
let _X86_INS_VPSLLVQ = 1353;;
let _X86_INS_VPSLLVW = 1354;;
let _X86_INS_VPSLLW = 1355;;
let _X86_INS_VPSRAD = 1356;;
let _X86_INS_VPSRAQ = 1357;;
let _X86_INS_VPSRAVD = 1358;;
let _X86_INS_VPSRAVQ = 1359;;
let _X86_INS_VPSRAVW = 1360;;
let _X86_INS_VPSRAW = 1361;;
let _X86_INS_VPSRLDQ = 1362;;
let _X86_INS_VPSRLD = 1363;;
let _X86_INS_VPSRLQ = 1364;;
let _X86_INS_VPSRLVD = 1365;;
let _X86_INS_VPSRLVQ = 1366;;
let _X86_INS_VPSRLVW = 1367;;
let _X86_INS_VPSRLW = 1368;;
let _X86_INS_VPSUBB = 1369;;
let _X86_INS_VPSUBD = 1370;;
let _X86_INS_VPSUBQ = 1371;;
let _X86_INS_VPSUBSB = 1372;;
let _X86_INS_VPSUBSW = 1373;;
let _X86_INS_VPSUBUSB = 1374;;
let _X86_INS_VPSUBUSW = 1375;;
let _X86_INS_VPSUBW = 1376;;
let _X86_INS_VPTERNLOGD = 1377;;
let _X86_INS_VPTERNLOGQ = 1378;;
let _X86_INS_VPTESTMB = 1379;;
let _X86_INS_VPTESTMD = 1380;;
let _X86_INS_VPTESTMQ = 1381;;
let _X86_INS_VPTESTMW = 1382;;
let _X86_INS_VPTESTNMB = 1383;;
let _X86_INS_VPTESTNMD = 1384;;
let _X86_INS_VPTESTNMQ = 1385;;
let _X86_INS_VPTESTNMW = 1386;;
let _X86_INS_VPTEST = 1387;;
let _X86_INS_VPUNPCKHBW = 1388;;
let _X86_INS_VPUNPCKHDQ = 1389;;
let _X86_INS_VPUNPCKHQDQ = 1390;;
let _X86_INS_VPUNPCKHWD = 1391;;
let _X86_INS_VPUNPCKLBW = 1392;;
let _X86_INS_VPUNPCKLDQ = 1393;;
let _X86_INS_VPUNPCKLQDQ = 1394;;
let _X86_INS_VPUNPCKLWD = 1395;;
let _X86_INS_VPXORD = 1396;;
let _X86_INS_VPXORQ = 1397;;
let _X86_INS_VPXOR = 1398;;
let _X86_INS_VRANGEPD = 1399;;
let _X86_INS_VRANGEPS = 1400;;
let _X86_INS_VRANGESD = 1401;;
let _X86_INS_VRANGESS = 1402;;
let _X86_INS_VRCP14PD = 1403;;
let _X86_INS_VRCP14PS = 1404;;
let _X86_INS_VRCP14SD = 1405;;
let _X86_INS_VRCP14SS = 1406;;
let _X86_INS_VRCP28PD = 1407;;
let _X86_INS_VRCP28PS = 1408;;
let _X86_INS_VRCP28SD = 1409;;
let _X86_INS_VRCP28SS = 1410;;
let _X86_INS_VRCPPS = 1411;;
let _X86_INS_VRCPSS = 1412;;
let _X86_INS_VREDUCEPD = 1413;;
let _X86_INS_VREDUCEPS = 1414;;
let _X86_INS_VREDUCESD = 1415;;
let _X86_INS_VREDUCESS = 1416;;
let _X86_INS_VRNDSCALEPD = 1417;;
let _X86_INS_VRNDSCALEPS = 1418;;
let _X86_INS_VRNDSCALESD = 1419;;
let _X86_INS_VRNDSCALESS = 1420;;
let _X86_INS_VROUNDPD = 1421;;
let _X86_INS_VROUNDPS = 1422;;
let _X86_INS_VROUNDSD = 1423;;
let _X86_INS_VROUNDSS = 1424;;
let _X86_INS_VRSQRT14PD = 1425;;
let _X86_INS_VRSQRT14PS = 1426;;
let _X86_INS_VRSQRT14SD = 1427;;
let _X86_INS_VRSQRT14SS = 1428;;
let _X86_INS_VRSQRT28PD = 1429;;
let _X86_INS_VRSQRT28PS = 1430;;
let _X86_INS_VRSQRT28SD = 1431;;
let _X86_INS_VRSQRT28SS = 1432;;
let _X86_INS_VRSQRTPS = 1433;;
let _X86_INS_VRSQRTSS = 1434;;
let _X86_INS_VSCALEFPD = 1435;;
let _X86_INS_VSCALEFPS = 1436;;
let _X86_INS_VSCALEFSD = 1437;;
let _X86_INS_VSCALEFSS = 1438;;
let _X86_INS_VSCATTERDPD = 1439;;
let _X86_INS_VSCATTERDPS = 1440;;
let _X86_INS_VSCATTERPF0DPD = 1441;;
let _X86_INS_VSCATTERPF0DPS = 1442;;
let _X86_INS_VSCATTERPF0QPD = 1443;;
let _X86_INS_VSCATTERPF0QPS = 1444;;
let _X86_INS_VSCATTERPF1DPD = 1445;;
let _X86_INS_VSCATTERPF1DPS = 1446;;
let _X86_INS_VSCATTERPF1QPD = 1447;;
let _X86_INS_VSCATTERPF1QPS = 1448;;
let _X86_INS_VSCATTERQPD = 1449;;
let _X86_INS_VSCATTERQPS = 1450;;
let _X86_INS_VSHUFF32X4 = 1451;;
let _X86_INS_VSHUFF64X2 = 1452;;
let _X86_INS_VSHUFI32X4 = 1453;;
let _X86_INS_VSHUFI64X2 = 1454;;
let _X86_INS_VSHUFPD = 1455;;
let _X86_INS_VSHUFPS = 1456;;
let _X86_INS_VSQRTPD = 1457;;
let _X86_INS_VSQRTPS = 1458;;
let _X86_INS_VSQRTSD = 1459;;
let _X86_INS_VSQRTSS = 1460;;
let _X86_INS_VSTMXCSR = 1461;;
let _X86_INS_VSUBPD = 1462;;
let _X86_INS_VSUBPS = 1463;;
let _X86_INS_VSUBSD = 1464;;
let _X86_INS_VSUBSS = 1465;;
let _X86_INS_VTESTPD = 1466;;
let _X86_INS_VTESTPS = 1467;;
let _X86_INS_VUCOMISD = 1468;;
let _X86_INS_VUCOMISS = 1469;;
let _X86_INS_VUNPCKHPD = 1470;;
let _X86_INS_VUNPCKHPS = 1471;;
let _X86_INS_VUNPCKLPD = 1472;;
let _X86_INS_VUNPCKLPS = 1473;;
let _X86_INS_VXORPD = 1474;;
let _X86_INS_VXORPS = 1475;;
let _X86_INS_VZEROALL = 1476;;
let _X86_INS_VZEROUPPER = 1477;;
let _X86_INS_WAIT = 1478;;
let _X86_INS_WBINVD = 1479;;
let _X86_INS_WBNOINVD = 1480;;
let _X86_INS_WRFSBASE = 1481;;
let _X86_INS_WRGSBASE = 1482;;
let _X86_INS_WRMSR = 1483;;
let _X86_INS_WRPKRU = 1484;;
let _X86_INS_WRSSD = 1485;;
let _X86_INS_WRSSQ = 1486;;
let _X86_INS_WRUSSD = 1487;;
let _X86_INS_WRUSSQ = 1488;;
let _X86_INS_XABORT = 1489;;
let _X86_INS_XACQUIRE = 1490;;
let _X86_INS_XADD = 1491;;
let _X86_INS_XBEGIN = 1492;;
let _X86_INS_XCHG = 1493;;
let _X86_INS_FXCH = 1494;;
let _X86_INS_XCRYPTCBC = 1495;;
let _X86_INS_XCRYPTCFB = 1496;;
let _X86_INS_XCRYPTCTR = 1497;;
let _X86_INS_XCRYPTECB = 1498;;
let _X86_INS_XCRYPTOFB = 1499;;
let _X86_INS_XEND = 1500;;
let _X86_INS_XGETBV = 1501;;
let _X86_INS_XLATB = 1502;;
let _X86_INS_XOR = 1503;;
let _X86_INS_XORPD = 1504;;
let _X86_INS_XORPS = 1505;;
let _X86_INS_XRELEASE = 1506;;
let _X86_INS_XRSTOR = 1507;;
let _X86_INS_XRSTOR64 = 1508;;
let _X86_INS_XRSTORS = 1509;;
let _X86_INS_XRSTORS64 = 1510;;
let _X86_INS_XSAVE = 1511;;
let _X86_INS_XSAVE64 = 1512;;
let _X86_INS_XSAVEC = 1513;;
let _X86_INS_XSAVEC64 = 1514;;
let _X86_INS_XSAVEOPT = 1515;;
let _X86_INS_XSAVEOPT64 = 1516;;
let _X86_INS_XSAVES = 1517;;
let _X86_INS_XSAVES64 = 1518;;
let _X86_INS_XSETBV = 1519;;
let _X86_INS_XSHA1 = 1520;;
let _X86_INS_XSHA256 = 1521;;
let _X86_INS_XSTORE = 1522;;
let _X86_INS_XTEST = 1523;;
let _X86_INS_ENDING = 1524;;

let _X86_GRP_INVALID = 0;;
let _X86_GRP_JUMP = 1;;
let _X86_GRP_CALL = 2;;
let _X86_GRP_RET = 3;;
let _X86_GRP_INT = 4;;
let _X86_GRP_IRET = 5;;
let _X86_GRP_PRIVILEGE = 6;;
let _X86_GRP_BRANCH_RELATIVE = 7;;
let _X86_GRP_VM = 128;;
let _X86_GRP_3DNOW = 129;;
let _X86_GRP_AES = 130;;
let _X86_GRP_ADX = 131;;
let _X86_GRP_AVX = 132;;
let _X86_GRP_AVX2 = 133;;
let _X86_GRP_AVX512 = 134;;
let _X86_GRP_BMI = 135;;
let _X86_GRP_BMI2 = 136;;
let _X86_GRP_CMOV = 137;;
let _X86_GRP_F16C = 138;;
let _X86_GRP_FMA = 139;;
let _X86_GRP_FMA4 = 140;;
let _X86_GRP_FSGSBASE = 141;;
let _X86_GRP_HLE = 142;;
let _X86_GRP_MMX = 143;;
let _X86_GRP_MODE32 = 144;;
let _X86_GRP_MODE64 = 145;;
let _X86_GRP_RTM = 146;;
let _X86_GRP_SHA = 147;;
let _X86_GRP_SSE1 = 148;;
let _X86_GRP_SSE2 = 149;;
let _X86_GRP_SSE3 = 150;;
let _X86_GRP_SSE41 = 151;;
let _X86_GRP_SSE42 = 152;;
let _X86_GRP_SSE4A = 153;;
let _X86_GRP_SSSE3 = 154;;
let _X86_GRP_PCLMUL = 155;;
let _X86_GRP_XOP = 156;;
let _X86_GRP_CDI = 157;;
let _X86_GRP_ERI = 158;;
let _X86_GRP_TBM = 159;;
let _X86_GRP_16BITMODE = 160;;
let _X86_GRP_NOT64BITMODE = 161;;
let _X86_GRP_SGX = 162;;
let _X86_GRP_DQI = 163;;
let _X86_GRP_BWI = 164;;
let _X86_GRP_PFI = 165;;
let _X86_GRP_VLX = 166;;
let _X86_GRP_SMAP = 167;;
let _X86_GRP_NOVLX = 168;;
let _X86_GRP_FPU = 169;;
let _X86_GRP_ENDING = 170;;
