# CS_ARCH_MIPS, CS_MODE_MIPS32+CS_MODE_MICRO+CS_MODE_BIG_ENDIAN, None
0x00,0xa4,0xcb,0x3c = madd $a0, $a1
0x00,0xa4,0xdb,0x3c = maddu $a0, $a1
0x00,0xa4,0xeb,0x3c = msub $a0, $a1
0x00,0xa4,0xfb,0x3c = msubu $a0, $a1
