# CS_ARCH_ARM, CS_MODE_THUMB+CS_MODE_V8, None
0xc1,0xfa,0x82,0xf0 = crc32b r0, r1, r2
0xc1,0xfa,0x92,0xf0 = crc32h r0, r1, r2
0xc1,0xfa,0xa2,0xf0 = crc32w r0, r1, r2
0xd1,0xfa,0x82,0xf0 = crc32cb r0, r1, r2
0xd1,0xfa,0x92,0xf0 = crc32ch r0, r1, r2
0xd1,0xfa,0xa2,0xf0 = crc32cw r0, r1, r2
