(* For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [ppc_const.ml] *)

let _PPC_BC_INVALID = 0;;
let _PPC_BC_LT = (0 lsl 5) lor 12;;
let _PPC_BC_LE = (1 lsl 5) lor 4;;
let _PPC_BC_EQ = (2 lsl 5) lor 12;;
let _PPC_BC_GE = (0 lsl 5) lor 4;;
let _PPC_BC_GT = (1 lsl 5) lor 12;;
let _PPC_BC_NE = (2 lsl 5) lor 4;;
let _PPC_BC_UN = (3 lsl 5) lor 12;;
let _PPC_BC_NU = (3 lsl 5) lor 4;;
let _PPC_BC_SO = (4 lsl 5) lor 12;;
let _PPC_BC_NS = (4 lsl 5) lor 4;;

let _PPC_BH_INVALID = 0;;
let _PPC_BH_PLUS = 1;;
let _PPC_BH_MINUS = 2;;

let _PPC_OP_INVALID = 0;;
let _PPC_OP_REG = 1;;
let _PPC_OP_IMM = 2;;
let _PPC_OP_MEM = 3;;
let _PPC_OP_CRX = 64;;

let _PPC_REG_INVALID = 0;;
let _PPC_REG_CARRY = 2;;
let _PPC_REG_CTR = 3;;
let _PPC_REG_LR = 5;;
let _PPC_REG_RM = 6;;
let _PPC_REG_VRSAVE = 8;;
let _PPC_REG_XER = 9;;
let _PPC_REG_ZERO = 10;;
let _PPC_REG_CR0 = 12;;
let _PPC_REG_CR1 = 13;;
let _PPC_REG_CR2 = 14;;
let _PPC_REG_CR3 = 15;;
let _PPC_REG_CR4 = 16;;
let _PPC_REG_CR5 = 17;;
let _PPC_REG_CR6 = 18;;
let _PPC_REG_CR7 = 19;;
let _PPC_REG_CTR8 = 20;;
let _PPC_REG_F0 = 21;;
let _PPC_REG_F1 = 22;;
let _PPC_REG_F2 = 23;;
let _PPC_REG_F3 = 24;;
let _PPC_REG_F4 = 25;;
let _PPC_REG_F5 = 26;;
let _PPC_REG_F6 = 27;;
let _PPC_REG_F7 = 28;;
let _PPC_REG_F8 = 29;;
let _PPC_REG_F9 = 30;;
let _PPC_REG_F10 = 31;;
let _PPC_REG_F11 = 32;;
let _PPC_REG_F12 = 33;;
let _PPC_REG_F13 = 34;;
let _PPC_REG_F14 = 35;;
let _PPC_REG_F15 = 36;;
let _PPC_REG_F16 = 37;;
let _PPC_REG_F17 = 38;;
let _PPC_REG_F18 = 39;;
let _PPC_REG_F19 = 40;;
let _PPC_REG_F20 = 41;;
let _PPC_REG_F21 = 42;;
let _PPC_REG_F22 = 43;;
let _PPC_REG_F23 = 44;;
let _PPC_REG_F24 = 45;;
let _PPC_REG_F25 = 46;;
let _PPC_REG_F26 = 47;;
let _PPC_REG_F27 = 48;;
let _PPC_REG_F28 = 49;;
let _PPC_REG_F29 = 50;;
let _PPC_REG_F30 = 51;;
let _PPC_REG_F31 = 52;;
let _PPC_REG_LR8 = 54;;
let _PPC_REG_Q0 = 55;;
let _PPC_REG_Q1 = 56;;
let _PPC_REG_Q2 = 57;;
let _PPC_REG_Q3 = 58;;
let _PPC_REG_Q4 = 59;;
let _PPC_REG_Q5 = 60;;
let _PPC_REG_Q6 = 61;;
let _PPC_REG_Q7 = 62;;
let _PPC_REG_Q8 = 63;;
let _PPC_REG_Q9 = 64;;
let _PPC_REG_Q10 = 65;;
let _PPC_REG_Q11 = 66;;
let _PPC_REG_Q12 = 67;;
let _PPC_REG_Q13 = 68;;
let _PPC_REG_Q14 = 69;;
let _PPC_REG_Q15 = 70;;
let _PPC_REG_Q16 = 71;;
let _PPC_REG_Q17 = 72;;
let _PPC_REG_Q18 = 73;;
let _PPC_REG_Q19 = 74;;
let _PPC_REG_Q20 = 75;;
let _PPC_REG_Q21 = 76;;
let _PPC_REG_Q22 = 77;;
let _PPC_REG_Q23 = 78;;
let _PPC_REG_Q24 = 79;;
let _PPC_REG_Q25 = 80;;
let _PPC_REG_Q26 = 81;;
let _PPC_REG_Q27 = 82;;
let _PPC_REG_Q28 = 83;;
let _PPC_REG_Q29 = 84;;
let _PPC_REG_Q30 = 85;;
let _PPC_REG_Q31 = 86;;
let _PPC_REG_R0 = 87;;
let _PPC_REG_R1 = 88;;
let _PPC_REG_R2 = 89;;
let _PPC_REG_R3 = 90;;
let _PPC_REG_R4 = 91;;
let _PPC_REG_R5 = 92;;
let _PPC_REG_R6 = 93;;
let _PPC_REG_R7 = 94;;
let _PPC_REG_R8 = 95;;
let _PPC_REG_R9 = 96;;
let _PPC_REG_R10 = 97;;
let _PPC_REG_R11 = 98;;
let _PPC_REG_R12 = 99;;
let _PPC_REG_R13 = 100;;
let _PPC_REG_R14 = 101;;
let _PPC_REG_R15 = 102;;
let _PPC_REG_R16 = 103;;
let _PPC_REG_R17 = 104;;
let _PPC_REG_R18 = 105;;
let _PPC_REG_R19 = 106;;
let _PPC_REG_R20 = 107;;
let _PPC_REG_R21 = 108;;
let _PPC_REG_R22 = 109;;
let _PPC_REG_R23 = 110;;
let _PPC_REG_R24 = 111;;
let _PPC_REG_R25 = 112;;
let _PPC_REG_R26 = 113;;
let _PPC_REG_R27 = 114;;
let _PPC_REG_R28 = 115;;
let _PPC_REG_R29 = 116;;
let _PPC_REG_R30 = 117;;
let _PPC_REG_R31 = 118;;
let _PPC_REG_V0 = 151;;
let _PPC_REG_V1 = 152;;
let _PPC_REG_V2 = 153;;
let _PPC_REG_V3 = 154;;
let _PPC_REG_V4 = 155;;
let _PPC_REG_V5 = 156;;
let _PPC_REG_V6 = 157;;
let _PPC_REG_V7 = 158;;
let _PPC_REG_V8 = 159;;
let _PPC_REG_V9 = 160;;
let _PPC_REG_V10 = 161;;
let _PPC_REG_V11 = 162;;
let _PPC_REG_V12 = 163;;
let _PPC_REG_V13 = 164;;
let _PPC_REG_V14 = 165;;
let _PPC_REG_V15 = 166;;
let _PPC_REG_V16 = 167;;
let _PPC_REG_V17 = 168;;
let _PPC_REG_V18 = 169;;
let _PPC_REG_V19 = 170;;
let _PPC_REG_V20 = 171;;
let _PPC_REG_V21 = 172;;
let _PPC_REG_V22 = 173;;
let _PPC_REG_V23 = 174;;
let _PPC_REG_V24 = 175;;
let _PPC_REG_V25 = 176;;
let _PPC_REG_V26 = 177;;
let _PPC_REG_V27 = 178;;
let _PPC_REG_V28 = 179;;
let _PPC_REG_V29 = 180;;
let _PPC_REG_V30 = 181;;
let _PPC_REG_V31 = 182;;
let _PPC_REG_VS0 = 215;;
let _PPC_REG_VS1 = 216;;
let _PPC_REG_VS2 = 217;;
let _PPC_REG_VS3 = 218;;
let _PPC_REG_VS4 = 219;;
let _PPC_REG_VS5 = 220;;
let _PPC_REG_VS6 = 221;;
let _PPC_REG_VS7 = 222;;
let _PPC_REG_VS8 = 223;;
let _PPC_REG_VS9 = 224;;
let _PPC_REG_VS10 = 225;;
let _PPC_REG_VS11 = 226;;
let _PPC_REG_VS12 = 227;;
let _PPC_REG_VS13 = 228;;
let _PPC_REG_VS14 = 229;;
let _PPC_REG_VS15 = 230;;
let _PPC_REG_VS16 = 231;;
let _PPC_REG_VS17 = 232;;
let _PPC_REG_VS18 = 233;;
let _PPC_REG_VS19 = 234;;
let _PPC_REG_VS20 = 235;;
let _PPC_REG_VS21 = 236;;
let _PPC_REG_VS22 = 237;;
let _PPC_REG_VS23 = 238;;
let _PPC_REG_VS24 = 239;;
let _PPC_REG_VS25 = 240;;
let _PPC_REG_VS26 = 241;;
let _PPC_REG_VS27 = 242;;
let _PPC_REG_VS28 = 243;;
let _PPC_REG_VS29 = 244;;
let _PPC_REG_VS30 = 245;;
let _PPC_REG_VS31 = 246;;
let _PPC_REG_VS32 = 247;;
let _PPC_REG_VS33 = 248;;
let _PPC_REG_VS34 = 249;;
let _PPC_REG_VS35 = 250;;
let _PPC_REG_VS36 = 251;;
let _PPC_REG_VS37 = 252;;
let _PPC_REG_VS38 = 253;;
let _PPC_REG_VS39 = 254;;
let _PPC_REG_VS40 = 255;;
let _PPC_REG_VS41 = 256;;
let _PPC_REG_VS42 = 257;;
let _PPC_REG_VS43 = 258;;
let _PPC_REG_VS44 = 259;;
let _PPC_REG_VS45 = 260;;
let _PPC_REG_VS46 = 261;;
let _PPC_REG_VS47 = 262;;
let _PPC_REG_VS48 = 263;;
let _PPC_REG_VS49 = 264;;
let _PPC_REG_VS50 = 265;;
let _PPC_REG_VS51 = 266;;
let _PPC_REG_VS52 = 267;;
let _PPC_REG_VS53 = 268;;
let _PPC_REG_VS54 = 269;;
let _PPC_REG_VS55 = 270;;
let _PPC_REG_VS56 = 271;;
let _PPC_REG_VS57 = 272;;
let _PPC_REG_VS58 = 273;;
let _PPC_REG_VS59 = 274;;
let _PPC_REG_VS60 = 275;;
let _PPC_REG_VS61 = 276;;
let _PPC_REG_VS62 = 277;;
let _PPC_REG_VS63 = 278;;
let _PPC_REG_CR0EQ = 312;;
let _PPC_REG_CR1EQ = 313;;
let _PPC_REG_CR2EQ = 314;;
let _PPC_REG_CR3EQ = 315;;
let _PPC_REG_CR4EQ = 316;;
let _PPC_REG_CR5EQ = 317;;
let _PPC_REG_CR6EQ = 318;;
let _PPC_REG_CR7EQ = 319;;
let _PPC_REG_CR0GT = 320;;
let _PPC_REG_CR1GT = 321;;
let _PPC_REG_CR2GT = 322;;
let _PPC_REG_CR3GT = 323;;
let _PPC_REG_CR4GT = 324;;
let _PPC_REG_CR5GT = 325;;
let _PPC_REG_CR6GT = 326;;
let _PPC_REG_CR7GT = 327;;
let _PPC_REG_CR0LT = 328;;
let _PPC_REG_CR1LT = 329;;
let _PPC_REG_CR2LT = 330;;
let _PPC_REG_CR3LT = 331;;
let _PPC_REG_CR4LT = 332;;
let _PPC_REG_CR5LT = 333;;
let _PPC_REG_CR6LT = 334;;
let _PPC_REG_CR7LT = 335;;
let _PPC_REG_CR0UN = 336;;
let _PPC_REG_CR1UN = 337;;
let _PPC_REG_CR2UN = 338;;
let _PPC_REG_CR3UN = 339;;
let _PPC_REG_CR4UN = 340;;
let _PPC_REG_CR5UN = 341;;
let _PPC_REG_CR6UN = 342;;
let _PPC_REG_CR7UN = 343;;
let _PPC_REG_ENDING = 344;;

let _PPC_INS_INVALID = 0;;
let _PPC_INS_ADD = 1;;
let _PPC_INS_ADDC = 2;;
let _PPC_INS_ADDE = 3;;
let _PPC_INS_ADDI = 4;;
let _PPC_INS_ADDIC = 5;;
let _PPC_INS_ADDIS = 6;;
let _PPC_INS_ADDME = 7;;
let _PPC_INS_ADDPCIS = 8;;
let _PPC_INS_ADDZE = 9;;
let _PPC_INS_AND = 10;;
let _PPC_INS_ANDC = 11;;
let _PPC_INS_ANDI = 12;;
let _PPC_INS_ANDIS = 13;;
let _PPC_INS_ATTN = 14;;
let _PPC_INS_B = 15;;
let _PPC_INS_BA = 16;;
let _PPC_INS_BC = 17;;
let _PPC_INS_BCA = 18;;
let _PPC_INS_BCCTR = 19;;
let _PPC_INS_BCCTRL = 20;;
let _PPC_INS_BCDCFN = 21;;
let _PPC_INS_BCDCFSQ = 22;;
let _PPC_INS_BCDCFZ = 23;;
let _PPC_INS_BCDCPSGN = 24;;
let _PPC_INS_BCDCTN = 25;;
let _PPC_INS_BCDCTSQ = 26;;
let _PPC_INS_BCDCTZ = 27;;
let _PPC_INS_BCDS = 28;;
let _PPC_INS_BCDSETSGN = 29;;
let _PPC_INS_BCDSR = 30;;
let _PPC_INS_BCDTRUNC = 31;;
let _PPC_INS_BCDUS = 32;;
let _PPC_INS_BCDUTRUNC = 33;;
let _PPC_INS_BCL = 34;;
let _PPC_INS_BCLA = 35;;
let _PPC_INS_BCLR = 36;;
let _PPC_INS_BCLRL = 37;;
let _PPC_INS_BCTR = 38;;
let _PPC_INS_BCTRL = 39;;
let _PPC_INS_BDNZ = 40;;
let _PPC_INS_BDNZA = 41;;
let _PPC_INS_BDNZF = 42;;
let _PPC_INS_BDNZFA = 43;;
let _PPC_INS_BDNZFL = 44;;
let _PPC_INS_BDNZFLA = 45;;
let _PPC_INS_BDNZFLR = 46;;
let _PPC_INS_BDNZFLRL = 47;;
let _PPC_INS_BDNZL = 48;;
let _PPC_INS_BDNZLA = 49;;
let _PPC_INS_BDNZLR = 50;;
let _PPC_INS_BDNZLRL = 51;;
let _PPC_INS_BDNZT = 52;;
let _PPC_INS_BDNZTA = 53;;
let _PPC_INS_BDNZTL = 54;;
let _PPC_INS_BDNZTLA = 55;;
let _PPC_INS_BDNZTLR = 56;;
let _PPC_INS_BDNZTLRL = 57;;
let _PPC_INS_BDZ = 58;;
let _PPC_INS_BDZA = 59;;
let _PPC_INS_BDZF = 60;;
let _PPC_INS_BDZFA = 61;;
let _PPC_INS_BDZFL = 62;;
let _PPC_INS_BDZFLA = 63;;
let _PPC_INS_BDZFLR = 64;;
let _PPC_INS_BDZFLRL = 65;;
let _PPC_INS_BDZL = 66;;
let _PPC_INS_BDZLA = 67;;
let _PPC_INS_BDZLR = 68;;
let _PPC_INS_BDZLRL = 69;;
let _PPC_INS_BDZT = 70;;
let _PPC_INS_BDZTA = 71;;
let _PPC_INS_BDZTL = 72;;
let _PPC_INS_BDZTLA = 73;;
let _PPC_INS_BDZTLR = 74;;
let _PPC_INS_BDZTLRL = 75;;
let _PPC_INS_BEQ = 76;;
let _PPC_INS_BEQA = 77;;
let _PPC_INS_BEQCTR = 78;;
let _PPC_INS_BEQCTRL = 79;;
let _PPC_INS_BEQL = 80;;
let _PPC_INS_BEQLA = 81;;
let _PPC_INS_BEQLR = 82;;
let _PPC_INS_BEQLRL = 83;;
let _PPC_INS_BF = 84;;
let _PPC_INS_BFA = 85;;
let _PPC_INS_BFCTR = 86;;
let _PPC_INS_BFCTRL = 87;;
let _PPC_INS_BFL = 88;;
let _PPC_INS_BFLA = 89;;
let _PPC_INS_BFLR = 90;;
let _PPC_INS_BFLRL = 91;;
let _PPC_INS_BGE = 92;;
let _PPC_INS_BGEA = 93;;
let _PPC_INS_BGECTR = 94;;
let _PPC_INS_BGECTRL = 95;;
let _PPC_INS_BGEL = 96;;
let _PPC_INS_BGELA = 97;;
let _PPC_INS_BGELR = 98;;
let _PPC_INS_BGELRL = 99;;
let _PPC_INS_BGT = 100;;
let _PPC_INS_BGTA = 101;;
let _PPC_INS_BGTCTR = 102;;
let _PPC_INS_BGTCTRL = 103;;
let _PPC_INS_BGTL = 104;;
let _PPC_INS_BGTLA = 105;;
let _PPC_INS_BGTLR = 106;;
let _PPC_INS_BGTLRL = 107;;
let _PPC_INS_BL = 108;;
let _PPC_INS_BLA = 109;;
let _PPC_INS_BLE = 110;;
let _PPC_INS_BLEA = 111;;
let _PPC_INS_BLECTR = 112;;
let _PPC_INS_BLECTRL = 113;;
let _PPC_INS_BLEL = 114;;
let _PPC_INS_BLELA = 115;;
let _PPC_INS_BLELR = 116;;
let _PPC_INS_BLELRL = 117;;
let _PPC_INS_BLR = 118;;
let _PPC_INS_BLRL = 119;;
let _PPC_INS_BLT = 120;;
let _PPC_INS_BLTA = 121;;
let _PPC_INS_BLTCTR = 122;;
let _PPC_INS_BLTCTRL = 123;;
let _PPC_INS_BLTL = 124;;
let _PPC_INS_BLTLA = 125;;
let _PPC_INS_BLTLR = 126;;
let _PPC_INS_BLTLRL = 127;;
let _PPC_INS_BNE = 128;;
let _PPC_INS_BNEA = 129;;
let _PPC_INS_BNECTR = 130;;
let _PPC_INS_BNECTRL = 131;;
let _PPC_INS_BNEL = 132;;
let _PPC_INS_BNELA = 133;;
let _PPC_INS_BNELR = 134;;
let _PPC_INS_BNELRL = 135;;
let _PPC_INS_BNG = 136;;
let _PPC_INS_BNGA = 137;;
let _PPC_INS_BNGCTR = 138;;
let _PPC_INS_BNGCTRL = 139;;
let _PPC_INS_BNGL = 140;;
let _PPC_INS_BNGLA = 141;;
let _PPC_INS_BNGLR = 142;;
let _PPC_INS_BNGLRL = 143;;
let _PPC_INS_BNL = 144;;
let _PPC_INS_BNLA = 145;;
let _PPC_INS_BNLCTR = 146;;
let _PPC_INS_BNLCTRL = 147;;
let _PPC_INS_BNLL = 148;;
let _PPC_INS_BNLLA = 149;;
let _PPC_INS_BNLLR = 150;;
let _PPC_INS_BNLLRL = 151;;
let _PPC_INS_BNS = 152;;
let _PPC_INS_BNSA = 153;;
let _PPC_INS_BNSCTR = 154;;
let _PPC_INS_BNSCTRL = 155;;
let _PPC_INS_BNSL = 156;;
let _PPC_INS_BNSLA = 157;;
let _PPC_INS_BNSLR = 158;;
let _PPC_INS_BNSLRL = 159;;
let _PPC_INS_BNU = 160;;
let _PPC_INS_BNUA = 161;;
let _PPC_INS_BNUCTR = 162;;
let _PPC_INS_BNUCTRL = 163;;
let _PPC_INS_BNUL = 164;;
let _PPC_INS_BNULA = 165;;
let _PPC_INS_BNULR = 166;;
let _PPC_INS_BNULRL = 167;;
let _PPC_INS_BPERMD = 168;;
let _PPC_INS_BRINC = 169;;
let _PPC_INS_BSO = 170;;
let _PPC_INS_BSOA = 171;;
let _PPC_INS_BSOCTR = 172;;
let _PPC_INS_BSOCTRL = 173;;
let _PPC_INS_BSOL = 174;;
let _PPC_INS_BSOLA = 175;;
let _PPC_INS_BSOLR = 176;;
let _PPC_INS_BSOLRL = 177;;
let _PPC_INS_BT = 178;;
let _PPC_INS_BTA = 179;;
let _PPC_INS_BTCTR = 180;;
let _PPC_INS_BTCTRL = 181;;
let _PPC_INS_BTL = 182;;
let _PPC_INS_BTLA = 183;;
let _PPC_INS_BTLR = 184;;
let _PPC_INS_BTLRL = 185;;
let _PPC_INS_BUN = 186;;
let _PPC_INS_BUNA = 187;;
let _PPC_INS_BUNCTR = 188;;
let _PPC_INS_BUNCTRL = 189;;
let _PPC_INS_BUNL = 190;;
let _PPC_INS_BUNLA = 191;;
let _PPC_INS_BUNLR = 192;;
let _PPC_INS_BUNLRL = 193;;
let _PPC_INS_CLRBHRB = 194;;
let _PPC_INS_CLRLDI = 195;;
let _PPC_INS_CLRLSLDI = 196;;
let _PPC_INS_CLRLSLWI = 197;;
let _PPC_INS_CLRLWI = 198;;
let _PPC_INS_CLRRDI = 199;;
let _PPC_INS_CLRRWI = 200;;
let _PPC_INS_CMP = 201;;
let _PPC_INS_CMPB = 202;;
let _PPC_INS_CMPD = 203;;
let _PPC_INS_CMPDI = 204;;
let _PPC_INS_CMPEQB = 205;;
let _PPC_INS_CMPI = 206;;
let _PPC_INS_CMPL = 207;;
let _PPC_INS_CMPLD = 208;;
let _PPC_INS_CMPLDI = 209;;
let _PPC_INS_CMPLI = 210;;
let _PPC_INS_CMPLW = 211;;
let _PPC_INS_CMPLWI = 212;;
let _PPC_INS_CMPRB = 213;;
let _PPC_INS_CMPW = 214;;
let _PPC_INS_CMPWI = 215;;
let _PPC_INS_CNTLZD = 216;;
let _PPC_INS_CNTLZW = 217;;
let _PPC_INS_CNTTZD = 218;;
let _PPC_INS_CNTTZW = 219;;
let _PPC_INS_COPY = 220;;
let _PPC_INS_COPY_FIRST = 221;;
let _PPC_INS_CP_ABORT = 222;;
let _PPC_INS_CRAND = 223;;
let _PPC_INS_CRANDC = 224;;
let _PPC_INS_CRCLR = 225;;
let _PPC_INS_CREQV = 226;;
let _PPC_INS_CRMOVE = 227;;
let _PPC_INS_CRNAND = 228;;
let _PPC_INS_CRNOR = 229;;
let _PPC_INS_CRNOT = 230;;
let _PPC_INS_CROR = 231;;
let _PPC_INS_CRORC = 232;;
let _PPC_INS_CRSET = 233;;
let _PPC_INS_CRXOR = 234;;
let _PPC_INS_DARN = 235;;
let _PPC_INS_DCBA = 236;;
let _PPC_INS_DCBF = 237;;
let _PPC_INS_DCBFEP = 238;;
let _PPC_INS_DCBFL = 239;;
let _PPC_INS_DCBFLP = 240;;
let _PPC_INS_DCBI = 241;;
let _PPC_INS_DCBST = 242;;
let _PPC_INS_DCBSTEP = 243;;
let _PPC_INS_DCBT = 244;;
let _PPC_INS_DCBTCT = 245;;
let _PPC_INS_DCBTDS = 246;;
let _PPC_INS_DCBTEP = 247;;
let _PPC_INS_DCBTST = 248;;
let _PPC_INS_DCBTSTCT = 249;;
let _PPC_INS_DCBTSTDS = 250;;
let _PPC_INS_DCBTSTEP = 251;;
let _PPC_INS_DCBTSTT = 252;;
let _PPC_INS_DCBTT = 253;;
let _PPC_INS_DCBZ = 254;;
let _PPC_INS_DCBZEP = 255;;
let _PPC_INS_DCBZL = 256;;
let _PPC_INS_DCBZLEP = 257;;
let _PPC_INS_DCCCI = 258;;
let _PPC_INS_DCI = 259;;
let _PPC_INS_DIVD = 260;;
let _PPC_INS_DIVDE = 261;;
let _PPC_INS_DIVDEU = 262;;
let _PPC_INS_DIVDU = 263;;
let _PPC_INS_DIVW = 264;;
let _PPC_INS_DIVWE = 265;;
let _PPC_INS_DIVWEU = 266;;
let _PPC_INS_DIVWU = 267;;
let _PPC_INS_DSS = 268;;
let _PPC_INS_DSSALL = 269;;
let _PPC_INS_DST = 270;;
let _PPC_INS_DSTST = 271;;
let _PPC_INS_DSTSTT = 272;;
let _PPC_INS_DSTT = 273;;
let _PPC_INS_EFDABS = 274;;
let _PPC_INS_EFDADD = 275;;
let _PPC_INS_EFDCFS = 276;;
let _PPC_INS_EFDCFSF = 277;;
let _PPC_INS_EFDCFSI = 278;;
let _PPC_INS_EFDCFSID = 279;;
let _PPC_INS_EFDCFUF = 280;;
let _PPC_INS_EFDCFUI = 281;;
let _PPC_INS_EFDCFUID = 282;;
let _PPC_INS_EFDCMPEQ = 283;;
let _PPC_INS_EFDCMPGT = 284;;
let _PPC_INS_EFDCMPLT = 285;;
let _PPC_INS_EFDCTSF = 286;;
let _PPC_INS_EFDCTSI = 287;;
let _PPC_INS_EFDCTSIDZ = 288;;
let _PPC_INS_EFDCTSIZ = 289;;
let _PPC_INS_EFDCTUF = 290;;
let _PPC_INS_EFDCTUI = 291;;
let _PPC_INS_EFDCTUIDZ = 292;;
let _PPC_INS_EFDCTUIZ = 293;;
let _PPC_INS_EFDDIV = 294;;
let _PPC_INS_EFDMUL = 295;;
let _PPC_INS_EFDNABS = 296;;
let _PPC_INS_EFDNEG = 297;;
let _PPC_INS_EFDSUB = 298;;
let _PPC_INS_EFDTSTEQ = 299;;
let _PPC_INS_EFDTSTGT = 300;;
let _PPC_INS_EFDTSTLT = 301;;
let _PPC_INS_EFSABS = 302;;
let _PPC_INS_EFSADD = 303;;
let _PPC_INS_EFSCFD = 304;;
let _PPC_INS_EFSCFSF = 305;;
let _PPC_INS_EFSCFSI = 306;;
let _PPC_INS_EFSCFUF = 307;;
let _PPC_INS_EFSCFUI = 308;;
let _PPC_INS_EFSCMPEQ = 309;;
let _PPC_INS_EFSCMPGT = 310;;
let _PPC_INS_EFSCMPLT = 311;;
let _PPC_INS_EFSCTSF = 312;;
let _PPC_INS_EFSCTSI = 313;;
let _PPC_INS_EFSCTSIZ = 314;;
let _PPC_INS_EFSCTUF = 315;;
let _PPC_INS_EFSCTUI = 316;;
let _PPC_INS_EFSCTUIZ = 317;;
let _PPC_INS_EFSDIV = 318;;
let _PPC_INS_EFSMUL = 319;;
let _PPC_INS_EFSNABS = 320;;
let _PPC_INS_EFSNEG = 321;;
let _PPC_INS_EFSSUB = 322;;
let _PPC_INS_EFSTSTEQ = 323;;
let _PPC_INS_EFSTSTGT = 324;;
let _PPC_INS_EFSTSTLT = 325;;
let _PPC_INS_EIEIO = 326;;
let _PPC_INS_EQV = 327;;
let _PPC_INS_EVABS = 328;;
let _PPC_INS_EVADDIW = 329;;
let _PPC_INS_EVADDSMIAAW = 330;;
let _PPC_INS_EVADDSSIAAW = 331;;
let _PPC_INS_EVADDUMIAAW = 332;;
let _PPC_INS_EVADDUSIAAW = 333;;
let _PPC_INS_EVADDW = 334;;
let _PPC_INS_EVAND = 335;;
let _PPC_INS_EVANDC = 336;;
let _PPC_INS_EVCMPEQ = 337;;
let _PPC_INS_EVCMPGTS = 338;;
let _PPC_INS_EVCMPGTU = 339;;
let _PPC_INS_EVCMPLTS = 340;;
let _PPC_INS_EVCMPLTU = 341;;
let _PPC_INS_EVCNTLSW = 342;;
let _PPC_INS_EVCNTLZW = 343;;
let _PPC_INS_EVDIVWS = 344;;
let _PPC_INS_EVDIVWU = 345;;
let _PPC_INS_EVEQV = 346;;
let _PPC_INS_EVEXTSB = 347;;
let _PPC_INS_EVEXTSH = 348;;
let _PPC_INS_EVFSABS = 349;;
let _PPC_INS_EVFSADD = 350;;
let _PPC_INS_EVFSCFSF = 351;;
let _PPC_INS_EVFSCFSI = 352;;
let _PPC_INS_EVFSCFUF = 353;;
let _PPC_INS_EVFSCFUI = 354;;
let _PPC_INS_EVFSCMPEQ = 355;;
let _PPC_INS_EVFSCMPGT = 356;;
let _PPC_INS_EVFSCMPLT = 357;;
let _PPC_INS_EVFSCTSF = 358;;
let _PPC_INS_EVFSCTSI = 359;;
let _PPC_INS_EVFSCTSIZ = 360;;
let _PPC_INS_EVFSCTUI = 361;;
let _PPC_INS_EVFSDIV = 362;;
let _PPC_INS_EVFSMUL = 363;;
let _PPC_INS_EVFSNABS = 364;;
let _PPC_INS_EVFSNEG = 365;;
let _PPC_INS_EVFSSUB = 366;;
let _PPC_INS_EVFSTSTEQ = 367;;
let _PPC_INS_EVFSTSTGT = 368;;
let _PPC_INS_EVFSTSTLT = 369;;
let _PPC_INS_EVLDD = 370;;
let _PPC_INS_EVLDDX = 371;;
let _PPC_INS_EVLDH = 372;;
let _PPC_INS_EVLDHX = 373;;
let _PPC_INS_EVLDW = 374;;
let _PPC_INS_EVLDWX = 375;;
let _PPC_INS_EVLHHESPLAT = 376;;
let _PPC_INS_EVLHHESPLATX = 377;;
let _PPC_INS_EVLHHOSSPLAT = 378;;
let _PPC_INS_EVLHHOSSPLATX = 379;;
let _PPC_INS_EVLHHOUSPLAT = 380;;
let _PPC_INS_EVLHHOUSPLATX = 381;;
let _PPC_INS_EVLWHE = 382;;
let _PPC_INS_EVLWHEX = 383;;
let _PPC_INS_EVLWHOS = 384;;
let _PPC_INS_EVLWHOSX = 385;;
let _PPC_INS_EVLWHOU = 386;;
let _PPC_INS_EVLWHOUX = 387;;
let _PPC_INS_EVLWHSPLAT = 388;;
let _PPC_INS_EVLWHSPLATX = 389;;
let _PPC_INS_EVLWWSPLAT = 390;;
let _PPC_INS_EVLWWSPLATX = 391;;
let _PPC_INS_EVMERGEHI = 392;;
let _PPC_INS_EVMERGEHILO = 393;;
let _PPC_INS_EVMERGELO = 394;;
let _PPC_INS_EVMERGELOHI = 395;;
let _PPC_INS_EVMHEGSMFAA = 396;;
let _PPC_INS_EVMHEGSMFAN = 397;;
let _PPC_INS_EVMHEGSMIAA = 398;;
let _PPC_INS_EVMHEGSMIAN = 399;;
let _PPC_INS_EVMHEGUMIAA = 400;;
let _PPC_INS_EVMHEGUMIAN = 401;;
let _PPC_INS_EVMHESMF = 402;;
let _PPC_INS_EVMHESMFA = 403;;
let _PPC_INS_EVMHESMFAAW = 404;;
let _PPC_INS_EVMHESMFANW = 405;;
let _PPC_INS_EVMHESMI = 406;;
let _PPC_INS_EVMHESMIA = 407;;
let _PPC_INS_EVMHESMIAAW = 408;;
let _PPC_INS_EVMHESMIANW = 409;;
let _PPC_INS_EVMHESSF = 410;;
let _PPC_INS_EVMHESSFA = 411;;
let _PPC_INS_EVMHESSFAAW = 412;;
let _PPC_INS_EVMHESSFANW = 413;;
let _PPC_INS_EVMHESSIAAW = 414;;
let _PPC_INS_EVMHESSIANW = 415;;
let _PPC_INS_EVMHEUMI = 416;;
let _PPC_INS_EVMHEUMIA = 417;;
let _PPC_INS_EVMHEUMIAAW = 418;;
let _PPC_INS_EVMHEUMIANW = 419;;
let _PPC_INS_EVMHEUSIAAW = 420;;
let _PPC_INS_EVMHEUSIANW = 421;;
let _PPC_INS_EVMHOGSMFAA = 422;;
let _PPC_INS_EVMHOGSMFAN = 423;;
let _PPC_INS_EVMHOGSMIAA = 424;;
let _PPC_INS_EVMHOGSMIAN = 425;;
let _PPC_INS_EVMHOGUMIAA = 426;;
let _PPC_INS_EVMHOGUMIAN = 427;;
let _PPC_INS_EVMHOSMF = 428;;
let _PPC_INS_EVMHOSMFA = 429;;
let _PPC_INS_EVMHOSMFAAW = 430;;
let _PPC_INS_EVMHOSMFANW = 431;;
let _PPC_INS_EVMHOSMI = 432;;
let _PPC_INS_EVMHOSMIA = 433;;
let _PPC_INS_EVMHOSMIAAW = 434;;
let _PPC_INS_EVMHOSMIANW = 435;;
let _PPC_INS_EVMHOSSF = 436;;
let _PPC_INS_EVMHOSSFA = 437;;
let _PPC_INS_EVMHOSSFAAW = 438;;
let _PPC_INS_EVMHOSSFANW = 439;;
let _PPC_INS_EVMHOSSIAAW = 440;;
let _PPC_INS_EVMHOSSIANW = 441;;
let _PPC_INS_EVMHOUMI = 442;;
let _PPC_INS_EVMHOUMIA = 443;;
let _PPC_INS_EVMHOUMIAAW = 444;;
let _PPC_INS_EVMHOUMIANW = 445;;
let _PPC_INS_EVMHOUSIAAW = 446;;
let _PPC_INS_EVMHOUSIANW = 447;;
let _PPC_INS_EVMRA = 448;;
let _PPC_INS_EVMWHSMF = 449;;
let _PPC_INS_EVMWHSMFA = 450;;
let _PPC_INS_EVMWHSMI = 451;;
let _PPC_INS_EVMWHSMIA = 452;;
let _PPC_INS_EVMWHSSF = 453;;
let _PPC_INS_EVMWHSSFA = 454;;
let _PPC_INS_EVMWHUMI = 455;;
let _PPC_INS_EVMWHUMIA = 456;;
let _PPC_INS_EVMWLSMIAAW = 457;;
let _PPC_INS_EVMWLSMIANW = 458;;
let _PPC_INS_EVMWLSSIAAW = 459;;
let _PPC_INS_EVMWLSSIANW = 460;;
let _PPC_INS_EVMWLUMI = 461;;
let _PPC_INS_EVMWLUMIA = 462;;
let _PPC_INS_EVMWLUMIAAW = 463;;
let _PPC_INS_EVMWLUMIANW = 464;;
let _PPC_INS_EVMWLUSIAAW = 465;;
let _PPC_INS_EVMWLUSIANW = 466;;
let _PPC_INS_EVMWSMF = 467;;
let _PPC_INS_EVMWSMFA = 468;;
let _PPC_INS_EVMWSMFAA = 469;;
let _PPC_INS_EVMWSMFAN = 470;;
let _PPC_INS_EVMWSMI = 471;;
let _PPC_INS_EVMWSMIA = 472;;
let _PPC_INS_EVMWSMIAA = 473;;
let _PPC_INS_EVMWSMIAN = 474;;
let _PPC_INS_EVMWSSF = 475;;
let _PPC_INS_EVMWSSFA = 476;;
let _PPC_INS_EVMWSSFAA = 477;;
let _PPC_INS_EVMWSSFAN = 478;;
let _PPC_INS_EVMWUMI = 479;;
let _PPC_INS_EVMWUMIA = 480;;
let _PPC_INS_EVMWUMIAA = 481;;
let _PPC_INS_EVMWUMIAN = 482;;
let _PPC_INS_EVNAND = 483;;
let _PPC_INS_EVNEG = 484;;
let _PPC_INS_EVNOR = 485;;
let _PPC_INS_EVOR = 486;;
let _PPC_INS_EVORC = 487;;
let _PPC_INS_EVRLW = 488;;
let _PPC_INS_EVRLWI = 489;;
let _PPC_INS_EVRNDW = 490;;
let _PPC_INS_EVSEL = 491;;
let _PPC_INS_EVSLW = 492;;
let _PPC_INS_EVSLWI = 493;;
let _PPC_INS_EVSPLATFI = 494;;
let _PPC_INS_EVSPLATI = 495;;
let _PPC_INS_EVSRWIS = 496;;
let _PPC_INS_EVSRWIU = 497;;
let _PPC_INS_EVSRWS = 498;;
let _PPC_INS_EVSRWU = 499;;
let _PPC_INS_EVSTDD = 500;;
let _PPC_INS_EVSTDDX = 501;;
let _PPC_INS_EVSTDH = 502;;
let _PPC_INS_EVSTDHX = 503;;
let _PPC_INS_EVSTDW = 504;;
let _PPC_INS_EVSTDWX = 505;;
let _PPC_INS_EVSTWHE = 506;;
let _PPC_INS_EVSTWHEX = 507;;
let _PPC_INS_EVSTWHO = 508;;
let _PPC_INS_EVSTWHOX = 509;;
let _PPC_INS_EVSTWWE = 510;;
let _PPC_INS_EVSTWWEX = 511;;
let _PPC_INS_EVSTWWO = 512;;
let _PPC_INS_EVSTWWOX = 513;;
let _PPC_INS_EVSUBFSMIAAW = 514;;
let _PPC_INS_EVSUBFSSIAAW = 515;;
let _PPC_INS_EVSUBFUMIAAW = 516;;
let _PPC_INS_EVSUBFUSIAAW = 517;;
let _PPC_INS_EVSUBFW = 518;;
let _PPC_INS_EVSUBIFW = 519;;
let _PPC_INS_EVXOR = 520;;
let _PPC_INS_EXTLDI = 521;;
let _PPC_INS_EXTLWI = 522;;
let _PPC_INS_EXTRDI = 523;;
let _PPC_INS_EXTRWI = 524;;
let _PPC_INS_EXTSB = 525;;
let _PPC_INS_EXTSH = 526;;
let _PPC_INS_EXTSW = 527;;
let _PPC_INS_EXTSWSLI = 528;;
let _PPC_INS_FABS = 529;;
let _PPC_INS_FADD = 530;;
let _PPC_INS_FADDS = 531;;
let _PPC_INS_FCFID = 532;;
let _PPC_INS_FCFIDS = 533;;
let _PPC_INS_FCFIDU = 534;;
let _PPC_INS_FCFIDUS = 535;;
let _PPC_INS_FCMPU = 536;;
let _PPC_INS_FCPSGN = 537;;
let _PPC_INS_FCTID = 538;;
let _PPC_INS_FCTIDU = 539;;
let _PPC_INS_FCTIDUZ = 540;;
let _PPC_INS_FCTIDZ = 541;;
let _PPC_INS_FCTIW = 542;;
let _PPC_INS_FCTIWU = 543;;
let _PPC_INS_FCTIWUZ = 544;;
let _PPC_INS_FCTIWZ = 545;;
let _PPC_INS_FDIV = 546;;
let _PPC_INS_FDIVS = 547;;
let _PPC_INS_FMADD = 548;;
let _PPC_INS_FMADDS = 549;;
let _PPC_INS_FMR = 550;;
let _PPC_INS_FMSUB = 551;;
let _PPC_INS_FMSUBS = 552;;
let _PPC_INS_FMUL = 553;;
let _PPC_INS_FMULS = 554;;
let _PPC_INS_FNABS = 555;;
let _PPC_INS_FNEG = 556;;
let _PPC_INS_FNMADD = 557;;
let _PPC_INS_FNMADDS = 558;;
let _PPC_INS_FNMSUB = 559;;
let _PPC_INS_FNMSUBS = 560;;
let _PPC_INS_FRE = 561;;
let _PPC_INS_FRES = 562;;
let _PPC_INS_FRIM = 563;;
let _PPC_INS_FRIN = 564;;
let _PPC_INS_FRIP = 565;;
let _PPC_INS_FRIZ = 566;;
let _PPC_INS_FRSP = 567;;
let _PPC_INS_FRSQRTE = 568;;
let _PPC_INS_FRSQRTES = 569;;
let _PPC_INS_FSEL = 570;;
let _PPC_INS_FSQRT = 571;;
let _PPC_INS_FSQRTS = 572;;
let _PPC_INS_FSUB = 573;;
let _PPC_INS_FSUBS = 574;;
let _PPC_INS_FTDIV = 575;;
let _PPC_INS_FTSQRT = 576;;
let _PPC_INS_HRFID = 577;;
let _PPC_INS_ICBI = 578;;
let _PPC_INS_ICBIEP = 579;;
let _PPC_INS_ICBLC = 580;;
let _PPC_INS_ICBLQ = 581;;
let _PPC_INS_ICBT = 582;;
let _PPC_INS_ICBTLS = 583;;
let _PPC_INS_ICCCI = 584;;
let _PPC_INS_ICI = 585;;
let _PPC_INS_INSLWI = 586;;
let _PPC_INS_INSRDI = 587;;
let _PPC_INS_INSRWI = 588;;
let _PPC_INS_ISEL = 589;;
let _PPC_INS_ISYNC = 590;;
let _PPC_INS_LA = 591;;
let _PPC_INS_LBARX = 592;;
let _PPC_INS_LBEPX = 593;;
let _PPC_INS_LBZ = 594;;
let _PPC_INS_LBZCIX = 595;;
let _PPC_INS_LBZU = 596;;
let _PPC_INS_LBZUX = 597;;
let _PPC_INS_LBZX = 598;;
let _PPC_INS_LD = 599;;
let _PPC_INS_LDARX = 600;;
let _PPC_INS_LDAT = 601;;
let _PPC_INS_LDBRX = 602;;
let _PPC_INS_LDCIX = 603;;
let _PPC_INS_LDMX = 604;;
let _PPC_INS_LDU = 605;;
let _PPC_INS_LDUX = 606;;
let _PPC_INS_LDX = 607;;
let _PPC_INS_LFD = 608;;
let _PPC_INS_LFDEPX = 609;;
let _PPC_INS_LFDU = 610;;
let _PPC_INS_LFDUX = 611;;
let _PPC_INS_LFDX = 612;;
let _PPC_INS_LFIWAX = 613;;
let _PPC_INS_LFIWZX = 614;;
let _PPC_INS_LFS = 615;;
let _PPC_INS_LFSU = 616;;
let _PPC_INS_LFSUX = 617;;
let _PPC_INS_LFSX = 618;;
let _PPC_INS_LHA = 619;;
let _PPC_INS_LHARX = 620;;
let _PPC_INS_LHAU = 621;;
let _PPC_INS_LHAUX = 622;;
let _PPC_INS_LHAX = 623;;
let _PPC_INS_LHBRX = 624;;
let _PPC_INS_LHEPX = 625;;
let _PPC_INS_LHZ = 626;;
let _PPC_INS_LHZCIX = 627;;
let _PPC_INS_LHZU = 628;;
let _PPC_INS_LHZUX = 629;;
let _PPC_INS_LHZX = 630;;
let _PPC_INS_LI = 631;;
let _PPC_INS_LIS = 632;;
let _PPC_INS_LMW = 633;;
let _PPC_INS_LNIA = 634;;
let _PPC_INS_LSWI = 635;;
let _PPC_INS_LVEBX = 636;;
let _PPC_INS_LVEHX = 637;;
let _PPC_INS_LVEWX = 638;;
let _PPC_INS_LVSL = 639;;
let _PPC_INS_LVSR = 640;;
let _PPC_INS_LVX = 641;;
let _PPC_INS_LVXL = 642;;
let _PPC_INS_LWA = 643;;
let _PPC_INS_LWARX = 644;;
let _PPC_INS_LWAT = 645;;
let _PPC_INS_LWAUX = 646;;
let _PPC_INS_LWAX = 647;;
let _PPC_INS_LWBRX = 648;;
let _PPC_INS_LWEPX = 649;;
let _PPC_INS_LWSYNC = 650;;
let _PPC_INS_LWZ = 651;;
let _PPC_INS_LWZCIX = 652;;
let _PPC_INS_LWZU = 653;;
let _PPC_INS_LWZUX = 654;;
let _PPC_INS_LWZX = 655;;
let _PPC_INS_LXSD = 656;;
let _PPC_INS_LXSDX = 657;;
let _PPC_INS_LXSIBZX = 658;;
let _PPC_INS_LXSIHZX = 659;;
let _PPC_INS_LXSIWAX = 660;;
let _PPC_INS_LXSIWZX = 661;;
let _PPC_INS_LXSSP = 662;;
let _PPC_INS_LXSSPX = 663;;
let _PPC_INS_LXV = 664;;
let _PPC_INS_LXVB16X = 665;;
let _PPC_INS_LXVD2X = 666;;
let _PPC_INS_LXVDSX = 667;;
let _PPC_INS_LXVH8X = 668;;
let _PPC_INS_LXVL = 669;;
let _PPC_INS_LXVLL = 670;;
let _PPC_INS_LXVW4X = 671;;
let _PPC_INS_LXVWSX = 672;;
let _PPC_INS_LXVX = 673;;
let _PPC_INS_MADDHD = 674;;
let _PPC_INS_MADDHDU = 675;;
let _PPC_INS_MADDLD = 676;;
let _PPC_INS_MBAR = 677;;
let _PPC_INS_MCRF = 678;;
let _PPC_INS_MCRFS = 679;;
let _PPC_INS_MCRXRX = 680;;
let _PPC_INS_MFAMR = 681;;
let _PPC_INS_MFASR = 682;;
let _PPC_INS_MFBHRBE = 683;;
let _PPC_INS_MFBR0 = 684;;
let _PPC_INS_MFBR1 = 685;;
let _PPC_INS_MFBR2 = 686;;
let _PPC_INS_MFBR3 = 687;;
let _PPC_INS_MFBR4 = 688;;
let _PPC_INS_MFBR5 = 689;;
let _PPC_INS_MFBR6 = 690;;
let _PPC_INS_MFBR7 = 691;;
let _PPC_INS_MFCFAR = 692;;
let _PPC_INS_MFCR = 693;;
let _PPC_INS_MFCTR = 694;;
let _PPC_INS_MFDAR = 695;;
let _PPC_INS_MFDBATL = 696;;
let _PPC_INS_MFDBATU = 697;;
let _PPC_INS_MFDCCR = 698;;
let _PPC_INS_MFDCR = 699;;
let _PPC_INS_MFDEAR = 700;;
let _PPC_INS_MFDEC = 701;;
let _PPC_INS_MFDSCR = 702;;
let _PPC_INS_MFDSISR = 703;;
let _PPC_INS_MFESR = 704;;
let _PPC_INS_MFFPRD = 705;;
let _PPC_INS_MFFS = 706;;
let _PPC_INS_MFFSCDRN = 707;;
let _PPC_INS_MFFSCDRNI = 708;;
let _PPC_INS_MFFSCE = 709;;
let _PPC_INS_MFFSCRN = 710;;
let _PPC_INS_MFFSCRNI = 711;;
let _PPC_INS_MFFSL = 712;;
let _PPC_INS_MFIBATL = 713;;
let _PPC_INS_MFIBATU = 714;;
let _PPC_INS_MFICCR = 715;;
let _PPC_INS_MFLR = 716;;
let _PPC_INS_MFMSR = 717;;
let _PPC_INS_MFOCRF = 718;;
let _PPC_INS_MFPID = 719;;
let _PPC_INS_MFPMR = 720;;
let _PPC_INS_MFPVR = 721;;
let _PPC_INS_MFRTCL = 722;;
let _PPC_INS_MFRTCU = 723;;
let _PPC_INS_MFSDR1 = 724;;
let _PPC_INS_MFSPEFSCR = 725;;
let _PPC_INS_MFSPR = 726;;
let _PPC_INS_MFSPRG = 727;;
let _PPC_INS_MFSPRG0 = 728;;
let _PPC_INS_MFSPRG1 = 729;;
let _PPC_INS_MFSPRG2 = 730;;
let _PPC_INS_MFSPRG3 = 731;;
let _PPC_INS_MFSPRG4 = 732;;
let _PPC_INS_MFSPRG5 = 733;;
let _PPC_INS_MFSPRG6 = 734;;
let _PPC_INS_MFSPRG7 = 735;;
let _PPC_INS_MFSR = 736;;
let _PPC_INS_MFSRIN = 737;;
let _PPC_INS_MFSRR0 = 738;;
let _PPC_INS_MFSRR1 = 739;;
let _PPC_INS_MFSRR2 = 740;;
let _PPC_INS_MFSRR3 = 741;;
let _PPC_INS_MFTB = 742;;
let _PPC_INS_MFTBHI = 743;;
let _PPC_INS_MFTBL = 744;;
let _PPC_INS_MFTBLO = 745;;
let _PPC_INS_MFTBU = 746;;
let _PPC_INS_MFTCR = 747;;
let _PPC_INS_MFVRD = 748;;
let _PPC_INS_MFVRSAVE = 749;;
let _PPC_INS_MFVSCR = 750;;
let _PPC_INS_MFVSRD = 751;;
let _PPC_INS_MFVSRLD = 752;;
let _PPC_INS_MFVSRWZ = 753;;
let _PPC_INS_MFXER = 754;;
let _PPC_INS_MODSD = 755;;
let _PPC_INS_MODSW = 756;;
let _PPC_INS_MODUD = 757;;
let _PPC_INS_MODUW = 758;;
let _PPC_INS_MR = 759;;
let _PPC_INS_MSGSYNC = 760;;
let _PPC_INS_MSYNC = 761;;
let _PPC_INS_MTAMR = 762;;
let _PPC_INS_MTASR = 763;;
let _PPC_INS_MTBR0 = 764;;
let _PPC_INS_MTBR1 = 765;;
let _PPC_INS_MTBR2 = 766;;
let _PPC_INS_MTBR3 = 767;;
let _PPC_INS_MTBR4 = 768;;
let _PPC_INS_MTBR5 = 769;;
let _PPC_INS_MTBR6 = 770;;
let _PPC_INS_MTBR7 = 771;;
let _PPC_INS_MTCFAR = 772;;
let _PPC_INS_MTCR = 773;;
let _PPC_INS_MTCRF = 774;;
let _PPC_INS_MTCTR = 775;;
let _PPC_INS_MTDAR = 776;;
let _PPC_INS_MTDBATL = 777;;
let _PPC_INS_MTDBATU = 778;;
let _PPC_INS_MTDCCR = 779;;
let _PPC_INS_MTDCR = 780;;
let _PPC_INS_MTDEAR = 781;;
let _PPC_INS_MTDEC = 782;;
let _PPC_INS_MTDSCR = 783;;
let _PPC_INS_MTDSISR = 784;;
let _PPC_INS_MTESR = 785;;
let _PPC_INS_MTFSB0 = 786;;
let _PPC_INS_MTFSB1 = 787;;
let _PPC_INS_MTFSF = 788;;
let _PPC_INS_MTFSFI = 789;;
let _PPC_INS_MTIBATL = 790;;
let _PPC_INS_MTIBATU = 791;;
let _PPC_INS_MTICCR = 792;;
let _PPC_INS_MTLR = 793;;
let _PPC_INS_MTMSR = 794;;
let _PPC_INS_MTMSRD = 795;;
let _PPC_INS_MTOCRF = 796;;
let _PPC_INS_MTPID = 797;;
let _PPC_INS_MTPMR = 798;;
let _PPC_INS_MTSDR1 = 799;;
let _PPC_INS_MTSPEFSCR = 800;;
let _PPC_INS_MTSPR = 801;;
let _PPC_INS_MTSPRG = 802;;
let _PPC_INS_MTSPRG0 = 803;;
let _PPC_INS_MTSPRG1 = 804;;
let _PPC_INS_MTSPRG2 = 805;;
let _PPC_INS_MTSPRG3 = 806;;
let _PPC_INS_MTSPRG4 = 807;;
let _PPC_INS_MTSPRG5 = 808;;
let _PPC_INS_MTSPRG6 = 809;;
let _PPC_INS_MTSPRG7 = 810;;
let _PPC_INS_MTSR = 811;;
let _PPC_INS_MTSRIN = 812;;
let _PPC_INS_MTSRR0 = 813;;
let _PPC_INS_MTSRR1 = 814;;
let _PPC_INS_MTSRR2 = 815;;
let _PPC_INS_MTSRR3 = 816;;
let _PPC_INS_MTTBHI = 817;;
let _PPC_INS_MTTBL = 818;;
let _PPC_INS_MTTBLO = 819;;
let _PPC_INS_MTTBU = 820;;
let _PPC_INS_MTTCR = 821;;
let _PPC_INS_MTVRSAVE = 822;;
let _PPC_INS_MTVSCR = 823;;
let _PPC_INS_MTVSRD = 824;;
let _PPC_INS_MTVSRDD = 825;;
let _PPC_INS_MTVSRWA = 826;;
let _PPC_INS_MTVSRWS = 827;;
let _PPC_INS_MTVSRWZ = 828;;
let _PPC_INS_MTXER = 829;;
let _PPC_INS_MULHD = 830;;
let _PPC_INS_MULHDU = 831;;
let _PPC_INS_MULHW = 832;;
let _PPC_INS_MULHWU = 833;;
let _PPC_INS_MULLD = 834;;
let _PPC_INS_MULLI = 835;;
let _PPC_INS_MULLW = 836;;
let _PPC_INS_NAND = 837;;
let _PPC_INS_NAP = 838;;
let _PPC_INS_NEG = 839;;
let _PPC_INS_NOP = 840;;
let _PPC_INS_NOR = 841;;
let _PPC_INS_NOT = 842;;
let _PPC_INS_OR = 843;;
let _PPC_INS_ORC = 844;;
let _PPC_INS_ORI = 845;;
let _PPC_INS_ORIS = 846;;
let _PPC_INS_PASTE = 847;;
let _PPC_INS_PASTE_LAST = 848;;
let _PPC_INS_POPCNTB = 849;;
let _PPC_INS_POPCNTD = 850;;
let _PPC_INS_POPCNTW = 851;;
let _PPC_INS_PTESYNC = 852;;
let _PPC_INS_QVALIGNI = 853;;
let _PPC_INS_QVESPLATI = 854;;
let _PPC_INS_QVFABS = 855;;
let _PPC_INS_QVFADD = 856;;
let _PPC_INS_QVFADDS = 857;;
let _PPC_INS_QVFAND = 858;;
let _PPC_INS_QVFANDC = 859;;
let _PPC_INS_QVFCFID = 860;;
let _PPC_INS_QVFCFIDS = 861;;
let _PPC_INS_QVFCFIDU = 862;;
let _PPC_INS_QVFCFIDUS = 863;;
let _PPC_INS_QVFCLR = 864;;
let _PPC_INS_QVFCMPEQ = 865;;
let _PPC_INS_QVFCMPGT = 866;;
let _PPC_INS_QVFCMPLT = 867;;
let _PPC_INS_QVFCPSGN = 868;;
let _PPC_INS_QVFCTFB = 869;;
let _PPC_INS_QVFCTID = 870;;
let _PPC_INS_QVFCTIDU = 871;;
let _PPC_INS_QVFCTIDUZ = 872;;
let _PPC_INS_QVFCTIDZ = 873;;
let _PPC_INS_QVFCTIW = 874;;
let _PPC_INS_QVFCTIWU = 875;;
let _PPC_INS_QVFCTIWUZ = 876;;
let _PPC_INS_QVFCTIWZ = 877;;
let _PPC_INS_QVFEQU = 878;;
let _PPC_INS_QVFLOGICAL = 879;;
let _PPC_INS_QVFMADD = 880;;
let _PPC_INS_QVFMADDS = 881;;
let _PPC_INS_QVFMR = 882;;
let _PPC_INS_QVFMSUB = 883;;
let _PPC_INS_QVFMSUBS = 884;;
let _PPC_INS_QVFMUL = 885;;
let _PPC_INS_QVFMULS = 886;;
let _PPC_INS_QVFNABS = 887;;
let _PPC_INS_QVFNAND = 888;;
let _PPC_INS_QVFNEG = 889;;
let _PPC_INS_QVFNMADD = 890;;
let _PPC_INS_QVFNMADDS = 891;;
let _PPC_INS_QVFNMSUB = 892;;
let _PPC_INS_QVFNMSUBS = 893;;
let _PPC_INS_QVFNOR = 894;;
let _PPC_INS_QVFNOT = 895;;
let _PPC_INS_QVFOR = 896;;
let _PPC_INS_QVFORC = 897;;
let _PPC_INS_QVFPERM = 898;;
let _PPC_INS_QVFRE = 899;;
let _PPC_INS_QVFRES = 900;;
let _PPC_INS_QVFRIM = 901;;
let _PPC_INS_QVFRIN = 902;;
let _PPC_INS_QVFRIP = 903;;
let _PPC_INS_QVFRIZ = 904;;
let _PPC_INS_QVFRSP = 905;;
let _PPC_INS_QVFRSQRTE = 906;;
let _PPC_INS_QVFRSQRTES = 907;;
let _PPC_INS_QVFSEL = 908;;
let _PPC_INS_QVFSET = 909;;
let _PPC_INS_QVFSUB = 910;;
let _PPC_INS_QVFSUBS = 911;;
let _PPC_INS_QVFTSTNAN = 912;;
let _PPC_INS_QVFXMADD = 913;;
let _PPC_INS_QVFXMADDS = 914;;
let _PPC_INS_QVFXMUL = 915;;
let _PPC_INS_QVFXMULS = 916;;
let _PPC_INS_QVFXOR = 917;;
let _PPC_INS_QVFXXCPNMADD = 918;;
let _PPC_INS_QVFXXCPNMADDS = 919;;
let _PPC_INS_QVFXXMADD = 920;;
let _PPC_INS_QVFXXMADDS = 921;;
let _PPC_INS_QVFXXNPMADD = 922;;
let _PPC_INS_QVFXXNPMADDS = 923;;
let _PPC_INS_QVGPCI = 924;;
let _PPC_INS_QVLFCDUX = 925;;
let _PPC_INS_QVLFCDUXA = 926;;
let _PPC_INS_QVLFCDX = 927;;
let _PPC_INS_QVLFCDXA = 928;;
let _PPC_INS_QVLFCSUX = 929;;
let _PPC_INS_QVLFCSUXA = 930;;
let _PPC_INS_QVLFCSX = 931;;
let _PPC_INS_QVLFCSXA = 932;;
let _PPC_INS_QVLFDUX = 933;;
let _PPC_INS_QVLFDUXA = 934;;
let _PPC_INS_QVLFDX = 935;;
let _PPC_INS_QVLFDXA = 936;;
let _PPC_INS_QVLFIWAX = 937;;
let _PPC_INS_QVLFIWAXA = 938;;
let _PPC_INS_QVLFIWZX = 939;;
let _PPC_INS_QVLFIWZXA = 940;;
let _PPC_INS_QVLFSUX = 941;;
let _PPC_INS_QVLFSUXA = 942;;
let _PPC_INS_QVLFSX = 943;;
let _PPC_INS_QVLFSXA = 944;;
let _PPC_INS_QVLPCLDX = 945;;
let _PPC_INS_QVLPCLSX = 946;;
let _PPC_INS_QVLPCRDX = 947;;
let _PPC_INS_QVLPCRSX = 948;;
let _PPC_INS_QVSTFCDUX = 949;;
let _PPC_INS_QVSTFCDUXA = 950;;
let _PPC_INS_QVSTFCDUXI = 951;;
let _PPC_INS_QVSTFCDUXIA = 952;;
let _PPC_INS_QVSTFCDX = 953;;
let _PPC_INS_QVSTFCDXA = 954;;
let _PPC_INS_QVSTFCDXI = 955;;
let _PPC_INS_QVSTFCDXIA = 956;;
let _PPC_INS_QVSTFCSUX = 957;;
let _PPC_INS_QVSTFCSUXA = 958;;
let _PPC_INS_QVSTFCSUXI = 959;;
let _PPC_INS_QVSTFCSUXIA = 960;;
let _PPC_INS_QVSTFCSX = 961;;
let _PPC_INS_QVSTFCSXA = 962;;
let _PPC_INS_QVSTFCSXI = 963;;
let _PPC_INS_QVSTFCSXIA = 964;;
let _PPC_INS_QVSTFDUX = 965;;
let _PPC_INS_QVSTFDUXA = 966;;
let _PPC_INS_QVSTFDUXI = 967;;
let _PPC_INS_QVSTFDUXIA = 968;;
let _PPC_INS_QVSTFDX = 969;;
let _PPC_INS_QVSTFDXA = 970;;
let _PPC_INS_QVSTFDXI = 971;;
let _PPC_INS_QVSTFDXIA = 972;;
let _PPC_INS_QVSTFIWX = 973;;
let _PPC_INS_QVSTFIWXA = 974;;
let _PPC_INS_QVSTFSUX = 975;;
let _PPC_INS_QVSTFSUXA = 976;;
let _PPC_INS_QVSTFSUXI = 977;;
let _PPC_INS_QVSTFSUXIA = 978;;
let _PPC_INS_QVSTFSX = 979;;
let _PPC_INS_QVSTFSXA = 980;;
let _PPC_INS_QVSTFSXI = 981;;
let _PPC_INS_QVSTFSXIA = 982;;
let _PPC_INS_RFCI = 983;;
let _PPC_INS_RFDI = 984;;
let _PPC_INS_RFEBB = 985;;
let _PPC_INS_RFI = 986;;
let _PPC_INS_RFID = 987;;
let _PPC_INS_RFMCI = 988;;
let _PPC_INS_RLDCL = 989;;
let _PPC_INS_RLDCR = 990;;
let _PPC_INS_RLDIC = 991;;
let _PPC_INS_RLDICL = 992;;
let _PPC_INS_RLDICR = 993;;
let _PPC_INS_RLDIMI = 994;;
let _PPC_INS_RLWIMI = 995;;
let _PPC_INS_RLWINM = 996;;
let _PPC_INS_RLWNM = 997;;
let _PPC_INS_ROTLD = 998;;
let _PPC_INS_ROTLDI = 999;;
let _PPC_INS_ROTLW = 1000;;
let _PPC_INS_ROTLWI = 1001;;
let _PPC_INS_ROTRDI = 1002;;
let _PPC_INS_ROTRWI = 1003;;
let _PPC_INS_SC = 1004;;
let _PPC_INS_SETB = 1005;;
let _PPC_INS_SLBIA = 1006;;
let _PPC_INS_SLBIE = 1007;;
let _PPC_INS_SLBIEG = 1008;;
let _PPC_INS_SLBMFEE = 1009;;
let _PPC_INS_SLBMFEV = 1010;;
let _PPC_INS_SLBMTE = 1011;;
let _PPC_INS_SLBSYNC = 1012;;
let _PPC_INS_SLD = 1013;;
let _PPC_INS_SLDI = 1014;;
let _PPC_INS_SLW = 1015;;
let _PPC_INS_SLWI = 1016;;
let _PPC_INS_SRAD = 1017;;
let _PPC_INS_SRADI = 1018;;
let _PPC_INS_SRAW = 1019;;
let _PPC_INS_SRAWI = 1020;;
let _PPC_INS_SRD = 1021;;
let _PPC_INS_SRDI = 1022;;
let _PPC_INS_SRW = 1023;;
let _PPC_INS_SRWI = 1024;;
let _PPC_INS_STB = 1025;;
let _PPC_INS_STBCIX = 1026;;
let _PPC_INS_STBCX = 1027;;
let _PPC_INS_STBEPX = 1028;;
let _PPC_INS_STBU = 1029;;
let _PPC_INS_STBUX = 1030;;
let _PPC_INS_STBX = 1031;;
let _PPC_INS_STD = 1032;;
let _PPC_INS_STDAT = 1033;;
let _PPC_INS_STDBRX = 1034;;
let _PPC_INS_STDCIX = 1035;;
let _PPC_INS_STDCX = 1036;;
let _PPC_INS_STDU = 1037;;
let _PPC_INS_STDUX = 1038;;
let _PPC_INS_STDX = 1039;;
let _PPC_INS_STFD = 1040;;
let _PPC_INS_STFDEPX = 1041;;
let _PPC_INS_STFDU = 1042;;
let _PPC_INS_STFDUX = 1043;;
let _PPC_INS_STFDX = 1044;;
let _PPC_INS_STFIWX = 1045;;
let _PPC_INS_STFS = 1046;;
let _PPC_INS_STFSU = 1047;;
let _PPC_INS_STFSUX = 1048;;
let _PPC_INS_STFSX = 1049;;
let _PPC_INS_STH = 1050;;
let _PPC_INS_STHBRX = 1051;;
let _PPC_INS_STHCIX = 1052;;
let _PPC_INS_STHCX = 1053;;
let _PPC_INS_STHEPX = 1054;;
let _PPC_INS_STHU = 1055;;
let _PPC_INS_STHUX = 1056;;
let _PPC_INS_STHX = 1057;;
let _PPC_INS_STMW = 1058;;
let _PPC_INS_STOP = 1059;;
let _PPC_INS_STSWI = 1060;;
let _PPC_INS_STVEBX = 1061;;
let _PPC_INS_STVEHX = 1062;;
let _PPC_INS_STVEWX = 1063;;
let _PPC_INS_STVX = 1064;;
let _PPC_INS_STVXL = 1065;;
let _PPC_INS_STW = 1066;;
let _PPC_INS_STWAT = 1067;;
let _PPC_INS_STWBRX = 1068;;
let _PPC_INS_STWCIX = 1069;;
let _PPC_INS_STWCX = 1070;;
let _PPC_INS_STWEPX = 1071;;
let _PPC_INS_STWU = 1072;;
let _PPC_INS_STWUX = 1073;;
let _PPC_INS_STWX = 1074;;
let _PPC_INS_STXSD = 1075;;
let _PPC_INS_STXSDX = 1076;;
let _PPC_INS_STXSIBX = 1077;;
let _PPC_INS_STXSIHX = 1078;;
let _PPC_INS_STXSIWX = 1079;;
let _PPC_INS_STXSSP = 1080;;
let _PPC_INS_STXSSPX = 1081;;
let _PPC_INS_STXV = 1082;;
let _PPC_INS_STXVB16X = 1083;;
let _PPC_INS_STXVD2X = 1084;;
let _PPC_INS_STXVH8X = 1085;;
let _PPC_INS_STXVL = 1086;;
let _PPC_INS_STXVLL = 1087;;
let _PPC_INS_STXVW4X = 1088;;
let _PPC_INS_STXVX = 1089;;
let _PPC_INS_SUB = 1090;;
let _PPC_INS_SUBC = 1091;;
let _PPC_INS_SUBF = 1092;;
let _PPC_INS_SUBFC = 1093;;
let _PPC_INS_SUBFE = 1094;;
let _PPC_INS_SUBFIC = 1095;;
let _PPC_INS_SUBFME = 1096;;
let _PPC_INS_SUBFZE = 1097;;
let _PPC_INS_SUBI = 1098;;
let _PPC_INS_SUBIC = 1099;;
let _PPC_INS_SUBIS = 1100;;
let _PPC_INS_SUBPCIS = 1101;;
let _PPC_INS_SYNC = 1102;;
let _PPC_INS_TABORT = 1103;;
let _PPC_INS_TABORTDC = 1104;;
let _PPC_INS_TABORTDCI = 1105;;
let _PPC_INS_TABORTWC = 1106;;
let _PPC_INS_TABORTWCI = 1107;;
let _PPC_INS_TBEGIN = 1108;;
let _PPC_INS_TCHECK = 1109;;
let _PPC_INS_TD = 1110;;
let _PPC_INS_TDEQ = 1111;;
let _PPC_INS_TDEQI = 1112;;
let _PPC_INS_TDGE = 1113;;
let _PPC_INS_TDGEI = 1114;;
let _PPC_INS_TDGT = 1115;;
let _PPC_INS_TDGTI = 1116;;
let _PPC_INS_TDI = 1117;;
let _PPC_INS_TDLE = 1118;;
let _PPC_INS_TDLEI = 1119;;
let _PPC_INS_TDLGE = 1120;;
let _PPC_INS_TDLGEI = 1121;;
let _PPC_INS_TDLGT = 1122;;
let _PPC_INS_TDLGTI = 1123;;
let _PPC_INS_TDLLE = 1124;;
let _PPC_INS_TDLLEI = 1125;;
let _PPC_INS_TDLLT = 1126;;
let _PPC_INS_TDLLTI = 1127;;
let _PPC_INS_TDLNG = 1128;;
let _PPC_INS_TDLNGI = 1129;;
let _PPC_INS_TDLNL = 1130;;
let _PPC_INS_TDLNLI = 1131;;
let _PPC_INS_TDLT = 1132;;
let _PPC_INS_TDLTI = 1133;;
let _PPC_INS_TDNE = 1134;;
let _PPC_INS_TDNEI = 1135;;
let _PPC_INS_TDNG = 1136;;
let _PPC_INS_TDNGI = 1137;;
let _PPC_INS_TDNL = 1138;;
let _PPC_INS_TDNLI = 1139;;
let _PPC_INS_TDU = 1140;;
let _PPC_INS_TDUI = 1141;;
let _PPC_INS_TEND = 1142;;
let _PPC_INS_TLBIA = 1143;;
let _PPC_INS_TLBIE = 1144;;
let _PPC_INS_TLBIEL = 1145;;
let _PPC_INS_TLBIVAX = 1146;;
let _PPC_INS_TLBLD = 1147;;
let _PPC_INS_TLBLI = 1148;;
let _PPC_INS_TLBRE = 1149;;
let _PPC_INS_TLBREHI = 1150;;
let _PPC_INS_TLBRELO = 1151;;
let _PPC_INS_TLBSX = 1152;;
let _PPC_INS_TLBSYNC = 1153;;
let _PPC_INS_TLBWE = 1154;;
let _PPC_INS_TLBWEHI = 1155;;
let _PPC_INS_TLBWELO = 1156;;
let _PPC_INS_TRAP = 1157;;
let _PPC_INS_TRECHKPT = 1158;;
let _PPC_INS_TRECLAIM = 1159;;
let _PPC_INS_TSR = 1160;;
let _PPC_INS_TW = 1161;;
let _PPC_INS_TWEQ = 1162;;
let _PPC_INS_TWEQI = 1163;;
let _PPC_INS_TWGE = 1164;;
let _PPC_INS_TWGEI = 1165;;
let _PPC_INS_TWGT = 1166;;
let _PPC_INS_TWGTI = 1167;;
let _PPC_INS_TWI = 1168;;
let _PPC_INS_TWLE = 1169;;
let _PPC_INS_TWLEI = 1170;;
let _PPC_INS_TWLGE = 1171;;
let _PPC_INS_TWLGEI = 1172;;
let _PPC_INS_TWLGT = 1173;;
let _PPC_INS_TWLGTI = 1174;;
let _PPC_INS_TWLLE = 1175;;
let _PPC_INS_TWLLEI = 1176;;
let _PPC_INS_TWLLT = 1177;;
let _PPC_INS_TWLLTI = 1178;;
let _PPC_INS_TWLNG = 1179;;
let _PPC_INS_TWLNGI = 1180;;
let _PPC_INS_TWLNL = 1181;;
let _PPC_INS_TWLNLI = 1182;;
let _PPC_INS_TWLT = 1183;;
let _PPC_INS_TWLTI = 1184;;
let _PPC_INS_TWNE = 1185;;
let _PPC_INS_TWNEI = 1186;;
let _PPC_INS_TWNG = 1187;;
let _PPC_INS_TWNGI = 1188;;
let _PPC_INS_TWNL = 1189;;
let _PPC_INS_TWNLI = 1190;;
let _PPC_INS_TWU = 1191;;
let _PPC_INS_TWUI = 1192;;
let _PPC_INS_VABSDUB = 1193;;
let _PPC_INS_VABSDUH = 1194;;
let _PPC_INS_VABSDUW = 1195;;
let _PPC_INS_VADDCUQ = 1196;;
let _PPC_INS_VADDCUW = 1197;;
let _PPC_INS_VADDECUQ = 1198;;
let _PPC_INS_VADDEUQM = 1199;;
let _PPC_INS_VADDFP = 1200;;
let _PPC_INS_VADDSBS = 1201;;
let _PPC_INS_VADDSHS = 1202;;
let _PPC_INS_VADDSWS = 1203;;
let _PPC_INS_VADDUBM = 1204;;
let _PPC_INS_VADDUBS = 1205;;
let _PPC_INS_VADDUDM = 1206;;
let _PPC_INS_VADDUHM = 1207;;
let _PPC_INS_VADDUHS = 1208;;
let _PPC_INS_VADDUQM = 1209;;
let _PPC_INS_VADDUWM = 1210;;
let _PPC_INS_VADDUWS = 1211;;
let _PPC_INS_VAND = 1212;;
let _PPC_INS_VANDC = 1213;;
let _PPC_INS_VAVGSB = 1214;;
let _PPC_INS_VAVGSH = 1215;;
let _PPC_INS_VAVGSW = 1216;;
let _PPC_INS_VAVGUB = 1217;;
let _PPC_INS_VAVGUH = 1218;;
let _PPC_INS_VAVGUW = 1219;;
let _PPC_INS_VBPERMD = 1220;;
let _PPC_INS_VBPERMQ = 1221;;
let _PPC_INS_VCFSX = 1222;;
let _PPC_INS_VCFUX = 1223;;
let _PPC_INS_VCIPHER = 1224;;
let _PPC_INS_VCIPHERLAST = 1225;;
let _PPC_INS_VCLZB = 1226;;
let _PPC_INS_VCLZD = 1227;;
let _PPC_INS_VCLZH = 1228;;
let _PPC_INS_VCLZLSBB = 1229;;
let _PPC_INS_VCLZW = 1230;;
let _PPC_INS_VCMPBFP = 1231;;
let _PPC_INS_VCMPEQFP = 1232;;
let _PPC_INS_VCMPEQUB = 1233;;
let _PPC_INS_VCMPEQUD = 1234;;
let _PPC_INS_VCMPEQUH = 1235;;
let _PPC_INS_VCMPEQUW = 1236;;
let _PPC_INS_VCMPGEFP = 1237;;
let _PPC_INS_VCMPGTFP = 1238;;
let _PPC_INS_VCMPGTSB = 1239;;
let _PPC_INS_VCMPGTSD = 1240;;
let _PPC_INS_VCMPGTSH = 1241;;
let _PPC_INS_VCMPGTSW = 1242;;
let _PPC_INS_VCMPGTUB = 1243;;
let _PPC_INS_VCMPGTUD = 1244;;
let _PPC_INS_VCMPGTUH = 1245;;
let _PPC_INS_VCMPGTUW = 1246;;
let _PPC_INS_VCMPNEB = 1247;;
let _PPC_INS_VCMPNEH = 1248;;
let _PPC_INS_VCMPNEW = 1249;;
let _PPC_INS_VCMPNEZB = 1250;;
let _PPC_INS_VCMPNEZH = 1251;;
let _PPC_INS_VCMPNEZW = 1252;;
let _PPC_INS_VCTSXS = 1253;;
let _PPC_INS_VCTUXS = 1254;;
let _PPC_INS_VCTZB = 1255;;
let _PPC_INS_VCTZD = 1256;;
let _PPC_INS_VCTZH = 1257;;
let _PPC_INS_VCTZLSBB = 1258;;
let _PPC_INS_VCTZW = 1259;;
let _PPC_INS_VEQV = 1260;;
let _PPC_INS_VEXPTEFP = 1261;;
let _PPC_INS_VEXTRACTD = 1262;;
let _PPC_INS_VEXTRACTUB = 1263;;
let _PPC_INS_VEXTRACTUH = 1264;;
let _PPC_INS_VEXTRACTUW = 1265;;
let _PPC_INS_VEXTSB2D = 1266;;
let _PPC_INS_VEXTSB2W = 1267;;
let _PPC_INS_VEXTSH2D = 1268;;
let _PPC_INS_VEXTSH2W = 1269;;
let _PPC_INS_VEXTSW2D = 1270;;
let _PPC_INS_VEXTUBLX = 1271;;
let _PPC_INS_VEXTUBRX = 1272;;
let _PPC_INS_VEXTUHLX = 1273;;
let _PPC_INS_VEXTUHRX = 1274;;
let _PPC_INS_VEXTUWLX = 1275;;
let _PPC_INS_VEXTUWRX = 1276;;
let _PPC_INS_VGBBD = 1277;;
let _PPC_INS_VINSERTB = 1278;;
let _PPC_INS_VINSERTD = 1279;;
let _PPC_INS_VINSERTH = 1280;;
let _PPC_INS_VINSERTW = 1281;;
let _PPC_INS_VLOGEFP = 1282;;
let _PPC_INS_VMADDFP = 1283;;
let _PPC_INS_VMAXFP = 1284;;
let _PPC_INS_VMAXSB = 1285;;
let _PPC_INS_VMAXSD = 1286;;
let _PPC_INS_VMAXSH = 1287;;
let _PPC_INS_VMAXSW = 1288;;
let _PPC_INS_VMAXUB = 1289;;
let _PPC_INS_VMAXUD = 1290;;
let _PPC_INS_VMAXUH = 1291;;
let _PPC_INS_VMAXUW = 1292;;
let _PPC_INS_VMHADDSHS = 1293;;
let _PPC_INS_VMHRADDSHS = 1294;;
let _PPC_INS_VMINFP = 1295;;
let _PPC_INS_VMINSB = 1296;;
let _PPC_INS_VMINSD = 1297;;
let _PPC_INS_VMINSH = 1298;;
let _PPC_INS_VMINSW = 1299;;
let _PPC_INS_VMINUB = 1300;;
let _PPC_INS_VMINUD = 1301;;
let _PPC_INS_VMINUH = 1302;;
let _PPC_INS_VMINUW = 1303;;
let _PPC_INS_VMLADDUHM = 1304;;
let _PPC_INS_VMR = 1305;;
let _PPC_INS_VMRGEW = 1306;;
let _PPC_INS_VMRGHB = 1307;;
let _PPC_INS_VMRGHH = 1308;;
let _PPC_INS_VMRGHW = 1309;;
let _PPC_INS_VMRGLB = 1310;;
let _PPC_INS_VMRGLH = 1311;;
let _PPC_INS_VMRGLW = 1312;;
let _PPC_INS_VMRGOW = 1313;;
let _PPC_INS_VMSUMMBM = 1314;;
let _PPC_INS_VMSUMSHM = 1315;;
let _PPC_INS_VMSUMSHS = 1316;;
let _PPC_INS_VMSUMUBM = 1317;;
let _PPC_INS_VMSUMUHM = 1318;;
let _PPC_INS_VMSUMUHS = 1319;;
let _PPC_INS_VMUL10CUQ = 1320;;
let _PPC_INS_VMUL10ECUQ = 1321;;
let _PPC_INS_VMUL10EUQ = 1322;;
let _PPC_INS_VMUL10UQ = 1323;;
let _PPC_INS_VMULESB = 1324;;
let _PPC_INS_VMULESH = 1325;;
let _PPC_INS_VMULESW = 1326;;
let _PPC_INS_VMULEUB = 1327;;
let _PPC_INS_VMULEUH = 1328;;
let _PPC_INS_VMULEUW = 1329;;
let _PPC_INS_VMULOSB = 1330;;
let _PPC_INS_VMULOSH = 1331;;
let _PPC_INS_VMULOSW = 1332;;
let _PPC_INS_VMULOUB = 1333;;
let _PPC_INS_VMULOUH = 1334;;
let _PPC_INS_VMULOUW = 1335;;
let _PPC_INS_VMULUWM = 1336;;
let _PPC_INS_VNAND = 1337;;
let _PPC_INS_VNCIPHER = 1338;;
let _PPC_INS_VNCIPHERLAST = 1339;;
let _PPC_INS_VNEGD = 1340;;
let _PPC_INS_VNEGW = 1341;;
let _PPC_INS_VNMSUBFP = 1342;;
let _PPC_INS_VNOR = 1343;;
let _PPC_INS_VNOT = 1344;;
let _PPC_INS_VOR = 1345;;
let _PPC_INS_VORC = 1346;;
let _PPC_INS_VPERM = 1347;;
let _PPC_INS_VPERMR = 1348;;
let _PPC_INS_VPERMXOR = 1349;;
let _PPC_INS_VPKPX = 1350;;
let _PPC_INS_VPKSDSS = 1351;;
let _PPC_INS_VPKSDUS = 1352;;
let _PPC_INS_VPKSHSS = 1353;;
let _PPC_INS_VPKSHUS = 1354;;
let _PPC_INS_VPKSWSS = 1355;;
let _PPC_INS_VPKSWUS = 1356;;
let _PPC_INS_VPKUDUM = 1357;;
let _PPC_INS_VPKUDUS = 1358;;
let _PPC_INS_VPKUHUM = 1359;;
let _PPC_INS_VPKUHUS = 1360;;
let _PPC_INS_VPKUWUM = 1361;;
let _PPC_INS_VPKUWUS = 1362;;
let _PPC_INS_VPMSUMB = 1363;;
let _PPC_INS_VPMSUMD = 1364;;
let _PPC_INS_VPMSUMH = 1365;;
let _PPC_INS_VPMSUMW = 1366;;
let _PPC_INS_VPOPCNTB = 1367;;
let _PPC_INS_VPOPCNTD = 1368;;
let _PPC_INS_VPOPCNTH = 1369;;
let _PPC_INS_VPOPCNTW = 1370;;
let _PPC_INS_VPRTYBD = 1371;;
let _PPC_INS_VPRTYBQ = 1372;;
let _PPC_INS_VPRTYBW = 1373;;
let _PPC_INS_VREFP = 1374;;
let _PPC_INS_VRFIM = 1375;;
let _PPC_INS_VRFIN = 1376;;
let _PPC_INS_VRFIP = 1377;;
let _PPC_INS_VRFIZ = 1378;;
let _PPC_INS_VRLB = 1379;;
let _PPC_INS_VRLD = 1380;;
let _PPC_INS_VRLDMI = 1381;;
let _PPC_INS_VRLDNM = 1382;;
let _PPC_INS_VRLH = 1383;;
let _PPC_INS_VRLW = 1384;;
let _PPC_INS_VRLWMI = 1385;;
let _PPC_INS_VRLWNM = 1386;;
let _PPC_INS_VRSQRTEFP = 1387;;
let _PPC_INS_VSBOX = 1388;;
let _PPC_INS_VSEL = 1389;;
let _PPC_INS_VSHASIGMAD = 1390;;
let _PPC_INS_VSHASIGMAW = 1391;;
let _PPC_INS_VSL = 1392;;
let _PPC_INS_VSLB = 1393;;
let _PPC_INS_VSLD = 1394;;
let _PPC_INS_VSLDOI = 1395;;
let _PPC_INS_VSLH = 1396;;
let _PPC_INS_VSLO = 1397;;
let _PPC_INS_VSLV = 1398;;
let _PPC_INS_VSLW = 1399;;
let _PPC_INS_VSPLTB = 1400;;
let _PPC_INS_VSPLTH = 1401;;
let _PPC_INS_VSPLTISB = 1402;;
let _PPC_INS_VSPLTISH = 1403;;
let _PPC_INS_VSPLTISW = 1404;;
let _PPC_INS_VSPLTW = 1405;;
let _PPC_INS_VSR = 1406;;
let _PPC_INS_VSRAB = 1407;;
let _PPC_INS_VSRAD = 1408;;
let _PPC_INS_VSRAH = 1409;;
let _PPC_INS_VSRAW = 1410;;
let _PPC_INS_VSRB = 1411;;
let _PPC_INS_VSRD = 1412;;
let _PPC_INS_VSRH = 1413;;
let _PPC_INS_VSRO = 1414;;
let _PPC_INS_VSRV = 1415;;
let _PPC_INS_VSRW = 1416;;
let _PPC_INS_VSUBCUQ = 1417;;
let _PPC_INS_VSUBCUW = 1418;;
let _PPC_INS_VSUBECUQ = 1419;;
let _PPC_INS_VSUBEUQM = 1420;;
let _PPC_INS_VSUBFP = 1421;;
let _PPC_INS_VSUBSBS = 1422;;
let _PPC_INS_VSUBSHS = 1423;;
let _PPC_INS_VSUBSWS = 1424;;
let _PPC_INS_VSUBUBM = 1425;;
let _PPC_INS_VSUBUBS = 1426;;
let _PPC_INS_VSUBUDM = 1427;;
let _PPC_INS_VSUBUHM = 1428;;
let _PPC_INS_VSUBUHS = 1429;;
let _PPC_INS_VSUBUQM = 1430;;
let _PPC_INS_VSUBUWM = 1431;;
let _PPC_INS_VSUBUWS = 1432;;
let _PPC_INS_VSUM2SWS = 1433;;
let _PPC_INS_VSUM4SBS = 1434;;
let _PPC_INS_VSUM4SHS = 1435;;
let _PPC_INS_VSUM4UBS = 1436;;
let _PPC_INS_VSUMSWS = 1437;;
let _PPC_INS_VUPKHPX = 1438;;
let _PPC_INS_VUPKHSB = 1439;;
let _PPC_INS_VUPKHSH = 1440;;
let _PPC_INS_VUPKHSW = 1441;;
let _PPC_INS_VUPKLPX = 1442;;
let _PPC_INS_VUPKLSB = 1443;;
let _PPC_INS_VUPKLSH = 1444;;
let _PPC_INS_VUPKLSW = 1445;;
let _PPC_INS_VXOR = 1446;;
let _PPC_INS_WAIT = 1447;;
let _PPC_INS_WAITIMPL = 1448;;
let _PPC_INS_WAITRSV = 1449;;
let _PPC_INS_WRTEE = 1450;;
let _PPC_INS_WRTEEI = 1451;;
let _PPC_INS_XNOP = 1452;;
let _PPC_INS_XOR = 1453;;
let _PPC_INS_XORI = 1454;;
let _PPC_INS_XORIS = 1455;;
let _PPC_INS_XSABSDP = 1456;;
let _PPC_INS_XSABSQP = 1457;;
let _PPC_INS_XSADDDP = 1458;;
let _PPC_INS_XSADDQP = 1459;;
let _PPC_INS_XSADDQPO = 1460;;
let _PPC_INS_XSADDSP = 1461;;
let _PPC_INS_XSCMPEQDP = 1462;;
let _PPC_INS_XSCMPEXPDP = 1463;;
let _PPC_INS_XSCMPEXPQP = 1464;;
let _PPC_INS_XSCMPGEDP = 1465;;
let _PPC_INS_XSCMPGTDP = 1466;;
let _PPC_INS_XSCMPODP = 1467;;
let _PPC_INS_XSCMPOQP = 1468;;
let _PPC_INS_XSCMPUDP = 1469;;
let _PPC_INS_XSCMPUQP = 1470;;
let _PPC_INS_XSCPSGNDP = 1471;;
let _PPC_INS_XSCPSGNQP = 1472;;
let _PPC_INS_XSCVDPHP = 1473;;
let _PPC_INS_XSCVDPQP = 1474;;
let _PPC_INS_XSCVDPSP = 1475;;
let _PPC_INS_XSCVDPSPN = 1476;;
let _PPC_INS_XSCVDPSXDS = 1477;;
let _PPC_INS_XSCVDPSXWS = 1478;;
let _PPC_INS_XSCVDPUXDS = 1479;;
let _PPC_INS_XSCVDPUXWS = 1480;;
let _PPC_INS_XSCVHPDP = 1481;;
let _PPC_INS_XSCVQPDP = 1482;;
let _PPC_INS_XSCVQPDPO = 1483;;
let _PPC_INS_XSCVQPSDZ = 1484;;
let _PPC_INS_XSCVQPSWZ = 1485;;
let _PPC_INS_XSCVQPUDZ = 1486;;
let _PPC_INS_XSCVQPUWZ = 1487;;
let _PPC_INS_XSCVSDQP = 1488;;
let _PPC_INS_XSCVSPDP = 1489;;
let _PPC_INS_XSCVSPDPN = 1490;;
let _PPC_INS_XSCVSXDDP = 1491;;
let _PPC_INS_XSCVSXDSP = 1492;;
let _PPC_INS_XSCVUDQP = 1493;;
let _PPC_INS_XSCVUXDDP = 1494;;
let _PPC_INS_XSCVUXDSP = 1495;;
let _PPC_INS_XSDIVDP = 1496;;
let _PPC_INS_XSDIVQP = 1497;;
let _PPC_INS_XSDIVQPO = 1498;;
let _PPC_INS_XSDIVSP = 1499;;
let _PPC_INS_XSIEXPDP = 1500;;
let _PPC_INS_XSIEXPQP = 1501;;
let _PPC_INS_XSMADDADP = 1502;;
let _PPC_INS_XSMADDASP = 1503;;
let _PPC_INS_XSMADDMDP = 1504;;
let _PPC_INS_XSMADDMSP = 1505;;
let _PPC_INS_XSMADDQP = 1506;;
let _PPC_INS_XSMADDQPO = 1507;;
let _PPC_INS_XSMAXCDP = 1508;;
let _PPC_INS_XSMAXDP = 1509;;
let _PPC_INS_XSMAXJDP = 1510;;
let _PPC_INS_XSMINCDP = 1511;;
let _PPC_INS_XSMINDP = 1512;;
let _PPC_INS_XSMINJDP = 1513;;
let _PPC_INS_XSMSUBADP = 1514;;
let _PPC_INS_XSMSUBASP = 1515;;
let _PPC_INS_XSMSUBMDP = 1516;;
let _PPC_INS_XSMSUBMSP = 1517;;
let _PPC_INS_XSMSUBQP = 1518;;
let _PPC_INS_XSMSUBQPO = 1519;;
let _PPC_INS_XSMULDP = 1520;;
let _PPC_INS_XSMULQP = 1521;;
let _PPC_INS_XSMULQPO = 1522;;
let _PPC_INS_XSMULSP = 1523;;
let _PPC_INS_XSNABSDP = 1524;;
let _PPC_INS_XSNABSQP = 1525;;
let _PPC_INS_XSNEGDP = 1526;;
let _PPC_INS_XSNEGQP = 1527;;
let _PPC_INS_XSNMADDADP = 1528;;
let _PPC_INS_XSNMADDASP = 1529;;
let _PPC_INS_XSNMADDMDP = 1530;;
let _PPC_INS_XSNMADDMSP = 1531;;
let _PPC_INS_XSNMADDQP = 1532;;
let _PPC_INS_XSNMADDQPO = 1533;;
let _PPC_INS_XSNMSUBADP = 1534;;
let _PPC_INS_XSNMSUBASP = 1535;;
let _PPC_INS_XSNMSUBMDP = 1536;;
let _PPC_INS_XSNMSUBMSP = 1537;;
let _PPC_INS_XSNMSUBQP = 1538;;
let _PPC_INS_XSNMSUBQPO = 1539;;
let _PPC_INS_XSRDPI = 1540;;
let _PPC_INS_XSRDPIC = 1541;;
let _PPC_INS_XSRDPIM = 1542;;
let _PPC_INS_XSRDPIP = 1543;;
let _PPC_INS_XSRDPIZ = 1544;;
let _PPC_INS_XSREDP = 1545;;
let _PPC_INS_XSRESP = 1546;;
let _PPC_INS_XSRQPI = 1547;;
let _PPC_INS_XSRQPIX = 1548;;
let _PPC_INS_XSRQPXP = 1549;;
let _PPC_INS_XSRSP = 1550;;
let _PPC_INS_XSRSQRTEDP = 1551;;
let _PPC_INS_XSRSQRTESP = 1552;;
let _PPC_INS_XSSQRTDP = 1553;;
let _PPC_INS_XSSQRTQP = 1554;;
let _PPC_INS_XSSQRTQPO = 1555;;
let _PPC_INS_XSSQRTSP = 1556;;
let _PPC_INS_XSSUBDP = 1557;;
let _PPC_INS_XSSUBQP = 1558;;
let _PPC_INS_XSSUBQPO = 1559;;
let _PPC_INS_XSSUBSP = 1560;;
let _PPC_INS_XSTDIVDP = 1561;;
let _PPC_INS_XSTSQRTDP = 1562;;
let _PPC_INS_XSTSTDCDP = 1563;;
let _PPC_INS_XSTSTDCQP = 1564;;
let _PPC_INS_XSTSTDCSP = 1565;;
let _PPC_INS_XSXEXPDP = 1566;;
let _PPC_INS_XSXEXPQP = 1567;;
let _PPC_INS_XSXSIGDP = 1568;;
let _PPC_INS_XSXSIGQP = 1569;;
let _PPC_INS_XVABSDP = 1570;;
let _PPC_INS_XVABSSP = 1571;;
let _PPC_INS_XVADDDP = 1572;;
let _PPC_INS_XVADDSP = 1573;;
let _PPC_INS_XVCMPEQDP = 1574;;
let _PPC_INS_XVCMPEQSP = 1575;;
let _PPC_INS_XVCMPGEDP = 1576;;
let _PPC_INS_XVCMPGESP = 1577;;
let _PPC_INS_XVCMPGTDP = 1578;;
let _PPC_INS_XVCMPGTSP = 1579;;
let _PPC_INS_XVCPSGNDP = 1580;;
let _PPC_INS_XVCPSGNSP = 1581;;
let _PPC_INS_XVCVDPSP = 1582;;
let _PPC_INS_XVCVDPSXDS = 1583;;
let _PPC_INS_XVCVDPSXWS = 1584;;
let _PPC_INS_XVCVDPUXDS = 1585;;
let _PPC_INS_XVCVDPUXWS = 1586;;
let _PPC_INS_XVCVHPSP = 1587;;
let _PPC_INS_XVCVSPDP = 1588;;
let _PPC_INS_XVCVSPHP = 1589;;
let _PPC_INS_XVCVSPSXDS = 1590;;
let _PPC_INS_XVCVSPSXWS = 1591;;
let _PPC_INS_XVCVSPUXDS = 1592;;
let _PPC_INS_XVCVSPUXWS = 1593;;
let _PPC_INS_XVCVSXDDP = 1594;;
let _PPC_INS_XVCVSXDSP = 1595;;
let _PPC_INS_XVCVSXWDP = 1596;;
let _PPC_INS_XVCVSXWSP = 1597;;
let _PPC_INS_XVCVUXDDP = 1598;;
let _PPC_INS_XVCVUXDSP = 1599;;
let _PPC_INS_XVCVUXWDP = 1600;;
let _PPC_INS_XVCVUXWSP = 1601;;
let _PPC_INS_XVDIVDP = 1602;;
let _PPC_INS_XVDIVSP = 1603;;
let _PPC_INS_XVIEXPDP = 1604;;
let _PPC_INS_XVIEXPSP = 1605;;
let _PPC_INS_XVMADDADP = 1606;;
let _PPC_INS_XVMADDASP = 1607;;
let _PPC_INS_XVMADDMDP = 1608;;
let _PPC_INS_XVMADDMSP = 1609;;
let _PPC_INS_XVMAXDP = 1610;;
let _PPC_INS_XVMAXSP = 1611;;
let _PPC_INS_XVMINDP = 1612;;
let _PPC_INS_XVMINSP = 1613;;
let _PPC_INS_XVMOVDP = 1614;;
let _PPC_INS_XVMOVSP = 1615;;
let _PPC_INS_XVMSUBADP = 1616;;
let _PPC_INS_XVMSUBASP = 1617;;
let _PPC_INS_XVMSUBMDP = 1618;;
let _PPC_INS_XVMSUBMSP = 1619;;
let _PPC_INS_XVMULDP = 1620;;
let _PPC_INS_XVMULSP = 1621;;
let _PPC_INS_XVNABSDP = 1622;;
let _PPC_INS_XVNABSSP = 1623;;
let _PPC_INS_XVNEGDP = 1624;;
let _PPC_INS_XVNEGSP = 1625;;
let _PPC_INS_XVNMADDADP = 1626;;
let _PPC_INS_XVNMADDASP = 1627;;
let _PPC_INS_XVNMADDMDP = 1628;;
let _PPC_INS_XVNMADDMSP = 1629;;
let _PPC_INS_XVNMSUBADP = 1630;;
let _PPC_INS_XVNMSUBASP = 1631;;
let _PPC_INS_XVNMSUBMDP = 1632;;
let _PPC_INS_XVNMSUBMSP = 1633;;
let _PPC_INS_XVRDPI = 1634;;
let _PPC_INS_XVRDPIC = 1635;;
let _PPC_INS_XVRDPIM = 1636;;
let _PPC_INS_XVRDPIP = 1637;;
let _PPC_INS_XVRDPIZ = 1638;;
let _PPC_INS_XVREDP = 1639;;
let _PPC_INS_XVRESP = 1640;;
let _PPC_INS_XVRSPI = 1641;;
let _PPC_INS_XVRSPIC = 1642;;
let _PPC_INS_XVRSPIM = 1643;;
let _PPC_INS_XVRSPIP = 1644;;
let _PPC_INS_XVRSPIZ = 1645;;
let _PPC_INS_XVRSQRTEDP = 1646;;
let _PPC_INS_XVRSQRTESP = 1647;;
let _PPC_INS_XVSQRTDP = 1648;;
let _PPC_INS_XVSQRTSP = 1649;;
let _PPC_INS_XVSUBDP = 1650;;
let _PPC_INS_XVSUBSP = 1651;;
let _PPC_INS_XVTDIVDP = 1652;;
let _PPC_INS_XVTDIVSP = 1653;;
let _PPC_INS_XVTSQRTDP = 1654;;
let _PPC_INS_XVTSQRTSP = 1655;;
let _PPC_INS_XVTSTDCDP = 1656;;
let _PPC_INS_XVTSTDCSP = 1657;;
let _PPC_INS_XVXEXPDP = 1658;;
let _PPC_INS_XVXEXPSP = 1659;;
let _PPC_INS_XVXSIGDP = 1660;;
let _PPC_INS_XVXSIGSP = 1661;;
let _PPC_INS_XXBRD = 1662;;
let _PPC_INS_XXBRH = 1663;;
let _PPC_INS_XXBRQ = 1664;;
let _PPC_INS_XXBRW = 1665;;
let _PPC_INS_XXEXTRACTUW = 1666;;
let _PPC_INS_XXINSERTW = 1667;;
let _PPC_INS_XXLAND = 1668;;
let _PPC_INS_XXLANDC = 1669;;
let _PPC_INS_XXLEQV = 1670;;
let _PPC_INS_XXLNAND = 1671;;
let _PPC_INS_XXLNOR = 1672;;
let _PPC_INS_XXLOR = 1673;;
let _PPC_INS_XXLORC = 1674;;
let _PPC_INS_XXLXOR = 1675;;
let _PPC_INS_XXMRGHD = 1676;;
let _PPC_INS_XXMRGHW = 1677;;
let _PPC_INS_XXMRGLD = 1678;;
let _PPC_INS_XXMRGLW = 1679;;
let _PPC_INS_XXPERM = 1680;;
let _PPC_INS_XXPERMDI = 1681;;
let _PPC_INS_XXPERMR = 1682;;
let _PPC_INS_XXSEL = 1683;;
let _PPC_INS_XXSLDWI = 1684;;
let _PPC_INS_XXSPLTD = 1685;;
let _PPC_INS_XXSPLTIB = 1686;;
let _PPC_INS_XXSPLTW = 1687;;
let _PPC_INS_XXSWAPD = 1688;;
let _PPC_INS_DCBZ_L = 1689;;
let _PPC_INS_PSQ_L = 1690;;
let _PPC_INS_PSQ_LU = 1691;;
let _PPC_INS_PSQ_LUX = 1692;;
let _PPC_INS_PSQ_LX = 1693;;
let _PPC_INS_PSQ_ST = 1694;;
let _PPC_INS_PSQ_STU = 1695;;
let _PPC_INS_PSQ_STUX = 1696;;
let _PPC_INS_PSQ_STX = 1697;;
let _PPC_INS_PS_ABS = 1698;;
let _PPC_INS_PS_ADD = 1699;;
let _PPC_INS_PS_CMPO0 = 1700;;
let _PPC_INS_PS_CMPO1 = 1701;;
let _PPC_INS_PS_CMPU0 = 1702;;
let _PPC_INS_PS_CMPU1 = 1703;;
let _PPC_INS_PS_DIV = 1704;;
let _PPC_INS_PS_MADD = 1705;;
let _PPC_INS_PS_MADDS0 = 1706;;
let _PPC_INS_PS_MADDS1 = 1707;;
let _PPC_INS_PS_MERGE00 = 1708;;
let _PPC_INS_PS_MERGE01 = 1709;;
let _PPC_INS_PS_MERGE10 = 1710;;
let _PPC_INS_PS_MERGE11 = 1711;;
let _PPC_INS_PS_MR = 1712;;
let _PPC_INS_PS_MSUB = 1713;;
let _PPC_INS_PS_MUL = 1714;;
let _PPC_INS_PS_MULS0 = 1715;;
let _PPC_INS_PS_MULS1 = 1716;;
let _PPC_INS_PS_NABS = 1717;;
let _PPC_INS_PS_NEG = 1718;;
let _PPC_INS_PS_NMADD = 1719;;
let _PPC_INS_PS_NMSUB = 1720;;
let _PPC_INS_PS_RES = 1721;;
let _PPC_INS_PS_RSQRTE = 1722;;
let _PPC_INS_PS_SEL = 1723;;
let _PPC_INS_PS_SUB = 1724;;
let _PPC_INS_PS_SUM0 = 1725;;
let _PPC_INS_PS_SUM1 = 1726;;
let _PPC_INS_ENDING = 1727;;

let _PPC_GRP_INVALID = 0;;
let _PPC_GRP_JUMP = 1;;
let _PPC_GRP_ALTIVEC = 128;;
let _PPC_GRP_MODE32 = 129;;
let _PPC_GRP_MODE64 = 130;;
let _PPC_GRP_BOOKE = 131;;
let _PPC_GRP_NOTBOOKE = 132;;
let _PPC_GRP_SPE = 133;;
let _PPC_GRP_VSX = 134;;
let _PPC_GRP_E500 = 135;;
let _PPC_GRP_PPC4XX = 136;;
let _PPC_GRP_PPC6XX = 137;;
let _PPC_GRP_ICBT = 138;;
let _PPC_GRP_P8ALTIVEC = 139;;
let _PPC_GRP_P8VECTOR = 140;;
let _PPC_GRP_QPX = 141;;
let _PPC_GRP_PS = 142;;
let _PPC_GRP_ENDING = 143;;
