/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Subtarget Enumeration Source Fragment                                      *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2015 */


#ifdef GET_SUBTARGETINFO_ENUM
#undef GET_SUBTARGETINFO_ENUM

enum {
  SystemZ_FeatureDFPPackedConversion = 1ULL << 0,
  SystemZ_FeatureDFPZonedConversion = 1ULL << 1,
  SystemZ_FeatureDistinctOps = 1ULL << 2,
  SystemZ_FeatureEnhancedDAT2 = 1ULL << 3,
  SystemZ_FeatureExecutionHint = 1ULL << 4,
  SystemZ_FeatureFPExtension = 1ULL << 5,
  SystemZ_FeatureFastSerialization = 1ULL << 6,
  SystemZ_FeatureGuardedStorage = 1ULL << 7,
  SystemZ_FeatureHighWord = 1ULL << 8,
  SystemZ_FeatureInsertReferenceBitsMultiple = 1ULL << 9,
  SystemZ_FeatureInterlockedAccess1 = 1ULL << 10,
  SystemZ_FeatureLoadAndTrap = 1ULL << 11,
  SystemZ_FeatureLoadAndZeroRightmostByte = 1ULL << 12,
  SystemZ_FeatureLoadStoreOnCond = 1ULL << 13,
  SystemZ_FeatureLoadStoreOnCond2 = 1ULL << 14,
  SystemZ_FeatureMessageSecurityAssist3 = 1ULL << 15,
  SystemZ_FeatureMessageSecurityAssist4 = 1ULL << 16,
  SystemZ_FeatureMessageSecurityAssist5 = 1ULL << 17,
  SystemZ_FeatureMessageSecurityAssist7 = 1ULL << 18,
  SystemZ_FeatureMessageSecurityAssist8 = 1ULL << 19,
  SystemZ_FeatureMiscellaneousExtensions = 1ULL << 20,
  SystemZ_FeatureMiscellaneousExtensions2 = 1ULL << 21,
  SystemZ_FeaturePopulationCount = 1ULL << 22,
  SystemZ_FeatureProcessorAssist = 1ULL << 23,
  SystemZ_FeatureResetReferenceBitsMultiple = 1ULL << 24,
  SystemZ_FeatureTransactionalExecution = 1ULL << 25,
  SystemZ_FeatureVector = 1ULL << 26,
  SystemZ_FeatureVectorEnhancements1 = 1ULL << 27,
  SystemZ_FeatureVectorPackedDecimal = 1ULL << 28,
};

#endif // GET_SUBTARGETINFO_ENUM

