// For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT
package capstone;

public class X86_const {

	public static final int X86_REG_INVALID = 0;
	public static final int X86_REG_AH = 1;
	public static final int X86_REG_AL = 2;
	public static final int X86_REG_AX = 3;
	public static final int X86_REG_BH = 4;
	public static final int X86_REG_BL = 5;
	public static final int X86_REG_BP = 6;
	public static final int X86_REG_BPL = 7;
	public static final int X86_REG_BX = 8;
	public static final int X86_REG_CH = 9;
	public static final int X86_REG_CL = 10;
	public static final int X86_REG_CS = 11;
	public static final int X86_REG_CX = 12;
	public static final int X86_REG_DH = 13;
	public static final int X86_REG_DI = 14;
	public static final int X86_REG_DIL = 15;
	public static final int X86_REG_DL = 16;
	public static final int X86_REG_DS = 17;
	public static final int X86_REG_DX = 18;
	public static final int X86_REG_EAX = 19;
	public static final int X86_REG_EBP = 20;
	public static final int X86_REG_EBX = 21;
	public static final int X86_REG_ECX = 22;
	public static final int X86_REG_EDI = 23;
	public static final int X86_REG_EDX = 24;
	public static final int X86_REG_EFLAGS = 25;
	public static final int X86_REG_EIP = 26;
	public static final int X86_REG_EIZ = 27;
	public static final int X86_REG_ES = 28;
	public static final int X86_REG_ESI = 29;
	public static final int X86_REG_ESP = 30;
	public static final int X86_REG_FPSW = 31;
	public static final int X86_REG_FS = 32;
	public static final int X86_REG_GS = 33;
	public static final int X86_REG_IP = 34;
	public static final int X86_REG_RAX = 35;
	public static final int X86_REG_RBP = 36;
	public static final int X86_REG_RBX = 37;
	public static final int X86_REG_RCX = 38;
	public static final int X86_REG_RDI = 39;
	public static final int X86_REG_RDX = 40;
	public static final int X86_REG_RIP = 41;
	public static final int X86_REG_RIZ = 42;
	public static final int X86_REG_RSI = 43;
	public static final int X86_REG_RSP = 44;
	public static final int X86_REG_SI = 45;
	public static final int X86_REG_SIL = 46;
	public static final int X86_REG_SP = 47;
	public static final int X86_REG_SPL = 48;
	public static final int X86_REG_SS = 49;
	public static final int X86_REG_CR0 = 50;
	public static final int X86_REG_CR1 = 51;
	public static final int X86_REG_CR2 = 52;
	public static final int X86_REG_CR3 = 53;
	public static final int X86_REG_CR4 = 54;
	public static final int X86_REG_CR5 = 55;
	public static final int X86_REG_CR6 = 56;
	public static final int X86_REG_CR7 = 57;
	public static final int X86_REG_CR8 = 58;
	public static final int X86_REG_CR9 = 59;
	public static final int X86_REG_CR10 = 60;
	public static final int X86_REG_CR11 = 61;
	public static final int X86_REG_CR12 = 62;
	public static final int X86_REG_CR13 = 63;
	public static final int X86_REG_CR14 = 64;
	public static final int X86_REG_CR15 = 65;
	public static final int X86_REG_DR0 = 66;
	public static final int X86_REG_DR1 = 67;
	public static final int X86_REG_DR2 = 68;
	public static final int X86_REG_DR3 = 69;
	public static final int X86_REG_DR4 = 70;
	public static final int X86_REG_DR5 = 71;
	public static final int X86_REG_DR6 = 72;
	public static final int X86_REG_DR7 = 73;
	public static final int X86_REG_DR8 = 74;
	public static final int X86_REG_DR9 = 75;
	public static final int X86_REG_DR10 = 76;
	public static final int X86_REG_DR11 = 77;
	public static final int X86_REG_DR12 = 78;
	public static final int X86_REG_DR13 = 79;
	public static final int X86_REG_DR14 = 80;
	public static final int X86_REG_DR15 = 81;
	public static final int X86_REG_FP0 = 82;
	public static final int X86_REG_FP1 = 83;
	public static final int X86_REG_FP2 = 84;
	public static final int X86_REG_FP3 = 85;
	public static final int X86_REG_FP4 = 86;
	public static final int X86_REG_FP5 = 87;
	public static final int X86_REG_FP6 = 88;
	public static final int X86_REG_FP7 = 89;
	public static final int X86_REG_K0 = 90;
	public static final int X86_REG_K1 = 91;
	public static final int X86_REG_K2 = 92;
	public static final int X86_REG_K3 = 93;
	public static final int X86_REG_K4 = 94;
	public static final int X86_REG_K5 = 95;
	public static final int X86_REG_K6 = 96;
	public static final int X86_REG_K7 = 97;
	public static final int X86_REG_MM0 = 98;
	public static final int X86_REG_MM1 = 99;
	public static final int X86_REG_MM2 = 100;
	public static final int X86_REG_MM3 = 101;
	public static final int X86_REG_MM4 = 102;
	public static final int X86_REG_MM5 = 103;
	public static final int X86_REG_MM6 = 104;
	public static final int X86_REG_MM7 = 105;
	public static final int X86_REG_R8 = 106;
	public static final int X86_REG_R9 = 107;
	public static final int X86_REG_R10 = 108;
	public static final int X86_REG_R11 = 109;
	public static final int X86_REG_R12 = 110;
	public static final int X86_REG_R13 = 111;
	public static final int X86_REG_R14 = 112;
	public static final int X86_REG_R15 = 113;
	public static final int X86_REG_ST0 = 114;
	public static final int X86_REG_ST1 = 115;
	public static final int X86_REG_ST2 = 116;
	public static final int X86_REG_ST3 = 117;
	public static final int X86_REG_ST4 = 118;
	public static final int X86_REG_ST5 = 119;
	public static final int X86_REG_ST6 = 120;
	public static final int X86_REG_ST7 = 121;
	public static final int X86_REG_XMM0 = 122;
	public static final int X86_REG_XMM1 = 123;
	public static final int X86_REG_XMM2 = 124;
	public static final int X86_REG_XMM3 = 125;
	public static final int X86_REG_XMM4 = 126;
	public static final int X86_REG_XMM5 = 127;
	public static final int X86_REG_XMM6 = 128;
	public static final int X86_REG_XMM7 = 129;
	public static final int X86_REG_XMM8 = 130;
	public static final int X86_REG_XMM9 = 131;
	public static final int X86_REG_XMM10 = 132;
	public static final int X86_REG_XMM11 = 133;
	public static final int X86_REG_XMM12 = 134;
	public static final int X86_REG_XMM13 = 135;
	public static final int X86_REG_XMM14 = 136;
	public static final int X86_REG_XMM15 = 137;
	public static final int X86_REG_XMM16 = 138;
	public static final int X86_REG_XMM17 = 139;
	public static final int X86_REG_XMM18 = 140;
	public static final int X86_REG_XMM19 = 141;
	public static final int X86_REG_XMM20 = 142;
	public static final int X86_REG_XMM21 = 143;
	public static final int X86_REG_XMM22 = 144;
	public static final int X86_REG_XMM23 = 145;
	public static final int X86_REG_XMM24 = 146;
	public static final int X86_REG_XMM25 = 147;
	public static final int X86_REG_XMM26 = 148;
	public static final int X86_REG_XMM27 = 149;
	public static final int X86_REG_XMM28 = 150;
	public static final int X86_REG_XMM29 = 151;
	public static final int X86_REG_XMM30 = 152;
	public static final int X86_REG_XMM31 = 153;
	public static final int X86_REG_YMM0 = 154;
	public static final int X86_REG_YMM1 = 155;
	public static final int X86_REG_YMM2 = 156;
	public static final int X86_REG_YMM3 = 157;
	public static final int X86_REG_YMM4 = 158;
	public static final int X86_REG_YMM5 = 159;
	public static final int X86_REG_YMM6 = 160;
	public static final int X86_REG_YMM7 = 161;
	public static final int X86_REG_YMM8 = 162;
	public static final int X86_REG_YMM9 = 163;
	public static final int X86_REG_YMM10 = 164;
	public static final int X86_REG_YMM11 = 165;
	public static final int X86_REG_YMM12 = 166;
	public static final int X86_REG_YMM13 = 167;
	public static final int X86_REG_YMM14 = 168;
	public static final int X86_REG_YMM15 = 169;
	public static final int X86_REG_YMM16 = 170;
	public static final int X86_REG_YMM17 = 171;
	public static final int X86_REG_YMM18 = 172;
	public static final int X86_REG_YMM19 = 173;
	public static final int X86_REG_YMM20 = 174;
	public static final int X86_REG_YMM21 = 175;
	public static final int X86_REG_YMM22 = 176;
	public static final int X86_REG_YMM23 = 177;
	public static final int X86_REG_YMM24 = 178;
	public static final int X86_REG_YMM25 = 179;
	public static final int X86_REG_YMM26 = 180;
	public static final int X86_REG_YMM27 = 181;
	public static final int X86_REG_YMM28 = 182;
	public static final int X86_REG_YMM29 = 183;
	public static final int X86_REG_YMM30 = 184;
	public static final int X86_REG_YMM31 = 185;
	public static final int X86_REG_ZMM0 = 186;
	public static final int X86_REG_ZMM1 = 187;
	public static final int X86_REG_ZMM2 = 188;
	public static final int X86_REG_ZMM3 = 189;
	public static final int X86_REG_ZMM4 = 190;
	public static final int X86_REG_ZMM5 = 191;
	public static final int X86_REG_ZMM6 = 192;
	public static final int X86_REG_ZMM7 = 193;
	public static final int X86_REG_ZMM8 = 194;
	public static final int X86_REG_ZMM9 = 195;
	public static final int X86_REG_ZMM10 = 196;
	public static final int X86_REG_ZMM11 = 197;
	public static final int X86_REG_ZMM12 = 198;
	public static final int X86_REG_ZMM13 = 199;
	public static final int X86_REG_ZMM14 = 200;
	public static final int X86_REG_ZMM15 = 201;
	public static final int X86_REG_ZMM16 = 202;
	public static final int X86_REG_ZMM17 = 203;
	public static final int X86_REG_ZMM18 = 204;
	public static final int X86_REG_ZMM19 = 205;
	public static final int X86_REG_ZMM20 = 206;
	public static final int X86_REG_ZMM21 = 207;
	public static final int X86_REG_ZMM22 = 208;
	public static final int X86_REG_ZMM23 = 209;
	public static final int X86_REG_ZMM24 = 210;
	public static final int X86_REG_ZMM25 = 211;
	public static final int X86_REG_ZMM26 = 212;
	public static final int X86_REG_ZMM27 = 213;
	public static final int X86_REG_ZMM28 = 214;
	public static final int X86_REG_ZMM29 = 215;
	public static final int X86_REG_ZMM30 = 216;
	public static final int X86_REG_ZMM31 = 217;
	public static final int X86_REG_R8B = 218;
	public static final int X86_REG_R9B = 219;
	public static final int X86_REG_R10B = 220;
	public static final int X86_REG_R11B = 221;
	public static final int X86_REG_R12B = 222;
	public static final int X86_REG_R13B = 223;
	public static final int X86_REG_R14B = 224;
	public static final int X86_REG_R15B = 225;
	public static final int X86_REG_R8D = 226;
	public static final int X86_REG_R9D = 227;
	public static final int X86_REG_R10D = 228;
	public static final int X86_REG_R11D = 229;
	public static final int X86_REG_R12D = 230;
	public static final int X86_REG_R13D = 231;
	public static final int X86_REG_R14D = 232;
	public static final int X86_REG_R15D = 233;
	public static final int X86_REG_R8W = 234;
	public static final int X86_REG_R9W = 235;
	public static final int X86_REG_R10W = 236;
	public static final int X86_REG_R11W = 237;
	public static final int X86_REG_R12W = 238;
	public static final int X86_REG_R13W = 239;
	public static final int X86_REG_R14W = 240;
	public static final int X86_REG_R15W = 241;
	public static final int X86_REG_BND0 = 242;
	public static final int X86_REG_BND1 = 243;
	public static final int X86_REG_BND2 = 244;
	public static final int X86_REG_BND3 = 245;
	public static final int X86_REG_ENDING = 246;
	public static final int X86_EFLAGS_MODIFY_AF = 1<<0;
	public static final int X86_EFLAGS_MODIFY_CF = 1<<1;
	public static final int X86_EFLAGS_MODIFY_SF = 1<<2;
	public static final int X86_EFLAGS_MODIFY_ZF = 1<<3;
	public static final int X86_EFLAGS_MODIFY_PF = 1<<4;
	public static final int X86_EFLAGS_MODIFY_OF = 1<<5;
	public static final int X86_EFLAGS_MODIFY_TF = 1<<6;
	public static final int X86_EFLAGS_MODIFY_IF = 1<<7;
	public static final int X86_EFLAGS_MODIFY_DF = 1<<8;
	public static final int X86_EFLAGS_MODIFY_NT = 1<<9;
	public static final int X86_EFLAGS_MODIFY_RF = 1<<10;
	public static final int X86_EFLAGS_PRIOR_OF = 1<<11;
	public static final int X86_EFLAGS_PRIOR_SF = 1<<12;
	public static final int X86_EFLAGS_PRIOR_ZF = 1<<13;
	public static final int X86_EFLAGS_PRIOR_AF = 1<<14;
	public static final int X86_EFLAGS_PRIOR_PF = 1<<15;
	public static final int X86_EFLAGS_PRIOR_CF = 1<<16;
	public static final int X86_EFLAGS_PRIOR_TF = 1<<17;
	public static final int X86_EFLAGS_PRIOR_IF = 1<<18;
	public static final int X86_EFLAGS_PRIOR_DF = 1<<19;
	public static final int X86_EFLAGS_PRIOR_NT = 1<<20;
	public static final int X86_EFLAGS_RESET_OF = 1<<21;
	public static final int X86_EFLAGS_RESET_CF = 1<<22;
	public static final int X86_EFLAGS_RESET_DF = 1<<23;
	public static final int X86_EFLAGS_RESET_IF = 1<<24;
	public static final int X86_EFLAGS_RESET_SF = 1<<25;
	public static final int X86_EFLAGS_RESET_AF = 1<<26;
	public static final int X86_EFLAGS_RESET_TF = 1<<27;
	public static final int X86_EFLAGS_RESET_NT = 1<<28;
	public static final int X86_EFLAGS_RESET_PF = 1<<29;
	public static final int X86_EFLAGS_SET_CF = 1<<30;
	public static final int X86_EFLAGS_SET_DF = 1<<31;
	public static final int X86_EFLAGS_SET_IF = 1<<32;
	public static final int X86_EFLAGS_TEST_OF = 1<<33;
	public static final int X86_EFLAGS_TEST_SF = 1<<34;
	public static final int X86_EFLAGS_TEST_ZF = 1<<35;
	public static final int X86_EFLAGS_TEST_PF = 1<<36;
	public static final int X86_EFLAGS_TEST_CF = 1<<37;
	public static final int X86_EFLAGS_TEST_NT = 1<<38;
	public static final int X86_EFLAGS_TEST_DF = 1<<39;
	public static final int X86_EFLAGS_UNDEFINED_OF = 1<<40;
	public static final int X86_EFLAGS_UNDEFINED_SF = 1<<41;
	public static final int X86_EFLAGS_UNDEFINED_ZF = 1<<42;
	public static final int X86_EFLAGS_UNDEFINED_PF = 1<<43;
	public static final int X86_EFLAGS_UNDEFINED_AF = 1<<44;
	public static final int X86_EFLAGS_UNDEFINED_CF = 1<<45;
	public static final int X86_EFLAGS_RESET_RF = 1<<46;
	public static final int X86_EFLAGS_TEST_RF = 1<<47;
	public static final int X86_EFLAGS_TEST_IF = 1<<48;
	public static final int X86_EFLAGS_TEST_TF = 1<<49;
	public static final int X86_EFLAGS_TEST_AF = 1<<50;
	public static final int X86_EFLAGS_RESET_ZF = 1<<51;
	public static final int X86_EFLAGS_SET_OF = 1<<52;
	public static final int X86_EFLAGS_SET_SF = 1<<53;
	public static final int X86_EFLAGS_SET_ZF = 1<<54;
	public static final int X86_EFLAGS_SET_AF = 1<<55;
	public static final int X86_EFLAGS_SET_PF = 1<<56;
	public static final int X86_EFLAGS_RESET_0F = 1<<57;
	public static final int X86_EFLAGS_RESET_AC = 1<<58;
	public static final int X86_FPU_FLAGS_MODIFY_C0 = 1<<0;
	public static final int X86_FPU_FLAGS_MODIFY_C1 = 1<<1;
	public static final int X86_FPU_FLAGS_MODIFY_C2 = 1<<2;
	public static final int X86_FPU_FLAGS_MODIFY_C3 = 1<<3;
	public static final int X86_FPU_FLAGS_RESET_C0 = 1<<4;
	public static final int X86_FPU_FLAGS_RESET_C1 = 1<<5;
	public static final int X86_FPU_FLAGS_RESET_C2 = 1<<6;
	public static final int X86_FPU_FLAGS_RESET_C3 = 1<<7;
	public static final int X86_FPU_FLAGS_SET_C0 = 1<<8;
	public static final int X86_FPU_FLAGS_SET_C1 = 1<<9;
	public static final int X86_FPU_FLAGS_SET_C2 = 1<<10;
	public static final int X86_FPU_FLAGS_SET_C3 = 1<<11;
	public static final int X86_FPU_FLAGS_UNDEFINED_C0 = 1<<12;
	public static final int X86_FPU_FLAGS_UNDEFINED_C1 = 1<<13;
	public static final int X86_FPU_FLAGS_UNDEFINED_C2 = 1<<14;
	public static final int X86_FPU_FLAGS_UNDEFINED_C3 = 1<<15;
	public static final int X86_FPU_FLAGS_TEST_C0 = 1<<16;
	public static final int X86_FPU_FLAGS_TEST_C1 = 1<<17;
	public static final int X86_FPU_FLAGS_TEST_C2 = 1<<18;
	public static final int X86_FPU_FLAGS_TEST_C3 = 1<<19;

	public static final int X86_OP_INVALID = 0;
	public static final int X86_OP_REG = 1;
	public static final int X86_OP_IMM = 2;
	public static final int X86_OP_MEM = 3;

	public static final int X86_XOP_CC_INVALID = 0;
	public static final int X86_XOP_CC_LT = 1;
	public static final int X86_XOP_CC_LE = 2;
	public static final int X86_XOP_CC_GT = 3;
	public static final int X86_XOP_CC_GE = 4;
	public static final int X86_XOP_CC_EQ = 5;
	public static final int X86_XOP_CC_NEQ = 6;
	public static final int X86_XOP_CC_FALSE = 7;
	public static final int X86_XOP_CC_TRUE = 8;

	public static final int X86_AVX_BCAST_INVALID = 0;
	public static final int X86_AVX_BCAST_2 = 1;
	public static final int X86_AVX_BCAST_4 = 2;
	public static final int X86_AVX_BCAST_8 = 3;
	public static final int X86_AVX_BCAST_16 = 4;

	public static final int X86_SSE_CC_INVALID = 0;
	public static final int X86_SSE_CC_EQ = 1;
	public static final int X86_SSE_CC_LT = 2;
	public static final int X86_SSE_CC_LE = 3;
	public static final int X86_SSE_CC_UNORD = 4;
	public static final int X86_SSE_CC_NEQ = 5;
	public static final int X86_SSE_CC_NLT = 6;
	public static final int X86_SSE_CC_NLE = 7;
	public static final int X86_SSE_CC_ORD = 8;

	public static final int X86_AVX_CC_INVALID = 0;
	public static final int X86_AVX_CC_EQ = 1;
	public static final int X86_AVX_CC_LT = 2;
	public static final int X86_AVX_CC_LE = 3;
	public static final int X86_AVX_CC_UNORD = 4;
	public static final int X86_AVX_CC_NEQ = 5;
	public static final int X86_AVX_CC_NLT = 6;
	public static final int X86_AVX_CC_NLE = 7;
	public static final int X86_AVX_CC_ORD = 8;
	public static final int X86_AVX_CC_EQ_UQ = 9;
	public static final int X86_AVX_CC_NGE = 10;
	public static final int X86_AVX_CC_NGT = 11;
	public static final int X86_AVX_CC_FALSE = 12;
	public static final int X86_AVX_CC_NEQ_OQ = 13;
	public static final int X86_AVX_CC_GE = 14;
	public static final int X86_AVX_CC_GT = 15;
	public static final int X86_AVX_CC_TRUE = 16;
	public static final int X86_AVX_CC_EQ_OS = 17;
	public static final int X86_AVX_CC_LT_OQ = 18;
	public static final int X86_AVX_CC_LE_OQ = 19;
	public static final int X86_AVX_CC_UNORD_S = 20;
	public static final int X86_AVX_CC_NEQ_US = 21;
	public static final int X86_AVX_CC_NLT_UQ = 22;
	public static final int X86_AVX_CC_NLE_UQ = 23;
	public static final int X86_AVX_CC_ORD_S = 24;
	public static final int X86_AVX_CC_EQ_US = 25;
	public static final int X86_AVX_CC_NGE_UQ = 26;
	public static final int X86_AVX_CC_NGT_UQ = 27;
	public static final int X86_AVX_CC_FALSE_OS = 28;
	public static final int X86_AVX_CC_NEQ_OS = 29;
	public static final int X86_AVX_CC_GE_OQ = 30;
	public static final int X86_AVX_CC_GT_OQ = 31;
	public static final int X86_AVX_CC_TRUE_US = 32;

	public static final int X86_AVX_RM_INVALID = 0;
	public static final int X86_AVX_RM_RN = 1;
	public static final int X86_AVX_RM_RD = 2;
	public static final int X86_AVX_RM_RU = 3;
	public static final int X86_AVX_RM_RZ = 4;
	public static final int X86_PREFIX_LOCK = 0xf0;
	public static final int X86_PREFIX_REP = 0xf3;
	public static final int X86_PREFIX_REPE = 0xf3;
	public static final int X86_PREFIX_REPNE = 0xf2;
	public static final int X86_PREFIX_CS = 0x2e;
	public static final int X86_PREFIX_SS = 0x36;
	public static final int X86_PREFIX_DS = 0x3e;
	public static final int X86_PREFIX_ES = 0x26;
	public static final int X86_PREFIX_FS = 0x64;
	public static final int X86_PREFIX_GS = 0x65;
	public static final int X86_PREFIX_OPSIZE = 0x66;
	public static final int X86_PREFIX_ADDRSIZE = 0x67;

	public static final int X86_INS_INVALID = 0;
	public static final int X86_INS_AAA = 1;
	public static final int X86_INS_AAD = 2;
	public static final int X86_INS_AAM = 3;
	public static final int X86_INS_AAS = 4;
	public static final int X86_INS_FABS = 5;
	public static final int X86_INS_ADC = 6;
	public static final int X86_INS_ADCX = 7;
	public static final int X86_INS_ADD = 8;
	public static final int X86_INS_ADDPD = 9;
	public static final int X86_INS_ADDPS = 10;
	public static final int X86_INS_ADDSD = 11;
	public static final int X86_INS_ADDSS = 12;
	public static final int X86_INS_ADDSUBPD = 13;
	public static final int X86_INS_ADDSUBPS = 14;
	public static final int X86_INS_FADD = 15;
	public static final int X86_INS_FIADD = 16;
	public static final int X86_INS_ADOX = 17;
	public static final int X86_INS_AESDECLAST = 18;
	public static final int X86_INS_AESDEC = 19;
	public static final int X86_INS_AESENCLAST = 20;
	public static final int X86_INS_AESENC = 21;
	public static final int X86_INS_AESIMC = 22;
	public static final int X86_INS_AESKEYGENASSIST = 23;
	public static final int X86_INS_AND = 24;
	public static final int X86_INS_ANDN = 25;
	public static final int X86_INS_ANDNPD = 26;
	public static final int X86_INS_ANDNPS = 27;
	public static final int X86_INS_ANDPD = 28;
	public static final int X86_INS_ANDPS = 29;
	public static final int X86_INS_ARPL = 30;
	public static final int X86_INS_BEXTR = 31;
	public static final int X86_INS_BLCFILL = 32;
	public static final int X86_INS_BLCI = 33;
	public static final int X86_INS_BLCIC = 34;
	public static final int X86_INS_BLCMSK = 35;
	public static final int X86_INS_BLCS = 36;
	public static final int X86_INS_BLENDPD = 37;
	public static final int X86_INS_BLENDPS = 38;
	public static final int X86_INS_BLENDVPD = 39;
	public static final int X86_INS_BLENDVPS = 40;
	public static final int X86_INS_BLSFILL = 41;
	public static final int X86_INS_BLSI = 42;
	public static final int X86_INS_BLSIC = 43;
	public static final int X86_INS_BLSMSK = 44;
	public static final int X86_INS_BLSR = 45;
	public static final int X86_INS_BNDCL = 46;
	public static final int X86_INS_BNDCN = 47;
	public static final int X86_INS_BNDCU = 48;
	public static final int X86_INS_BNDLDX = 49;
	public static final int X86_INS_BNDMK = 50;
	public static final int X86_INS_BNDMOV = 51;
	public static final int X86_INS_BNDSTX = 52;
	public static final int X86_INS_BOUND = 53;
	public static final int X86_INS_BSF = 54;
	public static final int X86_INS_BSR = 55;
	public static final int X86_INS_BSWAP = 56;
	public static final int X86_INS_BT = 57;
	public static final int X86_INS_BTC = 58;
	public static final int X86_INS_BTR = 59;
	public static final int X86_INS_BTS = 60;
	public static final int X86_INS_BZHI = 61;
	public static final int X86_INS_CALL = 62;
	public static final int X86_INS_CBW = 63;
	public static final int X86_INS_CDQ = 64;
	public static final int X86_INS_CDQE = 65;
	public static final int X86_INS_FCHS = 66;
	public static final int X86_INS_CLAC = 67;
	public static final int X86_INS_CLC = 68;
	public static final int X86_INS_CLD = 69;
	public static final int X86_INS_CLDEMOTE = 70;
	public static final int X86_INS_CLFLUSH = 71;
	public static final int X86_INS_CLFLUSHOPT = 72;
	public static final int X86_INS_CLGI = 73;
	public static final int X86_INS_CLI = 74;
	public static final int X86_INS_CLRSSBSY = 75;
	public static final int X86_INS_CLTS = 76;
	public static final int X86_INS_CLWB = 77;
	public static final int X86_INS_CLZERO = 78;
	public static final int X86_INS_CMC = 79;
	public static final int X86_INS_CMOVA = 80;
	public static final int X86_INS_CMOVAE = 81;
	public static final int X86_INS_CMOVB = 82;
	public static final int X86_INS_CMOVBE = 83;
	public static final int X86_INS_FCMOVBE = 84;
	public static final int X86_INS_FCMOVB = 85;
	public static final int X86_INS_CMOVE = 86;
	public static final int X86_INS_FCMOVE = 87;
	public static final int X86_INS_CMOVG = 88;
	public static final int X86_INS_CMOVGE = 89;
	public static final int X86_INS_CMOVL = 90;
	public static final int X86_INS_CMOVLE = 91;
	public static final int X86_INS_FCMOVNBE = 92;
	public static final int X86_INS_FCMOVNB = 93;
	public static final int X86_INS_CMOVNE = 94;
	public static final int X86_INS_FCMOVNE = 95;
	public static final int X86_INS_CMOVNO = 96;
	public static final int X86_INS_CMOVNP = 97;
	public static final int X86_INS_FCMOVNU = 98;
	public static final int X86_INS_FCMOVNP = 99;
	public static final int X86_INS_CMOVNS = 100;
	public static final int X86_INS_CMOVO = 101;
	public static final int X86_INS_CMOVP = 102;
	public static final int X86_INS_FCMOVU = 103;
	public static final int X86_INS_CMOVS = 104;
	public static final int X86_INS_CMP = 105;
	public static final int X86_INS_CMPPD = 106;
	public static final int X86_INS_CMPPS = 107;
	public static final int X86_INS_CMPSB = 108;
	public static final int X86_INS_CMPSD = 109;
	public static final int X86_INS_CMPSQ = 110;
	public static final int X86_INS_CMPSS = 111;
	public static final int X86_INS_CMPSW = 112;
	public static final int X86_INS_CMPXCHG16B = 113;
	public static final int X86_INS_CMPXCHG = 114;
	public static final int X86_INS_CMPXCHG8B = 115;
	public static final int X86_INS_COMISD = 116;
	public static final int X86_INS_COMISS = 117;
	public static final int X86_INS_FCOMP = 118;
	public static final int X86_INS_FCOMPI = 119;
	public static final int X86_INS_FCOMI = 120;
	public static final int X86_INS_FCOM = 121;
	public static final int X86_INS_FCOS = 122;
	public static final int X86_INS_CPUID = 123;
	public static final int X86_INS_CQO = 124;
	public static final int X86_INS_CRC32 = 125;
	public static final int X86_INS_CVTDQ2PD = 126;
	public static final int X86_INS_CVTDQ2PS = 127;
	public static final int X86_INS_CVTPD2DQ = 128;
	public static final int X86_INS_CVTPD2PS = 129;
	public static final int X86_INS_CVTPS2DQ = 130;
	public static final int X86_INS_CVTPS2PD = 131;
	public static final int X86_INS_CVTSD2SI = 132;
	public static final int X86_INS_CVTSD2SS = 133;
	public static final int X86_INS_CVTSI2SD = 134;
	public static final int X86_INS_CVTSI2SS = 135;
	public static final int X86_INS_CVTSS2SD = 136;
	public static final int X86_INS_CVTSS2SI = 137;
	public static final int X86_INS_CVTTPD2DQ = 138;
	public static final int X86_INS_CVTTPS2DQ = 139;
	public static final int X86_INS_CVTTSD2SI = 140;
	public static final int X86_INS_CVTTSS2SI = 141;
	public static final int X86_INS_CWD = 142;
	public static final int X86_INS_CWDE = 143;
	public static final int X86_INS_DAA = 144;
	public static final int X86_INS_DAS = 145;
	public static final int X86_INS_DATA16 = 146;
	public static final int X86_INS_DEC = 147;
	public static final int X86_INS_DIV = 148;
	public static final int X86_INS_DIVPD = 149;
	public static final int X86_INS_DIVPS = 150;
	public static final int X86_INS_FDIVR = 151;
	public static final int X86_INS_FIDIVR = 152;
	public static final int X86_INS_FDIVRP = 153;
	public static final int X86_INS_DIVSD = 154;
	public static final int X86_INS_DIVSS = 155;
	public static final int X86_INS_FDIV = 156;
	public static final int X86_INS_FIDIV = 157;
	public static final int X86_INS_FDIVP = 158;
	public static final int X86_INS_DPPD = 159;
	public static final int X86_INS_DPPS = 160;
	public static final int X86_INS_ENCLS = 161;
	public static final int X86_INS_ENCLU = 162;
	public static final int X86_INS_ENCLV = 163;
	public static final int X86_INS_ENDBR32 = 164;
	public static final int X86_INS_ENDBR64 = 165;
	public static final int X86_INS_ENTER = 166;
	public static final int X86_INS_EXTRACTPS = 167;
	public static final int X86_INS_EXTRQ = 168;
	public static final int X86_INS_F2XM1 = 169;
	public static final int X86_INS_LCALL = 170;
	public static final int X86_INS_LJMP = 171;
	public static final int X86_INS_JMP = 172;
	public static final int X86_INS_FBLD = 173;
	public static final int X86_INS_FBSTP = 174;
	public static final int X86_INS_FCOMPP = 175;
	public static final int X86_INS_FDECSTP = 176;
	public static final int X86_INS_FDISI8087_NOP = 177;
	public static final int X86_INS_FEMMS = 178;
	public static final int X86_INS_FENI8087_NOP = 179;
	public static final int X86_INS_FFREE = 180;
	public static final int X86_INS_FFREEP = 181;
	public static final int X86_INS_FICOM = 182;
	public static final int X86_INS_FICOMP = 183;
	public static final int X86_INS_FINCSTP = 184;
	public static final int X86_INS_FLDCW = 185;
	public static final int X86_INS_FLDENV = 186;
	public static final int X86_INS_FLDL2E = 187;
	public static final int X86_INS_FLDL2T = 188;
	public static final int X86_INS_FLDLG2 = 189;
	public static final int X86_INS_FLDLN2 = 190;
	public static final int X86_INS_FLDPI = 191;
	public static final int X86_INS_FNCLEX = 192;
	public static final int X86_INS_FNINIT = 193;
	public static final int X86_INS_FNOP = 194;
	public static final int X86_INS_FNSTCW = 195;
	public static final int X86_INS_FNSTSW = 196;
	public static final int X86_INS_FPATAN = 197;
	public static final int X86_INS_FSTPNCE = 198;
	public static final int X86_INS_FPREM = 199;
	public static final int X86_INS_FPREM1 = 200;
	public static final int X86_INS_FPTAN = 201;
	public static final int X86_INS_FRNDINT = 202;
	public static final int X86_INS_FRSTOR = 203;
	public static final int X86_INS_FNSAVE = 204;
	public static final int X86_INS_FSCALE = 205;
	public static final int X86_INS_FSETPM = 206;
	public static final int X86_INS_FSINCOS = 207;
	public static final int X86_INS_FNSTENV = 208;
	public static final int X86_INS_FXAM = 209;
	public static final int X86_INS_FXRSTOR = 210;
	public static final int X86_INS_FXRSTOR64 = 211;
	public static final int X86_INS_FXSAVE = 212;
	public static final int X86_INS_FXSAVE64 = 213;
	public static final int X86_INS_FXTRACT = 214;
	public static final int X86_INS_FYL2X = 215;
	public static final int X86_INS_FYL2XP1 = 216;
	public static final int X86_INS_GETSEC = 217;
	public static final int X86_INS_GF2P8AFFINEINVQB = 218;
	public static final int X86_INS_GF2P8AFFINEQB = 219;
	public static final int X86_INS_GF2P8MULB = 220;
	public static final int X86_INS_HADDPD = 221;
	public static final int X86_INS_HADDPS = 222;
	public static final int X86_INS_HLT = 223;
	public static final int X86_INS_HSUBPD = 224;
	public static final int X86_INS_HSUBPS = 225;
	public static final int X86_INS_IDIV = 226;
	public static final int X86_INS_FILD = 227;
	public static final int X86_INS_IMUL = 228;
	public static final int X86_INS_IN = 229;
	public static final int X86_INS_INC = 230;
	public static final int X86_INS_INCSSPD = 231;
	public static final int X86_INS_INCSSPQ = 232;
	public static final int X86_INS_INSB = 233;
	public static final int X86_INS_INSERTPS = 234;
	public static final int X86_INS_INSERTQ = 235;
	public static final int X86_INS_INSD = 236;
	public static final int X86_INS_INSW = 237;
	public static final int X86_INS_INT = 238;
	public static final int X86_INS_INT1 = 239;
	public static final int X86_INS_INT3 = 240;
	public static final int X86_INS_INTO = 241;
	public static final int X86_INS_INVD = 242;
	public static final int X86_INS_INVEPT = 243;
	public static final int X86_INS_INVLPG = 244;
	public static final int X86_INS_INVLPGA = 245;
	public static final int X86_INS_INVPCID = 246;
	public static final int X86_INS_INVVPID = 247;
	public static final int X86_INS_IRET = 248;
	public static final int X86_INS_IRETD = 249;
	public static final int X86_INS_IRETQ = 250;
	public static final int X86_INS_FISTTP = 251;
	public static final int X86_INS_FIST = 252;
	public static final int X86_INS_FISTP = 253;
	public static final int X86_INS_JAE = 254;
	public static final int X86_INS_JA = 255;
	public static final int X86_INS_JBE = 256;
	public static final int X86_INS_JB = 257;
	public static final int X86_INS_JCXZ = 258;
	public static final int X86_INS_JECXZ = 259;
	public static final int X86_INS_JE = 260;
	public static final int X86_INS_JGE = 261;
	public static final int X86_INS_JG = 262;
	public static final int X86_INS_JLE = 263;
	public static final int X86_INS_JL = 264;
	public static final int X86_INS_JNE = 265;
	public static final int X86_INS_JNO = 266;
	public static final int X86_INS_JNP = 267;
	public static final int X86_INS_JNS = 268;
	public static final int X86_INS_JO = 269;
	public static final int X86_INS_JP = 270;
	public static final int X86_INS_JRCXZ = 271;
	public static final int X86_INS_JS = 272;
	public static final int X86_INS_KADDB = 273;
	public static final int X86_INS_KADDD = 274;
	public static final int X86_INS_KADDQ = 275;
	public static final int X86_INS_KADDW = 276;
	public static final int X86_INS_KANDB = 277;
	public static final int X86_INS_KANDD = 278;
	public static final int X86_INS_KANDNB = 279;
	public static final int X86_INS_KANDND = 280;
	public static final int X86_INS_KANDNQ = 281;
	public static final int X86_INS_KANDNW = 282;
	public static final int X86_INS_KANDQ = 283;
	public static final int X86_INS_KANDW = 284;
	public static final int X86_INS_KMOVB = 285;
	public static final int X86_INS_KMOVD = 286;
	public static final int X86_INS_KMOVQ = 287;
	public static final int X86_INS_KMOVW = 288;
	public static final int X86_INS_KNOTB = 289;
	public static final int X86_INS_KNOTD = 290;
	public static final int X86_INS_KNOTQ = 291;
	public static final int X86_INS_KNOTW = 292;
	public static final int X86_INS_KORB = 293;
	public static final int X86_INS_KORD = 294;
	public static final int X86_INS_KORQ = 295;
	public static final int X86_INS_KORTESTB = 296;
	public static final int X86_INS_KORTESTD = 297;
	public static final int X86_INS_KORTESTQ = 298;
	public static final int X86_INS_KORTESTW = 299;
	public static final int X86_INS_KORW = 300;
	public static final int X86_INS_KSHIFTLB = 301;
	public static final int X86_INS_KSHIFTLD = 302;
	public static final int X86_INS_KSHIFTLQ = 303;
	public static final int X86_INS_KSHIFTLW = 304;
	public static final int X86_INS_KSHIFTRB = 305;
	public static final int X86_INS_KSHIFTRD = 306;
	public static final int X86_INS_KSHIFTRQ = 307;
	public static final int X86_INS_KSHIFTRW = 308;
	public static final int X86_INS_KTESTB = 309;
	public static final int X86_INS_KTESTD = 310;
	public static final int X86_INS_KTESTQ = 311;
	public static final int X86_INS_KTESTW = 312;
	public static final int X86_INS_KUNPCKBW = 313;
	public static final int X86_INS_KUNPCKDQ = 314;
	public static final int X86_INS_KUNPCKWD = 315;
	public static final int X86_INS_KXNORB = 316;
	public static final int X86_INS_KXNORD = 317;
	public static final int X86_INS_KXNORQ = 318;
	public static final int X86_INS_KXNORW = 319;
	public static final int X86_INS_KXORB = 320;
	public static final int X86_INS_KXORD = 321;
	public static final int X86_INS_KXORQ = 322;
	public static final int X86_INS_KXORW = 323;
	public static final int X86_INS_LAHF = 324;
	public static final int X86_INS_LAR = 325;
	public static final int X86_INS_LDDQU = 326;
	public static final int X86_INS_LDMXCSR = 327;
	public static final int X86_INS_LDS = 328;
	public static final int X86_INS_FLDZ = 329;
	public static final int X86_INS_FLD1 = 330;
	public static final int X86_INS_FLD = 331;
	public static final int X86_INS_LEA = 332;
	public static final int X86_INS_LEAVE = 333;
	public static final int X86_INS_LES = 334;
	public static final int X86_INS_LFENCE = 335;
	public static final int X86_INS_LFS = 336;
	public static final int X86_INS_LGDT = 337;
	public static final int X86_INS_LGS = 338;
	public static final int X86_INS_LIDT = 339;
	public static final int X86_INS_LLDT = 340;
	public static final int X86_INS_LLWPCB = 341;
	public static final int X86_INS_LMSW = 342;
	public static final int X86_INS_LOCK = 343;
	public static final int X86_INS_LODSB = 344;
	public static final int X86_INS_LODSD = 345;
	public static final int X86_INS_LODSQ = 346;
	public static final int X86_INS_LODSW = 347;
	public static final int X86_INS_LOOP = 348;
	public static final int X86_INS_LOOPE = 349;
	public static final int X86_INS_LOOPNE = 350;
	public static final int X86_INS_RETF = 351;
	public static final int X86_INS_RETFQ = 352;
	public static final int X86_INS_LSL = 353;
	public static final int X86_INS_LSS = 354;
	public static final int X86_INS_LTR = 355;
	public static final int X86_INS_LWPINS = 356;
	public static final int X86_INS_LWPVAL = 357;
	public static final int X86_INS_LZCNT = 358;
	public static final int X86_INS_MASKMOVDQU = 359;
	public static final int X86_INS_MAXPD = 360;
	public static final int X86_INS_MAXPS = 361;
	public static final int X86_INS_MAXSD = 362;
	public static final int X86_INS_MAXSS = 363;
	public static final int X86_INS_MFENCE = 364;
	public static final int X86_INS_MINPD = 365;
	public static final int X86_INS_MINPS = 366;
	public static final int X86_INS_MINSD = 367;
	public static final int X86_INS_MINSS = 368;
	public static final int X86_INS_CVTPD2PI = 369;
	public static final int X86_INS_CVTPI2PD = 370;
	public static final int X86_INS_CVTPI2PS = 371;
	public static final int X86_INS_CVTPS2PI = 372;
	public static final int X86_INS_CVTTPD2PI = 373;
	public static final int X86_INS_CVTTPS2PI = 374;
	public static final int X86_INS_EMMS = 375;
	public static final int X86_INS_MASKMOVQ = 376;
	public static final int X86_INS_MOVD = 377;
	public static final int X86_INS_MOVQ = 378;
	public static final int X86_INS_MOVDQ2Q = 379;
	public static final int X86_INS_MOVNTQ = 380;
	public static final int X86_INS_MOVQ2DQ = 381;
	public static final int X86_INS_PABSB = 382;
	public static final int X86_INS_PABSD = 383;
	public static final int X86_INS_PABSW = 384;
	public static final int X86_INS_PACKSSDW = 385;
	public static final int X86_INS_PACKSSWB = 386;
	public static final int X86_INS_PACKUSWB = 387;
	public static final int X86_INS_PADDB = 388;
	public static final int X86_INS_PADDD = 389;
	public static final int X86_INS_PADDQ = 390;
	public static final int X86_INS_PADDSB = 391;
	public static final int X86_INS_PADDSW = 392;
	public static final int X86_INS_PADDUSB = 393;
	public static final int X86_INS_PADDUSW = 394;
	public static final int X86_INS_PADDW = 395;
	public static final int X86_INS_PALIGNR = 396;
	public static final int X86_INS_PANDN = 397;
	public static final int X86_INS_PAND = 398;
	public static final int X86_INS_PAVGB = 399;
	public static final int X86_INS_PAVGW = 400;
	public static final int X86_INS_PCMPEQB = 401;
	public static final int X86_INS_PCMPEQD = 402;
	public static final int X86_INS_PCMPEQW = 403;
	public static final int X86_INS_PCMPGTB = 404;
	public static final int X86_INS_PCMPGTD = 405;
	public static final int X86_INS_PCMPGTW = 406;
	public static final int X86_INS_PEXTRW = 407;
	public static final int X86_INS_PHADDD = 408;
	public static final int X86_INS_PHADDSW = 409;
	public static final int X86_INS_PHADDW = 410;
	public static final int X86_INS_PHSUBD = 411;
	public static final int X86_INS_PHSUBSW = 412;
	public static final int X86_INS_PHSUBW = 413;
	public static final int X86_INS_PINSRW = 414;
	public static final int X86_INS_PMADDUBSW = 415;
	public static final int X86_INS_PMADDWD = 416;
	public static final int X86_INS_PMAXSW = 417;
	public static final int X86_INS_PMAXUB = 418;
	public static final int X86_INS_PMINSW = 419;
	public static final int X86_INS_PMINUB = 420;
	public static final int X86_INS_PMOVMSKB = 421;
	public static final int X86_INS_PMULHRSW = 422;
	public static final int X86_INS_PMULHUW = 423;
	public static final int X86_INS_PMULHW = 424;
	public static final int X86_INS_PMULLW = 425;
	public static final int X86_INS_PMULUDQ = 426;
	public static final int X86_INS_POR = 427;
	public static final int X86_INS_PSADBW = 428;
	public static final int X86_INS_PSHUFB = 429;
	public static final int X86_INS_PSHUFW = 430;
	public static final int X86_INS_PSIGNB = 431;
	public static final int X86_INS_PSIGND = 432;
	public static final int X86_INS_PSIGNW = 433;
	public static final int X86_INS_PSLLD = 434;
	public static final int X86_INS_PSLLQ = 435;
	public static final int X86_INS_PSLLW = 436;
	public static final int X86_INS_PSRAD = 437;
	public static final int X86_INS_PSRAW = 438;
	public static final int X86_INS_PSRLD = 439;
	public static final int X86_INS_PSRLQ = 440;
	public static final int X86_INS_PSRLW = 441;
	public static final int X86_INS_PSUBB = 442;
	public static final int X86_INS_PSUBD = 443;
	public static final int X86_INS_PSUBQ = 444;
	public static final int X86_INS_PSUBSB = 445;
	public static final int X86_INS_PSUBSW = 446;
	public static final int X86_INS_PSUBUSB = 447;
	public static final int X86_INS_PSUBUSW = 448;
	public static final int X86_INS_PSUBW = 449;
	public static final int X86_INS_PUNPCKHBW = 450;
	public static final int X86_INS_PUNPCKHDQ = 451;
	public static final int X86_INS_PUNPCKHWD = 452;
	public static final int X86_INS_PUNPCKLBW = 453;
	public static final int X86_INS_PUNPCKLDQ = 454;
	public static final int X86_INS_PUNPCKLWD = 455;
	public static final int X86_INS_PXOR = 456;
	public static final int X86_INS_MONITORX = 457;
	public static final int X86_INS_MONITOR = 458;
	public static final int X86_INS_MONTMUL = 459;
	public static final int X86_INS_MOV = 460;
	public static final int X86_INS_MOVABS = 461;
	public static final int X86_INS_MOVAPD = 462;
	public static final int X86_INS_MOVAPS = 463;
	public static final int X86_INS_MOVBE = 464;
	public static final int X86_INS_MOVDDUP = 465;
	public static final int X86_INS_MOVDIR64B = 466;
	public static final int X86_INS_MOVDIRI = 467;
	public static final int X86_INS_MOVDQA = 468;
	public static final int X86_INS_MOVDQU = 469;
	public static final int X86_INS_MOVHLPS = 470;
	public static final int X86_INS_MOVHPD = 471;
	public static final int X86_INS_MOVHPS = 472;
	public static final int X86_INS_MOVLHPS = 473;
	public static final int X86_INS_MOVLPD = 474;
	public static final int X86_INS_MOVLPS = 475;
	public static final int X86_INS_MOVMSKPD = 476;
	public static final int X86_INS_MOVMSKPS = 477;
	public static final int X86_INS_MOVNTDQA = 478;
	public static final int X86_INS_MOVNTDQ = 479;
	public static final int X86_INS_MOVNTI = 480;
	public static final int X86_INS_MOVNTPD = 481;
	public static final int X86_INS_MOVNTPS = 482;
	public static final int X86_INS_MOVNTSD = 483;
	public static final int X86_INS_MOVNTSS = 484;
	public static final int X86_INS_MOVSB = 485;
	public static final int X86_INS_MOVSD = 486;
	public static final int X86_INS_MOVSHDUP = 487;
	public static final int X86_INS_MOVSLDUP = 488;
	public static final int X86_INS_MOVSQ = 489;
	public static final int X86_INS_MOVSS = 490;
	public static final int X86_INS_MOVSW = 491;
	public static final int X86_INS_MOVSX = 492;
	public static final int X86_INS_MOVSXD = 493;
	public static final int X86_INS_MOVUPD = 494;
	public static final int X86_INS_MOVUPS = 495;
	public static final int X86_INS_MOVZX = 496;
	public static final int X86_INS_MPSADBW = 497;
	public static final int X86_INS_MUL = 498;
	public static final int X86_INS_MULPD = 499;
	public static final int X86_INS_MULPS = 500;
	public static final int X86_INS_MULSD = 501;
	public static final int X86_INS_MULSS = 502;
	public static final int X86_INS_MULX = 503;
	public static final int X86_INS_FMUL = 504;
	public static final int X86_INS_FIMUL = 505;
	public static final int X86_INS_FMULP = 506;
	public static final int X86_INS_MWAITX = 507;
	public static final int X86_INS_MWAIT = 508;
	public static final int X86_INS_NEG = 509;
	public static final int X86_INS_NOP = 510;
	public static final int X86_INS_NOT = 511;
	public static final int X86_INS_OR = 512;
	public static final int X86_INS_ORPD = 513;
	public static final int X86_INS_ORPS = 514;
	public static final int X86_INS_OUT = 515;
	public static final int X86_INS_OUTSB = 516;
	public static final int X86_INS_OUTSD = 517;
	public static final int X86_INS_OUTSW = 518;
	public static final int X86_INS_PACKUSDW = 519;
	public static final int X86_INS_PAUSE = 520;
	public static final int X86_INS_PAVGUSB = 521;
	public static final int X86_INS_PBLENDVB = 522;
	public static final int X86_INS_PBLENDW = 523;
	public static final int X86_INS_PCLMULQDQ = 524;
	public static final int X86_INS_PCMPEQQ = 525;
	public static final int X86_INS_PCMPESTRI = 526;
	public static final int X86_INS_PCMPESTRM = 527;
	public static final int X86_INS_PCMPGTQ = 528;
	public static final int X86_INS_PCMPISTRI = 529;
	public static final int X86_INS_PCMPISTRM = 530;
	public static final int X86_INS_PCONFIG = 531;
	public static final int X86_INS_PDEP = 532;
	public static final int X86_INS_PEXT = 533;
	public static final int X86_INS_PEXTRB = 534;
	public static final int X86_INS_PEXTRD = 535;
	public static final int X86_INS_PEXTRQ = 536;
	public static final int X86_INS_PF2ID = 537;
	public static final int X86_INS_PF2IW = 538;
	public static final int X86_INS_PFACC = 539;
	public static final int X86_INS_PFADD = 540;
	public static final int X86_INS_PFCMPEQ = 541;
	public static final int X86_INS_PFCMPGE = 542;
	public static final int X86_INS_PFCMPGT = 543;
	public static final int X86_INS_PFMAX = 544;
	public static final int X86_INS_PFMIN = 545;
	public static final int X86_INS_PFMUL = 546;
	public static final int X86_INS_PFNACC = 547;
	public static final int X86_INS_PFPNACC = 548;
	public static final int X86_INS_PFRCPIT1 = 549;
	public static final int X86_INS_PFRCPIT2 = 550;
	public static final int X86_INS_PFRCP = 551;
	public static final int X86_INS_PFRSQIT1 = 552;
	public static final int X86_INS_PFRSQRT = 553;
	public static final int X86_INS_PFSUBR = 554;
	public static final int X86_INS_PFSUB = 555;
	public static final int X86_INS_PHMINPOSUW = 556;
	public static final int X86_INS_PI2FD = 557;
	public static final int X86_INS_PI2FW = 558;
	public static final int X86_INS_PINSRB = 559;
	public static final int X86_INS_PINSRD = 560;
	public static final int X86_INS_PINSRQ = 561;
	public static final int X86_INS_PMAXSB = 562;
	public static final int X86_INS_PMAXSD = 563;
	public static final int X86_INS_PMAXUD = 564;
	public static final int X86_INS_PMAXUW = 565;
	public static final int X86_INS_PMINSB = 566;
	public static final int X86_INS_PMINSD = 567;
	public static final int X86_INS_PMINUD = 568;
	public static final int X86_INS_PMINUW = 569;
	public static final int X86_INS_PMOVSXBD = 570;
	public static final int X86_INS_PMOVSXBQ = 571;
	public static final int X86_INS_PMOVSXBW = 572;
	public static final int X86_INS_PMOVSXDQ = 573;
	public static final int X86_INS_PMOVSXWD = 574;
	public static final int X86_INS_PMOVSXWQ = 575;
	public static final int X86_INS_PMOVZXBD = 576;
	public static final int X86_INS_PMOVZXBQ = 577;
	public static final int X86_INS_PMOVZXBW = 578;
	public static final int X86_INS_PMOVZXDQ = 579;
	public static final int X86_INS_PMOVZXWD = 580;
	public static final int X86_INS_PMOVZXWQ = 581;
	public static final int X86_INS_PMULDQ = 582;
	public static final int X86_INS_PMULHRW = 583;
	public static final int X86_INS_PMULLD = 584;
	public static final int X86_INS_POP = 585;
	public static final int X86_INS_POPAW = 586;
	public static final int X86_INS_POPAL = 587;
	public static final int X86_INS_POPCNT = 588;
	public static final int X86_INS_POPF = 589;
	public static final int X86_INS_POPFD = 590;
	public static final int X86_INS_POPFQ = 591;
	public static final int X86_INS_PREFETCH = 592;
	public static final int X86_INS_PREFETCHNTA = 593;
	public static final int X86_INS_PREFETCHT0 = 594;
	public static final int X86_INS_PREFETCHT1 = 595;
	public static final int X86_INS_PREFETCHT2 = 596;
	public static final int X86_INS_PREFETCHW = 597;
	public static final int X86_INS_PREFETCHWT1 = 598;
	public static final int X86_INS_PSHUFD = 599;
	public static final int X86_INS_PSHUFHW = 600;
	public static final int X86_INS_PSHUFLW = 601;
	public static final int X86_INS_PSLLDQ = 602;
	public static final int X86_INS_PSRLDQ = 603;
	public static final int X86_INS_PSWAPD = 604;
	public static final int X86_INS_PTEST = 605;
	public static final int X86_INS_PTWRITE = 606;
	public static final int X86_INS_PUNPCKHQDQ = 607;
	public static final int X86_INS_PUNPCKLQDQ = 608;
	public static final int X86_INS_PUSH = 609;
	public static final int X86_INS_PUSHAW = 610;
	public static final int X86_INS_PUSHAL = 611;
	public static final int X86_INS_PUSHF = 612;
	public static final int X86_INS_PUSHFD = 613;
	public static final int X86_INS_PUSHFQ = 614;
	public static final int X86_INS_RCL = 615;
	public static final int X86_INS_RCPPS = 616;
	public static final int X86_INS_RCPSS = 617;
	public static final int X86_INS_RCR = 618;
	public static final int X86_INS_RDFSBASE = 619;
	public static final int X86_INS_RDGSBASE = 620;
	public static final int X86_INS_RDMSR = 621;
	public static final int X86_INS_RDPID = 622;
	public static final int X86_INS_RDPKRU = 623;
	public static final int X86_INS_RDPMC = 624;
	public static final int X86_INS_RDRAND = 625;
	public static final int X86_INS_RDSEED = 626;
	public static final int X86_INS_RDSSPD = 627;
	public static final int X86_INS_RDSSPQ = 628;
	public static final int X86_INS_RDTSC = 629;
	public static final int X86_INS_RDTSCP = 630;
	public static final int X86_INS_REPNE = 631;
	public static final int X86_INS_REP = 632;
	public static final int X86_INS_RET = 633;
	public static final int X86_INS_REX64 = 634;
	public static final int X86_INS_ROL = 635;
	public static final int X86_INS_ROR = 636;
	public static final int X86_INS_RORX = 637;
	public static final int X86_INS_ROUNDPD = 638;
	public static final int X86_INS_ROUNDPS = 639;
	public static final int X86_INS_ROUNDSD = 640;
	public static final int X86_INS_ROUNDSS = 641;
	public static final int X86_INS_RSM = 642;
	public static final int X86_INS_RSQRTPS = 643;
	public static final int X86_INS_RSQRTSS = 644;
	public static final int X86_INS_RSTORSSP = 645;
	public static final int X86_INS_SAHF = 646;
	public static final int X86_INS_SAL = 647;
	public static final int X86_INS_SALC = 648;
	public static final int X86_INS_SAR = 649;
	public static final int X86_INS_SARX = 650;
	public static final int X86_INS_SAVEPREVSSP = 651;
	public static final int X86_INS_SBB = 652;
	public static final int X86_INS_SCASB = 653;
	public static final int X86_INS_SCASD = 654;
	public static final int X86_INS_SCASQ = 655;
	public static final int X86_INS_SCASW = 656;
	public static final int X86_INS_SETAE = 657;
	public static final int X86_INS_SETA = 658;
	public static final int X86_INS_SETBE = 659;
	public static final int X86_INS_SETB = 660;
	public static final int X86_INS_SETE = 661;
	public static final int X86_INS_SETGE = 662;
	public static final int X86_INS_SETG = 663;
	public static final int X86_INS_SETLE = 664;
	public static final int X86_INS_SETL = 665;
	public static final int X86_INS_SETNE = 666;
	public static final int X86_INS_SETNO = 667;
	public static final int X86_INS_SETNP = 668;
	public static final int X86_INS_SETNS = 669;
	public static final int X86_INS_SETO = 670;
	public static final int X86_INS_SETP = 671;
	public static final int X86_INS_SETSSBSY = 672;
	public static final int X86_INS_SETS = 673;
	public static final int X86_INS_SFENCE = 674;
	public static final int X86_INS_SGDT = 675;
	public static final int X86_INS_SHA1MSG1 = 676;
	public static final int X86_INS_SHA1MSG2 = 677;
	public static final int X86_INS_SHA1NEXTE = 678;
	public static final int X86_INS_SHA1RNDS4 = 679;
	public static final int X86_INS_SHA256MSG1 = 680;
	public static final int X86_INS_SHA256MSG2 = 681;
	public static final int X86_INS_SHA256RNDS2 = 682;
	public static final int X86_INS_SHL = 683;
	public static final int X86_INS_SHLD = 684;
	public static final int X86_INS_SHLX = 685;
	public static final int X86_INS_SHR = 686;
	public static final int X86_INS_SHRD = 687;
	public static final int X86_INS_SHRX = 688;
	public static final int X86_INS_SHUFPD = 689;
	public static final int X86_INS_SHUFPS = 690;
	public static final int X86_INS_SIDT = 691;
	public static final int X86_INS_FSIN = 692;
	public static final int X86_INS_SKINIT = 693;
	public static final int X86_INS_SLDT = 694;
	public static final int X86_INS_SLWPCB = 695;
	public static final int X86_INS_SMSW = 696;
	public static final int X86_INS_SQRTPD = 697;
	public static final int X86_INS_SQRTPS = 698;
	public static final int X86_INS_SQRTSD = 699;
	public static final int X86_INS_SQRTSS = 700;
	public static final int X86_INS_FSQRT = 701;
	public static final int X86_INS_STAC = 702;
	public static final int X86_INS_STC = 703;
	public static final int X86_INS_STD = 704;
	public static final int X86_INS_STGI = 705;
	public static final int X86_INS_STI = 706;
	public static final int X86_INS_STMXCSR = 707;
	public static final int X86_INS_STOSB = 708;
	public static final int X86_INS_STOSD = 709;
	public static final int X86_INS_STOSQ = 710;
	public static final int X86_INS_STOSW = 711;
	public static final int X86_INS_STR = 712;
	public static final int X86_INS_FST = 713;
	public static final int X86_INS_FSTP = 714;
	public static final int X86_INS_SUB = 715;
	public static final int X86_INS_SUBPD = 716;
	public static final int X86_INS_SUBPS = 717;
	public static final int X86_INS_FSUBR = 718;
	public static final int X86_INS_FISUBR = 719;
	public static final int X86_INS_FSUBRP = 720;
	public static final int X86_INS_SUBSD = 721;
	public static final int X86_INS_SUBSS = 722;
	public static final int X86_INS_FSUB = 723;
	public static final int X86_INS_FISUB = 724;
	public static final int X86_INS_FSUBP = 725;
	public static final int X86_INS_SWAPGS = 726;
	public static final int X86_INS_SYSCALL = 727;
	public static final int X86_INS_SYSENTER = 728;
	public static final int X86_INS_SYSEXIT = 729;
	public static final int X86_INS_SYSEXITQ = 730;
	public static final int X86_INS_SYSRET = 731;
	public static final int X86_INS_SYSRETQ = 732;
	public static final int X86_INS_T1MSKC = 733;
	public static final int X86_INS_TEST = 734;
	public static final int X86_INS_TPAUSE = 735;
	public static final int X86_INS_FTST = 736;
	public static final int X86_INS_TZCNT = 737;
	public static final int X86_INS_TZMSK = 738;
	public static final int X86_INS_UCOMISD = 739;
	public static final int X86_INS_UCOMISS = 740;
	public static final int X86_INS_FUCOMPI = 741;
	public static final int X86_INS_FUCOMI = 742;
	public static final int X86_INS_FUCOMPP = 743;
	public static final int X86_INS_FUCOMP = 744;
	public static final int X86_INS_FUCOM = 745;
	public static final int X86_INS_UD0 = 746;
	public static final int X86_INS_UD1 = 747;
	public static final int X86_INS_UD2 = 748;
	public static final int X86_INS_UMONITOR = 749;
	public static final int X86_INS_UMWAIT = 750;
	public static final int X86_INS_UNPCKHPD = 751;
	public static final int X86_INS_UNPCKHPS = 752;
	public static final int X86_INS_UNPCKLPD = 753;
	public static final int X86_INS_UNPCKLPS = 754;
	public static final int X86_INS_V4FMADDPS = 755;
	public static final int X86_INS_V4FMADDSS = 756;
	public static final int X86_INS_V4FNMADDPS = 757;
	public static final int X86_INS_V4FNMADDSS = 758;
	public static final int X86_INS_VADDPD = 759;
	public static final int X86_INS_VADDPS = 760;
	public static final int X86_INS_VADDSD = 761;
	public static final int X86_INS_VADDSS = 762;
	public static final int X86_INS_VADDSUBPD = 763;
	public static final int X86_INS_VADDSUBPS = 764;
	public static final int X86_INS_VAESDECLAST = 765;
	public static final int X86_INS_VAESDEC = 766;
	public static final int X86_INS_VAESENCLAST = 767;
	public static final int X86_INS_VAESENC = 768;
	public static final int X86_INS_VAESIMC = 769;
	public static final int X86_INS_VAESKEYGENASSIST = 770;
	public static final int X86_INS_VALIGND = 771;
	public static final int X86_INS_VALIGNQ = 772;
	public static final int X86_INS_VANDNPD = 773;
	public static final int X86_INS_VANDNPS = 774;
	public static final int X86_INS_VANDPD = 775;
	public static final int X86_INS_VANDPS = 776;
	public static final int X86_INS_VBLENDMPD = 777;
	public static final int X86_INS_VBLENDMPS = 778;
	public static final int X86_INS_VBLENDPD = 779;
	public static final int X86_INS_VBLENDPS = 780;
	public static final int X86_INS_VBLENDVPD = 781;
	public static final int X86_INS_VBLENDVPS = 782;
	public static final int X86_INS_VBROADCASTF128 = 783;
	public static final int X86_INS_VBROADCASTF32X2 = 784;
	public static final int X86_INS_VBROADCASTF32X4 = 785;
	public static final int X86_INS_VBROADCASTF32X8 = 786;
	public static final int X86_INS_VBROADCASTF64X2 = 787;
	public static final int X86_INS_VBROADCASTF64X4 = 788;
	public static final int X86_INS_VBROADCASTI128 = 789;
	public static final int X86_INS_VBROADCASTI32X2 = 790;
	public static final int X86_INS_VBROADCASTI32X4 = 791;
	public static final int X86_INS_VBROADCASTI32X8 = 792;
	public static final int X86_INS_VBROADCASTI64X2 = 793;
	public static final int X86_INS_VBROADCASTI64X4 = 794;
	public static final int X86_INS_VBROADCASTSD = 795;
	public static final int X86_INS_VBROADCASTSS = 796;
	public static final int X86_INS_VCMP = 797;
	public static final int X86_INS_VCMPPD = 798;
	public static final int X86_INS_VCMPPS = 799;
	public static final int X86_INS_VCMPSD = 800;
	public static final int X86_INS_VCMPSS = 801;
	public static final int X86_INS_VCOMISD = 802;
	public static final int X86_INS_VCOMISS = 803;
	public static final int X86_INS_VCOMPRESSPD = 804;
	public static final int X86_INS_VCOMPRESSPS = 805;
	public static final int X86_INS_VCVTDQ2PD = 806;
	public static final int X86_INS_VCVTDQ2PS = 807;
	public static final int X86_INS_VCVTPD2DQ = 808;
	public static final int X86_INS_VCVTPD2PS = 809;
	public static final int X86_INS_VCVTPD2QQ = 810;
	public static final int X86_INS_VCVTPD2UDQ = 811;
	public static final int X86_INS_VCVTPD2UQQ = 812;
	public static final int X86_INS_VCVTPH2PS = 813;
	public static final int X86_INS_VCVTPS2DQ = 814;
	public static final int X86_INS_VCVTPS2PD = 815;
	public static final int X86_INS_VCVTPS2PH = 816;
	public static final int X86_INS_VCVTPS2QQ = 817;
	public static final int X86_INS_VCVTPS2UDQ = 818;
	public static final int X86_INS_VCVTPS2UQQ = 819;
	public static final int X86_INS_VCVTQQ2PD = 820;
	public static final int X86_INS_VCVTQQ2PS = 821;
	public static final int X86_INS_VCVTSD2SI = 822;
	public static final int X86_INS_VCVTSD2SS = 823;
	public static final int X86_INS_VCVTSD2USI = 824;
	public static final int X86_INS_VCVTSI2SD = 825;
	public static final int X86_INS_VCVTSI2SS = 826;
	public static final int X86_INS_VCVTSS2SD = 827;
	public static final int X86_INS_VCVTSS2SI = 828;
	public static final int X86_INS_VCVTSS2USI = 829;
	public static final int X86_INS_VCVTTPD2DQ = 830;
	public static final int X86_INS_VCVTTPD2QQ = 831;
	public static final int X86_INS_VCVTTPD2UDQ = 832;
	public static final int X86_INS_VCVTTPD2UQQ = 833;
	public static final int X86_INS_VCVTTPS2DQ = 834;
	public static final int X86_INS_VCVTTPS2QQ = 835;
	public static final int X86_INS_VCVTTPS2UDQ = 836;
	public static final int X86_INS_VCVTTPS2UQQ = 837;
	public static final int X86_INS_VCVTTSD2SI = 838;
	public static final int X86_INS_VCVTTSD2USI = 839;
	public static final int X86_INS_VCVTTSS2SI = 840;
	public static final int X86_INS_VCVTTSS2USI = 841;
	public static final int X86_INS_VCVTUDQ2PD = 842;
	public static final int X86_INS_VCVTUDQ2PS = 843;
	public static final int X86_INS_VCVTUQQ2PD = 844;
	public static final int X86_INS_VCVTUQQ2PS = 845;
	public static final int X86_INS_VCVTUSI2SD = 846;
	public static final int X86_INS_VCVTUSI2SS = 847;
	public static final int X86_INS_VDBPSADBW = 848;
	public static final int X86_INS_VDIVPD = 849;
	public static final int X86_INS_VDIVPS = 850;
	public static final int X86_INS_VDIVSD = 851;
	public static final int X86_INS_VDIVSS = 852;
	public static final int X86_INS_VDPPD = 853;
	public static final int X86_INS_VDPPS = 854;
	public static final int X86_INS_VERR = 855;
	public static final int X86_INS_VERW = 856;
	public static final int X86_INS_VEXP2PD = 857;
	public static final int X86_INS_VEXP2PS = 858;
	public static final int X86_INS_VEXPANDPD = 859;
	public static final int X86_INS_VEXPANDPS = 860;
	public static final int X86_INS_VEXTRACTF128 = 861;
	public static final int X86_INS_VEXTRACTF32X4 = 862;
	public static final int X86_INS_VEXTRACTF32X8 = 863;
	public static final int X86_INS_VEXTRACTF64X2 = 864;
	public static final int X86_INS_VEXTRACTF64X4 = 865;
	public static final int X86_INS_VEXTRACTI128 = 866;
	public static final int X86_INS_VEXTRACTI32X4 = 867;
	public static final int X86_INS_VEXTRACTI32X8 = 868;
	public static final int X86_INS_VEXTRACTI64X2 = 869;
	public static final int X86_INS_VEXTRACTI64X4 = 870;
	public static final int X86_INS_VEXTRACTPS = 871;
	public static final int X86_INS_VFIXUPIMMPD = 872;
	public static final int X86_INS_VFIXUPIMMPS = 873;
	public static final int X86_INS_VFIXUPIMMSD = 874;
	public static final int X86_INS_VFIXUPIMMSS = 875;
	public static final int X86_INS_VFMADD132PD = 876;
	public static final int X86_INS_VFMADD132PS = 877;
	public static final int X86_INS_VFMADD132SD = 878;
	public static final int X86_INS_VFMADD132SS = 879;
	public static final int X86_INS_VFMADD213PD = 880;
	public static final int X86_INS_VFMADD213PS = 881;
	public static final int X86_INS_VFMADD213SD = 882;
	public static final int X86_INS_VFMADD213SS = 883;
	public static final int X86_INS_VFMADD231PD = 884;
	public static final int X86_INS_VFMADD231PS = 885;
	public static final int X86_INS_VFMADD231SD = 886;
	public static final int X86_INS_VFMADD231SS = 887;
	public static final int X86_INS_VFMADDPD = 888;
	public static final int X86_INS_VFMADDPS = 889;
	public static final int X86_INS_VFMADDSD = 890;
	public static final int X86_INS_VFMADDSS = 891;
	public static final int X86_INS_VFMADDSUB132PD = 892;
	public static final int X86_INS_VFMADDSUB132PS = 893;
	public static final int X86_INS_VFMADDSUB213PD = 894;
	public static final int X86_INS_VFMADDSUB213PS = 895;
	public static final int X86_INS_VFMADDSUB231PD = 896;
	public static final int X86_INS_VFMADDSUB231PS = 897;
	public static final int X86_INS_VFMADDSUBPD = 898;
	public static final int X86_INS_VFMADDSUBPS = 899;
	public static final int X86_INS_VFMSUB132PD = 900;
	public static final int X86_INS_VFMSUB132PS = 901;
	public static final int X86_INS_VFMSUB132SD = 902;
	public static final int X86_INS_VFMSUB132SS = 903;
	public static final int X86_INS_VFMSUB213PD = 904;
	public static final int X86_INS_VFMSUB213PS = 905;
	public static final int X86_INS_VFMSUB213SD = 906;
	public static final int X86_INS_VFMSUB213SS = 907;
	public static final int X86_INS_VFMSUB231PD = 908;
	public static final int X86_INS_VFMSUB231PS = 909;
	public static final int X86_INS_VFMSUB231SD = 910;
	public static final int X86_INS_VFMSUB231SS = 911;
	public static final int X86_INS_VFMSUBADD132PD = 912;
	public static final int X86_INS_VFMSUBADD132PS = 913;
	public static final int X86_INS_VFMSUBADD213PD = 914;
	public static final int X86_INS_VFMSUBADD213PS = 915;
	public static final int X86_INS_VFMSUBADD231PD = 916;
	public static final int X86_INS_VFMSUBADD231PS = 917;
	public static final int X86_INS_VFMSUBADDPD = 918;
	public static final int X86_INS_VFMSUBADDPS = 919;
	public static final int X86_INS_VFMSUBPD = 920;
	public static final int X86_INS_VFMSUBPS = 921;
	public static final int X86_INS_VFMSUBSD = 922;
	public static final int X86_INS_VFMSUBSS = 923;
	public static final int X86_INS_VFNMADD132PD = 924;
	public static final int X86_INS_VFNMADD132PS = 925;
	public static final int X86_INS_VFNMADD132SD = 926;
	public static final int X86_INS_VFNMADD132SS = 927;
	public static final int X86_INS_VFNMADD213PD = 928;
	public static final int X86_INS_VFNMADD213PS = 929;
	public static final int X86_INS_VFNMADD213SD = 930;
	public static final int X86_INS_VFNMADD213SS = 931;
	public static final int X86_INS_VFNMADD231PD = 932;
	public static final int X86_INS_VFNMADD231PS = 933;
	public static final int X86_INS_VFNMADD231SD = 934;
	public static final int X86_INS_VFNMADD231SS = 935;
	public static final int X86_INS_VFNMADDPD = 936;
	public static final int X86_INS_VFNMADDPS = 937;
	public static final int X86_INS_VFNMADDSD = 938;
	public static final int X86_INS_VFNMADDSS = 939;
	public static final int X86_INS_VFNMSUB132PD = 940;
	public static final int X86_INS_VFNMSUB132PS = 941;
	public static final int X86_INS_VFNMSUB132SD = 942;
	public static final int X86_INS_VFNMSUB132SS = 943;
	public static final int X86_INS_VFNMSUB213PD = 944;
	public static final int X86_INS_VFNMSUB213PS = 945;
	public static final int X86_INS_VFNMSUB213SD = 946;
	public static final int X86_INS_VFNMSUB213SS = 947;
	public static final int X86_INS_VFNMSUB231PD = 948;
	public static final int X86_INS_VFNMSUB231PS = 949;
	public static final int X86_INS_VFNMSUB231SD = 950;
	public static final int X86_INS_VFNMSUB231SS = 951;
	public static final int X86_INS_VFNMSUBPD = 952;
	public static final int X86_INS_VFNMSUBPS = 953;
	public static final int X86_INS_VFNMSUBSD = 954;
	public static final int X86_INS_VFNMSUBSS = 955;
	public static final int X86_INS_VFPCLASSPD = 956;
	public static final int X86_INS_VFPCLASSPS = 957;
	public static final int X86_INS_VFPCLASSSD = 958;
	public static final int X86_INS_VFPCLASSSS = 959;
	public static final int X86_INS_VFRCZPD = 960;
	public static final int X86_INS_VFRCZPS = 961;
	public static final int X86_INS_VFRCZSD = 962;
	public static final int X86_INS_VFRCZSS = 963;
	public static final int X86_INS_VGATHERDPD = 964;
	public static final int X86_INS_VGATHERDPS = 965;
	public static final int X86_INS_VGATHERPF0DPD = 966;
	public static final int X86_INS_VGATHERPF0DPS = 967;
	public static final int X86_INS_VGATHERPF0QPD = 968;
	public static final int X86_INS_VGATHERPF0QPS = 969;
	public static final int X86_INS_VGATHERPF1DPD = 970;
	public static final int X86_INS_VGATHERPF1DPS = 971;
	public static final int X86_INS_VGATHERPF1QPD = 972;
	public static final int X86_INS_VGATHERPF1QPS = 973;
	public static final int X86_INS_VGATHERQPD = 974;
	public static final int X86_INS_VGATHERQPS = 975;
	public static final int X86_INS_VGETEXPPD = 976;
	public static final int X86_INS_VGETEXPPS = 977;
	public static final int X86_INS_VGETEXPSD = 978;
	public static final int X86_INS_VGETEXPSS = 979;
	public static final int X86_INS_VGETMANTPD = 980;
	public static final int X86_INS_VGETMANTPS = 981;
	public static final int X86_INS_VGETMANTSD = 982;
	public static final int X86_INS_VGETMANTSS = 983;
	public static final int X86_INS_VGF2P8AFFINEINVQB = 984;
	public static final int X86_INS_VGF2P8AFFINEQB = 985;
	public static final int X86_INS_VGF2P8MULB = 986;
	public static final int X86_INS_VHADDPD = 987;
	public static final int X86_INS_VHADDPS = 988;
	public static final int X86_INS_VHSUBPD = 989;
	public static final int X86_INS_VHSUBPS = 990;
	public static final int X86_INS_VINSERTF128 = 991;
	public static final int X86_INS_VINSERTF32X4 = 992;
	public static final int X86_INS_VINSERTF32X8 = 993;
	public static final int X86_INS_VINSERTF64X2 = 994;
	public static final int X86_INS_VINSERTF64X4 = 995;
	public static final int X86_INS_VINSERTI128 = 996;
	public static final int X86_INS_VINSERTI32X4 = 997;
	public static final int X86_INS_VINSERTI32X8 = 998;
	public static final int X86_INS_VINSERTI64X2 = 999;
	public static final int X86_INS_VINSERTI64X4 = 1000;
	public static final int X86_INS_VINSERTPS = 1001;
	public static final int X86_INS_VLDDQU = 1002;
	public static final int X86_INS_VLDMXCSR = 1003;
	public static final int X86_INS_VMASKMOVDQU = 1004;
	public static final int X86_INS_VMASKMOVPD = 1005;
	public static final int X86_INS_VMASKMOVPS = 1006;
	public static final int X86_INS_VMAXPD = 1007;
	public static final int X86_INS_VMAXPS = 1008;
	public static final int X86_INS_VMAXSD = 1009;
	public static final int X86_INS_VMAXSS = 1010;
	public static final int X86_INS_VMCALL = 1011;
	public static final int X86_INS_VMCLEAR = 1012;
	public static final int X86_INS_VMFUNC = 1013;
	public static final int X86_INS_VMINPD = 1014;
	public static final int X86_INS_VMINPS = 1015;
	public static final int X86_INS_VMINSD = 1016;
	public static final int X86_INS_VMINSS = 1017;
	public static final int X86_INS_VMLAUNCH = 1018;
	public static final int X86_INS_VMLOAD = 1019;
	public static final int X86_INS_VMMCALL = 1020;
	public static final int X86_INS_VMOVQ = 1021;
	public static final int X86_INS_VMOVAPD = 1022;
	public static final int X86_INS_VMOVAPS = 1023;
	public static final int X86_INS_VMOVDDUP = 1024;
	public static final int X86_INS_VMOVD = 1025;
	public static final int X86_INS_VMOVDQA32 = 1026;
	public static final int X86_INS_VMOVDQA64 = 1027;
	public static final int X86_INS_VMOVDQA = 1028;
	public static final int X86_INS_VMOVDQU16 = 1029;
	public static final int X86_INS_VMOVDQU32 = 1030;
	public static final int X86_INS_VMOVDQU64 = 1031;
	public static final int X86_INS_VMOVDQU8 = 1032;
	public static final int X86_INS_VMOVDQU = 1033;
	public static final int X86_INS_VMOVHLPS = 1034;
	public static final int X86_INS_VMOVHPD = 1035;
	public static final int X86_INS_VMOVHPS = 1036;
	public static final int X86_INS_VMOVLHPS = 1037;
	public static final int X86_INS_VMOVLPD = 1038;
	public static final int X86_INS_VMOVLPS = 1039;
	public static final int X86_INS_VMOVMSKPD = 1040;
	public static final int X86_INS_VMOVMSKPS = 1041;
	public static final int X86_INS_VMOVNTDQA = 1042;
	public static final int X86_INS_VMOVNTDQ = 1043;
	public static final int X86_INS_VMOVNTPD = 1044;
	public static final int X86_INS_VMOVNTPS = 1045;
	public static final int X86_INS_VMOVSD = 1046;
	public static final int X86_INS_VMOVSHDUP = 1047;
	public static final int X86_INS_VMOVSLDUP = 1048;
	public static final int X86_INS_VMOVSS = 1049;
	public static final int X86_INS_VMOVUPD = 1050;
	public static final int X86_INS_VMOVUPS = 1051;
	public static final int X86_INS_VMPSADBW = 1052;
	public static final int X86_INS_VMPTRLD = 1053;
	public static final int X86_INS_VMPTRST = 1054;
	public static final int X86_INS_VMREAD = 1055;
	public static final int X86_INS_VMRESUME = 1056;
	public static final int X86_INS_VMRUN = 1057;
	public static final int X86_INS_VMSAVE = 1058;
	public static final int X86_INS_VMULPD = 1059;
	public static final int X86_INS_VMULPS = 1060;
	public static final int X86_INS_VMULSD = 1061;
	public static final int X86_INS_VMULSS = 1062;
	public static final int X86_INS_VMWRITE = 1063;
	public static final int X86_INS_VMXOFF = 1064;
	public static final int X86_INS_VMXON = 1065;
	public static final int X86_INS_VORPD = 1066;
	public static final int X86_INS_VORPS = 1067;
	public static final int X86_INS_VP4DPWSSDS = 1068;
	public static final int X86_INS_VP4DPWSSD = 1069;
	public static final int X86_INS_VPABSB = 1070;
	public static final int X86_INS_VPABSD = 1071;
	public static final int X86_INS_VPABSQ = 1072;
	public static final int X86_INS_VPABSW = 1073;
	public static final int X86_INS_VPACKSSDW = 1074;
	public static final int X86_INS_VPACKSSWB = 1075;
	public static final int X86_INS_VPACKUSDW = 1076;
	public static final int X86_INS_VPACKUSWB = 1077;
	public static final int X86_INS_VPADDB = 1078;
	public static final int X86_INS_VPADDD = 1079;
	public static final int X86_INS_VPADDQ = 1080;
	public static final int X86_INS_VPADDSB = 1081;
	public static final int X86_INS_VPADDSW = 1082;
	public static final int X86_INS_VPADDUSB = 1083;
	public static final int X86_INS_VPADDUSW = 1084;
	public static final int X86_INS_VPADDW = 1085;
	public static final int X86_INS_VPALIGNR = 1086;
	public static final int X86_INS_VPANDD = 1087;
	public static final int X86_INS_VPANDND = 1088;
	public static final int X86_INS_VPANDNQ = 1089;
	public static final int X86_INS_VPANDN = 1090;
	public static final int X86_INS_VPANDQ = 1091;
	public static final int X86_INS_VPAND = 1092;
	public static final int X86_INS_VPAVGB = 1093;
	public static final int X86_INS_VPAVGW = 1094;
	public static final int X86_INS_VPBLENDD = 1095;
	public static final int X86_INS_VPBLENDMB = 1096;
	public static final int X86_INS_VPBLENDMD = 1097;
	public static final int X86_INS_VPBLENDMQ = 1098;
	public static final int X86_INS_VPBLENDMW = 1099;
	public static final int X86_INS_VPBLENDVB = 1100;
	public static final int X86_INS_VPBLENDW = 1101;
	public static final int X86_INS_VPBROADCASTB = 1102;
	public static final int X86_INS_VPBROADCASTD = 1103;
	public static final int X86_INS_VPBROADCASTMB2Q = 1104;
	public static final int X86_INS_VPBROADCASTMW2D = 1105;
	public static final int X86_INS_VPBROADCASTQ = 1106;
	public static final int X86_INS_VPBROADCASTW = 1107;
	public static final int X86_INS_VPCLMULQDQ = 1108;
	public static final int X86_INS_VPCMOV = 1109;
	public static final int X86_INS_VPCMP = 1110;
	public static final int X86_INS_VPCMPB = 1111;
	public static final int X86_INS_VPCMPD = 1112;
	public static final int X86_INS_VPCMPEQB = 1113;
	public static final int X86_INS_VPCMPEQD = 1114;
	public static final int X86_INS_VPCMPEQQ = 1115;
	public static final int X86_INS_VPCMPEQW = 1116;
	public static final int X86_INS_VPCMPESTRI = 1117;
	public static final int X86_INS_VPCMPESTRM = 1118;
	public static final int X86_INS_VPCMPGTB = 1119;
	public static final int X86_INS_VPCMPGTD = 1120;
	public static final int X86_INS_VPCMPGTQ = 1121;
	public static final int X86_INS_VPCMPGTW = 1122;
	public static final int X86_INS_VPCMPISTRI = 1123;
	public static final int X86_INS_VPCMPISTRM = 1124;
	public static final int X86_INS_VPCMPQ = 1125;
	public static final int X86_INS_VPCMPUB = 1126;
	public static final int X86_INS_VPCMPUD = 1127;
	public static final int X86_INS_VPCMPUQ = 1128;
	public static final int X86_INS_VPCMPUW = 1129;
	public static final int X86_INS_VPCMPW = 1130;
	public static final int X86_INS_VPCOM = 1131;
	public static final int X86_INS_VPCOMB = 1132;
	public static final int X86_INS_VPCOMD = 1133;
	public static final int X86_INS_VPCOMPRESSB = 1134;
	public static final int X86_INS_VPCOMPRESSD = 1135;
	public static final int X86_INS_VPCOMPRESSQ = 1136;
	public static final int X86_INS_VPCOMPRESSW = 1137;
	public static final int X86_INS_VPCOMQ = 1138;
	public static final int X86_INS_VPCOMUB = 1139;
	public static final int X86_INS_VPCOMUD = 1140;
	public static final int X86_INS_VPCOMUQ = 1141;
	public static final int X86_INS_VPCOMUW = 1142;
	public static final int X86_INS_VPCOMW = 1143;
	public static final int X86_INS_VPCONFLICTD = 1144;
	public static final int X86_INS_VPCONFLICTQ = 1145;
	public static final int X86_INS_VPDPBUSDS = 1146;
	public static final int X86_INS_VPDPBUSD = 1147;
	public static final int X86_INS_VPDPWSSDS = 1148;
	public static final int X86_INS_VPDPWSSD = 1149;
	public static final int X86_INS_VPERM2F128 = 1150;
	public static final int X86_INS_VPERM2I128 = 1151;
	public static final int X86_INS_VPERMB = 1152;
	public static final int X86_INS_VPERMD = 1153;
	public static final int X86_INS_VPERMI2B = 1154;
	public static final int X86_INS_VPERMI2D = 1155;
	public static final int X86_INS_VPERMI2PD = 1156;
	public static final int X86_INS_VPERMI2PS = 1157;
	public static final int X86_INS_VPERMI2Q = 1158;
	public static final int X86_INS_VPERMI2W = 1159;
	public static final int X86_INS_VPERMIL2PD = 1160;
	public static final int X86_INS_VPERMILPD = 1161;
	public static final int X86_INS_VPERMIL2PS = 1162;
	public static final int X86_INS_VPERMILPS = 1163;
	public static final int X86_INS_VPERMPD = 1164;
	public static final int X86_INS_VPERMPS = 1165;
	public static final int X86_INS_VPERMQ = 1166;
	public static final int X86_INS_VPERMT2B = 1167;
	public static final int X86_INS_VPERMT2D = 1168;
	public static final int X86_INS_VPERMT2PD = 1169;
	public static final int X86_INS_VPERMT2PS = 1170;
	public static final int X86_INS_VPERMT2Q = 1171;
	public static final int X86_INS_VPERMT2W = 1172;
	public static final int X86_INS_VPERMW = 1173;
	public static final int X86_INS_VPEXPANDB = 1174;
	public static final int X86_INS_VPEXPANDD = 1175;
	public static final int X86_INS_VPEXPANDQ = 1176;
	public static final int X86_INS_VPEXPANDW = 1177;
	public static final int X86_INS_VPEXTRB = 1178;
	public static final int X86_INS_VPEXTRD = 1179;
	public static final int X86_INS_VPEXTRQ = 1180;
	public static final int X86_INS_VPEXTRW = 1181;
	public static final int X86_INS_VPGATHERDD = 1182;
	public static final int X86_INS_VPGATHERDQ = 1183;
	public static final int X86_INS_VPGATHERQD = 1184;
	public static final int X86_INS_VPGATHERQQ = 1185;
	public static final int X86_INS_VPHADDBD = 1186;
	public static final int X86_INS_VPHADDBQ = 1187;
	public static final int X86_INS_VPHADDBW = 1188;
	public static final int X86_INS_VPHADDDQ = 1189;
	public static final int X86_INS_VPHADDD = 1190;
	public static final int X86_INS_VPHADDSW = 1191;
	public static final int X86_INS_VPHADDUBD = 1192;
	public static final int X86_INS_VPHADDUBQ = 1193;
	public static final int X86_INS_VPHADDUBW = 1194;
	public static final int X86_INS_VPHADDUDQ = 1195;
	public static final int X86_INS_VPHADDUWD = 1196;
	public static final int X86_INS_VPHADDUWQ = 1197;
	public static final int X86_INS_VPHADDWD = 1198;
	public static final int X86_INS_VPHADDWQ = 1199;
	public static final int X86_INS_VPHADDW = 1200;
	public static final int X86_INS_VPHMINPOSUW = 1201;
	public static final int X86_INS_VPHSUBBW = 1202;
	public static final int X86_INS_VPHSUBDQ = 1203;
	public static final int X86_INS_VPHSUBD = 1204;
	public static final int X86_INS_VPHSUBSW = 1205;
	public static final int X86_INS_VPHSUBWD = 1206;
	public static final int X86_INS_VPHSUBW = 1207;
	public static final int X86_INS_VPINSRB = 1208;
	public static final int X86_INS_VPINSRD = 1209;
	public static final int X86_INS_VPINSRQ = 1210;
	public static final int X86_INS_VPINSRW = 1211;
	public static final int X86_INS_VPLZCNTD = 1212;
	public static final int X86_INS_VPLZCNTQ = 1213;
	public static final int X86_INS_VPMACSDD = 1214;
	public static final int X86_INS_VPMACSDQH = 1215;
	public static final int X86_INS_VPMACSDQL = 1216;
	public static final int X86_INS_VPMACSSDD = 1217;
	public static final int X86_INS_VPMACSSDQH = 1218;
	public static final int X86_INS_VPMACSSDQL = 1219;
	public static final int X86_INS_VPMACSSWD = 1220;
	public static final int X86_INS_VPMACSSWW = 1221;
	public static final int X86_INS_VPMACSWD = 1222;
	public static final int X86_INS_VPMACSWW = 1223;
	public static final int X86_INS_VPMADCSSWD = 1224;
	public static final int X86_INS_VPMADCSWD = 1225;
	public static final int X86_INS_VPMADD52HUQ = 1226;
	public static final int X86_INS_VPMADD52LUQ = 1227;
	public static final int X86_INS_VPMADDUBSW = 1228;
	public static final int X86_INS_VPMADDWD = 1229;
	public static final int X86_INS_VPMASKMOVD = 1230;
	public static final int X86_INS_VPMASKMOVQ = 1231;
	public static final int X86_INS_VPMAXSB = 1232;
	public static final int X86_INS_VPMAXSD = 1233;
	public static final int X86_INS_VPMAXSQ = 1234;
	public static final int X86_INS_VPMAXSW = 1235;
	public static final int X86_INS_VPMAXUB = 1236;
	public static final int X86_INS_VPMAXUD = 1237;
	public static final int X86_INS_VPMAXUQ = 1238;
	public static final int X86_INS_VPMAXUW = 1239;
	public static final int X86_INS_VPMINSB = 1240;
	public static final int X86_INS_VPMINSD = 1241;
	public static final int X86_INS_VPMINSQ = 1242;
	public static final int X86_INS_VPMINSW = 1243;
	public static final int X86_INS_VPMINUB = 1244;
	public static final int X86_INS_VPMINUD = 1245;
	public static final int X86_INS_VPMINUQ = 1246;
	public static final int X86_INS_VPMINUW = 1247;
	public static final int X86_INS_VPMOVB2M = 1248;
	public static final int X86_INS_VPMOVD2M = 1249;
	public static final int X86_INS_VPMOVDB = 1250;
	public static final int X86_INS_VPMOVDW = 1251;
	public static final int X86_INS_VPMOVM2B = 1252;
	public static final int X86_INS_VPMOVM2D = 1253;
	public static final int X86_INS_VPMOVM2Q = 1254;
	public static final int X86_INS_VPMOVM2W = 1255;
	public static final int X86_INS_VPMOVMSKB = 1256;
	public static final int X86_INS_VPMOVQ2M = 1257;
	public static final int X86_INS_VPMOVQB = 1258;
	public static final int X86_INS_VPMOVQD = 1259;
	public static final int X86_INS_VPMOVQW = 1260;
	public static final int X86_INS_VPMOVSDB = 1261;
	public static final int X86_INS_VPMOVSDW = 1262;
	public static final int X86_INS_VPMOVSQB = 1263;
	public static final int X86_INS_VPMOVSQD = 1264;
	public static final int X86_INS_VPMOVSQW = 1265;
	public static final int X86_INS_VPMOVSWB = 1266;
	public static final int X86_INS_VPMOVSXBD = 1267;
	public static final int X86_INS_VPMOVSXBQ = 1268;
	public static final int X86_INS_VPMOVSXBW = 1269;
	public static final int X86_INS_VPMOVSXDQ = 1270;
	public static final int X86_INS_VPMOVSXWD = 1271;
	public static final int X86_INS_VPMOVSXWQ = 1272;
	public static final int X86_INS_VPMOVUSDB = 1273;
	public static final int X86_INS_VPMOVUSDW = 1274;
	public static final int X86_INS_VPMOVUSQB = 1275;
	public static final int X86_INS_VPMOVUSQD = 1276;
	public static final int X86_INS_VPMOVUSQW = 1277;
	public static final int X86_INS_VPMOVUSWB = 1278;
	public static final int X86_INS_VPMOVW2M = 1279;
	public static final int X86_INS_VPMOVWB = 1280;
	public static final int X86_INS_VPMOVZXBD = 1281;
	public static final int X86_INS_VPMOVZXBQ = 1282;
	public static final int X86_INS_VPMOVZXBW = 1283;
	public static final int X86_INS_VPMOVZXDQ = 1284;
	public static final int X86_INS_VPMOVZXWD = 1285;
	public static final int X86_INS_VPMOVZXWQ = 1286;
	public static final int X86_INS_VPMULDQ = 1287;
	public static final int X86_INS_VPMULHRSW = 1288;
	public static final int X86_INS_VPMULHUW = 1289;
	public static final int X86_INS_VPMULHW = 1290;
	public static final int X86_INS_VPMULLD = 1291;
	public static final int X86_INS_VPMULLQ = 1292;
	public static final int X86_INS_VPMULLW = 1293;
	public static final int X86_INS_VPMULTISHIFTQB = 1294;
	public static final int X86_INS_VPMULUDQ = 1295;
	public static final int X86_INS_VPOPCNTB = 1296;
	public static final int X86_INS_VPOPCNTD = 1297;
	public static final int X86_INS_VPOPCNTQ = 1298;
	public static final int X86_INS_VPOPCNTW = 1299;
	public static final int X86_INS_VPORD = 1300;
	public static final int X86_INS_VPORQ = 1301;
	public static final int X86_INS_VPOR = 1302;
	public static final int X86_INS_VPPERM = 1303;
	public static final int X86_INS_VPROLD = 1304;
	public static final int X86_INS_VPROLQ = 1305;
	public static final int X86_INS_VPROLVD = 1306;
	public static final int X86_INS_VPROLVQ = 1307;
	public static final int X86_INS_VPRORD = 1308;
	public static final int X86_INS_VPRORQ = 1309;
	public static final int X86_INS_VPRORVD = 1310;
	public static final int X86_INS_VPRORVQ = 1311;
	public static final int X86_INS_VPROTB = 1312;
	public static final int X86_INS_VPROTD = 1313;
	public static final int X86_INS_VPROTQ = 1314;
	public static final int X86_INS_VPROTW = 1315;
	public static final int X86_INS_VPSADBW = 1316;
	public static final int X86_INS_VPSCATTERDD = 1317;
	public static final int X86_INS_VPSCATTERDQ = 1318;
	public static final int X86_INS_VPSCATTERQD = 1319;
	public static final int X86_INS_VPSCATTERQQ = 1320;
	public static final int X86_INS_VPSHAB = 1321;
	public static final int X86_INS_VPSHAD = 1322;
	public static final int X86_INS_VPSHAQ = 1323;
	public static final int X86_INS_VPSHAW = 1324;
	public static final int X86_INS_VPSHLB = 1325;
	public static final int X86_INS_VPSHLDD = 1326;
	public static final int X86_INS_VPSHLDQ = 1327;
	public static final int X86_INS_VPSHLDVD = 1328;
	public static final int X86_INS_VPSHLDVQ = 1329;
	public static final int X86_INS_VPSHLDVW = 1330;
	public static final int X86_INS_VPSHLDW = 1331;
	public static final int X86_INS_VPSHLD = 1332;
	public static final int X86_INS_VPSHLQ = 1333;
	public static final int X86_INS_VPSHLW = 1334;
	public static final int X86_INS_VPSHRDD = 1335;
	public static final int X86_INS_VPSHRDQ = 1336;
	public static final int X86_INS_VPSHRDVD = 1337;
	public static final int X86_INS_VPSHRDVQ = 1338;
	public static final int X86_INS_VPSHRDVW = 1339;
	public static final int X86_INS_VPSHRDW = 1340;
	public static final int X86_INS_VPSHUFBITQMB = 1341;
	public static final int X86_INS_VPSHUFB = 1342;
	public static final int X86_INS_VPSHUFD = 1343;
	public static final int X86_INS_VPSHUFHW = 1344;
	public static final int X86_INS_VPSHUFLW = 1345;
	public static final int X86_INS_VPSIGNB = 1346;
	public static final int X86_INS_VPSIGND = 1347;
	public static final int X86_INS_VPSIGNW = 1348;
	public static final int X86_INS_VPSLLDQ = 1349;
	public static final int X86_INS_VPSLLD = 1350;
	public static final int X86_INS_VPSLLQ = 1351;
	public static final int X86_INS_VPSLLVD = 1352;
	public static final int X86_INS_VPSLLVQ = 1353;
	public static final int X86_INS_VPSLLVW = 1354;
	public static final int X86_INS_VPSLLW = 1355;
	public static final int X86_INS_VPSRAD = 1356;
	public static final int X86_INS_VPSRAQ = 1357;
	public static final int X86_INS_VPSRAVD = 1358;
	public static final int X86_INS_VPSRAVQ = 1359;
	public static final int X86_INS_VPSRAVW = 1360;
	public static final int X86_INS_VPSRAW = 1361;
	public static final int X86_INS_VPSRLDQ = 1362;
	public static final int X86_INS_VPSRLD = 1363;
	public static final int X86_INS_VPSRLQ = 1364;
	public static final int X86_INS_VPSRLVD = 1365;
	public static final int X86_INS_VPSRLVQ = 1366;
	public static final int X86_INS_VPSRLVW = 1367;
	public static final int X86_INS_VPSRLW = 1368;
	public static final int X86_INS_VPSUBB = 1369;
	public static final int X86_INS_VPSUBD = 1370;
	public static final int X86_INS_VPSUBQ = 1371;
	public static final int X86_INS_VPSUBSB = 1372;
	public static final int X86_INS_VPSUBSW = 1373;
	public static final int X86_INS_VPSUBUSB = 1374;
	public static final int X86_INS_VPSUBUSW = 1375;
	public static final int X86_INS_VPSUBW = 1376;
	public static final int X86_INS_VPTERNLOGD = 1377;
	public static final int X86_INS_VPTERNLOGQ = 1378;
	public static final int X86_INS_VPTESTMB = 1379;
	public static final int X86_INS_VPTESTMD = 1380;
	public static final int X86_INS_VPTESTMQ = 1381;
	public static final int X86_INS_VPTESTMW = 1382;
	public static final int X86_INS_VPTESTNMB = 1383;
	public static final int X86_INS_VPTESTNMD = 1384;
	public static final int X86_INS_VPTESTNMQ = 1385;
	public static final int X86_INS_VPTESTNMW = 1386;
	public static final int X86_INS_VPTEST = 1387;
	public static final int X86_INS_VPUNPCKHBW = 1388;
	public static final int X86_INS_VPUNPCKHDQ = 1389;
	public static final int X86_INS_VPUNPCKHQDQ = 1390;
	public static final int X86_INS_VPUNPCKHWD = 1391;
	public static final int X86_INS_VPUNPCKLBW = 1392;
	public static final int X86_INS_VPUNPCKLDQ = 1393;
	public static final int X86_INS_VPUNPCKLQDQ = 1394;
	public static final int X86_INS_VPUNPCKLWD = 1395;
	public static final int X86_INS_VPXORD = 1396;
	public static final int X86_INS_VPXORQ = 1397;
	public static final int X86_INS_VPXOR = 1398;
	public static final int X86_INS_VRANGEPD = 1399;
	public static final int X86_INS_VRANGEPS = 1400;
	public static final int X86_INS_VRANGESD = 1401;
	public static final int X86_INS_VRANGESS = 1402;
	public static final int X86_INS_VRCP14PD = 1403;
	public static final int X86_INS_VRCP14PS = 1404;
	public static final int X86_INS_VRCP14SD = 1405;
	public static final int X86_INS_VRCP14SS = 1406;
	public static final int X86_INS_VRCP28PD = 1407;
	public static final int X86_INS_VRCP28PS = 1408;
	public static final int X86_INS_VRCP28SD = 1409;
	public static final int X86_INS_VRCP28SS = 1410;
	public static final int X86_INS_VRCPPS = 1411;
	public static final int X86_INS_VRCPSS = 1412;
	public static final int X86_INS_VREDUCEPD = 1413;
	public static final int X86_INS_VREDUCEPS = 1414;
	public static final int X86_INS_VREDUCESD = 1415;
	public static final int X86_INS_VREDUCESS = 1416;
	public static final int X86_INS_VRNDSCALEPD = 1417;
	public static final int X86_INS_VRNDSCALEPS = 1418;
	public static final int X86_INS_VRNDSCALESD = 1419;
	public static final int X86_INS_VRNDSCALESS = 1420;
	public static final int X86_INS_VROUNDPD = 1421;
	public static final int X86_INS_VROUNDPS = 1422;
	public static final int X86_INS_VROUNDSD = 1423;
	public static final int X86_INS_VROUNDSS = 1424;
	public static final int X86_INS_VRSQRT14PD = 1425;
	public static final int X86_INS_VRSQRT14PS = 1426;
	public static final int X86_INS_VRSQRT14SD = 1427;
	public static final int X86_INS_VRSQRT14SS = 1428;
	public static final int X86_INS_VRSQRT28PD = 1429;
	public static final int X86_INS_VRSQRT28PS = 1430;
	public static final int X86_INS_VRSQRT28SD = 1431;
	public static final int X86_INS_VRSQRT28SS = 1432;
	public static final int X86_INS_VRSQRTPS = 1433;
	public static final int X86_INS_VRSQRTSS = 1434;
	public static final int X86_INS_VSCALEFPD = 1435;
	public static final int X86_INS_VSCALEFPS = 1436;
	public static final int X86_INS_VSCALEFSD = 1437;
	public static final int X86_INS_VSCALEFSS = 1438;
	public static final int X86_INS_VSCATTERDPD = 1439;
	public static final int X86_INS_VSCATTERDPS = 1440;
	public static final int X86_INS_VSCATTERPF0DPD = 1441;
	public static final int X86_INS_VSCATTERPF0DPS = 1442;
	public static final int X86_INS_VSCATTERPF0QPD = 1443;
	public static final int X86_INS_VSCATTERPF0QPS = 1444;
	public static final int X86_INS_VSCATTERPF1DPD = 1445;
	public static final int X86_INS_VSCATTERPF1DPS = 1446;
	public static final int X86_INS_VSCATTERPF1QPD = 1447;
	public static final int X86_INS_VSCATTERPF1QPS = 1448;
	public static final int X86_INS_VSCATTERQPD = 1449;
	public static final int X86_INS_VSCATTERQPS = 1450;
	public static final int X86_INS_VSHUFF32X4 = 1451;
	public static final int X86_INS_VSHUFF64X2 = 1452;
	public static final int X86_INS_VSHUFI32X4 = 1453;
	public static final int X86_INS_VSHUFI64X2 = 1454;
	public static final int X86_INS_VSHUFPD = 1455;
	public static final int X86_INS_VSHUFPS = 1456;
	public static final int X86_INS_VSQRTPD = 1457;
	public static final int X86_INS_VSQRTPS = 1458;
	public static final int X86_INS_VSQRTSD = 1459;
	public static final int X86_INS_VSQRTSS = 1460;
	public static final int X86_INS_VSTMXCSR = 1461;
	public static final int X86_INS_VSUBPD = 1462;
	public static final int X86_INS_VSUBPS = 1463;
	public static final int X86_INS_VSUBSD = 1464;
	public static final int X86_INS_VSUBSS = 1465;
	public static final int X86_INS_VTESTPD = 1466;
	public static final int X86_INS_VTESTPS = 1467;
	public static final int X86_INS_VUCOMISD = 1468;
	public static final int X86_INS_VUCOMISS = 1469;
	public static final int X86_INS_VUNPCKHPD = 1470;
	public static final int X86_INS_VUNPCKHPS = 1471;
	public static final int X86_INS_VUNPCKLPD = 1472;
	public static final int X86_INS_VUNPCKLPS = 1473;
	public static final int X86_INS_VXORPD = 1474;
	public static final int X86_INS_VXORPS = 1475;
	public static final int X86_INS_VZEROALL = 1476;
	public static final int X86_INS_VZEROUPPER = 1477;
	public static final int X86_INS_WAIT = 1478;
	public static final int X86_INS_WBINVD = 1479;
	public static final int X86_INS_WBNOINVD = 1480;
	public static final int X86_INS_WRFSBASE = 1481;
	public static final int X86_INS_WRGSBASE = 1482;
	public static final int X86_INS_WRMSR = 1483;
	public static final int X86_INS_WRPKRU = 1484;
	public static final int X86_INS_WRSSD = 1485;
	public static final int X86_INS_WRSSQ = 1486;
	public static final int X86_INS_WRUSSD = 1487;
	public static final int X86_INS_WRUSSQ = 1488;
	public static final int X86_INS_XABORT = 1489;
	public static final int X86_INS_XACQUIRE = 1490;
	public static final int X86_INS_XADD = 1491;
	public static final int X86_INS_XBEGIN = 1492;
	public static final int X86_INS_XCHG = 1493;
	public static final int X86_INS_FXCH = 1494;
	public static final int X86_INS_XCRYPTCBC = 1495;
	public static final int X86_INS_XCRYPTCFB = 1496;
	public static final int X86_INS_XCRYPTCTR = 1497;
	public static final int X86_INS_XCRYPTECB = 1498;
	public static final int X86_INS_XCRYPTOFB = 1499;
	public static final int X86_INS_XEND = 1500;
	public static final int X86_INS_XGETBV = 1501;
	public static final int X86_INS_XLATB = 1502;
	public static final int X86_INS_XOR = 1503;
	public static final int X86_INS_XORPD = 1504;
	public static final int X86_INS_XORPS = 1505;
	public static final int X86_INS_XRELEASE = 1506;
	public static final int X86_INS_XRSTOR = 1507;
	public static final int X86_INS_XRSTOR64 = 1508;
	public static final int X86_INS_XRSTORS = 1509;
	public static final int X86_INS_XRSTORS64 = 1510;
	public static final int X86_INS_XSAVE = 1511;
	public static final int X86_INS_XSAVE64 = 1512;
	public static final int X86_INS_XSAVEC = 1513;
	public static final int X86_INS_XSAVEC64 = 1514;
	public static final int X86_INS_XSAVEOPT = 1515;
	public static final int X86_INS_XSAVEOPT64 = 1516;
	public static final int X86_INS_XSAVES = 1517;
	public static final int X86_INS_XSAVES64 = 1518;
	public static final int X86_INS_XSETBV = 1519;
	public static final int X86_INS_XSHA1 = 1520;
	public static final int X86_INS_XSHA256 = 1521;
	public static final int X86_INS_XSTORE = 1522;
	public static final int X86_INS_XTEST = 1523;
	public static final int X86_INS_ENDING = 1524;

	public static final int X86_GRP_INVALID = 0;
	public static final int X86_GRP_JUMP = 1;
	public static final int X86_GRP_CALL = 2;
	public static final int X86_GRP_RET = 3;
	public static final int X86_GRP_INT = 4;
	public static final int X86_GRP_IRET = 5;
	public static final int X86_GRP_PRIVILEGE = 6;
	public static final int X86_GRP_BRANCH_RELATIVE = 7;
	public static final int X86_GRP_VM = 128;
	public static final int X86_GRP_3DNOW = 129;
	public static final int X86_GRP_AES = 130;
	public static final int X86_GRP_ADX = 131;
	public static final int X86_GRP_AVX = 132;
	public static final int X86_GRP_AVX2 = 133;
	public static final int X86_GRP_AVX512 = 134;
	public static final int X86_GRP_BMI = 135;
	public static final int X86_GRP_BMI2 = 136;
	public static final int X86_GRP_CMOV = 137;
	public static final int X86_GRP_F16C = 138;
	public static final int X86_GRP_FMA = 139;
	public static final int X86_GRP_FMA4 = 140;
	public static final int X86_GRP_FSGSBASE = 141;
	public static final int X86_GRP_HLE = 142;
	public static final int X86_GRP_MMX = 143;
	public static final int X86_GRP_MODE32 = 144;
	public static final int X86_GRP_MODE64 = 145;
	public static final int X86_GRP_RTM = 146;
	public static final int X86_GRP_SHA = 147;
	public static final int X86_GRP_SSE1 = 148;
	public static final int X86_GRP_SSE2 = 149;
	public static final int X86_GRP_SSE3 = 150;
	public static final int X86_GRP_SSE41 = 151;
	public static final int X86_GRP_SSE42 = 152;
	public static final int X86_GRP_SSE4A = 153;
	public static final int X86_GRP_SSSE3 = 154;
	public static final int X86_GRP_PCLMUL = 155;
	public static final int X86_GRP_XOP = 156;
	public static final int X86_GRP_CDI = 157;
	public static final int X86_GRP_ERI = 158;
	public static final int X86_GRP_TBM = 159;
	public static final int X86_GRP_16BITMODE = 160;
	public static final int X86_GRP_NOT64BITMODE = 161;
	public static final int X86_GRP_SGX = 162;
	public static final int X86_GRP_DQI = 163;
	public static final int X86_GRP_BWI = 164;
	public static final int X86_GRP_PFI = 165;
	public static final int X86_GRP_VLX = 166;
	public static final int X86_GRP_SMAP = 167;
	public static final int X86_GRP_NOVLX = 168;
	public static final int X86_GRP_FPU = 169;
	public static final int X86_GRP_ENDING = 170;
}