# CS_ARCH_ARM, CS_MODE_ARM+CS_MODE_V8, None
0x59,0xf0,0x7f,0xf5 = dmb ishld
0x51,0xf0,0x7f,0xf5 = dmb oshld
0x55,0xf0,0x7f,0xf5 = dmb nshld
0x5d,0xf0,0x7f,0xf5 = dmb ld
0x49,0xf0,0x7f,0xf5 = dsb ishld
0x41,0xf0,0x7f,0xf5 = dsb oshld
0x45,0xf0,0x7f,0xf5 = dsb nshld
0x4d,0xf0,0x7f,0xf5 = dsb ld
0x05,0xf0,0x20,0xe3 = sevl 
