
/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

/*===- TableGen'erated file -------------------------------------*- C++ -*-===*|*                                                                            *|
|* Subtarget Enumeration Source Fragment                                      *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/


enum {
  PPC_DeprecatedDST = 0,
  PPC_Directive32 = 1,
  PPC_Directive64 = 2,
  PPC_Directive440 = 3,
  PPC_Directive601 = 4,
  PPC_Directive602 = 5,
  PPC_Directive603 = 6,
  PPC_Directive604 = 7,
  PPC_Directive620 = 8,
  PPC_Directive750 = 9,
  PPC_Directive970 = 10,
  PPC_Directive7400 = 11,
  PPC_DirectiveA2 = 12,
  PPC_DirectiveE500 = 13,
  PPC_DirectiveE500mc = 14,
  PPC_DirectiveE5500 = 15,
  PPC_DirectivePwr3 = 16,
  PPC_DirectivePwr4 = 17,
  PPC_DirectivePwr5 = 18,
  PPC_DirectivePwr5x = 19,
  PPC_DirectivePwr6 = 20,
  PPC_DirectivePwr6x = 21,
  PPC_DirectivePwr7 = 22,
  PPC_DirectivePwr8 = 23,
  PPC_DirectivePwr9 = 24,
  PPC_Feature64Bit = 25,
  PPC_Feature64BitRegs = 26,
  PPC_FeatureAltivec = 27,
  PPC_FeatureBPERMD = 28,
  PPC_FeatureBookE = 29,
  PPC_FeatureCMPB = 30,
  PPC_FeatureCRBits = 31,
  PPC_FeatureDirectMove = 32,
  PPC_FeatureE500 = 33,
  PPC_FeatureExtDiv = 34,
  PPC_FeatureFCPSGN = 35,
  PPC_FeatureFPCVT = 36,
  PPC_FeatureFPRND = 37,
  PPC_FeatureFPU = 38,
  PPC_FeatureFRE = 39,
  PPC_FeatureFRES = 40,
  PPC_FeatureFRSQRTE = 41,
  PPC_FeatureFRSQRTES = 42,
  PPC_FeatureFSqrt = 43,
  PPC_FeatureFloat128 = 44,
  PPC_FeatureFusion = 45,
  PPC_FeatureHTM = 46,
  PPC_FeatureHardFloat = 47,
  PPC_FeatureICBT = 48,
  PPC_FeatureISA3_0 = 49,
  PPC_FeatureISEL = 50,
  PPC_FeatureInvariantFunctionDescriptors = 51,
  PPC_FeatureLDBRX = 52,
  PPC_FeatureLFIWAX = 53,
  PPC_FeatureLongCall = 54,
  PPC_FeatureMFOCRF = 55,
  PPC_FeatureMFTB = 56,
  PPC_FeatureMSYNC = 57,
  PPC_FeatureP8Altivec = 58,
  PPC_FeatureP8Crypto = 59,
  PPC_FeatureP8Vector = 60,
  PPC_FeatureP9Altivec = 61,
  PPC_FeatureP9Vector = 62,
  PPC_FeaturePOPCNTD = 63,
  PPC_FeaturePPC4xx = 64,
  PPC_FeaturePPC6xx = 65,
  PPC_FeaturePS = 66,
  PPC_FeaturePartwordAtomic = 67,
  PPC_FeatureQPX = 68,
  PPC_FeatureRecipPrec = 69,
  PPC_FeatureSPE = 70,
  PPC_FeatureSTFIWX = 71,
  PPC_FeatureSecurePlt = 72,
  PPC_FeatureSlowPOPCNTD = 73,
  PPC_FeatureVSX = 74,
};

