/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* This is auto-gen data for Capstone disassembly engine (www.capstone-engine.org) */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

	"add", // PPC_INS_ADD,
	"addc", // PPC_INS_ADDC,
	"adde", // PPC_INS_ADDE,
	"addi", // PPC_INS_ADDI,
	"addic", // PPC_INS_ADDIC,
	"addis", // PPC_INS_ADDIS,
	"addme", // PPC_INS_ADDME,
	"addpcis", // PPC_INS_ADDPCIS,
	"addze", // PPC_INS_ADDZE,
	"and", // PPC_INS_AND,
	"andc", // PPC_INS_ANDC,
	"andi", // PPC_INS_ANDI,
	"andis", // PPC_INS_ANDIS,
	"attn", // PPC_INS_ATTN,
	"b", // PPC_INS_B,
	"ba", // PPC_INS_BA,
	"bc", // PPC_INS_BC,
	"bca", // PPC_INS_BCA,
	"bcctr", // PPC_INS_BCCTR,
	"bcctrl", // PPC_INS_BCCTRL,
	"bcdcfn", // PPC_INS_BCDCFN,
	"bcdcfsq", // PPC_INS_BCDCFSQ,
	"bcdcfz", // PPC_INS_BCDCFZ,
	"bcdcpsgn", // PPC_INS_BCDCPSGN,
	"bcdctn", // PPC_INS_BCDCTN,
	"bcdctsq", // PPC_INS_BCDCTSQ,
	"bcdctz", // PPC_INS_BCDCTZ,
	"bcds", // PPC_INS_BCDS,
	"bcdsetsgn", // PPC_INS_BCDSETSGN,
	"bcdsr", // PPC_INS_BCDSR,
	"bcdtrunc", // PPC_INS_BCDTRUNC,
	"bcdus", // PPC_INS_BCDUS,
	"bcdutrunc", // PPC_INS_BCDUTRUNC,
	"bcl", // PPC_INS_BCL,
	"bcla", // PPC_INS_BCLA,
	"bclr", // PPC_INS_BCLR,
	"bclrl", // PPC_INS_BCLRL,
	"bctr", // PPC_INS_BCTR,
	"bctrl", // PPC_INS_BCTRL,
	"bdnz", // PPC_INS_BDNZ,
	"bdnza", // PPC_INS_BDNZA,
	"bdnzf", // PPC_INS_BDNZF,
	"bdnzfa", // PPC_INS_BDNZFA,
	"bdnzfl", // PPC_INS_BDNZFL,
	"bdnzfla", // PPC_INS_BDNZFLA,
	"bdnzflr", // PPC_INS_BDNZFLR,
	"bdnzflrl", // PPC_INS_BDNZFLRL,
	"bdnzl", // PPC_INS_BDNZL,
	"bdnzla", // PPC_INS_BDNZLA,
	"bdnzlr", // PPC_INS_BDNZLR,
	"bdnzlrl", // PPC_INS_BDNZLRL,
	"bdnzt", // PPC_INS_BDNZT,
	"bdnzta", // PPC_INS_BDNZTA,
	"bdnztl", // PPC_INS_BDNZTL,
	"bdnztla", // PPC_INS_BDNZTLA,
	"bdnztlr", // PPC_INS_BDNZTLR,
	"bdnztlrl", // PPC_INS_BDNZTLRL,
	"bdz", // PPC_INS_BDZ,
	"bdza", // PPC_INS_BDZA,
	"bdzf", // PPC_INS_BDZF,
	"bdzfa", // PPC_INS_BDZFA,
	"bdzfl", // PPC_INS_BDZFL,
	"bdzfla", // PPC_INS_BDZFLA,
	"bdzflr", // PPC_INS_BDZFLR,
	"bdzflrl", // PPC_INS_BDZFLRL,
	"bdzl", // PPC_INS_BDZL,
	"bdzla", // PPC_INS_BDZLA,
	"bdzlr", // PPC_INS_BDZLR,
	"bdzlrl", // PPC_INS_BDZLRL,
	"bdzt", // PPC_INS_BDZT,
	"bdzta", // PPC_INS_BDZTA,
	"bdztl", // PPC_INS_BDZTL,
	"bdztla", // PPC_INS_BDZTLA,
	"bdztlr", // PPC_INS_BDZTLR,
	"bdztlrl", // PPC_INS_BDZTLRL,
	"beq", // PPC_INS_BEQ,
	"beqa", // PPC_INS_BEQA,
	"beqctr", // PPC_INS_BEQCTR,
	"beqctrl", // PPC_INS_BEQCTRL,
	"beql", // PPC_INS_BEQL,
	"beqla", // PPC_INS_BEQLA,
	"beqlr", // PPC_INS_BEQLR,
	"beqlrl", // PPC_INS_BEQLRL,
	"bf", // PPC_INS_BF,
	"bfa", // PPC_INS_BFA,
	"bfctr", // PPC_INS_BFCTR,
	"bfctrl", // PPC_INS_BFCTRL,
	"bfl", // PPC_INS_BFL,
	"bfla", // PPC_INS_BFLA,
	"bflr", // PPC_INS_BFLR,
	"bflrl", // PPC_INS_BFLRL,
	"bge", // PPC_INS_BGE,
	"bgea", // PPC_INS_BGEA,
	"bgectr", // PPC_INS_BGECTR,
	"bgectrl", // PPC_INS_BGECTRL,
	"bgel", // PPC_INS_BGEL,
	"bgela", // PPC_INS_BGELA,
	"bgelr", // PPC_INS_BGELR,
	"bgelrl", // PPC_INS_BGELRL,
	"bgt", // PPC_INS_BGT,
	"bgta", // PPC_INS_BGTA,
	"bgtctr", // PPC_INS_BGTCTR,
	"bgtctrl", // PPC_INS_BGTCTRL,
	"bgtl", // PPC_INS_BGTL,
	"bgtla", // PPC_INS_BGTLA,
	"bgtlr", // PPC_INS_BGTLR,
	"bgtlrl", // PPC_INS_BGTLRL,
	"bl", // PPC_INS_BL,
	"bla", // PPC_INS_BLA,
	"ble", // PPC_INS_BLE,
	"blea", // PPC_INS_BLEA,
	"blectr", // PPC_INS_BLECTR,
	"blectrl", // PPC_INS_BLECTRL,
	"blel", // PPC_INS_BLEL,
	"blela", // PPC_INS_BLELA,
	"blelr", // PPC_INS_BLELR,
	"blelrl", // PPC_INS_BLELRL,
	"blr", // PPC_INS_BLR,
	"blrl", // PPC_INS_BLRL,
	"blt", // PPC_INS_BLT,
	"blta", // PPC_INS_BLTA,
	"bltctr", // PPC_INS_BLTCTR,
	"bltctrl", // PPC_INS_BLTCTRL,
	"bltl", // PPC_INS_BLTL,
	"bltla", // PPC_INS_BLTLA,
	"bltlr", // PPC_INS_BLTLR,
	"bltlrl", // PPC_INS_BLTLRL,
	"bne", // PPC_INS_BNE,
	"bnea", // PPC_INS_BNEA,
	"bnectr", // PPC_INS_BNECTR,
	"bnectrl", // PPC_INS_BNECTRL,
	"bnel", // PPC_INS_BNEL,
	"bnela", // PPC_INS_BNELA,
	"bnelr", // PPC_INS_BNELR,
	"bnelrl", // PPC_INS_BNELRL,
	"bng", // PPC_INS_BNG,
	"bnga", // PPC_INS_BNGA,
	"bngctr", // PPC_INS_BNGCTR,
	"bngctrl", // PPC_INS_BNGCTRL,
	"bngl", // PPC_INS_BNGL,
	"bngla", // PPC_INS_BNGLA,
	"bnglr", // PPC_INS_BNGLR,
	"bnglrl", // PPC_INS_BNGLRL,
	"bnl", // PPC_INS_BNL,
	"bnla", // PPC_INS_BNLA,
	"bnlctr", // PPC_INS_BNLCTR,
	"bnlctrl", // PPC_INS_BNLCTRL,
	"bnll", // PPC_INS_BNLL,
	"bnlla", // PPC_INS_BNLLA,
	"bnllr", // PPC_INS_BNLLR,
	"bnllrl", // PPC_INS_BNLLRL,
	"bns", // PPC_INS_BNS,
	"bnsa", // PPC_INS_BNSA,
	"bnsctr", // PPC_INS_BNSCTR,
	"bnsctrl", // PPC_INS_BNSCTRL,
	"bnsl", // PPC_INS_BNSL,
	"bnsla", // PPC_INS_BNSLA,
	"bnslr", // PPC_INS_BNSLR,
	"bnslrl", // PPC_INS_BNSLRL,
	"bnu", // PPC_INS_BNU,
	"bnua", // PPC_INS_BNUA,
	"bnuctr", // PPC_INS_BNUCTR,
	"bnuctrl", // PPC_INS_BNUCTRL,
	"bnul", // PPC_INS_BNUL,
	"bnula", // PPC_INS_BNULA,
	"bnulr", // PPC_INS_BNULR,
	"bnulrl", // PPC_INS_BNULRL,
	"bpermd", // PPC_INS_BPERMD,
	"brinc", // PPC_INS_BRINC,
	"bso", // PPC_INS_BSO,
	"bsoa", // PPC_INS_BSOA,
	"bsoctr", // PPC_INS_BSOCTR,
	"bsoctrl", // PPC_INS_BSOCTRL,
	"bsol", // PPC_INS_BSOL,
	"bsola", // PPC_INS_BSOLA,
	"bsolr", // PPC_INS_BSOLR,
	"bsolrl", // PPC_INS_BSOLRL,
	"bt", // PPC_INS_BT,
	"bta", // PPC_INS_BTA,
	"btctr", // PPC_INS_BTCTR,
	"btctrl", // PPC_INS_BTCTRL,
	"btl", // PPC_INS_BTL,
	"btla", // PPC_INS_BTLA,
	"btlr", // PPC_INS_BTLR,
	"btlrl", // PPC_INS_BTLRL,
	"bun", // PPC_INS_BUN,
	"buna", // PPC_INS_BUNA,
	"bunctr", // PPC_INS_BUNCTR,
	"bunctrl", // PPC_INS_BUNCTRL,
	"bunl", // PPC_INS_BUNL,
	"bunla", // PPC_INS_BUNLA,
	"bunlr", // PPC_INS_BUNLR,
	"bunlrl", // PPC_INS_BUNLRL,
	"clrbhrb", // PPC_INS_CLRBHRB,
	"clrldi", // PPC_INS_CLRLDI,
	"clrlsldi", // PPC_INS_CLRLSLDI,
	"clrlslwi", // PPC_INS_CLRLSLWI,
	"clrlwi", // PPC_INS_CLRLWI,
	"clrrdi", // PPC_INS_CLRRDI,
	"clrrwi", // PPC_INS_CLRRWI,
	"cmp", // PPC_INS_CMP,
	"cmpb", // PPC_INS_CMPB,
	"cmpd", // PPC_INS_CMPD,
	"cmpdi", // PPC_INS_CMPDI,
	"cmpeqb", // PPC_INS_CMPEQB,
	"cmpi", // PPC_INS_CMPI,
	"cmpl", // PPC_INS_CMPL,
	"cmpld", // PPC_INS_CMPLD,
	"cmpldi", // PPC_INS_CMPLDI,
	"cmpli", // PPC_INS_CMPLI,
	"cmplw", // PPC_INS_CMPLW,
	"cmplwi", // PPC_INS_CMPLWI,
	"cmprb", // PPC_INS_CMPRB,
	"cmpw", // PPC_INS_CMPW,
	"cmpwi", // PPC_INS_CMPWI,
	"cntlzd", // PPC_INS_CNTLZD,
	"cntlzw", // PPC_INS_CNTLZW,
	"cnttzd", // PPC_INS_CNTTZD,
	"cnttzw", // PPC_INS_CNTTZW,
	"copy", // PPC_INS_COPY,
	"copy_first", // PPC_INS_COPY_FIRST,
	"cp_abort", // PPC_INS_CP_ABORT,
	"crand", // PPC_INS_CRAND,
	"crandc", // PPC_INS_CRANDC,
	"crclr", // PPC_INS_CRCLR,
	"creqv", // PPC_INS_CREQV,
	"crmove", // PPC_INS_CRMOVE,
	"crnand", // PPC_INS_CRNAND,
	"crnor", // PPC_INS_CRNOR,
	"crnot", // PPC_INS_CRNOT,
	"cror", // PPC_INS_CROR,
	"crorc", // PPC_INS_CRORC,
	"crset", // PPC_INS_CRSET,
	"crxor", // PPC_INS_CRXOR,
	"darn", // PPC_INS_DARN,
	"dcba", // PPC_INS_DCBA,
	"dcbf", // PPC_INS_DCBF,
	"dcbfep", // PPC_INS_DCBFEP,
	"dcbfl", // PPC_INS_DCBFL,
	"dcbflp", // PPC_INS_DCBFLP,
	"dcbi", // PPC_INS_DCBI,
	"dcbst", // PPC_INS_DCBST,
	"dcbstep", // PPC_INS_DCBSTEP,
	"dcbt", // PPC_INS_DCBT,
	"dcbtct", // PPC_INS_DCBTCT,
	"dcbtds", // PPC_INS_DCBTDS,
	"dcbtep", // PPC_INS_DCBTEP,
	"dcbtst", // PPC_INS_DCBTST,
	"dcbtstct", // PPC_INS_DCBTSTCT,
	"dcbtstds", // PPC_INS_DCBTSTDS,
	"dcbtstep", // PPC_INS_DCBTSTEP,
	"dcbtstt", // PPC_INS_DCBTSTT,
	"dcbtt", // PPC_INS_DCBTT,
	"dcbz", // PPC_INS_DCBZ,
	"dcbzep", // PPC_INS_DCBZEP,
	"dcbzl", // PPC_INS_DCBZL,
	"dcbzlep", // PPC_INS_DCBZLEP,
	"dccci", // PPC_INS_DCCCI,
	"dci", // PPC_INS_DCI,
	"divd", // PPC_INS_DIVD,
	"divde", // PPC_INS_DIVDE,
	"divdeu", // PPC_INS_DIVDEU,
	"divdu", // PPC_INS_DIVDU,
	"divw", // PPC_INS_DIVW,
	"divwe", // PPC_INS_DIVWE,
	"divweu", // PPC_INS_DIVWEU,
	"divwu", // PPC_INS_DIVWU,
	"dss", // PPC_INS_DSS,
	"dssall", // PPC_INS_DSSALL,
	"dst", // PPC_INS_DST,
	"dstst", // PPC_INS_DSTST,
	"dststt", // PPC_INS_DSTSTT,
	"dstt", // PPC_INS_DSTT,
	"efdabs", // PPC_INS_EFDABS,
	"efdadd", // PPC_INS_EFDADD,
	"efdcfs", // PPC_INS_EFDCFS,
	"efdcfsf", // PPC_INS_EFDCFSF,
	"efdcfsi", // PPC_INS_EFDCFSI,
	"efdcfsid", // PPC_INS_EFDCFSID,
	"efdcfuf", // PPC_INS_EFDCFUF,
	"efdcfui", // PPC_INS_EFDCFUI,
	"efdcfuid", // PPC_INS_EFDCFUID,
	"efdcmpeq", // PPC_INS_EFDCMPEQ,
	"efdcmpgt", // PPC_INS_EFDCMPGT,
	"efdcmplt", // PPC_INS_EFDCMPLT,
	"efdctsf", // PPC_INS_EFDCTSF,
	"efdctsi", // PPC_INS_EFDCTSI,
	"efdctsidz", // PPC_INS_EFDCTSIDZ,
	"efdctsiz", // PPC_INS_EFDCTSIZ,
	"efdctuf", // PPC_INS_EFDCTUF,
	"efdctui", // PPC_INS_EFDCTUI,
	"efdctuidz", // PPC_INS_EFDCTUIDZ,
	"efdctuiz", // PPC_INS_EFDCTUIZ,
	"efddiv", // PPC_INS_EFDDIV,
	"efdmul", // PPC_INS_EFDMUL,
	"efdnabs", // PPC_INS_EFDNABS,
	"efdneg", // PPC_INS_EFDNEG,
	"efdsub", // PPC_INS_EFDSUB,
	"efdtsteq", // PPC_INS_EFDTSTEQ,
	"efdtstgt", // PPC_INS_EFDTSTGT,
	"efdtstlt", // PPC_INS_EFDTSTLT,
	"efsabs", // PPC_INS_EFSABS,
	"efsadd", // PPC_INS_EFSADD,
	"efscfd", // PPC_INS_EFSCFD,
	"efscfsf", // PPC_INS_EFSCFSF,
	"efscfsi", // PPC_INS_EFSCFSI,
	"efscfuf", // PPC_INS_EFSCFUF,
	"efscfui", // PPC_INS_EFSCFUI,
	"efscmpeq", // PPC_INS_EFSCMPEQ,
	"efscmpgt", // PPC_INS_EFSCMPGT,
	"efscmplt", // PPC_INS_EFSCMPLT,
	"efsctsf", // PPC_INS_EFSCTSF,
	"efsctsi", // PPC_INS_EFSCTSI,
	"efsctsiz", // PPC_INS_EFSCTSIZ,
	"efsctuf", // PPC_INS_EFSCTUF,
	"efsctui", // PPC_INS_EFSCTUI,
	"efsctuiz", // PPC_INS_EFSCTUIZ,
	"efsdiv", // PPC_INS_EFSDIV,
	"efsmul", // PPC_INS_EFSMUL,
	"efsnabs", // PPC_INS_EFSNABS,
	"efsneg", // PPC_INS_EFSNEG,
	"efssub", // PPC_INS_EFSSUB,
	"efststeq", // PPC_INS_EFSTSTEQ,
	"efststgt", // PPC_INS_EFSTSTGT,
	"efststlt", // PPC_INS_EFSTSTLT,
	"eieio", // PPC_INS_EIEIO,
	"eqv", // PPC_INS_EQV,
	"evabs", // PPC_INS_EVABS,
	"evaddiw", // PPC_INS_EVADDIW,
	"evaddsmiaaw", // PPC_INS_EVADDSMIAAW,
	"evaddssiaaw", // PPC_INS_EVADDSSIAAW,
	"evaddumiaaw", // PPC_INS_EVADDUMIAAW,
	"evaddusiaaw", // PPC_INS_EVADDUSIAAW,
	"evaddw", // PPC_INS_EVADDW,
	"evand", // PPC_INS_EVAND,
	"evandc", // PPC_INS_EVANDC,
	"evcmpeq", // PPC_INS_EVCMPEQ,
	"evcmpgts", // PPC_INS_EVCMPGTS,
	"evcmpgtu", // PPC_INS_EVCMPGTU,
	"evcmplts", // PPC_INS_EVCMPLTS,
	"evcmpltu", // PPC_INS_EVCMPLTU,
	"evcntlsw", // PPC_INS_EVCNTLSW,
	"evcntlzw", // PPC_INS_EVCNTLZW,
	"evdivws", // PPC_INS_EVDIVWS,
	"evdivwu", // PPC_INS_EVDIVWU,
	"eveqv", // PPC_INS_EVEQV,
	"evextsb", // PPC_INS_EVEXTSB,
	"evextsh", // PPC_INS_EVEXTSH,
	"evfsabs", // PPC_INS_EVFSABS,
	"evfsadd", // PPC_INS_EVFSADD,
	"evfscfsf", // PPC_INS_EVFSCFSF,
	"evfscfsi", // PPC_INS_EVFSCFSI,
	"evfscfuf", // PPC_INS_EVFSCFUF,
	"evfscfui", // PPC_INS_EVFSCFUI,
	"evfscmpeq", // PPC_INS_EVFSCMPEQ,
	"evfscmpgt", // PPC_INS_EVFSCMPGT,
	"evfscmplt", // PPC_INS_EVFSCMPLT,
	"evfsctsf", // PPC_INS_EVFSCTSF,
	"evfsctsi", // PPC_INS_EVFSCTSI,
	"evfsctsiz", // PPC_INS_EVFSCTSIZ,
	"evfsctui", // PPC_INS_EVFSCTUI,
	"evfsdiv", // PPC_INS_EVFSDIV,
	"evfsmul", // PPC_INS_EVFSMUL,
	"evfsnabs", // PPC_INS_EVFSNABS,
	"evfsneg", // PPC_INS_EVFSNEG,
	"evfssub", // PPC_INS_EVFSSUB,
	"evfststeq", // PPC_INS_EVFSTSTEQ,
	"evfststgt", // PPC_INS_EVFSTSTGT,
	"evfststlt", // PPC_INS_EVFSTSTLT,
	"evldd", // PPC_INS_EVLDD,
	"evlddx", // PPC_INS_EVLDDX,
	"evldh", // PPC_INS_EVLDH,
	"evldhx", // PPC_INS_EVLDHX,
	"evldw", // PPC_INS_EVLDW,
	"evldwx", // PPC_INS_EVLDWX,
	"evlhhesplat", // PPC_INS_EVLHHESPLAT,
	"evlhhesplatx", // PPC_INS_EVLHHESPLATX,
	"evlhhossplat", // PPC_INS_EVLHHOSSPLAT,
	"evlhhossplatx", // PPC_INS_EVLHHOSSPLATX,
	"evlhhousplat", // PPC_INS_EVLHHOUSPLAT,
	"evlhhousplatx", // PPC_INS_EVLHHOUSPLATX,
	"evlwhe", // PPC_INS_EVLWHE,
	"evlwhex", // PPC_INS_EVLWHEX,
	"evlwhos", // PPC_INS_EVLWHOS,
	"evlwhosx", // PPC_INS_EVLWHOSX,
	"evlwhou", // PPC_INS_EVLWHOU,
	"evlwhoux", // PPC_INS_EVLWHOUX,
	"evlwhsplat", // PPC_INS_EVLWHSPLAT,
	"evlwhsplatx", // PPC_INS_EVLWHSPLATX,
	"evlwwsplat", // PPC_INS_EVLWWSPLAT,
	"evlwwsplatx", // PPC_INS_EVLWWSPLATX,
	"evmergehi", // PPC_INS_EVMERGEHI,
	"evmergehilo", // PPC_INS_EVMERGEHILO,
	"evmergelo", // PPC_INS_EVMERGELO,
	"evmergelohi", // PPC_INS_EVMERGELOHI,
	"evmhegsmfaa", // PPC_INS_EVMHEGSMFAA,
	"evmhegsmfan", // PPC_INS_EVMHEGSMFAN,
	"evmhegsmiaa", // PPC_INS_EVMHEGSMIAA,
	"evmhegsmian", // PPC_INS_EVMHEGSMIAN,
	"evmhegumiaa", // PPC_INS_EVMHEGUMIAA,
	"evmhegumian", // PPC_INS_EVMHEGUMIAN,
	"evmhesmf", // PPC_INS_EVMHESMF,
	"evmhesmfa", // PPC_INS_EVMHESMFA,
	"evmhesmfaaw", // PPC_INS_EVMHESMFAAW,
	"evmhesmfanw", // PPC_INS_EVMHESMFANW,
	"evmhesmi", // PPC_INS_EVMHESMI,
	"evmhesmia", // PPC_INS_EVMHESMIA,
	"evmhesmiaaw", // PPC_INS_EVMHESMIAAW,
	"evmhesmianw", // PPC_INS_EVMHESMIANW,
	"evmhessf", // PPC_INS_EVMHESSF,
	"evmhessfa", // PPC_INS_EVMHESSFA,
	"evmhessfaaw", // PPC_INS_EVMHESSFAAW,
	"evmhessfanw", // PPC_INS_EVMHESSFANW,
	"evmhessiaaw", // PPC_INS_EVMHESSIAAW,
	"evmhessianw", // PPC_INS_EVMHESSIANW,
	"evmheumi", // PPC_INS_EVMHEUMI,
	"evmheumia", // PPC_INS_EVMHEUMIA,
	"evmheumiaaw", // PPC_INS_EVMHEUMIAAW,
	"evmheumianw", // PPC_INS_EVMHEUMIANW,
	"evmheusiaaw", // PPC_INS_EVMHEUSIAAW,
	"evmheusianw", // PPC_INS_EVMHEUSIANW,
	"evmhogsmfaa", // PPC_INS_EVMHOGSMFAA,
	"evmhogsmfan", // PPC_INS_EVMHOGSMFAN,
	"evmhogsmiaa", // PPC_INS_EVMHOGSMIAA,
	"evmhogsmian", // PPC_INS_EVMHOGSMIAN,
	"evmhogumiaa", // PPC_INS_EVMHOGUMIAA,
	"evmhogumian", // PPC_INS_EVMHOGUMIAN,
	"evmhosmf", // PPC_INS_EVMHOSMF,
	"evmhosmfa", // PPC_INS_EVMHOSMFA,
	"evmhosmfaaw", // PPC_INS_EVMHOSMFAAW,
	"evmhosmfanw", // PPC_INS_EVMHOSMFANW,
	"evmhosmi", // PPC_INS_EVMHOSMI,
	"evmhosmia", // PPC_INS_EVMHOSMIA,
	"evmhosmiaaw", // PPC_INS_EVMHOSMIAAW,
	"evmhosmianw", // PPC_INS_EVMHOSMIANW,
	"evmhossf", // PPC_INS_EVMHOSSF,
	"evmhossfa", // PPC_INS_EVMHOSSFA,
	"evmhossfaaw", // PPC_INS_EVMHOSSFAAW,
	"evmhossfanw", // PPC_INS_EVMHOSSFANW,
	"evmhossiaaw", // PPC_INS_EVMHOSSIAAW,
	"evmhossianw", // PPC_INS_EVMHOSSIANW,
	"evmhoumi", // PPC_INS_EVMHOUMI,
	"evmhoumia", // PPC_INS_EVMHOUMIA,
	"evmhoumiaaw", // PPC_INS_EVMHOUMIAAW,
	"evmhoumianw", // PPC_INS_EVMHOUMIANW,
	"evmhousiaaw", // PPC_INS_EVMHOUSIAAW,
	"evmhousianw", // PPC_INS_EVMHOUSIANW,
	"evmra", // PPC_INS_EVMRA,
	"evmwhsmf", // PPC_INS_EVMWHSMF,
	"evmwhsmfa", // PPC_INS_EVMWHSMFA,
	"evmwhsmi", // PPC_INS_EVMWHSMI,
	"evmwhsmia", // PPC_INS_EVMWHSMIA,
	"evmwhssf", // PPC_INS_EVMWHSSF,
	"evmwhssfa", // PPC_INS_EVMWHSSFA,
	"evmwhumi", // PPC_INS_EVMWHUMI,
	"evmwhumia", // PPC_INS_EVMWHUMIA,
	"evmwlsmiaaw", // PPC_INS_EVMWLSMIAAW,
	"evmwlsmianw", // PPC_INS_EVMWLSMIANW,
	"evmwlssiaaw", // PPC_INS_EVMWLSSIAAW,
	"evmwlssianw", // PPC_INS_EVMWLSSIANW,
	"evmwlumi", // PPC_INS_EVMWLUMI,
	"evmwlumia", // PPC_INS_EVMWLUMIA,
	"evmwlumiaaw", // PPC_INS_EVMWLUMIAAW,
	"evmwlumianw", // PPC_INS_EVMWLUMIANW,
	"evmwlusiaaw", // PPC_INS_EVMWLUSIAAW,
	"evmwlusianw", // PPC_INS_EVMWLUSIANW,
	"evmwsmf", // PPC_INS_EVMWSMF,
	"evmwsmfa", // PPC_INS_EVMWSMFA,
	"evmwsmfaa", // PPC_INS_EVMWSMFAA,
	"evmwsmfan", // PPC_INS_EVMWSMFAN,
	"evmwsmi", // PPC_INS_EVMWSMI,
	"evmwsmia", // PPC_INS_EVMWSMIA,
	"evmwsmiaa", // PPC_INS_EVMWSMIAA,
	"evmwsmian", // PPC_INS_EVMWSMIAN,
	"evmwssf", // PPC_INS_EVMWSSF,
	"evmwssfa", // PPC_INS_EVMWSSFA,
	"evmwssfaa", // PPC_INS_EVMWSSFAA,
	"evmwssfan", // PPC_INS_EVMWSSFAN,
	"evmwumi", // PPC_INS_EVMWUMI,
	"evmwumia", // PPC_INS_EVMWUMIA,
	"evmwumiaa", // PPC_INS_EVMWUMIAA,
	"evmwumian", // PPC_INS_EVMWUMIAN,
	"evnand", // PPC_INS_EVNAND,
	"evneg", // PPC_INS_EVNEG,
	"evnor", // PPC_INS_EVNOR,
	"evor", // PPC_INS_EVOR,
	"evorc", // PPC_INS_EVORC,
	"evrlw", // PPC_INS_EVRLW,
	"evrlwi", // PPC_INS_EVRLWI,
	"evrndw", // PPC_INS_EVRNDW,
	"evsel", // PPC_INS_EVSEL,
	"evslw", // PPC_INS_EVSLW,
	"evslwi", // PPC_INS_EVSLWI,
	"evsplatfi", // PPC_INS_EVSPLATFI,
	"evsplati", // PPC_INS_EVSPLATI,
	"evsrwis", // PPC_INS_EVSRWIS,
	"evsrwiu", // PPC_INS_EVSRWIU,
	"evsrws", // PPC_INS_EVSRWS,
	"evsrwu", // PPC_INS_EVSRWU,
	"evstdd", // PPC_INS_EVSTDD,
	"evstddx", // PPC_INS_EVSTDDX,
	"evstdh", // PPC_INS_EVSTDH,
	"evstdhx", // PPC_INS_EVSTDHX,
	"evstdw", // PPC_INS_EVSTDW,
	"evstdwx", // PPC_INS_EVSTDWX,
	"evstwhe", // PPC_INS_EVSTWHE,
	"evstwhex", // PPC_INS_EVSTWHEX,
	"evstwho", // PPC_INS_EVSTWHO,
	"evstwhox", // PPC_INS_EVSTWHOX,
	"evstwwe", // PPC_INS_EVSTWWE,
	"evstwwex", // PPC_INS_EVSTWWEX,
	"evstwwo", // PPC_INS_EVSTWWO,
	"evstwwox", // PPC_INS_EVSTWWOX,
	"evsubfsmiaaw", // PPC_INS_EVSUBFSMIAAW,
	"evsubfssiaaw", // PPC_INS_EVSUBFSSIAAW,
	"evsubfumiaaw", // PPC_INS_EVSUBFUMIAAW,
	"evsubfusiaaw", // PPC_INS_EVSUBFUSIAAW,
	"evsubfw", // PPC_INS_EVSUBFW,
	"evsubifw", // PPC_INS_EVSUBIFW,
	"evxor", // PPC_INS_EVXOR,
	"extldi", // PPC_INS_EXTLDI,
	"extlwi", // PPC_INS_EXTLWI,
	"extrdi", // PPC_INS_EXTRDI,
	"extrwi", // PPC_INS_EXTRWI,
	"extsb", // PPC_INS_EXTSB,
	"extsh", // PPC_INS_EXTSH,
	"extsw", // PPC_INS_EXTSW,
	"extswsli", // PPC_INS_EXTSWSLI,
	"fabs", // PPC_INS_FABS,
	"fadd", // PPC_INS_FADD,
	"fadds", // PPC_INS_FADDS,
	"fcfid", // PPC_INS_FCFID,
	"fcfids", // PPC_INS_FCFIDS,
	"fcfidu", // PPC_INS_FCFIDU,
	"fcfidus", // PPC_INS_FCFIDUS,
	"fcmpu", // PPC_INS_FCMPU,
	"fcpsgn", // PPC_INS_FCPSGN,
	"fctid", // PPC_INS_FCTID,
	"fctidu", // PPC_INS_FCTIDU,
	"fctiduz", // PPC_INS_FCTIDUZ,
	"fctidz", // PPC_INS_FCTIDZ,
	"fctiw", // PPC_INS_FCTIW,
	"fctiwu", // PPC_INS_FCTIWU,
	"fctiwuz", // PPC_INS_FCTIWUZ,
	"fctiwz", // PPC_INS_FCTIWZ,
	"fdiv", // PPC_INS_FDIV,
	"fdivs", // PPC_INS_FDIVS,
	"fmadd", // PPC_INS_FMADD,
	"fmadds", // PPC_INS_FMADDS,
	"fmr", // PPC_INS_FMR,
	"fmsub", // PPC_INS_FMSUB,
	"fmsubs", // PPC_INS_FMSUBS,
	"fmul", // PPC_INS_FMUL,
	"fmuls", // PPC_INS_FMULS,
	"fnabs", // PPC_INS_FNABS,
	"fneg", // PPC_INS_FNEG,
	"fnmadd", // PPC_INS_FNMADD,
	"fnmadds", // PPC_INS_FNMADDS,
	"fnmsub", // PPC_INS_FNMSUB,
	"fnmsubs", // PPC_INS_FNMSUBS,
	"fre", // PPC_INS_FRE,
	"fres", // PPC_INS_FRES,
	"frim", // PPC_INS_FRIM,
	"frin", // PPC_INS_FRIN,
	"frip", // PPC_INS_FRIP,
	"friz", // PPC_INS_FRIZ,
	"frsp", // PPC_INS_FRSP,
	"frsqrte", // PPC_INS_FRSQRTE,
	"frsqrtes", // PPC_INS_FRSQRTES,
	"fsel", // PPC_INS_FSEL,
	"fsqrt", // PPC_INS_FSQRT,
	"fsqrts", // PPC_INS_FSQRTS,
	"fsub", // PPC_INS_FSUB,
	"fsubs", // PPC_INS_FSUBS,
	"ftdiv", // PPC_INS_FTDIV,
	"ftsqrt", // PPC_INS_FTSQRT,
	"hrfid", // PPC_INS_HRFID,
	"icbi", // PPC_INS_ICBI,
	"icbiep", // PPC_INS_ICBIEP,
	"icblc", // PPC_INS_ICBLC,
	"icblq", // PPC_INS_ICBLQ,
	"icbt", // PPC_INS_ICBT,
	"icbtls", // PPC_INS_ICBTLS,
	"iccci", // PPC_INS_ICCCI,
	"ici", // PPC_INS_ICI,
	"inslwi", // PPC_INS_INSLWI,
	"insrdi", // PPC_INS_INSRDI,
	"insrwi", // PPC_INS_INSRWI,
	"isel", // PPC_INS_ISEL,
	"isync", // PPC_INS_ISYNC,
	"la", // PPC_INS_LA,
	"lbarx", // PPC_INS_LBARX,
	"lbepx", // PPC_INS_LBEPX,
	"lbz", // PPC_INS_LBZ,
	"lbzcix", // PPC_INS_LBZCIX,
	"lbzu", // PPC_INS_LBZU,
	"lbzux", // PPC_INS_LBZUX,
	"lbzx", // PPC_INS_LBZX,
	"ld", // PPC_INS_LD,
	"ldarx", // PPC_INS_LDARX,
	"ldat", // PPC_INS_LDAT,
	"ldbrx", // PPC_INS_LDBRX,
	"ldcix", // PPC_INS_LDCIX,
	"ldmx", // PPC_INS_LDMX,
	"ldu", // PPC_INS_LDU,
	"ldux", // PPC_INS_LDUX,
	"ldx", // PPC_INS_LDX,
	"lfd", // PPC_INS_LFD,
	"lfdepx", // PPC_INS_LFDEPX,
	"lfdu", // PPC_INS_LFDU,
	"lfdux", // PPC_INS_LFDUX,
	"lfdx", // PPC_INS_LFDX,
	"lfiwax", // PPC_INS_LFIWAX,
	"lfiwzx", // PPC_INS_LFIWZX,
	"lfs", // PPC_INS_LFS,
	"lfsu", // PPC_INS_LFSU,
	"lfsux", // PPC_INS_LFSUX,
	"lfsx", // PPC_INS_LFSX,
	"lha", // PPC_INS_LHA,
	"lharx", // PPC_INS_LHARX,
	"lhau", // PPC_INS_LHAU,
	"lhaux", // PPC_INS_LHAUX,
	"lhax", // PPC_INS_LHAX,
	"lhbrx", // PPC_INS_LHBRX,
	"lhepx", // PPC_INS_LHEPX,
	"lhz", // PPC_INS_LHZ,
	"lhzcix", // PPC_INS_LHZCIX,
	"lhzu", // PPC_INS_LHZU,
	"lhzux", // PPC_INS_LHZUX,
	"lhzx", // PPC_INS_LHZX,
	"li", // PPC_INS_LI,
	"lis", // PPC_INS_LIS,
	"lmw", // PPC_INS_LMW,
	"lnia", // PPC_INS_LNIA,
	"lswi", // PPC_INS_LSWI,
	"lvebx", // PPC_INS_LVEBX,
	"lvehx", // PPC_INS_LVEHX,
	"lvewx", // PPC_INS_LVEWX,
	"lvsl", // PPC_INS_LVSL,
	"lvsr", // PPC_INS_LVSR,
	"lvx", // PPC_INS_LVX,
	"lvxl", // PPC_INS_LVXL,
	"lwa", // PPC_INS_LWA,
	"lwarx", // PPC_INS_LWARX,
	"lwat", // PPC_INS_LWAT,
	"lwaux", // PPC_INS_LWAUX,
	"lwax", // PPC_INS_LWAX,
	"lwbrx", // PPC_INS_LWBRX,
	"lwepx", // PPC_INS_LWEPX,
	"lwsync", // PPC_INS_LWSYNC,
	"lwz", // PPC_INS_LWZ,
	"lwzcix", // PPC_INS_LWZCIX,
	"lwzu", // PPC_INS_LWZU,
	"lwzux", // PPC_INS_LWZUX,
	"lwzx", // PPC_INS_LWZX,
	"lxsd", // PPC_INS_LXSD,
	"lxsdx", // PPC_INS_LXSDX,
	"lxsibzx", // PPC_INS_LXSIBZX,
	"lxsihzx", // PPC_INS_LXSIHZX,
	"lxsiwax", // PPC_INS_LXSIWAX,
	"lxsiwzx", // PPC_INS_LXSIWZX,
	"lxssp", // PPC_INS_LXSSP,
	"lxsspx", // PPC_INS_LXSSPX,
	"lxv", // PPC_INS_LXV,
	"lxvb16x", // PPC_INS_LXVB16X,
	"lxvd2x", // PPC_INS_LXVD2X,
	"lxvdsx", // PPC_INS_LXVDSX,
	"lxvh8x", // PPC_INS_LXVH8X,
	"lxvl", // PPC_INS_LXVL,
	"lxvll", // PPC_INS_LXVLL,
	"lxvw4x", // PPC_INS_LXVW4X,
	"lxvwsx", // PPC_INS_LXVWSX,
	"lxvx", // PPC_INS_LXVX,
	"maddhd", // PPC_INS_MADDHD,
	"maddhdu", // PPC_INS_MADDHDU,
	"maddld", // PPC_INS_MADDLD,
	"mbar", // PPC_INS_MBAR,
	"mcrf", // PPC_INS_MCRF,
	"mcrfs", // PPC_INS_MCRFS,
	"mcrxrx", // PPC_INS_MCRXRX,
	"mfamr", // PPC_INS_MFAMR,
	"mfasr", // PPC_INS_MFASR,
	"mfbhrbe", // PPC_INS_MFBHRBE,
	"mfbr0", // PPC_INS_MFBR0,
	"mfbr1", // PPC_INS_MFBR1,
	"mfbr2", // PPC_INS_MFBR2,
	"mfbr3", // PPC_INS_MFBR3,
	"mfbr4", // PPC_INS_MFBR4,
	"mfbr5", // PPC_INS_MFBR5,
	"mfbr6", // PPC_INS_MFBR6,
	"mfbr7", // PPC_INS_MFBR7,
	"mfcfar", // PPC_INS_MFCFAR,
	"mfcr", // PPC_INS_MFCR,
	"mfctr", // PPC_INS_MFCTR,
	"mfdar", // PPC_INS_MFDAR,
	"mfdbatl", // PPC_INS_MFDBATL,
	"mfdbatu", // PPC_INS_MFDBATU,
	"mfdccr", // PPC_INS_MFDCCR,
	"mfdcr", // PPC_INS_MFDCR,
	"mfdear", // PPC_INS_MFDEAR,
	"mfdec", // PPC_INS_MFDEC,
	"mfdscr", // PPC_INS_MFDSCR,
	"mfdsisr", // PPC_INS_MFDSISR,
	"mfesr", // PPC_INS_MFESR,
	"mffprd", // PPC_INS_MFFPRD,
	"mffs", // PPC_INS_MFFS,
	"mffscdrn", // PPC_INS_MFFSCDRN,
	"mffscdrni", // PPC_INS_MFFSCDRNI,
	"mffsce", // PPC_INS_MFFSCE,
	"mffscrn", // PPC_INS_MFFSCRN,
	"mffscrni", // PPC_INS_MFFSCRNI,
	"mffsl", // PPC_INS_MFFSL,
	"mfibatl", // PPC_INS_MFIBATL,
	"mfibatu", // PPC_INS_MFIBATU,
	"mficcr", // PPC_INS_MFICCR,
	"mflr", // PPC_INS_MFLR,
	"mfmsr", // PPC_INS_MFMSR,
	"mfocrf", // PPC_INS_MFOCRF,
	"mfpid", // PPC_INS_MFPID,
	"mfpmr", // PPC_INS_MFPMR,
	"mfpvr", // PPC_INS_MFPVR,
	"mfrtcl", // PPC_INS_MFRTCL,
	"mfrtcu", // PPC_INS_MFRTCU,
	"mfsdr1", // PPC_INS_MFSDR1,
	"mfspefscr", // PPC_INS_MFSPEFSCR,
	"mfspr", // PPC_INS_MFSPR,
	"mfsprg", // PPC_INS_MFSPRG,
	"mfsprg0", // PPC_INS_MFSPRG0,
	"mfsprg1", // PPC_INS_MFSPRG1,
	"mfsprg2", // PPC_INS_MFSPRG2,
	"mfsprg3", // PPC_INS_MFSPRG3,
	"mfsprg4", // PPC_INS_MFSPRG4,
	"mfsprg5", // PPC_INS_MFSPRG5,
	"mfsprg6", // PPC_INS_MFSPRG6,
	"mfsprg7", // PPC_INS_MFSPRG7,
	"mfsr", // PPC_INS_MFSR,
	"mfsrin", // PPC_INS_MFSRIN,
	"mfsrr0", // PPC_INS_MFSRR0,
	"mfsrr1", // PPC_INS_MFSRR1,
	"mfsrr2", // PPC_INS_MFSRR2,
	"mfsrr3", // PPC_INS_MFSRR3,
	"mftb", // PPC_INS_MFTB,
	"mftbhi", // PPC_INS_MFTBHI,
	"mftbl", // PPC_INS_MFTBL,
	"mftblo", // PPC_INS_MFTBLO,
	"mftbu", // PPC_INS_MFTBU,
	"mftcr", // PPC_INS_MFTCR,
	"mfvrd", // PPC_INS_MFVRD,
	"mfvrsave", // PPC_INS_MFVRSAVE,
	"mfvscr", // PPC_INS_MFVSCR,
	"mfvsrd", // PPC_INS_MFVSRD,
	"mfvsrld", // PPC_INS_MFVSRLD,
	"mfvsrwz", // PPC_INS_MFVSRWZ,
	"mfxer", // PPC_INS_MFXER,
	"modsd", // PPC_INS_MODSD,
	"modsw", // PPC_INS_MODSW,
	"modud", // PPC_INS_MODUD,
	"moduw", // PPC_INS_MODUW,
	"mr", // PPC_INS_MR,
	"msgsync", // PPC_INS_MSGSYNC,
	"msync", // PPC_INS_MSYNC,
	"mtamr", // PPC_INS_MTAMR,
	"mtasr", // PPC_INS_MTASR,
	"mtbr0", // PPC_INS_MTBR0,
	"mtbr1", // PPC_INS_MTBR1,
	"mtbr2", // PPC_INS_MTBR2,
	"mtbr3", // PPC_INS_MTBR3,
	"mtbr4", // PPC_INS_MTBR4,
	"mtbr5", // PPC_INS_MTBR5,
	"mtbr6", // PPC_INS_MTBR6,
	"mtbr7", // PPC_INS_MTBR7,
	"mtcfar", // PPC_INS_MTCFAR,
	"mtcr", // PPC_INS_MTCR,
	"mtcrf", // PPC_INS_MTCRF,
	"mtctr", // PPC_INS_MTCTR,
	"mtdar", // PPC_INS_MTDAR,
	"mtdbatl", // PPC_INS_MTDBATL,
	"mtdbatu", // PPC_INS_MTDBATU,
	"mtdccr", // PPC_INS_MTDCCR,
	"mtdcr", // PPC_INS_MTDCR,
	"mtdear", // PPC_INS_MTDEAR,
	"mtdec", // PPC_INS_MTDEC,
	"mtdscr", // PPC_INS_MTDSCR,
	"mtdsisr", // PPC_INS_MTDSISR,
	"mtesr", // PPC_INS_MTESR,
	"mtfsb0", // PPC_INS_MTFSB0,
	"mtfsb1", // PPC_INS_MTFSB1,
	"mtfsf", // PPC_INS_MTFSF,
	"mtfsfi", // PPC_INS_MTFSFI,
	"mtibatl", // PPC_INS_MTIBATL,
	"mtibatu", // PPC_INS_MTIBATU,
	"mticcr", // PPC_INS_MTICCR,
	"mtlr", // PPC_INS_MTLR,
	"mtmsr", // PPC_INS_MTMSR,
	"mtmsrd", // PPC_INS_MTMSRD,
	"mtocrf", // PPC_INS_MTOCRF,
	"mtpid", // PPC_INS_MTPID,
	"mtpmr", // PPC_INS_MTPMR,
	"mtsdr1", // PPC_INS_MTSDR1,
	"mtspefscr", // PPC_INS_MTSPEFSCR,
	"mtspr", // PPC_INS_MTSPR,
	"mtsprg", // PPC_INS_MTSPRG,
	"mtsprg0", // PPC_INS_MTSPRG0,
	"mtsprg1", // PPC_INS_MTSPRG1,
	"mtsprg2", // PPC_INS_MTSPRG2,
	"mtsprg3", // PPC_INS_MTSPRG3,
	"mtsprg4", // PPC_INS_MTSPRG4,
	"mtsprg5", // PPC_INS_MTSPRG5,
	"mtsprg6", // PPC_INS_MTSPRG6,
	"mtsprg7", // PPC_INS_MTSPRG7,
	"mtsr", // PPC_INS_MTSR,
	"mtsrin", // PPC_INS_MTSRIN,
	"mtsrr0", // PPC_INS_MTSRR0,
	"mtsrr1", // PPC_INS_MTSRR1,
	"mtsrr2", // PPC_INS_MTSRR2,
	"mtsrr3", // PPC_INS_MTSRR3,
	"mttbhi", // PPC_INS_MTTBHI,
	"mttbl", // PPC_INS_MTTBL,
	"mttblo", // PPC_INS_MTTBLO,
	"mttbu", // PPC_INS_MTTBU,
	"mttcr", // PPC_INS_MTTCR,
	"mtvrsave", // PPC_INS_MTVRSAVE,
	"mtvscr", // PPC_INS_MTVSCR,
	"mtvsrd", // PPC_INS_MTVSRD,
	"mtvsrdd", // PPC_INS_MTVSRDD,
	"mtvsrwa", // PPC_INS_MTVSRWA,
	"mtvsrws", // PPC_INS_MTVSRWS,
	"mtvsrwz", // PPC_INS_MTVSRWZ,
	"mtxer", // PPC_INS_MTXER,
	"mulhd", // PPC_INS_MULHD,
	"mulhdu", // PPC_INS_MULHDU,
	"mulhw", // PPC_INS_MULHW,
	"mulhwu", // PPC_INS_MULHWU,
	"mulld", // PPC_INS_MULLD,
	"mulli", // PPC_INS_MULLI,
	"mullw", // PPC_INS_MULLW,
	"nand", // PPC_INS_NAND,
	"nap", // PPC_INS_NAP,
	"neg", // PPC_INS_NEG,
	"nop", // PPC_INS_NOP,
	"nor", // PPC_INS_NOR,
	"not", // PPC_INS_NOT,
	"or", // PPC_INS_OR,
	"orc", // PPC_INS_ORC,
	"ori", // PPC_INS_ORI,
	"oris", // PPC_INS_ORIS,
	"paste", // PPC_INS_PASTE,
	"paste_last", // PPC_INS_PASTE_LAST,
	"popcntb", // PPC_INS_POPCNTB,
	"popcntd", // PPC_INS_POPCNTD,
	"popcntw", // PPC_INS_POPCNTW,
	"ptesync", // PPC_INS_PTESYNC,
	"qvaligni", // PPC_INS_QVALIGNI,
	"qvesplati", // PPC_INS_QVESPLATI,
	"qvfabs", // PPC_INS_QVFABS,
	"qvfadd", // PPC_INS_QVFADD,
	"qvfadds", // PPC_INS_QVFADDS,
	"qvfand", // PPC_INS_QVFAND,
	"qvfandc", // PPC_INS_QVFANDC,
	"qvfcfid", // PPC_INS_QVFCFID,
	"qvfcfids", // PPC_INS_QVFCFIDS,
	"qvfcfidu", // PPC_INS_QVFCFIDU,
	"qvfcfidus", // PPC_INS_QVFCFIDUS,
	"qvfclr", // PPC_INS_QVFCLR,
	"qvfcmpeq", // PPC_INS_QVFCMPEQ,
	"qvfcmpgt", // PPC_INS_QVFCMPGT,
	"qvfcmplt", // PPC_INS_QVFCMPLT,
	"qvfcpsgn", // PPC_INS_QVFCPSGN,
	"qvfctfb", // PPC_INS_QVFCTFB,
	"qvfctid", // PPC_INS_QVFCTID,
	"qvfctidu", // PPC_INS_QVFCTIDU,
	"qvfctiduz", // PPC_INS_QVFCTIDUZ,
	"qvfctidz", // PPC_INS_QVFCTIDZ,
	"qvfctiw", // PPC_INS_QVFCTIW,
	"qvfctiwu", // PPC_INS_QVFCTIWU,
	"qvfctiwuz", // PPC_INS_QVFCTIWUZ,
	"qvfctiwz", // PPC_INS_QVFCTIWZ,
	"qvfequ", // PPC_INS_QVFEQU,
	"qvflogical", // PPC_INS_QVFLOGICAL,
	"qvfmadd", // PPC_INS_QVFMADD,
	"qvfmadds", // PPC_INS_QVFMADDS,
	"qvfmr", // PPC_INS_QVFMR,
	"qvfmsub", // PPC_INS_QVFMSUB,
	"qvfmsubs", // PPC_INS_QVFMSUBS,
	"qvfmul", // PPC_INS_QVFMUL,
	"qvfmuls", // PPC_INS_QVFMULS,
	"qvfnabs", // PPC_INS_QVFNABS,
	"qvfnand", // PPC_INS_QVFNAND,
	"qvfneg", // PPC_INS_QVFNEG,
	"qvfnmadd", // PPC_INS_QVFNMADD,
	"qvfnmadds", // PPC_INS_QVFNMADDS,
	"qvfnmsub", // PPC_INS_QVFNMSUB,
	"qvfnmsubs", // PPC_INS_QVFNMSUBS,
	"qvfnor", // PPC_INS_QVFNOR,
	"qvfnot", // PPC_INS_QVFNOT,
	"qvfor", // PPC_INS_QVFOR,
	"qvforc", // PPC_INS_QVFORC,
	"qvfperm", // PPC_INS_QVFPERM,
	"qvfre", // PPC_INS_QVFRE,
	"qvfres", // PPC_INS_QVFRES,
	"qvfrim", // PPC_INS_QVFRIM,
	"qvfrin", // PPC_INS_QVFRIN,
	"qvfrip", // PPC_INS_QVFRIP,
	"qvfriz", // PPC_INS_QVFRIZ,
	"qvfrsp", // PPC_INS_QVFRSP,
	"qvfrsqrte", // PPC_INS_QVFRSQRTE,
	"qvfrsqrtes", // PPC_INS_QVFRSQRTES,
	"qvfsel", // PPC_INS_QVFSEL,
	"qvfset", // PPC_INS_QVFSET,
	"qvfsub", // PPC_INS_QVFSUB,
	"qvfsubs", // PPC_INS_QVFSUBS,
	"qvftstnan", // PPC_INS_QVFTSTNAN,
	"qvfxmadd", // PPC_INS_QVFXMADD,
	"qvfxmadds", // PPC_INS_QVFXMADDS,
	"qvfxmul", // PPC_INS_QVFXMUL,
	"qvfxmuls", // PPC_INS_QVFXMULS,
	"qvfxor", // PPC_INS_QVFXOR,
	"qvfxxcpnmadd", // PPC_INS_QVFXXCPNMADD,
	"qvfxxcpnmadds", // PPC_INS_QVFXXCPNMADDS,
	"qvfxxmadd", // PPC_INS_QVFXXMADD,
	"qvfxxmadds", // PPC_INS_QVFXXMADDS,
	"qvfxxnpmadd", // PPC_INS_QVFXXNPMADD,
	"qvfxxnpmadds", // PPC_INS_QVFXXNPMADDS,
	"qvgpci", // PPC_INS_QVGPCI,
	"qvlfcdux", // PPC_INS_QVLFCDUX,
	"qvlfcduxa", // PPC_INS_QVLFCDUXA,
	"qvlfcdx", // PPC_INS_QVLFCDX,
	"qvlfcdxa", // PPC_INS_QVLFCDXA,
	"qvlfcsux", // PPC_INS_QVLFCSUX,
	"qvlfcsuxa", // PPC_INS_QVLFCSUXA,
	"qvlfcsx", // PPC_INS_QVLFCSX,
	"qvlfcsxa", // PPC_INS_QVLFCSXA,
	"qvlfdux", // PPC_INS_QVLFDUX,
	"qvlfduxa", // PPC_INS_QVLFDUXA,
	"qvlfdx", // PPC_INS_QVLFDX,
	"qvlfdxa", // PPC_INS_QVLFDXA,
	"qvlfiwax", // PPC_INS_QVLFIWAX,
	"qvlfiwaxa", // PPC_INS_QVLFIWAXA,
	"qvlfiwzx", // PPC_INS_QVLFIWZX,
	"qvlfiwzxa", // PPC_INS_QVLFIWZXA,
	"qvlfsux", // PPC_INS_QVLFSUX,
	"qvlfsuxa", // PPC_INS_QVLFSUXA,
	"qvlfsx", // PPC_INS_QVLFSX,
	"qvlfsxa", // PPC_INS_QVLFSXA,
	"qvlpcldx", // PPC_INS_QVLPCLDX,
	"qvlpclsx", // PPC_INS_QVLPCLSX,
	"qvlpcrdx", // PPC_INS_QVLPCRDX,
	"qvlpcrsx", // PPC_INS_QVLPCRSX,
	"qvstfcdux", // PPC_INS_QVSTFCDUX,
	"qvstfcduxa", // PPC_INS_QVSTFCDUXA,
	"qvstfcduxi", // PPC_INS_QVSTFCDUXI,
	"qvstfcduxia", // PPC_INS_QVSTFCDUXIA,
	"qvstfcdx", // PPC_INS_QVSTFCDX,
	"qvstfcdxa", // PPC_INS_QVSTFCDXA,
	"qvstfcdxi", // PPC_INS_QVSTFCDXI,
	"qvstfcdxia", // PPC_INS_QVSTFCDXIA,
	"qvstfcsux", // PPC_INS_QVSTFCSUX,
	"qvstfcsuxa", // PPC_INS_QVSTFCSUXA,
	"qvstfcsuxi", // PPC_INS_QVSTFCSUXI,
	"qvstfcsuxia", // PPC_INS_QVSTFCSUXIA,
	"qvstfcsx", // PPC_INS_QVSTFCSX,
	"qvstfcsxa", // PPC_INS_QVSTFCSXA,
	"qvstfcsxi", // PPC_INS_QVSTFCSXI,
	"qvstfcsxia", // PPC_INS_QVSTFCSXIA,
	"qvstfdux", // PPC_INS_QVSTFDUX,
	"qvstfduxa", // PPC_INS_QVSTFDUXA,
	"qvstfduxi", // PPC_INS_QVSTFDUXI,
	"qvstfduxia", // PPC_INS_QVSTFDUXIA,
	"qvstfdx", // PPC_INS_QVSTFDX,
	"qvstfdxa", // PPC_INS_QVSTFDXA,
	"qvstfdxi", // PPC_INS_QVSTFDXI,
	"qvstfdxia", // PPC_INS_QVSTFDXIA,
	"qvstfiwx", // PPC_INS_QVSTFIWX,
	"qvstfiwxa", // PPC_INS_QVSTFIWXA,
	"qvstfsux", // PPC_INS_QVSTFSUX,
	"qvstfsuxa", // PPC_INS_QVSTFSUXA,
	"qvstfsuxi", // PPC_INS_QVSTFSUXI,
	"qvstfsuxia", // PPC_INS_QVSTFSUXIA,
	"qvstfsx", // PPC_INS_QVSTFSX,
	"qvstfsxa", // PPC_INS_QVSTFSXA,
	"qvstfsxi", // PPC_INS_QVSTFSXI,
	"qvstfsxia", // PPC_INS_QVSTFSXIA,
	"rfci", // PPC_INS_RFCI,
	"rfdi", // PPC_INS_RFDI,
	"rfebb", // PPC_INS_RFEBB,
	"rfi", // PPC_INS_RFI,
	"rfid", // PPC_INS_RFID,
	"rfmci", // PPC_INS_RFMCI,
	"rldcl", // PPC_INS_RLDCL,
	"rldcr", // PPC_INS_RLDCR,
	"rldic", // PPC_INS_RLDIC,
	"rldicl", // PPC_INS_RLDICL,
	"rldicr", // PPC_INS_RLDICR,
	"rldimi", // PPC_INS_RLDIMI,
	"rlwimi", // PPC_INS_RLWIMI,
	"rlwinm", // PPC_INS_RLWINM,
	"rlwnm", // PPC_INS_RLWNM,
	"rotld", // PPC_INS_ROTLD,
	"rotldi", // PPC_INS_ROTLDI,
	"rotlw", // PPC_INS_ROTLW,
	"rotlwi", // PPC_INS_ROTLWI,
	"rotrdi", // PPC_INS_ROTRDI,
	"rotrwi", // PPC_INS_ROTRWI,
	"sc", // PPC_INS_SC,
	"setb", // PPC_INS_SETB,
	"slbia", // PPC_INS_SLBIA,
	"slbie", // PPC_INS_SLBIE,
	"slbieg", // PPC_INS_SLBIEG,
	"slbmfee", // PPC_INS_SLBMFEE,
	"slbmfev", // PPC_INS_SLBMFEV,
	"slbmte", // PPC_INS_SLBMTE,
	"slbsync", // PPC_INS_SLBSYNC,
	"sld", // PPC_INS_SLD,
	"sldi", // PPC_INS_SLDI,
	"slw", // PPC_INS_SLW,
	"slwi", // PPC_INS_SLWI,
	"srad", // PPC_INS_SRAD,
	"sradi", // PPC_INS_SRADI,
	"sraw", // PPC_INS_SRAW,
	"srawi", // PPC_INS_SRAWI,
	"srd", // PPC_INS_SRD,
	"srdi", // PPC_INS_SRDI,
	"srw", // PPC_INS_SRW,
	"srwi", // PPC_INS_SRWI,
	"stb", // PPC_INS_STB,
	"stbcix", // PPC_INS_STBCIX,
	"stbcx", // PPC_INS_STBCX,
	"stbepx", // PPC_INS_STBEPX,
	"stbu", // PPC_INS_STBU,
	"stbux", // PPC_INS_STBUX,
	"stbx", // PPC_INS_STBX,
	"std", // PPC_INS_STD,
	"stdat", // PPC_INS_STDAT,
	"stdbrx", // PPC_INS_STDBRX,
	"stdcix", // PPC_INS_STDCIX,
	"stdcx", // PPC_INS_STDCX,
	"stdu", // PPC_INS_STDU,
	"stdux", // PPC_INS_STDUX,
	"stdx", // PPC_INS_STDX,
	"stfd", // PPC_INS_STFD,
	"stfdepx", // PPC_INS_STFDEPX,
	"stfdu", // PPC_INS_STFDU,
	"stfdux", // PPC_INS_STFDUX,
	"stfdx", // PPC_INS_STFDX,
	"stfiwx", // PPC_INS_STFIWX,
	"stfs", // PPC_INS_STFS,
	"stfsu", // PPC_INS_STFSU,
	"stfsux", // PPC_INS_STFSUX,
	"stfsx", // PPC_INS_STFSX,
	"sth", // PPC_INS_STH,
	"sthbrx", // PPC_INS_STHBRX,
	"sthcix", // PPC_INS_STHCIX,
	"sthcx", // PPC_INS_STHCX,
	"sthepx", // PPC_INS_STHEPX,
	"sthu", // PPC_INS_STHU,
	"sthux", // PPC_INS_STHUX,
	"sthx", // PPC_INS_STHX,
	"stmw", // PPC_INS_STMW,
	"stop", // PPC_INS_STOP,
	"stswi", // PPC_INS_STSWI,
	"stvebx", // PPC_INS_STVEBX,
	"stvehx", // PPC_INS_STVEHX,
	"stvewx", // PPC_INS_STVEWX,
	"stvx", // PPC_INS_STVX,
	"stvxl", // PPC_INS_STVXL,
	"stw", // PPC_INS_STW,
	"stwat", // PPC_INS_STWAT,
	"stwbrx", // PPC_INS_STWBRX,
	"stwcix", // PPC_INS_STWCIX,
	"stwcx", // PPC_INS_STWCX,
	"stwepx", // PPC_INS_STWEPX,
	"stwu", // PPC_INS_STWU,
	"stwux", // PPC_INS_STWUX,
	"stwx", // PPC_INS_STWX,
	"stxsd", // PPC_INS_STXSD,
	"stxsdx", // PPC_INS_STXSDX,
	"stxsibx", // PPC_INS_STXSIBX,
	"stxsihx", // PPC_INS_STXSIHX,
	"stxsiwx", // PPC_INS_STXSIWX,
	"stxssp", // PPC_INS_STXSSP,
	"stxsspx", // PPC_INS_STXSSPX,
	"stxv", // PPC_INS_STXV,
	"stxvb16x", // PPC_INS_STXVB16X,
	"stxvd2x", // PPC_INS_STXVD2X,
	"stxvh8x", // PPC_INS_STXVH8X,
	"stxvl", // PPC_INS_STXVL,
	"stxvll", // PPC_INS_STXVLL,
	"stxvw4x", // PPC_INS_STXVW4X,
	"stxvx", // PPC_INS_STXVX,
	"sub", // PPC_INS_SUB,
	"subc", // PPC_INS_SUBC,
	"subf", // PPC_INS_SUBF,
	"subfc", // PPC_INS_SUBFC,
	"subfe", // PPC_INS_SUBFE,
	"subfic", // PPC_INS_SUBFIC,
	"subfme", // PPC_INS_SUBFME,
	"subfze", // PPC_INS_SUBFZE,
	"subi", // PPC_INS_SUBI,
	"subic", // PPC_INS_SUBIC,
	"subis", // PPC_INS_SUBIS,
	"subpcis", // PPC_INS_SUBPCIS,
	"sync", // PPC_INS_SYNC,
	"tabort", // PPC_INS_TABORT,
	"tabortdc", // PPC_INS_TABORTDC,
	"tabortdci", // PPC_INS_TABORTDCI,
	"tabortwc", // PPC_INS_TABORTWC,
	"tabortwci", // PPC_INS_TABORTWCI,
	"tbegin", // PPC_INS_TBEGIN,
	"tcheck", // PPC_INS_TCHECK,
	"td", // PPC_INS_TD,
	"tdeq", // PPC_INS_TDEQ,
	"tdeqi", // PPC_INS_TDEQI,
	"tdge", // PPC_INS_TDGE,
	"tdgei", // PPC_INS_TDGEI,
	"tdgt", // PPC_INS_TDGT,
	"tdgti", // PPC_INS_TDGTI,
	"tdi", // PPC_INS_TDI,
	"tdle", // PPC_INS_TDLE,
	"tdlei", // PPC_INS_TDLEI,
	"tdlge", // PPC_INS_TDLGE,
	"tdlgei", // PPC_INS_TDLGEI,
	"tdlgt", // PPC_INS_TDLGT,
	"tdlgti", // PPC_INS_TDLGTI,
	"tdlle", // PPC_INS_TDLLE,
	"tdllei", // PPC_INS_TDLLEI,
	"tdllt", // PPC_INS_TDLLT,
	"tdllti", // PPC_INS_TDLLTI,
	"tdlng", // PPC_INS_TDLNG,
	"tdlngi", // PPC_INS_TDLNGI,
	"tdlnl", // PPC_INS_TDLNL,
	"tdlnli", // PPC_INS_TDLNLI,
	"tdlt", // PPC_INS_TDLT,
	"tdlti", // PPC_INS_TDLTI,
	"tdne", // PPC_INS_TDNE,
	"tdnei", // PPC_INS_TDNEI,
	"tdng", // PPC_INS_TDNG,
	"tdngi", // PPC_INS_TDNGI,
	"tdnl", // PPC_INS_TDNL,
	"tdnli", // PPC_INS_TDNLI,
	"tdu", // PPC_INS_TDU,
	"tdui", // PPC_INS_TDUI,
	"tend", // PPC_INS_TEND,
	"tlbia", // PPC_INS_TLBIA,
	"tlbie", // PPC_INS_TLBIE,
	"tlbiel", // PPC_INS_TLBIEL,
	"tlbivax", // PPC_INS_TLBIVAX,
	"tlbld", // PPC_INS_TLBLD,
	"tlbli", // PPC_INS_TLBLI,
	"tlbre", // PPC_INS_TLBRE,
	"tlbrehi", // PPC_INS_TLBREHI,
	"tlbrelo", // PPC_INS_TLBRELO,
	"tlbsx", // PPC_INS_TLBSX,
	"tlbsync", // PPC_INS_TLBSYNC,
	"tlbwe", // PPC_INS_TLBWE,
	"tlbwehi", // PPC_INS_TLBWEHI,
	"tlbwelo", // PPC_INS_TLBWELO,
	"trap", // PPC_INS_TRAP,
	"trechkpt", // PPC_INS_TRECHKPT,
	"treclaim", // PPC_INS_TRECLAIM,
	"tsr", // PPC_INS_TSR,
	"tw", // PPC_INS_TW,
	"tweq", // PPC_INS_TWEQ,
	"tweqi", // PPC_INS_TWEQI,
	"twge", // PPC_INS_TWGE,
	"twgei", // PPC_INS_TWGEI,
	"twgt", // PPC_INS_TWGT,
	"twgti", // PPC_INS_TWGTI,
	"twi", // PPC_INS_TWI,
	"twle", // PPC_INS_TWLE,
	"twlei", // PPC_INS_TWLEI,
	"twlge", // PPC_INS_TWLGE,
	"twlgei", // PPC_INS_TWLGEI,
	"twlgt", // PPC_INS_TWLGT,
	"twlgti", // PPC_INS_TWLGTI,
	"twlle", // PPC_INS_TWLLE,
	"twllei", // PPC_INS_TWLLEI,
	"twllt", // PPC_INS_TWLLT,
	"twllti", // PPC_INS_TWLLTI,
	"twlng", // PPC_INS_TWLNG,
	"twlngi", // PPC_INS_TWLNGI,
	"twlnl", // PPC_INS_TWLNL,
	"twlnli", // PPC_INS_TWLNLI,
	"twlt", // PPC_INS_TWLT,
	"twlti", // PPC_INS_TWLTI,
	"twne", // PPC_INS_TWNE,
	"twnei", // PPC_INS_TWNEI,
	"twng", // PPC_INS_TWNG,
	"twngi", // PPC_INS_TWNGI,
	"twnl", // PPC_INS_TWNL,
	"twnli", // PPC_INS_TWNLI,
	"twu", // PPC_INS_TWU,
	"twui", // PPC_INS_TWUI,
	"vabsdub", // PPC_INS_VABSDUB,
	"vabsduh", // PPC_INS_VABSDUH,
	"vabsduw", // PPC_INS_VABSDUW,
	"vaddcuq", // PPC_INS_VADDCUQ,
	"vaddcuw", // PPC_INS_VADDCUW,
	"vaddecuq", // PPC_INS_VADDECUQ,
	"vaddeuqm", // PPC_INS_VADDEUQM,
	"vaddfp", // PPC_INS_VADDFP,
	"vaddsbs", // PPC_INS_VADDSBS,
	"vaddshs", // PPC_INS_VADDSHS,
	"vaddsws", // PPC_INS_VADDSWS,
	"vaddubm", // PPC_INS_VADDUBM,
	"vaddubs", // PPC_INS_VADDUBS,
	"vaddudm", // PPC_INS_VADDUDM,
	"vadduhm", // PPC_INS_VADDUHM,
	"vadduhs", // PPC_INS_VADDUHS,
	"vadduqm", // PPC_INS_VADDUQM,
	"vadduwm", // PPC_INS_VADDUWM,
	"vadduws", // PPC_INS_VADDUWS,
	"vand", // PPC_INS_VAND,
	"vandc", // PPC_INS_VANDC,
	"vavgsb", // PPC_INS_VAVGSB,
	"vavgsh", // PPC_INS_VAVGSH,
	"vavgsw", // PPC_INS_VAVGSW,
	"vavgub", // PPC_INS_VAVGUB,
	"vavguh", // PPC_INS_VAVGUH,
	"vavguw", // PPC_INS_VAVGUW,
	"vbpermd", // PPC_INS_VBPERMD,
	"vbpermq", // PPC_INS_VBPERMQ,
	"vcfsx", // PPC_INS_VCFSX,
	"vcfux", // PPC_INS_VCFUX,
	"vcipher", // PPC_INS_VCIPHER,
	"vcipherlast", // PPC_INS_VCIPHERLAST,
	"vclzb", // PPC_INS_VCLZB,
	"vclzd", // PPC_INS_VCLZD,
	"vclzh", // PPC_INS_VCLZH,
	"vclzlsbb", // PPC_INS_VCLZLSBB,
	"vclzw", // PPC_INS_VCLZW,
	"vcmpbfp", // PPC_INS_VCMPBFP,
	"vcmpeqfp", // PPC_INS_VCMPEQFP,
	"vcmpequb", // PPC_INS_VCMPEQUB,
	"vcmpequd", // PPC_INS_VCMPEQUD,
	"vcmpequh", // PPC_INS_VCMPEQUH,
	"vcmpequw", // PPC_INS_VCMPEQUW,
	"vcmpgefp", // PPC_INS_VCMPGEFP,
	"vcmpgtfp", // PPC_INS_VCMPGTFP,
	"vcmpgtsb", // PPC_INS_VCMPGTSB,
	"vcmpgtsd", // PPC_INS_VCMPGTSD,
	"vcmpgtsh", // PPC_INS_VCMPGTSH,
	"vcmpgtsw", // PPC_INS_VCMPGTSW,
	"vcmpgtub", // PPC_INS_VCMPGTUB,
	"vcmpgtud", // PPC_INS_VCMPGTUD,
	"vcmpgtuh", // PPC_INS_VCMPGTUH,
	"vcmpgtuw", // PPC_INS_VCMPGTUW,
	"vcmpneb", // PPC_INS_VCMPNEB,
	"vcmpneh", // PPC_INS_VCMPNEH,
	"vcmpnew", // PPC_INS_VCMPNEW,
	"vcmpnezb", // PPC_INS_VCMPNEZB,
	"vcmpnezh", // PPC_INS_VCMPNEZH,
	"vcmpnezw", // PPC_INS_VCMPNEZW,
	"vctsxs", // PPC_INS_VCTSXS,
	"vctuxs", // PPC_INS_VCTUXS,
	"vctzb", // PPC_INS_VCTZB,
	"vctzd", // PPC_INS_VCTZD,
	"vctzh", // PPC_INS_VCTZH,
	"vctzlsbb", // PPC_INS_VCTZLSBB,
	"vctzw", // PPC_INS_VCTZW,
	"veqv", // PPC_INS_VEQV,
	"vexptefp", // PPC_INS_VEXPTEFP,
	"vextractd", // PPC_INS_VEXTRACTD,
	"vextractub", // PPC_INS_VEXTRACTUB,
	"vextractuh", // PPC_INS_VEXTRACTUH,
	"vextractuw", // PPC_INS_VEXTRACTUW,
	"vextsb2d", // PPC_INS_VEXTSB2D,
	"vextsb2w", // PPC_INS_VEXTSB2W,
	"vextsh2d", // PPC_INS_VEXTSH2D,
	"vextsh2w", // PPC_INS_VEXTSH2W,
	"vextsw2d", // PPC_INS_VEXTSW2D,
	"vextublx", // PPC_INS_VEXTUBLX,
	"vextubrx", // PPC_INS_VEXTUBRX,
	"vextuhlx", // PPC_INS_VEXTUHLX,
	"vextuhrx", // PPC_INS_VEXTUHRX,
	"vextuwlx", // PPC_INS_VEXTUWLX,
	"vextuwrx", // PPC_INS_VEXTUWRX,
	"vgbbd", // PPC_INS_VGBBD,
	"vinsertb", // PPC_INS_VINSERTB,
	"vinsertd", // PPC_INS_VINSERTD,
	"vinserth", // PPC_INS_VINSERTH,
	"vinsertw", // PPC_INS_VINSERTW,
	"vlogefp", // PPC_INS_VLOGEFP,
	"vmaddfp", // PPC_INS_VMADDFP,
	"vmaxfp", // PPC_INS_VMAXFP,
	"vmaxsb", // PPC_INS_VMAXSB,
	"vmaxsd", // PPC_INS_VMAXSD,
	"vmaxsh", // PPC_INS_VMAXSH,
	"vmaxsw", // PPC_INS_VMAXSW,
	"vmaxub", // PPC_INS_VMAXUB,
	"vmaxud", // PPC_INS_VMAXUD,
	"vmaxuh", // PPC_INS_VMAXUH,
	"vmaxuw", // PPC_INS_VMAXUW,
	"vmhaddshs", // PPC_INS_VMHADDSHS,
	"vmhraddshs", // PPC_INS_VMHRADDSHS,
	"vminfp", // PPC_INS_VMINFP,
	"vminsb", // PPC_INS_VMINSB,
	"vminsd", // PPC_INS_VMINSD,
	"vminsh", // PPC_INS_VMINSH,
	"vminsw", // PPC_INS_VMINSW,
	"vminub", // PPC_INS_VMINUB,
	"vminud", // PPC_INS_VMINUD,
	"vminuh", // PPC_INS_VMINUH,
	"vminuw", // PPC_INS_VMINUW,
	"vmladduhm", // PPC_INS_VMLADDUHM,
	"vmr", // PPC_INS_VMR,
	"vmrgew", // PPC_INS_VMRGEW,
	"vmrghb", // PPC_INS_VMRGHB,
	"vmrghh", // PPC_INS_VMRGHH,
	"vmrghw", // PPC_INS_VMRGHW,
	"vmrglb", // PPC_INS_VMRGLB,
	"vmrglh", // PPC_INS_VMRGLH,
	"vmrglw", // PPC_INS_VMRGLW,
	"vmrgow", // PPC_INS_VMRGOW,
	"vmsummbm", // PPC_INS_VMSUMMBM,
	"vmsumshm", // PPC_INS_VMSUMSHM,
	"vmsumshs", // PPC_INS_VMSUMSHS,
	"vmsumubm", // PPC_INS_VMSUMUBM,
	"vmsumuhm", // PPC_INS_VMSUMUHM,
	"vmsumuhs", // PPC_INS_VMSUMUHS,
	"vmul10cuq", // PPC_INS_VMUL10CUQ,
	"vmul10ecuq", // PPC_INS_VMUL10ECUQ,
	"vmul10euq", // PPC_INS_VMUL10EUQ,
	"vmul10uq", // PPC_INS_VMUL10UQ,
	"vmulesb", // PPC_INS_VMULESB,
	"vmulesh", // PPC_INS_VMULESH,
	"vmulesw", // PPC_INS_VMULESW,
	"vmuleub", // PPC_INS_VMULEUB,
	"vmuleuh", // PPC_INS_VMULEUH,
	"vmuleuw", // PPC_INS_VMULEUW,
	"vmulosb", // PPC_INS_VMULOSB,
	"vmulosh", // PPC_INS_VMULOSH,
	"vmulosw", // PPC_INS_VMULOSW,
	"vmuloub", // PPC_INS_VMULOUB,
	"vmulouh", // PPC_INS_VMULOUH,
	"vmulouw", // PPC_INS_VMULOUW,
	"vmuluwm", // PPC_INS_VMULUWM,
	"vnand", // PPC_INS_VNAND,
	"vncipher", // PPC_INS_VNCIPHER,
	"vncipherlast", // PPC_INS_VNCIPHERLAST,
	"vnegd", // PPC_INS_VNEGD,
	"vnegw", // PPC_INS_VNEGW,
	"vnmsubfp", // PPC_INS_VNMSUBFP,
	"vnor", // PPC_INS_VNOR,
	"vnot", // PPC_INS_VNOT,
	"vor", // PPC_INS_VOR,
	"vorc", // PPC_INS_VORC,
	"vperm", // PPC_INS_VPERM,
	"vpermr", // PPC_INS_VPERMR,
	"vpermxor", // PPC_INS_VPERMXOR,
	"vpkpx", // PPC_INS_VPKPX,
	"vpksdss", // PPC_INS_VPKSDSS,
	"vpksdus", // PPC_INS_VPKSDUS,
	"vpkshss", // PPC_INS_VPKSHSS,
	"vpkshus", // PPC_INS_VPKSHUS,
	"vpkswss", // PPC_INS_VPKSWSS,
	"vpkswus", // PPC_INS_VPKSWUS,
	"vpkudum", // PPC_INS_VPKUDUM,
	"vpkudus", // PPC_INS_VPKUDUS,
	"vpkuhum", // PPC_INS_VPKUHUM,
	"vpkuhus", // PPC_INS_VPKUHUS,
	"vpkuwum", // PPC_INS_VPKUWUM,
	"vpkuwus", // PPC_INS_VPKUWUS,
	"vpmsumb", // PPC_INS_VPMSUMB,
	"vpmsumd", // PPC_INS_VPMSUMD,
	"vpmsumh", // PPC_INS_VPMSUMH,
	"vpmsumw", // PPC_INS_VPMSUMW,
	"vpopcntb", // PPC_INS_VPOPCNTB,
	"vpopcntd", // PPC_INS_VPOPCNTD,
	"vpopcnth", // PPC_INS_VPOPCNTH,
	"vpopcntw", // PPC_INS_VPOPCNTW,
	"vprtybd", // PPC_INS_VPRTYBD,
	"vprtybq", // PPC_INS_VPRTYBQ,
	"vprtybw", // PPC_INS_VPRTYBW,
	"vrefp", // PPC_INS_VREFP,
	"vrfim", // PPC_INS_VRFIM,
	"vrfin", // PPC_INS_VRFIN,
	"vrfip", // PPC_INS_VRFIP,
	"vrfiz", // PPC_INS_VRFIZ,
	"vrlb", // PPC_INS_VRLB,
	"vrld", // PPC_INS_VRLD,
	"vrldmi", // PPC_INS_VRLDMI,
	"vrldnm", // PPC_INS_VRLDNM,
	"vrlh", // PPC_INS_VRLH,
	"vrlw", // PPC_INS_VRLW,
	"vrlwmi", // PPC_INS_VRLWMI,
	"vrlwnm", // PPC_INS_VRLWNM,
	"vrsqrtefp", // PPC_INS_VRSQRTEFP,
	"vsbox", // PPC_INS_VSBOX,
	"vsel", // PPC_INS_VSEL,
	"vshasigmad", // PPC_INS_VSHASIGMAD,
	"vshasigmaw", // PPC_INS_VSHASIGMAW,
	"vsl", // PPC_INS_VSL,
	"vslb", // PPC_INS_VSLB,
	"vsld", // PPC_INS_VSLD,
	"vsldoi", // PPC_INS_VSLDOI,
	"vslh", // PPC_INS_VSLH,
	"vslo", // PPC_INS_VSLO,
	"vslv", // PPC_INS_VSLV,
	"vslw", // PPC_INS_VSLW,
	"vspltb", // PPC_INS_VSPLTB,
	"vsplth", // PPC_INS_VSPLTH,
	"vspltisb", // PPC_INS_VSPLTISB,
	"vspltish", // PPC_INS_VSPLTISH,
	"vspltisw", // PPC_INS_VSPLTISW,
	"vspltw", // PPC_INS_VSPLTW,
	"vsr", // PPC_INS_VSR,
	"vsrab", // PPC_INS_VSRAB,
	"vsrad", // PPC_INS_VSRAD,
	"vsrah", // PPC_INS_VSRAH,
	"vsraw", // PPC_INS_VSRAW,
	"vsrb", // PPC_INS_VSRB,
	"vsrd", // PPC_INS_VSRD,
	"vsrh", // PPC_INS_VSRH,
	"vsro", // PPC_INS_VSRO,
	"vsrv", // PPC_INS_VSRV,
	"vsrw", // PPC_INS_VSRW,
	"vsubcuq", // PPC_INS_VSUBCUQ,
	"vsubcuw", // PPC_INS_VSUBCUW,
	"vsubecuq", // PPC_INS_VSUBECUQ,
	"vsubeuqm", // PPC_INS_VSUBEUQM,
	"vsubfp", // PPC_INS_VSUBFP,
	"vsubsbs", // PPC_INS_VSUBSBS,
	"vsubshs", // PPC_INS_VSUBSHS,
	"vsubsws", // PPC_INS_VSUBSWS,
	"vsububm", // PPC_INS_VSUBUBM,
	"vsububs", // PPC_INS_VSUBUBS,
	"vsubudm", // PPC_INS_VSUBUDM,
	"vsubuhm", // PPC_INS_VSUBUHM,
	"vsubuhs", // PPC_INS_VSUBUHS,
	"vsubuqm", // PPC_INS_VSUBUQM,
	"vsubuwm", // PPC_INS_VSUBUWM,
	"vsubuws", // PPC_INS_VSUBUWS,
	"vsum2sws", // PPC_INS_VSUM2SWS,
	"vsum4sbs", // PPC_INS_VSUM4SBS,
	"vsum4shs", // PPC_INS_VSUM4SHS,
	"vsum4ubs", // PPC_INS_VSUM4UBS,
	"vsumsws", // PPC_INS_VSUMSWS,
	"vupkhpx", // PPC_INS_VUPKHPX,
	"vupkhsb", // PPC_INS_VUPKHSB,
	"vupkhsh", // PPC_INS_VUPKHSH,
	"vupkhsw", // PPC_INS_VUPKHSW,
	"vupklpx", // PPC_INS_VUPKLPX,
	"vupklsb", // PPC_INS_VUPKLSB,
	"vupklsh", // PPC_INS_VUPKLSH,
	"vupklsw", // PPC_INS_VUPKLSW,
	"vxor", // PPC_INS_VXOR,
	"wait", // PPC_INS_WAIT,
	"waitimpl", // PPC_INS_WAITIMPL,
	"waitrsv", // PPC_INS_WAITRSV,
	"wrtee", // PPC_INS_WRTEE,
	"wrteei", // PPC_INS_WRTEEI,
	"xnop", // PPC_INS_XNOP,
	"xor", // PPC_INS_XOR,
	"xori", // PPC_INS_XORI,
	"xoris", // PPC_INS_XORIS,
	"xsabsdp", // PPC_INS_XSABSDP,
	"xsabsqp", // PPC_INS_XSABSQP,
	"xsadddp", // PPC_INS_XSADDDP,
	"xsaddqp", // PPC_INS_XSADDQP,
	"xsaddqpo", // PPC_INS_XSADDQPO,
	"xsaddsp", // PPC_INS_XSADDSP,
	"xscmpeqdp", // PPC_INS_XSCMPEQDP,
	"xscmpexpdp", // PPC_INS_XSCMPEXPDP,
	"xscmpexpqp", // PPC_INS_XSCMPEXPQP,
	"xscmpgedp", // PPC_INS_XSCMPGEDP,
	"xscmpgtdp", // PPC_INS_XSCMPGTDP,
	"xscmpodp", // PPC_INS_XSCMPODP,
	"xscmpoqp", // PPC_INS_XSCMPOQP,
	"xscmpudp", // PPC_INS_XSCMPUDP,
	"xscmpuqp", // PPC_INS_XSCMPUQP,
	"xscpsgndp", // PPC_INS_XSCPSGNDP,
	"xscpsgnqp", // PPC_INS_XSCPSGNQP,
	"xscvdphp", // PPC_INS_XSCVDPHP,
	"xscvdpqp", // PPC_INS_XSCVDPQP,
	"xscvdpsp", // PPC_INS_XSCVDPSP,
	"xscvdpspn", // PPC_INS_XSCVDPSPN,
	"xscvdpsxds", // PPC_INS_XSCVDPSXDS,
	"xscvdpsxws", // PPC_INS_XSCVDPSXWS,
	"xscvdpuxds", // PPC_INS_XSCVDPUXDS,
	"xscvdpuxws", // PPC_INS_XSCVDPUXWS,
	"xscvhpdp", // PPC_INS_XSCVHPDP,
	"xscvqpdp", // PPC_INS_XSCVQPDP,
	"xscvqpdpo", // PPC_INS_XSCVQPDPO,
	"xscvqpsdz", // PPC_INS_XSCVQPSDZ,
	"xscvqpswz", // PPC_INS_XSCVQPSWZ,
	"xscvqpudz", // PPC_INS_XSCVQPUDZ,
	"xscvqpuwz", // PPC_INS_XSCVQPUWZ,
	"xscvsdqp", // PPC_INS_XSCVSDQP,
	"xscvspdp", // PPC_INS_XSCVSPDP,
	"xscvspdpn", // PPC_INS_XSCVSPDPN,
	"xscvsxddp", // PPC_INS_XSCVSXDDP,
	"xscvsxdsp", // PPC_INS_XSCVSXDSP,
	"xscvudqp", // PPC_INS_XSCVUDQP,
	"xscvuxddp", // PPC_INS_XSCVUXDDP,
	"xscvuxdsp", // PPC_INS_XSCVUXDSP,
	"xsdivdp", // PPC_INS_XSDIVDP,
	"xsdivqp", // PPC_INS_XSDIVQP,
	"xsdivqpo", // PPC_INS_XSDIVQPO,
	"xsdivsp", // PPC_INS_XSDIVSP,
	"xsiexpdp", // PPC_INS_XSIEXPDP,
	"xsiexpqp", // PPC_INS_XSIEXPQP,
	"xsmaddadp", // PPC_INS_XSMADDADP,
	"xsmaddasp", // PPC_INS_XSMADDASP,
	"xsmaddmdp", // PPC_INS_XSMADDMDP,
	"xsmaddmsp", // PPC_INS_XSMADDMSP,
	"xsmaddqp", // PPC_INS_XSMADDQP,
	"xsmaddqpo", // PPC_INS_XSMADDQPO,
	"xsmaxcdp", // PPC_INS_XSMAXCDP,
	"xsmaxdp", // PPC_INS_XSMAXDP,
	"xsmaxjdp", // PPC_INS_XSMAXJDP,
	"xsmincdp", // PPC_INS_XSMINCDP,
	"xsmindp", // PPC_INS_XSMINDP,
	"xsminjdp", // PPC_INS_XSMINJDP,
	"xsmsubadp", // PPC_INS_XSMSUBADP,
	"xsmsubasp", // PPC_INS_XSMSUBASP,
	"xsmsubmdp", // PPC_INS_XSMSUBMDP,
	"xsmsubmsp", // PPC_INS_XSMSUBMSP,
	"xsmsubqp", // PPC_INS_XSMSUBQP,
	"xsmsubqpo", // PPC_INS_XSMSUBQPO,
	"xsmuldp", // PPC_INS_XSMULDP,
	"xsmulqp", // PPC_INS_XSMULQP,
	"xsmulqpo", // PPC_INS_XSMULQPO,
	"xsmulsp", // PPC_INS_XSMULSP,
	"xsnabsdp", // PPC_INS_XSNABSDP,
	"xsnabsqp", // PPC_INS_XSNABSQP,
	"xsnegdp", // PPC_INS_XSNEGDP,
	"xsnegqp", // PPC_INS_XSNEGQP,
	"xsnmaddadp", // PPC_INS_XSNMADDADP,
	"xsnmaddasp", // PPC_INS_XSNMADDASP,
	"xsnmaddmdp", // PPC_INS_XSNMADDMDP,
	"xsnmaddmsp", // PPC_INS_XSNMADDMSP,
	"xsnmaddqp", // PPC_INS_XSNMADDQP,
	"xsnmaddqpo", // PPC_INS_XSNMADDQPO,
	"xsnmsubadp", // PPC_INS_XSNMSUBADP,
	"xsnmsubasp", // PPC_INS_XSNMSUBASP,
	"xsnmsubmdp", // PPC_INS_XSNMSUBMDP,
	"xsnmsubmsp", // PPC_INS_XSNMSUBMSP,
	"xsnmsubqp", // PPC_INS_XSNMSUBQP,
	"xsnmsubqpo", // PPC_INS_XSNMSUBQPO,
	"xsrdpi", // PPC_INS_XSRDPI,
	"xsrdpic", // PPC_INS_XSRDPIC,
	"xsrdpim", // PPC_INS_XSRDPIM,
	"xsrdpip", // PPC_INS_XSRDPIP,
	"xsrdpiz", // PPC_INS_XSRDPIZ,
	"xsredp", // PPC_INS_XSREDP,
	"xsresp", // PPC_INS_XSRESP,
	"xsrqpi", // PPC_INS_XSRQPI,
	"xsrqpix", // PPC_INS_XSRQPIX,
	"xsrqpxp", // PPC_INS_XSRQPXP,
	"xsrsp", // PPC_INS_XSRSP,
	"xsrsqrtedp", // PPC_INS_XSRSQRTEDP,
	"xsrsqrtesp", // PPC_INS_XSRSQRTESP,
	"xssqrtdp", // PPC_INS_XSSQRTDP,
	"xssqrtqp", // PPC_INS_XSSQRTQP,
	"xssqrtqpo", // PPC_INS_XSSQRTQPO,
	"xssqrtsp", // PPC_INS_XSSQRTSP,
	"xssubdp", // PPC_INS_XSSUBDP,
	"xssubqp", // PPC_INS_XSSUBQP,
	"xssubqpo", // PPC_INS_XSSUBQPO,
	"xssubsp", // PPC_INS_XSSUBSP,
	"xstdivdp", // PPC_INS_XSTDIVDP,
	"xstsqrtdp", // PPC_INS_XSTSQRTDP,
	"xststdcdp", // PPC_INS_XSTSTDCDP,
	"xststdcqp", // PPC_INS_XSTSTDCQP,
	"xststdcsp", // PPC_INS_XSTSTDCSP,
	"xsxexpdp", // PPC_INS_XSXEXPDP,
	"xsxexpqp", // PPC_INS_XSXEXPQP,
	"xsxsigdp", // PPC_INS_XSXSIGDP,
	"xsxsigqp", // PPC_INS_XSXSIGQP,
	"xvabsdp", // PPC_INS_XVABSDP,
	"xvabssp", // PPC_INS_XVABSSP,
	"xvadddp", // PPC_INS_XVADDDP,
	"xvaddsp", // PPC_INS_XVADDSP,
	"xvcmpeqdp", // PPC_INS_XVCMPEQDP,
	"xvcmpeqsp", // PPC_INS_XVCMPEQSP,
	"xvcmpgedp", // PPC_INS_XVCMPGEDP,
	"xvcmpgesp", // PPC_INS_XVCMPGESP,
	"xvcmpgtdp", // PPC_INS_XVCMPGTDP,
	"xvcmpgtsp", // PPC_INS_XVCMPGTSP,
	"xvcpsgndp", // PPC_INS_XVCPSGNDP,
	"xvcpsgnsp", // PPC_INS_XVCPSGNSP,
	"xvcvdpsp", // PPC_INS_XVCVDPSP,
	"xvcvdpsxds", // PPC_INS_XVCVDPSXDS,
	"xvcvdpsxws", // PPC_INS_XVCVDPSXWS,
	"xvcvdpuxds", // PPC_INS_XVCVDPUXDS,
	"xvcvdpuxws", // PPC_INS_XVCVDPUXWS,
	"xvcvhpsp", // PPC_INS_XVCVHPSP,
	"xvcvspdp", // PPC_INS_XVCVSPDP,
	"xvcvsphp", // PPC_INS_XVCVSPHP,
	"xvcvspsxds", // PPC_INS_XVCVSPSXDS,
	"xvcvspsxws", // PPC_INS_XVCVSPSXWS,
	"xvcvspuxds", // PPC_INS_XVCVSPUXDS,
	"xvcvspuxws", // PPC_INS_XVCVSPUXWS,
	"xvcvsxddp", // PPC_INS_XVCVSXDDP,
	"xvcvsxdsp", // PPC_INS_XVCVSXDSP,
	"xvcvsxwdp", // PPC_INS_XVCVSXWDP,
	"xvcvsxwsp", // PPC_INS_XVCVSXWSP,
	"xvcvuxddp", // PPC_INS_XVCVUXDDP,
	"xvcvuxdsp", // PPC_INS_XVCVUXDSP,
	"xvcvuxwdp", // PPC_INS_XVCVUXWDP,
	"xvcvuxwsp", // PPC_INS_XVCVUXWSP,
	"xvdivdp", // PPC_INS_XVDIVDP,
	"xvdivsp", // PPC_INS_XVDIVSP,
	"xviexpdp", // PPC_INS_XVIEXPDP,
	"xviexpsp", // PPC_INS_XVIEXPSP,
	"xvmaddadp", // PPC_INS_XVMADDADP,
	"xvmaddasp", // PPC_INS_XVMADDASP,
	"xvmaddmdp", // PPC_INS_XVMADDMDP,
	"xvmaddmsp", // PPC_INS_XVMADDMSP,
	"xvmaxdp", // PPC_INS_XVMAXDP,
	"xvmaxsp", // PPC_INS_XVMAXSP,
	"xvmindp", // PPC_INS_XVMINDP,
	"xvminsp", // PPC_INS_XVMINSP,
	"xvmovdp", // PPC_INS_XVMOVDP,
	"xvmovsp", // PPC_INS_XVMOVSP,
	"xvmsubadp", // PPC_INS_XVMSUBADP,
	"xvmsubasp", // PPC_INS_XVMSUBASP,
	"xvmsubmdp", // PPC_INS_XVMSUBMDP,
	"xvmsubmsp", // PPC_INS_XVMSUBMSP,
	"xvmuldp", // PPC_INS_XVMULDP,
	"xvmulsp", // PPC_INS_XVMULSP,
	"xvnabsdp", // PPC_INS_XVNABSDP,
	"xvnabssp", // PPC_INS_XVNABSSP,
	"xvnegdp", // PPC_INS_XVNEGDP,
	"xvnegsp", // PPC_INS_XVNEGSP,
	"xvnmaddadp", // PPC_INS_XVNMADDADP,
	"xvnmaddasp", // PPC_INS_XVNMADDASP,
	"xvnmaddmdp", // PPC_INS_XVNMADDMDP,
	"xvnmaddmsp", // PPC_INS_XVNMADDMSP,
	"xvnmsubadp", // PPC_INS_XVNMSUBADP,
	"xvnmsubasp", // PPC_INS_XVNMSUBASP,
	"xvnmsubmdp", // PPC_INS_XVNMSUBMDP,
	"xvnmsubmsp", // PPC_INS_XVNMSUBMSP,
	"xvrdpi", // PPC_INS_XVRDPI,
	"xvrdpic", // PPC_INS_XVRDPIC,
	"xvrdpim", // PPC_INS_XVRDPIM,
	"xvrdpip", // PPC_INS_XVRDPIP,
	"xvrdpiz", // PPC_INS_XVRDPIZ,
	"xvredp", // PPC_INS_XVREDP,
	"xvresp", // PPC_INS_XVRESP,
	"xvrspi", // PPC_INS_XVRSPI,
	"xvrspic", // PPC_INS_XVRSPIC,
	"xvrspim", // PPC_INS_XVRSPIM,
	"xvrspip", // PPC_INS_XVRSPIP,
	"xvrspiz", // PPC_INS_XVRSPIZ,
	"xvrsqrtedp", // PPC_INS_XVRSQRTEDP,
	"xvrsqrtesp", // PPC_INS_XVRSQRTESP,
	"xvsqrtdp", // PPC_INS_XVSQRTDP,
	"xvsqrtsp", // PPC_INS_XVSQRTSP,
	"xvsubdp", // PPC_INS_XVSUBDP,
	"xvsubsp", // PPC_INS_XVSUBSP,
	"xvtdivdp", // PPC_INS_XVTDIVDP,
	"xvtdivsp", // PPC_INS_XVTDIVSP,
	"xvtsqrtdp", // PPC_INS_XVTSQRTDP,
	"xvtsqrtsp", // PPC_INS_XVTSQRTSP,
	"xvtstdcdp", // PPC_INS_XVTSTDCDP,
	"xvtstdcsp", // PPC_INS_XVTSTDCSP,
	"xvxexpdp", // PPC_INS_XVXEXPDP,
	"xvxexpsp", // PPC_INS_XVXEXPSP,
	"xvxsigdp", // PPC_INS_XVXSIGDP,
	"xvxsigsp", // PPC_INS_XVXSIGSP,
	"xxbrd", // PPC_INS_XXBRD,
	"xxbrh", // PPC_INS_XXBRH,
	"xxbrq", // PPC_INS_XXBRQ,
	"xxbrw", // PPC_INS_XXBRW,
	"xxextractuw", // PPC_INS_XXEXTRACTUW,
	"xxinsertw", // PPC_INS_XXINSERTW,
	"xxland", // PPC_INS_XXLAND,
	"xxlandc", // PPC_INS_XXLANDC,
	"xxleqv", // PPC_INS_XXLEQV,
	"xxlnand", // PPC_INS_XXLNAND,
	"xxlnor", // PPC_INS_XXLNOR,
	"xxlor", // PPC_INS_XXLOR,
	"xxlorc", // PPC_INS_XXLORC,
	"xxlxor", // PPC_INS_XXLXOR,
	"xxmrghd", // PPC_INS_XXMRGHD,
	"xxmrghw", // PPC_INS_XXMRGHW,
	"xxmrgld", // PPC_INS_XXMRGLD,
	"xxmrglw", // PPC_INS_XXMRGLW,
	"xxperm", // PPC_INS_XXPERM,
	"xxpermdi", // PPC_INS_XXPERMDI,
	"xxpermr", // PPC_INS_XXPERMR,
	"xxsel", // PPC_INS_XXSEL,
	"xxsldwi", // PPC_INS_XXSLDWI,
	"xxspltd", // PPC_INS_XXSPLTD,
	"xxspltib", // PPC_INS_XXSPLTIB,
	"xxspltw", // PPC_INS_XXSPLTW,
	"xxswapd", // PPC_INS_XXSWAPD,

	"dcbz_l", // PPC_INS_DCBZ_L,
	"psq_l", // PPC_INS_PSQ_L,
	"psq_lu", // PPC_INS_PSQ_LU,
	"psq_lux", // PPC_INS_PSQ_LUX,
	"psq_lx", // PPC_INS_PSQ_LX,
	"psq_st", // PPC_INS_PSQ_ST,
	"psq_stu", // PPC_INS_PSQ_STU,
	"psq_stux", // PPC_INS_PSQ_STUX,
	"psq_stx", // PPC_INS_PSQ_STX,
	"ps_abs", // PPC_INS_PS_ABS,
	"ps_add", // PPC_INS_PS_ADD,
	"ps_cmpo0", // PPC_INS_PS_CMPO0,
	"ps_cmpo1", // PPC_INS_PS_CMPO1,
	"ps_cmpu0", // PPC_INS_PS_CMPU0,
	"ps_cmpu1", // PPC_INS_PS_CMPU1,
	"ps_div", // PPC_INS_PS_DIV,
	"ps_madd", // PPC_INS_PS_MADD,
	"ps_madds0", // PPC_INS_PS_MADDS0,
	"ps_madds1", // PPC_INS_PS_MADDS1,
	"ps_merge00", // PPC_INS_PS_MERGE00,
	"ps_merge01", // PPC_INS_PS_MERGE01,
	"ps_merge10", // PPC_INS_PS_MERGE10,
	"ps_merge11", // PPC_INS_PS_MERGE11,
	"ps_mr", // PPC_INS_PS_MR,
	"ps_msub", // PPC_INS_PS_MSUB,
	"ps_mul", // PPC_INS_PS_MUL,
	"ps_muls0", // PPC_INS_PS_MULS0,
	"ps_muls1", // PPC_INS_PS_MULS1,
	"ps_nabs", // PPC_INS_PS_NABS,
	"ps_neg", // PPC_INS_PS_NEG,
	"ps_nmadd", // PPC_INS_PS_NMADD,
	"ps_nmsub", // PPC_INS_PS_NMSUB,
	"ps_res", // PPC_INS_PS_RES,
	"ps_rsqrte", // PPC_INS_PS_RSQRTE,
	"ps_sel", // PPC_INS_PS_SEL,
	"ps_sub", // PPC_INS_PS_SUB,
	"ps_sum0", // PPC_INS_PS_SUM0,
	"ps_sum1", // PPC_INS_PS_SUM1,
