/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2022, */
/*    Rot127 <unisono@quyllur.org> 2022-2023 */
/* Automatically generated file by Capstone's LLVM TableGen Disassembler Backend. */

/* LLVM-commit: <commit> */
/* LLVM-tag: <tag> */

/* Do not edit. */

/* Capstone's LLVM TableGen Backends: */
/* https://github.com/capstone-engine/llvm-capstone */

#ifdef GET_SUBTARGETINFO_ENUM
#undef GET_SUBTARGETINFO_ENUM

enum {
  TRICORE_HasV110Ops = 0,
  TRICORE_HasV120Ops = 1,
  TRICORE_HasV130Ops = 2,
  TRICORE_HasV131Ops = 3,
  TRICORE_HasV160Ops = 4,
  TRICORE_HasV161Ops = 5,
  TRICORE_HasV162Ops = 6,
  TRICORE_TRICORE_PCP = 7,
  TRICORE_TRICORE_PCP2 = 8,
  TRICORE_TRICORE_RIDER_A = 9,
  TRICORE_TRICORE_V1_1 = 10,
  TRICORE_TRICORE_V1_2 = 11,
  TRICORE_TRICORE_V1_3 = 12,
  TRICORE_TRICORE_V1_3_1 = 13,
  TRICORE_TRICORE_V1_6 = 14,
  TRICORE_TRICORE_V1_6_1 = 15,
  TRICORE_TRICORE_V1_6_2 = 16,
  TRICORE_NumSubtargetFeatures = 17
};
#endif // GET_SUBTARGETINFO_ENUM



