# CS_ARCH_ARM64, 0, None
0x08,0x03,0x31,0xd5 = mrs x8, trcstatr
0xc9,0x00,0x31,0xd5 = mrs x9, trcidr8
0xcb,0x01,0x31,0xd5 = mrs x11, trcidr9
0xd9,0x02,0x31,0xd5 = mrs x25, trcidr10
0xc7,0x03,0x31,0xd5 = mrs x7, trcidr11
0xc7,0x04,0x31,0xd5 = mrs x7, trcidr12
0xc6,0x05,0x31,0xd5 = mrs x6, trcidr13
0xfb,0x08,0x31,0xd5 = mrs x27, trcidr0
0xfd,0x09,0x31,0xd5 = mrs x29, trcidr1
0xe4,0x0a,0x31,0xd5 = mrs x4, trcidr2
0xe8,0x0b,0x31,0xd5 = mrs x8, trcidr3
0xef,0x0c,0x31,0xd5 = mrs x15, trcidr4
0xf4,0x0d,0x31,0xd5 = mrs x20, trcidr5
0xe6,0x0e,0x31,0xd5 = mrs x6, trcidr6
0xe6,0x0f,0x31,0xd5 = mrs x6, trcidr7
0x98,0x11,0x31,0xd5 = mrs x24, trcoslsr
0x92,0x15,0x31,0xd5 = mrs x18, trcpdsr
0xdc,0x7a,0x31,0xd5 = mrs x28, trcdevaff0
0xc5,0x7b,0x31,0xd5 = mrs x5, trcdevaff1
0xc5,0x7d,0x31,0xd5 = mrs x5, trclsr
0xcb,0x7e,0x31,0xd5 = mrs x11, trcauthstatus
0xcd,0x7f,0x31,0xd5 = mrs x13, trcdevarch
0xf2,0x72,0x31,0xd5 = mrs x18, trcdevid
0xf6,0x73,0x31,0xd5 = mrs x22, trcdevtype
0xee,0x74,0x31,0xd5 = mrs x14, trcpidr4
0xe5,0x75,0x31,0xd5 = mrs x5, trcpidr5
0xe5,0x76,0x31,0xd5 = mrs x5, trcpidr6
0xe9,0x77,0x31,0xd5 = mrs x9, trcpidr7
0xef,0x78,0x31,0xd5 = mrs x15, trcpidr0
0xe6,0x79,0x31,0xd5 = mrs x6, trcpidr1
0xeb,0x7a,0x31,0xd5 = mrs x11, trcpidr2
0xf4,0x7b,0x31,0xd5 = mrs x20, trcpidr3
0xf1,0x7c,0x31,0xd5 = mrs x17, trccidr0
0xe2,0x7d,0x31,0xd5 = mrs x2, trccidr1
0xf4,0x7e,0x31,0xd5 = mrs x20, trccidr2
0xe4,0x7f,0x31,0xd5 = mrs x4, trccidr3
0x0b,0x01,0x31,0xd5 = mrs x11, trcprgctlr
0x17,0x02,0x31,0xd5 = mrs x23, trcprocselr
0x0d,0x04,0x31,0xd5 = mrs x13, trcconfigr
0x17,0x06,0x31,0xd5 = mrs x23, trcauxctlr
0x09,0x08,0x31,0xd5 = mrs x9, trceventctl0r
0x10,0x09,0x31,0xd5 = mrs x16, trceventctl1r
0x04,0x0b,0x31,0xd5 = mrs x4, trcstallctlr
0x0e,0x0c,0x31,0xd5 = mrs x14, trctsctlr
0x18,0x0d,0x31,0xd5 = mrs x24, trcsyncpr
0x1c,0x0e,0x31,0xd5 = mrs x28, trcccctlr
0x0f,0x0f,0x31,0xd5 = mrs x15, trcbbctlr
0x21,0x00,0x31,0xd5 = mrs x1, trctraceidr
0x34,0x01,0x31,0xd5 = mrs x20, trcqctlr
0x42,0x00,0x31,0xd5 = mrs x2, trcvictlr
0x4c,0x01,0x31,0xd5 = mrs x12, trcviiectlr
0x50,0x02,0x31,0xd5 = mrs x16, trcvissctlr
0x48,0x03,0x31,0xd5 = mrs x8, trcvipcssctlr
0x5b,0x08,0x31,0xd5 = mrs x27, trcvdctlr
0x49,0x09,0x31,0xd5 = mrs x9, trcvdsacctlr
0x40,0x0a,0x31,0xd5 = mrs x0, trcvdarcctlr
0x8d,0x00,0x31,0xd5 = mrs x13, trcseqevr0
0x8b,0x01,0x31,0xd5 = mrs x11, trcseqevr1
0x9a,0x02,0x31,0xd5 = mrs x26, trcseqevr2
0x8e,0x06,0x31,0xd5 = mrs x14, trcseqrstevr
0x84,0x07,0x31,0xd5 = mrs x4, trcseqstr
0x91,0x08,0x31,0xd5 = mrs x17, trcextinselr0
0xb5,0x00,0x31,0xd5 = mrs x21, trccntrldvr0
0xaa,0x01,0x31,0xd5 = mrs x10, trccntrldvr1
0xb4,0x02,0x31,0xd5 = mrs x20, trccntrldvr2
0xa5,0x03,0x31,0xd5 = mrs x5, trccntrldvr3
0xb1,0x04,0x31,0xd5 = mrs x17, trccntctlr0
0xa1,0x05,0x31,0xd5 = mrs x1, trccntctlr1
0xb1,0x06,0x31,0xd5 = mrs x17, trccntctlr2
0xa6,0x07,0x31,0xd5 = mrs x6, trccntctlr3
0xbc,0x08,0x31,0xd5 = mrs x28, trccntvr0
0xb7,0x09,0x31,0xd5 = mrs x23, trccntvr1
0xa9,0x0a,0x31,0xd5 = mrs x9, trccntvr2
0xa6,0x0b,0x31,0xd5 = mrs x6, trccntvr3
0xf8,0x00,0x31,0xd5 = mrs x24, trcimspec0
0xf8,0x01,0x31,0xd5 = mrs x24, trcimspec1
0xef,0x02,0x31,0xd5 = mrs x15, trcimspec2
0xea,0x03,0x31,0xd5 = mrs x10, trcimspec3
0xfd,0x04,0x31,0xd5 = mrs x29, trcimspec4
0xf2,0x05,0x31,0xd5 = mrs x18, trcimspec5
0xfd,0x06,0x31,0xd5 = mrs x29, trcimspec6
0xe2,0x07,0x31,0xd5 = mrs x2, trcimspec7
0x08,0x12,0x31,0xd5 = mrs x8, trcrsctlr2
0x00,0x13,0x31,0xd5 = mrs x0, trcrsctlr3
0x0c,0x14,0x31,0xd5 = mrs x12, trcrsctlr4
0x1a,0x15,0x31,0xd5 = mrs x26, trcrsctlr5
0x1d,0x16,0x31,0xd5 = mrs x29, trcrsctlr6
0x11,0x17,0x31,0xd5 = mrs x17, trcrsctlr7
0x00,0x18,0x31,0xd5 = mrs x0, trcrsctlr8
0x01,0x19,0x31,0xd5 = mrs x1, trcrsctlr9
0x11,0x1a,0x31,0xd5 = mrs x17, trcrsctlr10
0x15,0x1b,0x31,0xd5 = mrs x21, trcrsctlr11
0x01,0x1c,0x31,0xd5 = mrs x1, trcrsctlr12
0x08,0x1d,0x31,0xd5 = mrs x8, trcrsctlr13
0x18,0x1e,0x31,0xd5 = mrs x24, trcrsctlr14
0x00,0x1f,0x31,0xd5 = mrs x0, trcrsctlr15
0x22,0x10,0x31,0xd5 = mrs x2, trcrsctlr16
0x3d,0x11,0x31,0xd5 = mrs x29, trcrsctlr17
0x36,0x12,0x31,0xd5 = mrs x22, trcrsctlr18
0x26,0x13,0x31,0xd5 = mrs x6, trcrsctlr19
0x3a,0x14,0x31,0xd5 = mrs x26, trcrsctlr20
0x3a,0x15,0x31,0xd5 = mrs x26, trcrsctlr21
0x24,0x16,0x31,0xd5 = mrs x4, trcrsctlr22
0x2c,0x17,0x31,0xd5 = mrs x12, trcrsctlr23
0x21,0x18,0x31,0xd5 = mrs x1, trcrsctlr24
0x20,0x19,0x31,0xd5 = mrs x0, trcrsctlr25
0x31,0x1a,0x31,0xd5 = mrs x17, trcrsctlr26
0x28,0x1b,0x31,0xd5 = mrs x8, trcrsctlr27
0x2a,0x1c,0x31,0xd5 = mrs x10, trcrsctlr28
0x39,0x1d,0x31,0xd5 = mrs x25, trcrsctlr29
0x2c,0x1e,0x31,0xd5 = mrs x12, trcrsctlr30
0x2b,0x1f,0x31,0xd5 = mrs x11, trcrsctlr31
0x52,0x10,0x31,0xd5 = mrs x18, trcssccr0
0x4c,0x11,0x31,0xd5 = mrs x12, trcssccr1
0x43,0x12,0x31,0xd5 = mrs x3, trcssccr2
0x42,0x13,0x31,0xd5 = mrs x2, trcssccr3
0x55,0x14,0x31,0xd5 = mrs x21, trcssccr4
0x4a,0x15,0x31,0xd5 = mrs x10, trcssccr5
0x56,0x16,0x31,0xd5 = mrs x22, trcssccr6
0x57,0x17,0x31,0xd5 = mrs x23, trcssccr7
0x57,0x18,0x31,0xd5 = mrs x23, trcsscsr0
0x53,0x19,0x31,0xd5 = mrs x19, trcsscsr1
0x59,0x1a,0x31,0xd5 = mrs x25, trcsscsr2
0x51,0x1b,0x31,0xd5 = mrs x17, trcsscsr3
0x53,0x1c,0x31,0xd5 = mrs x19, trcsscsr4
0x4b,0x1d,0x31,0xd5 = mrs x11, trcsscsr5
0x45,0x1e,0x31,0xd5 = mrs x5, trcsscsr6
0x49,0x1f,0x31,0xd5 = mrs x9, trcsscsr7
0x61,0x10,0x31,0xd5 = mrs x1, trcsspcicr0
0x6c,0x11,0x31,0xd5 = mrs x12, trcsspcicr1
0x75,0x12,0x31,0xd5 = mrs x21, trcsspcicr2
0x6b,0x13,0x31,0xd5 = mrs x11, trcsspcicr3
0x63,0x14,0x31,0xd5 = mrs x3, trcsspcicr4
0x69,0x15,0x31,0xd5 = mrs x9, trcsspcicr5
0x65,0x16,0x31,0xd5 = mrs x5, trcsspcicr6
0x62,0x17,0x31,0xd5 = mrs x2, trcsspcicr7
0x9a,0x14,0x31,0xd5 = mrs x26, trcpdcr
0x08,0x20,0x31,0xd5 = mrs x8, trcacvr0
0x0f,0x22,0x31,0xd5 = mrs x15, trcacvr1
0x13,0x24,0x31,0xd5 = mrs x19, trcacvr2
0x08,0x26,0x31,0xd5 = mrs x8, trcacvr3
0x1c,0x28,0x31,0xd5 = mrs x28, trcacvr4
0x03,0x2a,0x31,0xd5 = mrs x3, trcacvr5
0x19,0x2c,0x31,0xd5 = mrs x25, trcacvr6
0x18,0x2e,0x31,0xd5 = mrs x24, trcacvr7
0x26,0x20,0x31,0xd5 = mrs x6, trcacvr8
0x23,0x22,0x31,0xd5 = mrs x3, trcacvr9
0x38,0x24,0x31,0xd5 = mrs x24, trcacvr10
0x23,0x26,0x31,0xd5 = mrs x3, trcacvr11
0x2c,0x28,0x31,0xd5 = mrs x12, trcacvr12
0x29,0x2a,0x31,0xd5 = mrs x9, trcacvr13
0x2e,0x2c,0x31,0xd5 = mrs x14, trcacvr14
0x23,0x2e,0x31,0xd5 = mrs x3, trcacvr15
0x55,0x20,0x31,0xd5 = mrs x21, trcacatr0
0x5a,0x22,0x31,0xd5 = mrs x26, trcacatr1
0x48,0x24,0x31,0xd5 = mrs x8, trcacatr2
0x56,0x26,0x31,0xd5 = mrs x22, trcacatr3
0x46,0x28,0x31,0xd5 = mrs x6, trcacatr4
0x5d,0x2a,0x31,0xd5 = mrs x29, trcacatr5
0x45,0x2c,0x31,0xd5 = mrs x5, trcacatr6
0x52,0x2e,0x31,0xd5 = mrs x18, trcacatr7
0x62,0x20,0x31,0xd5 = mrs x2, trcacatr8
0x73,0x22,0x31,0xd5 = mrs x19, trcacatr9
0x6d,0x24,0x31,0xd5 = mrs x13, trcacatr10
0x79,0x26,0x31,0xd5 = mrs x25, trcacatr11
0x72,0x28,0x31,0xd5 = mrs x18, trcacatr12
0x7d,0x2a,0x31,0xd5 = mrs x29, trcacatr13
0x69,0x2c,0x31,0xd5 = mrs x9, trcacatr14
0x72,0x2e,0x31,0xd5 = mrs x18, trcacatr15
0x9d,0x20,0x31,0xd5 = mrs x29, trcdvcvr0
0x8f,0x24,0x31,0xd5 = mrs x15, trcdvcvr1
0x8f,0x28,0x31,0xd5 = mrs x15, trcdvcvr2
0x8f,0x2c,0x31,0xd5 = mrs x15, trcdvcvr3
0xb3,0x20,0x31,0xd5 = mrs x19, trcdvcvr4
0xb6,0x24,0x31,0xd5 = mrs x22, trcdvcvr5
0xbb,0x28,0x31,0xd5 = mrs x27, trcdvcvr6
0xa1,0x2c,0x31,0xd5 = mrs x1, trcdvcvr7
0xdd,0x20,0x31,0xd5 = mrs x29, trcdvcmr0
0xc9,0x24,0x31,0xd5 = mrs x9, trcdvcmr1
0xc1,0x28,0x31,0xd5 = mrs x1, trcdvcmr2
0xc2,0x2c,0x31,0xd5 = mrs x2, trcdvcmr3
0xe5,0x20,0x31,0xd5 = mrs x5, trcdvcmr4
0xf5,0x24,0x31,0xd5 = mrs x21, trcdvcmr5
0xe5,0x28,0x31,0xd5 = mrs x5, trcdvcmr6
0xe1,0x2c,0x31,0xd5 = mrs x1, trcdvcmr7
0x15,0x30,0x31,0xd5 = mrs x21, trccidcvr0
0x18,0x32,0x31,0xd5 = mrs x24, trccidcvr1
0x18,0x34,0x31,0xd5 = mrs x24, trccidcvr2
0x0c,0x36,0x31,0xd5 = mrs x12, trccidcvr3
0x0a,0x38,0x31,0xd5 = mrs x10, trccidcvr4
0x09,0x3a,0x31,0xd5 = mrs x9, trccidcvr5
0x06,0x3c,0x31,0xd5 = mrs x6, trccidcvr6
0x14,0x3e,0x31,0xd5 = mrs x20, trccidcvr7
0x34,0x30,0x31,0xd5 = mrs x20, trcvmidcvr0
0x34,0x32,0x31,0xd5 = mrs x20, trcvmidcvr1
0x3a,0x34,0x31,0xd5 = mrs x26, trcvmidcvr2
0x21,0x36,0x31,0xd5 = mrs x1, trcvmidcvr3
0x2e,0x38,0x31,0xd5 = mrs x14, trcvmidcvr4
0x3b,0x3a,0x31,0xd5 = mrs x27, trcvmidcvr5
0x3d,0x3c,0x31,0xd5 = mrs x29, trcvmidcvr6
0x31,0x3e,0x31,0xd5 = mrs x17, trcvmidcvr7
0x4a,0x30,0x31,0xd5 = mrs x10, trccidcctlr0
0x44,0x31,0x31,0xd5 = mrs x4, trccidcctlr1
0x49,0x32,0x31,0xd5 = mrs x9, trcvmidcctlr0
0x4b,0x33,0x31,0xd5 = mrs x11, trcvmidcctlr1
0x96,0x70,0x31,0xd5 = mrs x22, trcitctrl
0xd7,0x78,0x31,0xd5 = mrs x23, trcclaimset
0xce,0x79,0x31,0xd5 = mrs x14, trcclaimclr
0x9c,0x10,0x11,0xd5 = msr trcoslar, x28
0xce,0x7c,0x11,0xd5 = msr trclar, x14
0x0a,0x01,0x11,0xd5 = msr trcprgctlr, x10
0x1b,0x02,0x11,0xd5 = msr trcprocselr, x27
0x18,0x04,0x11,0xd5 = msr trcconfigr, x24
0x08,0x06,0x11,0xd5 = msr trcauxctlr, x8
0x10,0x08,0x11,0xd5 = msr trceventctl0r, x16
0x1b,0x09,0x11,0xd5 = msr trceventctl1r, x27
0x1a,0x0b,0x11,0xd5 = msr trcstallctlr, x26
0x00,0x0c,0x11,0xd5 = msr trctsctlr, x0
0x0e,0x0d,0x11,0xd5 = msr trcsyncpr, x14
0x08,0x0e,0x11,0xd5 = msr trcccctlr, x8
0x06,0x0f,0x11,0xd5 = msr trcbbctlr, x6
0x37,0x00,0x11,0xd5 = msr trctraceidr, x23
0x25,0x01,0x11,0xd5 = msr trcqctlr, x5
0x40,0x00,0x11,0xd5 = msr trcvictlr, x0
0x40,0x01,0x11,0xd5 = msr trcviiectlr, x0
0x41,0x02,0x11,0xd5 = msr trcvissctlr, x1
0x40,0x03,0x11,0xd5 = msr trcvipcssctlr, x0
0x47,0x08,0x11,0xd5 = msr trcvdctlr, x7
0x52,0x09,0x11,0xd5 = msr trcvdsacctlr, x18
0x58,0x0a,0x11,0xd5 = msr trcvdarcctlr, x24
0x9c,0x00,0x11,0xd5 = msr trcseqevr0, x28
0x95,0x01,0x11,0xd5 = msr trcseqevr1, x21
0x90,0x02,0x11,0xd5 = msr trcseqevr2, x16
0x90,0x06,0x11,0xd5 = msr trcseqrstevr, x16
0x99,0x07,0x11,0xd5 = msr trcseqstr, x25
0x9d,0x08,0x11,0xd5 = msr trcextinselr0, x29
0xb4,0x00,0x11,0xd5 = msr trccntrldvr0, x20
0xb4,0x01,0x11,0xd5 = msr trccntrldvr1, x20
0xb6,0x02,0x11,0xd5 = msr trccntrldvr2, x22
0xac,0x03,0x11,0xd5 = msr trccntrldvr3, x12
0xb4,0x04,0x11,0xd5 = msr trccntctlr0, x20
0xa4,0x05,0x11,0xd5 = msr trccntctlr1, x4
0xa8,0x06,0x11,0xd5 = msr trccntctlr2, x8
0xb0,0x07,0x11,0xd5 = msr trccntctlr3, x16
0xa5,0x08,0x11,0xd5 = msr trccntvr0, x5
0xbb,0x09,0x11,0xd5 = msr trccntvr1, x27
0xb5,0x0a,0x11,0xd5 = msr trccntvr2, x21
0xa8,0x0b,0x11,0xd5 = msr trccntvr3, x8
0xe6,0x00,0x11,0xd5 = msr trcimspec0, x6
0xfb,0x01,0x11,0xd5 = msr trcimspec1, x27
0xf7,0x02,0x11,0xd5 = msr trcimspec2, x23
0xef,0x03,0x11,0xd5 = msr trcimspec3, x15
0xed,0x04,0x11,0xd5 = msr trcimspec4, x13
0xf9,0x05,0x11,0xd5 = msr trcimspec5, x25
0xf3,0x06,0x11,0xd5 = msr trcimspec6, x19
0xfb,0x07,0x11,0xd5 = msr trcimspec7, x27
0x04,0x12,0x11,0xd5 = msr trcrsctlr2, x4
0x00,0x13,0x11,0xd5 = msr trcrsctlr3, x0
0x15,0x14,0x11,0xd5 = msr trcrsctlr4, x21
0x08,0x15,0x11,0xd5 = msr trcrsctlr5, x8
0x14,0x16,0x11,0xd5 = msr trcrsctlr6, x20
0x0b,0x17,0x11,0xd5 = msr trcrsctlr7, x11
0x12,0x18,0x11,0xd5 = msr trcrsctlr8, x18
0x18,0x19,0x11,0xd5 = msr trcrsctlr9, x24
0x0f,0x1a,0x11,0xd5 = msr trcrsctlr10, x15
0x15,0x1b,0x11,0xd5 = msr trcrsctlr11, x21
0x04,0x1c,0x11,0xd5 = msr trcrsctlr12, x4
0x1c,0x1d,0x11,0xd5 = msr trcrsctlr13, x28
0x03,0x1e,0x11,0xd5 = msr trcrsctlr14, x3
0x14,0x1f,0x11,0xd5 = msr trcrsctlr15, x20
0x2c,0x10,0x11,0xd5 = msr trcrsctlr16, x12
0x31,0x11,0x11,0xd5 = msr trcrsctlr17, x17
0x2a,0x12,0x11,0xd5 = msr trcrsctlr18, x10
0x2b,0x13,0x11,0xd5 = msr trcrsctlr19, x11
0x23,0x14,0x11,0xd5 = msr trcrsctlr20, x3
0x32,0x15,0x11,0xd5 = msr trcrsctlr21, x18
0x3a,0x16,0x11,0xd5 = msr trcrsctlr22, x26
0x25,0x17,0x11,0xd5 = msr trcrsctlr23, x5
0x39,0x18,0x11,0xd5 = msr trcrsctlr24, x25
0x25,0x19,0x11,0xd5 = msr trcrsctlr25, x5
0x24,0x1a,0x11,0xd5 = msr trcrsctlr26, x4
0x34,0x1b,0x11,0xd5 = msr trcrsctlr27, x20
0x25,0x1c,0x11,0xd5 = msr trcrsctlr28, x5
0x2a,0x1d,0x11,0xd5 = msr trcrsctlr29, x10
0x38,0x1e,0x11,0xd5 = msr trcrsctlr30, x24
0x34,0x1f,0x11,0xd5 = msr trcrsctlr31, x20
0x57,0x10,0x11,0xd5 = msr trcssccr0, x23
0x5b,0x11,0x11,0xd5 = msr trcssccr1, x27
0x5b,0x12,0x11,0xd5 = msr trcssccr2, x27
0x46,0x13,0x11,0xd5 = msr trcssccr3, x6
0x43,0x14,0x11,0xd5 = msr trcssccr4, x3
0x4c,0x15,0x11,0xd5 = msr trcssccr5, x12
0x47,0x16,0x11,0xd5 = msr trcssccr6, x7
0x46,0x17,0x11,0xd5 = msr trcssccr7, x6
0x54,0x18,0x11,0xd5 = msr trcsscsr0, x20
0x51,0x19,0x11,0xd5 = msr trcsscsr1, x17
0x4b,0x1a,0x11,0xd5 = msr trcsscsr2, x11
0x44,0x1b,0x11,0xd5 = msr trcsscsr3, x4
0x4e,0x1c,0x11,0xd5 = msr trcsscsr4, x14
0x56,0x1d,0x11,0xd5 = msr trcsscsr5, x22
0x43,0x1e,0x11,0xd5 = msr trcsscsr6, x3
0x4b,0x1f,0x11,0xd5 = msr trcsscsr7, x11
0x62,0x10,0x11,0xd5 = msr trcsspcicr0, x2
0x63,0x11,0x11,0xd5 = msr trcsspcicr1, x3
0x65,0x12,0x11,0xd5 = msr trcsspcicr2, x5
0x67,0x13,0x11,0xd5 = msr trcsspcicr3, x7
0x6b,0x14,0x11,0xd5 = msr trcsspcicr4, x11
0x6d,0x15,0x11,0xd5 = msr trcsspcicr5, x13
0x71,0x16,0x11,0xd5 = msr trcsspcicr6, x17
0x77,0x17,0x11,0xd5 = msr trcsspcicr7, x23
0x83,0x14,0x11,0xd5 = msr trcpdcr, x3
0x06,0x20,0x11,0xd5 = msr trcacvr0, x6
0x14,0x22,0x11,0xd5 = msr trcacvr1, x20
0x19,0x24,0x11,0xd5 = msr trcacvr2, x25
0x01,0x26,0x11,0xd5 = msr trcacvr3, x1
0x1c,0x28,0x11,0xd5 = msr trcacvr4, x28
0x0f,0x2a,0x11,0xd5 = msr trcacvr5, x15
0x19,0x2c,0x11,0xd5 = msr trcacvr6, x25
0x0c,0x2e,0x11,0xd5 = msr trcacvr7, x12
0x25,0x20,0x11,0xd5 = msr trcacvr8, x5
0x39,0x22,0x11,0xd5 = msr trcacvr9, x25
0x2d,0x24,0x11,0xd5 = msr trcacvr10, x13
0x2a,0x26,0x11,0xd5 = msr trcacvr11, x10
0x33,0x28,0x11,0xd5 = msr trcacvr12, x19
0x2a,0x2a,0x11,0xd5 = msr trcacvr13, x10
0x33,0x2c,0x11,0xd5 = msr trcacvr14, x19
0x22,0x2e,0x11,0xd5 = msr trcacvr15, x2
0x4f,0x20,0x11,0xd5 = msr trcacatr0, x15
0x4d,0x22,0x11,0xd5 = msr trcacatr1, x13
0x48,0x24,0x11,0xd5 = msr trcacatr2, x8
0x41,0x26,0x11,0xd5 = msr trcacatr3, x1
0x4b,0x28,0x11,0xd5 = msr trcacatr4, x11
0x48,0x2a,0x11,0xd5 = msr trcacatr5, x8
0x58,0x2c,0x11,0xd5 = msr trcacatr6, x24
0x46,0x2e,0x11,0xd5 = msr trcacatr7, x6
0x77,0x20,0x11,0xd5 = msr trcacatr8, x23
0x65,0x22,0x11,0xd5 = msr trcacatr9, x5
0x6b,0x24,0x11,0xd5 = msr trcacatr10, x11
0x6b,0x26,0x11,0xd5 = msr trcacatr11, x11
0x63,0x28,0x11,0xd5 = msr trcacatr12, x3
0x7c,0x2a,0x11,0xd5 = msr trcacatr13, x28
0x79,0x2c,0x11,0xd5 = msr trcacatr14, x25
0x64,0x2e,0x11,0xd5 = msr trcacatr15, x4
0x86,0x20,0x11,0xd5 = msr trcdvcvr0, x6
0x83,0x24,0x11,0xd5 = msr trcdvcvr1, x3
0x85,0x28,0x11,0xd5 = msr trcdvcvr2, x5
0x8b,0x2c,0x11,0xd5 = msr trcdvcvr3, x11
0xa9,0x20,0x11,0xd5 = msr trcdvcvr4, x9
0xae,0x24,0x11,0xd5 = msr trcdvcvr5, x14
0xaa,0x28,0x11,0xd5 = msr trcdvcvr6, x10
0xac,0x2c,0x11,0xd5 = msr trcdvcvr7, x12
0xc8,0x20,0x11,0xd5 = msr trcdvcmr0, x8
0xc8,0x24,0x11,0xd5 = msr trcdvcmr1, x8
0xd6,0x28,0x11,0xd5 = msr trcdvcmr2, x22
0xd6,0x2c,0x11,0xd5 = msr trcdvcmr3, x22
0xe5,0x20,0x11,0xd5 = msr trcdvcmr4, x5
0xf0,0x24,0x11,0xd5 = msr trcdvcmr5, x16
0xfb,0x28,0x11,0xd5 = msr trcdvcmr6, x27
0xf5,0x2c,0x11,0xd5 = msr trcdvcmr7, x21
0x08,0x30,0x11,0xd5 = msr trccidcvr0, x8
0x06,0x32,0x11,0xd5 = msr trccidcvr1, x6
0x09,0x34,0x11,0xd5 = msr trccidcvr2, x9
0x08,0x36,0x11,0xd5 = msr trccidcvr3, x8
0x03,0x38,0x11,0xd5 = msr trccidcvr4, x3
0x15,0x3a,0x11,0xd5 = msr trccidcvr5, x21
0x0c,0x3c,0x11,0xd5 = msr trccidcvr6, x12
0x07,0x3e,0x11,0xd5 = msr trccidcvr7, x7
0x24,0x30,0x11,0xd5 = msr trcvmidcvr0, x4
0x23,0x32,0x11,0xd5 = msr trcvmidcvr1, x3
0x29,0x34,0x11,0xd5 = msr trcvmidcvr2, x9
0x31,0x36,0x11,0xd5 = msr trcvmidcvr3, x17
0x2e,0x38,0x11,0xd5 = msr trcvmidcvr4, x14
0x2c,0x3a,0x11,0xd5 = msr trcvmidcvr5, x12
0x2a,0x3c,0x11,0xd5 = msr trcvmidcvr6, x10
0x23,0x3e,0x11,0xd5 = msr trcvmidcvr7, x3
0x4e,0x30,0x11,0xd5 = msr trccidcctlr0, x14
0x56,0x31,0x11,0xd5 = msr trccidcctlr1, x22
0x48,0x32,0x11,0xd5 = msr trcvmidcctlr0, x8
0x4f,0x33,0x11,0xd5 = msr trcvmidcctlr1, x15
0x81,0x70,0x11,0xd5 = msr trcitctrl, x1
0xc7,0x78,0x11,0xd5 = msr trcclaimset, x7
0xdd,0x79,0x11,0xd5 = msr trcclaimclr, x29
