// For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT
package capstone;

public class Wasm_const {

	public static final int WASM_OP_INVALID = 0;
	public static final int WASM_OP_NONE = 1;
	public static final int WASM_OP_INT7 = 2;
	public static final int WASM_OP_VARUINT32 = 3;
	public static final int WASM_OP_VARUINT64 = 4;
	public static final int WASM_OP_UINT32 = 5;
	public static final int WASM_OP_UINT64 = 6;
	public static final int WASM_OP_IMM = 7;
	public static final int WASM_OP_BRTABLE = 8;
	public static final int WASM_INS_UNREACHABLE = 0x0;
	public static final int WASM_INS_NOP = 0x1;
	public static final int WASM_INS_BLOCK = 0x2;
	public static final int WASM_INS_LOOP = 0x3;
	public static final int WASM_INS_IF = 0x4;
	public static final int WASM_INS_ELSE = 0x5;
	public static final int WASM_INS_END = 0xb;
	public static final int WASM_INS_BR = 0xc;
	public static final int WASM_INS_BR_IF = 0xd;
	public static final int WASM_INS_BR_TABLE = 0xe;
	public static final int WASM_INS_RETURN = 0xf;
	public static final int WASM_INS_CALL = 0x10;
	public static final int WASM_INS_CALL_INDIRECT = 0x11;
	public static final int WASM_INS_DROP = 0x1a;
	public static final int WASM_INS_SELECT = 0x1b;
	public static final int WASM_INS_GET_LOCAL = 0x20;
	public static final int WASM_INS_SET_LOCAL = 0x21;
	public static final int WASM_INS_TEE_LOCAL = 0x22;
	public static final int WASM_INS_GET_GLOBAL = 0x23;
	public static final int WASM_INS_SET_GLOBAL = 0x24;
	public static final int WASM_INS_I32_LOAD = 0x28;
	public static final int WASM_INS_I64_LOAD = 0x29;
	public static final int WASM_INS_F32_LOAD = 0x2a;
	public static final int WASM_INS_F64_LOAD = 0x2b;
	public static final int WASM_INS_I32_LOAD8_S = 0x2c;
	public static final int WASM_INS_I32_LOAD8_U = 0x2d;
	public static final int WASM_INS_I32_LOAD16_S = 0x2e;
	public static final int WASM_INS_I32_LOAD16_U = 0x2f;
	public static final int WASM_INS_I64_LOAD8_S = 0x30;
	public static final int WASM_INS_I64_LOAD8_U = 0x31;
	public static final int WASM_INS_I64_LOAD16_S = 0x32;
	public static final int WASM_INS_I64_LOAD16_U = 0x33;
	public static final int WASM_INS_I64_LOAD32_S = 0x34;
	public static final int WASM_INS_I64_LOAD32_U = 0x35;
	public static final int WASM_INS_I32_STORE = 0x36;
	public static final int WASM_INS_I64_STORE = 0x37;
	public static final int WASM_INS_F32_STORE = 0x38;
	public static final int WASM_INS_F64_STORE = 0x39;
	public static final int WASM_INS_I32_STORE8 = 0x3a;
	public static final int WASM_INS_I32_STORE16 = 0x3b;
	public static final int WASM_INS_I64_STORE8 = 0x3c;
	public static final int WASM_INS_I64_STORE16 = 0x3d;
	public static final int WASM_INS_I64_STORE32 = 0x3e;
	public static final int WASM_INS_CURRENT_MEMORY = 0x3f;
	public static final int WASM_INS_GROW_MEMORY = 0x40;
	public static final int WASM_INS_I32_CONST = 0x41;
	public static final int WASM_INS_I64_CONST = 0x42;
	public static final int WASM_INS_F32_CONST = 0x43;
	public static final int WASM_INS_F64_CONST = 0x44;
	public static final int WASM_INS_I32_EQZ = 0x45;
	public static final int WASM_INS_I32_EQ = 0x46;
	public static final int WASM_INS_I32_NE = 0x47;
	public static final int WASM_INS_I32_LT_S = 0x48;
	public static final int WASM_INS_I32_LT_U = 0x49;
	public static final int WASM_INS_I32_GT_S = 0x4a;
	public static final int WASM_INS_I32_GT_U = 0x4b;
	public static final int WASM_INS_I32_LE_S = 0x4c;
	public static final int WASM_INS_I32_LE_U = 0x4d;
	public static final int WASM_INS_I32_GE_S = 0x4e;
	public static final int WASM_INS_I32_GE_U = 0x4f;
	public static final int WASM_INS_I64_EQZ = 0x50;
	public static final int WASM_INS_I64_EQ = 0x51;
	public static final int WASM_INS_I64_NE = 0x52;
	public static final int WASM_INS_I64_LT_S = 0x53;
	public static final int WASM_INS_I64_LT_U = 0x54;
	public static final int WASM_INS_I64_GT_U = 0x56;
	public static final int WASM_INS_I64_LE_S = 0x57;
	public static final int WASM_INS_I64_LE_U = 0x58;
	public static final int WASM_INS_I64_GE_S = 0x59;
	public static final int WASM_INS_I64_GE_U = 0x5a;
	public static final int WASM_INS_F32_EQ = 0x5b;
	public static final int WASM_INS_F32_NE = 0x5c;
	public static final int WASM_INS_F32_LT = 0x5d;
	public static final int WASM_INS_F32_GT = 0x5e;
	public static final int WASM_INS_F32_LE = 0x5f;
	public static final int WASM_INS_F32_GE = 0x60;
	public static final int WASM_INS_F64_EQ = 0x61;
	public static final int WASM_INS_F64_NE = 0x62;
	public static final int WASM_INS_F64_LT = 0x63;
	public static final int WASM_INS_F64_GT = 0x64;
	public static final int WASM_INS_F64_LE = 0x65;
	public static final int WASM_INS_F64_GE = 0x66;
	public static final int WASM_INS_I32_CLZ = 0x67;
	public static final int WASM_INS_I32_CTZ = 0x68;
	public static final int WASM_INS_I32_POPCNT = 0x69;
	public static final int WASM_INS_I32_ADD = 0x6a;
	public static final int WASM_INS_I32_SUB = 0x6b;
	public static final int WASM_INS_I32_MUL = 0x6c;
	public static final int WASM_INS_I32_DIV_S = 0x6d;
	public static final int WASM_INS_I32_DIV_U = 0x6e;
	public static final int WASM_INS_I32_REM_S = 0x6f;
	public static final int WASM_INS_I32_REM_U = 0x70;
	public static final int WASM_INS_I32_AND = 0x71;
	public static final int WASM_INS_I32_OR = 0x72;
	public static final int WASM_INS_I32_XOR = 0x73;
	public static final int WASM_INS_I32_SHL = 0x74;
	public static final int WASM_INS_I32_SHR_S = 0x75;
	public static final int WASM_INS_I32_SHR_U = 0x76;
	public static final int WASM_INS_I32_ROTL = 0x77;
	public static final int WASM_INS_I32_ROTR = 0x78;
	public static final int WASM_INS_I64_CLZ = 0x79;
	public static final int WASM_INS_I64_CTZ = 0x7a;
	public static final int WASM_INS_I64_POPCNT = 0x7b;
	public static final int WASM_INS_I64_ADD = 0x7c;
	public static final int WASM_INS_I64_SUB = 0x7d;
	public static final int WASM_INS_I64_MUL = 0x7e;
	public static final int WASM_INS_I64_DIV_S = 0x7f;
	public static final int WASM_INS_I64_DIV_U = 0x80;
	public static final int WASM_INS_I64_REM_S = 0x81;
	public static final int WASM_INS_I64_REM_U = 0x82;
	public static final int WASM_INS_I64_AND = 0x83;
	public static final int WASM_INS_I64_OR = 0x84;
	public static final int WASM_INS_I64_XOR = 0x85;
	public static final int WASM_INS_I64_SHL = 0x86;
	public static final int WASM_INS_I64_SHR_S = 0x87;
	public static final int WASM_INS_I64_SHR_U = 0x88;
	public static final int WASM_INS_I64_ROTL = 0x89;
	public static final int WASM_INS_I64_ROTR = 0x8a;
	public static final int WASM_INS_F32_ABS = 0x8b;
	public static final int WASM_INS_F32_NEG = 0x8c;
	public static final int WASM_INS_F32_CEIL = 0x8d;
	public static final int WASM_INS_F32_FLOOR = 0x8e;
	public static final int WASM_INS_F32_TRUNC = 0x8f;
	public static final int WASM_INS_F32_NEAREST = 0x90;
	public static final int WASM_INS_F32_SQRT = 0x91;
	public static final int WASM_INS_F32_ADD = 0x92;
	public static final int WASM_INS_F32_SUB = 0x93;
	public static final int WASM_INS_F32_MUL = 0x94;
	public static final int WASM_INS_F32_DIV = 0x95;
	public static final int WASM_INS_F32_MIN = 0x96;
	public static final int WASM_INS_F32_MAX = 0x97;
	public static final int WASM_INS_F32_COPYSIGN = 0x98;
	public static final int WASM_INS_F64_ABS = 0x99;
	public static final int WASM_INS_F64_NEG = 0x9a;
	public static final int WASM_INS_F64_CEIL = 0x9b;
	public static final int WASM_INS_F64_FLOOR = 0x9c;
	public static final int WASM_INS_F64_TRUNC = 0x9d;
	public static final int WASM_INS_F64_NEAREST = 0x9e;
	public static final int WASM_INS_F64_SQRT = 0x9f;
	public static final int WASM_INS_F64_ADD = 0xa0;
	public static final int WASM_INS_F64_SUB = 0xa1;
	public static final int WASM_INS_F64_MUL = 0xa2;
	public static final int WASM_INS_F64_DIV = 0xa3;
	public static final int WASM_INS_F64_MIN = 0xa4;
	public static final int WASM_INS_F64_MAX = 0xa5;
	public static final int WASM_INS_F64_COPYSIGN = 0xa6;
	public static final int WASM_INS_I32_WARP_I64 = 0xa7;
	public static final int WASM_INS_I32_TRUNC_U_F32 = 0xa9;
	public static final int WASM_INS_I32_TRUNC_S_F64 = 0xaa;
	public static final int WASM_INS_I32_TRUNC_U_F64 = 0xab;
	public static final int WASM_INS_I64_EXTEND_S_I32 = 0xac;
	public static final int WASM_INS_I64_EXTEND_U_I32 = 0xad;
	public static final int WASM_INS_I64_TRUNC_S_F32 = 0xae;
	public static final int WASM_INS_I64_TRUNC_U_F32 = 0xaf;
	public static final int WASM_INS_I64_TRUNC_S_F64 = 0xb0;
	public static final int WASM_INS_I64_TRUNC_U_F64 = 0xb1;
	public static final int WASM_INS_F32_CONVERT_S_I32 = 0xb2;
	public static final int WASM_INS_F32_CONVERT_U_I32 = 0xb3;
	public static final int WASM_INS_F32_CONVERT_S_I64 = 0xb4;
	public static final int WASM_INS_F32_CONVERT_U_I64 = 0xb5;
	public static final int WASM_INS_F32_DEMOTE_F64 = 0xb6;
	public static final int WASM_INS_F64_CONVERT_S_I32 = 0xb7;
	public static final int WASM_INS_F64_CONVERT_U_I32 = 0xb8;
	public static final int WASM_INS_F64_CONVERT_S_I64 = 0xb9;
	public static final int WASM_INS_F64_CONVERT_U_I64 = 0xba;
	public static final int WASM_INS_F64_PROMOTE_F32 = 0xbb;
	public static final int WASM_INS_I32_REINTERPRET_F32 = 0xbc;
	public static final int WASM_INS_I64_REINTERPRET_F64 = 0xbd;
	public static final int WASM_INS_F32_REINTERPRET_I32 = 0xbe;
	public static final int WASM_INS_F64_REINTERPRET_I64 = 0xbf;
	public static final int WASM_INS_INVALID = 512;
	public static final int WASM_INS_ENDING = 513;

	public static final int WASM_GRP_INVALID = 0;
	public static final int WASM_GRP_NUMBERIC = 8;
	public static final int WASM_GRP_PARAMETRIC = 9;
	public static final int WASM_GRP_VARIABLE = 10;
	public static final int WASM_GRP_MEMORY = 11;
	public static final int WASM_GRP_CONTROL = 12;
	public static final int WASM_GRP_ENDING = 13;
}