/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* This is auto-gen data for Capstone disassembly engine (www.capstone-engine.org) */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

	"aaa", // X86_INS_AAA
	"aad", // X86_INS_AAD
	"aam", // X86_INS_AAM
	"aas", // X86_INS_AAS
	"adc", // X86_INS_ADC
	"adcx", // X86_INS_ADCX
	"add", // X86_INS_ADD
	"adox", // X86_INS_ADOX
	"and", // X86_INS_AND
	"andn", // X86_INS_ANDN
	"arpl", // X86_INS_ARPL
	"bextr", // X86_INS_BEXTR
	"blcfill", // X86_INS_BLCFILL
	"blci", // X86_INS_BLCI
	"blcic", // X86_INS_BLCIC
	"blcmsk", // X86_INS_BLCMSK
	"blcs", // X86_INS_BLCS
	"blsfill", // X86_INS_BLSFILL
	"blsi", // X86_INS_BLSI
	"blsic", // X86_INS_BLSIC
	"blsmsk", // X86_INS_BLSMSK
	"blsr", // X86_INS_BLSR
	"bound", // X86_INS_BOUND
	"bsf", // X86_INS_BSF
	"bsr", // X86_INS_BSR
	"bswap", // X86_INS_BSWAP
	"bt", // X86_INS_BT
	"btc", // X86_INS_BTC
	"btr", // X86_INS_BTR
	"bts", // X86_INS_BTS
	"bzhi", // X86_INS_BZHI
	"call", // X86_INS_CALL
	"cbw", // X86_INS_CBW
	"cdq", // X86_INS_CDQ
	"cdqe", // X86_INS_CDQE
	"clac", // X86_INS_CLAC
	"clc", // X86_INS_CLC
	"cld", // X86_INS_CLD
	"cldemote", // X86_INS_CLDEMOTE
	"clflushopt", // X86_INS_CLFLUSHOPT
	"clgi", // X86_INS_CLGI
	"cli", // X86_INS_CLI
	"clrssbsy", // X86_INS_CLRSSBSY
	"clts", // X86_INS_CLTS
	"clwb", // X86_INS_CLWB
	"clzero", // X86_INS_CLZERO
	"cmc", // X86_INS_CMC
	"cmova", // X86_INS_CMOVA
	"cmovae", // X86_INS_CMOVAE
	"cmovb", // X86_INS_CMOVB
	"cmovbe", // X86_INS_CMOVBE
	"cmove", // X86_INS_CMOVE
	"cmovg", // X86_INS_CMOVG
	"cmovge", // X86_INS_CMOVGE
	"cmovl", // X86_INS_CMOVL
	"cmovle", // X86_INS_CMOVLE
	"cmovne", // X86_INS_CMOVNE
	"cmovno", // X86_INS_CMOVNO
	"cmovnp", // X86_INS_CMOVNP
	"cmovns", // X86_INS_CMOVNS
	"cmovo", // X86_INS_CMOVO
	"cmovp", // X86_INS_CMOVP
	"cmovs", // X86_INS_CMOVS
	"cmp", // X86_INS_CMP
	"cmpsb", // X86_INS_CMPSB
	"cmpsd", // X86_INS_CMPSD
	"cmpsq", // X86_INS_CMPSQ
	"cmpsw", // X86_INS_CMPSW
	"cmpxchg16b", // X86_INS_CMPXCHG16B
	"cmpxchg", // X86_INS_CMPXCHG
	"cmpxchg8b", // X86_INS_CMPXCHG8B
	"cpuid", // X86_INS_CPUID
	"cqo", // X86_INS_CQO
	"cwd", // X86_INS_CWD
	"cwde", // X86_INS_CWDE
	"daa", // X86_INS_DAA
	"das", // X86_INS_DAS
	"data16", // X86_INS_DATA16
	"dec", // X86_INS_DEC
	"div", // X86_INS_DIV
	"endbr32", // X86_INS_ENDBR32
	"endbr64", // X86_INS_ENDBR64
	"enter", // X86_INS_ENTER
	"lcall", // X86_INS_LCALL
	"ljmp", // X86_INS_LJMP
	"jmp", // X86_INS_JMP
	"fsetpm", // X86_INS_FSETPM
	"getsec", // X86_INS_GETSEC
	"hlt", // X86_INS_HLT
	"idiv", // X86_INS_IDIV
	"imul", // X86_INS_IMUL
	"in", // X86_INS_IN
	"inc", // X86_INS_INC
	"incsspd", // X86_INS_INCSSPD
	"incsspq", // X86_INS_INCSSPQ
	"insb", // X86_INS_INSB
	"insd", // X86_INS_INSD
	"insw", // X86_INS_INSW
	"int", // X86_INS_INT
	"int1", // X86_INS_INT1
	"int3", // X86_INS_INT3
	"into", // X86_INS_INTO
	"invd", // X86_INS_INVD
	"invept", // X86_INS_INVEPT
	"invlpg", // X86_INS_INVLPG
	"invlpga", // X86_INS_INVLPGA
	"invpcid", // X86_INS_INVPCID
	"invvpid", // X86_INS_INVVPID
	"iret", // X86_INS_IRET
	"iretd", // X86_INS_IRETD
	"iretq", // X86_INS_IRETQ
	"jae", // X86_INS_JAE
	"ja", // X86_INS_JA
	"jbe", // X86_INS_JBE
	"jb", // X86_INS_JB
	"jcxz", // X86_INS_JCXZ
	"jecxz", // X86_INS_JECXZ
	"je", // X86_INS_JE
	"jge", // X86_INS_JGE
	"jg", // X86_INS_JG
	"jle", // X86_INS_JLE
	"jl", // X86_INS_JL
	"jne", // X86_INS_JNE
	"jno", // X86_INS_JNO
	"jnp", // X86_INS_JNP
	"jns", // X86_INS_JNS
	"jo", // X86_INS_JO
	"jp", // X86_INS_JP
	"jrcxz", // X86_INS_JRCXZ
	"js", // X86_INS_JS
	"lahf", // X86_INS_LAHF
	"lar", // X86_INS_LAR
	"lds", // X86_INS_LDS
	"lea", // X86_INS_LEA
	"leave", // X86_INS_LEAVE
	"les", // X86_INS_LES
	"lfs", // X86_INS_LFS
	"lgdt", // X86_INS_LGDT
	"lgs", // X86_INS_LGS
	"lidt", // X86_INS_LIDT
	"lldt", // X86_INS_LLDT
	"llwpcb", // X86_INS_LLWPCB
	"lmsw", // X86_INS_LMSW
	"lock", // X86_INS_LOCK
	"lodsb", // X86_INS_LODSB
	"lodsd", // X86_INS_LODSD
	"lodsq", // X86_INS_LODSQ
	"lodsw", // X86_INS_LODSW
	"loop", // X86_INS_LOOP
	"loope", // X86_INS_LOOPE
	"loopne", // X86_INS_LOOPNE
	"retf", // X86_INS_RETF
	"retfq", // X86_INS_RETFQ
	"lsl", // X86_INS_LSL
	"lss", // X86_INS_LSS
	"ltr", // X86_INS_LTR
	"lwpins", // X86_INS_LWPINS
	"lwpval", // X86_INS_LWPVAL
	"lzcnt", // X86_INS_LZCNT
	"monitorx", // X86_INS_MONITORX
	"montmul", // X86_INS_MONTMUL
	"mov", // X86_INS_MOV
	"movabs", // X86_INS_MOVABS
	"movbe", // X86_INS_MOVBE
	"movdir64b", // X86_INS_MOVDIR64B
	"movdiri", // X86_INS_MOVDIRI
	"movsb", // X86_INS_MOVSB
	"movsd", // X86_INS_MOVSD
	"movsq", // X86_INS_MOVSQ
	"movsw", // X86_INS_MOVSW
	"movsx", // X86_INS_MOVSX
	"movsxd", // X86_INS_MOVSXD
	"movzx", // X86_INS_MOVZX
	"mul", // X86_INS_MUL
	"mulx", // X86_INS_MULX
	"mwaitx", // X86_INS_MWAITX
	"neg", // X86_INS_NEG
	"nop", // X86_INS_NOP
	"not", // X86_INS_NOT
	"or", // X86_INS_OR
	"out", // X86_INS_OUT
	"outsb", // X86_INS_OUTSB
	"outsd", // X86_INS_OUTSD
	"outsw", // X86_INS_OUTSW
	"pconfig", // X86_INS_PCONFIG
	"pdep", // X86_INS_PDEP
	"pext", // X86_INS_PEXT
	"pop", // X86_INS_POP
	"popaw", // X86_INS_POPAW
	"popal", // X86_INS_POPAL
	"popf", // X86_INS_POPF
	"popfd", // X86_INS_POPFD
	"popfq", // X86_INS_POPFQ
	"ptwrite", // X86_INS_PTWRITE
	"push", // X86_INS_PUSH
	"pushaw", // X86_INS_PUSHAW
	"pushal", // X86_INS_PUSHAL
	"pushf", // X86_INS_PUSHF
	"pushfd", // X86_INS_PUSHFD
	"pushfq", // X86_INS_PUSHFQ
	"rcl", // X86_INS_RCL
	"rcr", // X86_INS_RCR
	"rdfsbase", // X86_INS_RDFSBASE
	"rdgsbase", // X86_INS_RDGSBASE
	"rdmsr", // X86_INS_RDMSR
	"rdpid", // X86_INS_RDPID
	"rdpkru", // X86_INS_RDPKRU
	"rdpmc", // X86_INS_RDPMC
	"rdrand", // X86_INS_RDRAND
	"rdseed", // X86_INS_RDSEED
	"rdsspd", // X86_INS_RDSSPD
	"rdsspq", // X86_INS_RDSSPQ
	"rdtsc", // X86_INS_RDTSC
	"rdtscp", // X86_INS_RDTSCP
	"repne", // X86_INS_REPNE
	"rep", // X86_INS_REP
	"ret", // X86_INS_RET
	"rex64", // X86_INS_REX64
	"rol", // X86_INS_ROL
	"ror", // X86_INS_ROR
	"rorx", // X86_INS_RORX
	"rsm", // X86_INS_RSM
	"rstorssp", // X86_INS_RSTORSSP
	"sahf", // X86_INS_SAHF
	"sal", // X86_INS_SAL
	"salc", // X86_INS_SALC
	"sar", // X86_INS_SAR
	"sarx", // X86_INS_SARX
	"saveprevssp", // X86_INS_SAVEPREVSSP
	"sbb", // X86_INS_SBB
	"scasb", // X86_INS_SCASB
	"scasd", // X86_INS_SCASD
	"scasq", // X86_INS_SCASQ
	"scasw", // X86_INS_SCASW
	"setae", // X86_INS_SETAE
	"seta", // X86_INS_SETA
	"setbe", // X86_INS_SETBE
	"setb", // X86_INS_SETB
	"sete", // X86_INS_SETE
	"setge", // X86_INS_SETGE
	"setg", // X86_INS_SETG
	"setle", // X86_INS_SETLE
	"setl", // X86_INS_SETL
	"setne", // X86_INS_SETNE
	"setno", // X86_INS_SETNO
	"setnp", // X86_INS_SETNP
	"setns", // X86_INS_SETNS
	"seto", // X86_INS_SETO
	"setp", // X86_INS_SETP
	"setssbsy", // X86_INS_SETSSBSY
	"sets", // X86_INS_SETS
	"sgdt", // X86_INS_SGDT
	"shl", // X86_INS_SHL
	"shld", // X86_INS_SHLD
	"shlx", // X86_INS_SHLX
	"shr", // X86_INS_SHR
	"shrd", // X86_INS_SHRD
	"shrx", // X86_INS_SHRX
	"sidt", // X86_INS_SIDT
	"skinit", // X86_INS_SKINIT
	"sldt", // X86_INS_SLDT
	"slwpcb", // X86_INS_SLWPCB
	"smsw", // X86_INS_SMSW
	"stac", // X86_INS_STAC
	"stc", // X86_INS_STC
	"std", // X86_INS_STD
	"stgi", // X86_INS_STGI
	"sti", // X86_INS_STI
	"stosb", // X86_INS_STOSB
	"stosd", // X86_INS_STOSD
	"stosq", // X86_INS_STOSQ
	"stosw", // X86_INS_STOSW
	"str", // X86_INS_STR
	"sub", // X86_INS_SUB
	"swapgs", // X86_INS_SWAPGS
	"syscall", // X86_INS_SYSCALL
	"sysenter", // X86_INS_SYSENTER
	"sysexit", // X86_INS_SYSEXIT
	"sysexitq", // X86_INS_SYSEXITQ
	"sysret", // X86_INS_SYSRET
	"sysretq", // X86_INS_SYSRETQ
	"t1mskc", // X86_INS_T1MSKC
	"test", // X86_INS_TEST
	"tpause", // X86_INS_TPAUSE
	"tzcnt", // X86_INS_TZCNT
	"tzmsk", // X86_INS_TZMSK
	"ud0", // X86_INS_UD0
	"ud1", // X86_INS_UD1
	"ud2", // X86_INS_UD2
	"umonitor", // X86_INS_UMONITOR
	"umwait", // X86_INS_UMWAIT
	"verr", // X86_INS_VERR
	"verw", // X86_INS_VERW
	"vmcall", // X86_INS_VMCALL
	"vmclear", // X86_INS_VMCLEAR
	"vmfunc", // X86_INS_VMFUNC
	"vmlaunch", // X86_INS_VMLAUNCH
	"vmload", // X86_INS_VMLOAD
	"vmmcall", // X86_INS_VMMCALL
	"vmptrld", // X86_INS_VMPTRLD
	"vmptrst", // X86_INS_VMPTRST
	"vmread", // X86_INS_VMREAD
	"vmresume", // X86_INS_VMRESUME
	"vmrun", // X86_INS_VMRUN
	"vmsave", // X86_INS_VMSAVE
	"vmwrite", // X86_INS_VMWRITE
	"vmxoff", // X86_INS_VMXOFF
	"vmxon", // X86_INS_VMXON
	"wbinvd", // X86_INS_WBINVD
	"wbnoinvd", // X86_INS_WBNOINVD
	"wrfsbase", // X86_INS_WRFSBASE
	"wrgsbase", // X86_INS_WRGSBASE
	"wrmsr", // X86_INS_WRMSR
	"wrpkru", // X86_INS_WRPKRU
	"wrssd", // X86_INS_WRSSD
	"wrssq", // X86_INS_WRSSQ
	"wrussd", // X86_INS_WRUSSD
	"wrussq", // X86_INS_WRUSSQ
	"xadd", // X86_INS_XADD
	"xchg", // X86_INS_XCHG
	"xcryptcbc", // X86_INS_XCRYPTCBC
	"xcryptcfb", // X86_INS_XCRYPTCFB
	"xcryptctr", // X86_INS_XCRYPTCTR
	"xcryptecb", // X86_INS_XCRYPTECB
	"xcryptofb", // X86_INS_XCRYPTOFB
	"xgetbv", // X86_INS_XGETBV
	"xlatb", // X86_INS_XLATB
	"xor", // X86_INS_XOR
	"xrstor", // X86_INS_XRSTOR
	"xrstor64", // X86_INS_XRSTOR64
	"xrstors", // X86_INS_XRSTORS
	"xrstors64", // X86_INS_XRSTORS64
	"xsave", // X86_INS_XSAVE
	"xsave64", // X86_INS_XSAVE64
	"xsavec", // X86_INS_XSAVEC
	"xsavec64", // X86_INS_XSAVEC64
	"xsaveopt", // X86_INS_XSAVEOPT
	"xsaveopt64", // X86_INS_XSAVEOPT64
	"xsaves", // X86_INS_XSAVES
	"xsaves64", // X86_INS_XSAVES64
	"xsetbv", // X86_INS_XSETBV
	"xsha1", // X86_INS_XSHA1
	"xsha256", // X86_INS_XSHA256
	"xstore", // X86_INS_XSTORE
