/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Target Instruction Enum Values and Descriptors                             *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

/* Capstone Disassembly Engine */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2015 */


#ifdef GET_INSTRINFO_ENUM
#undef GET_INSTRINFO_ENUM

enum {
    SystemZ_PHI	= 0,
    SystemZ_INLINEASM	= 1,
    SystemZ_CFI_INSTRUCTION	= 2,
    SystemZ_EH_LABEL	= 3,
    SystemZ_GC_LABEL	= 4,
    SystemZ_ANNOTATION_LABEL	= 5,
    SystemZ_KILL	= 6,
    SystemZ_EXTRACT_SUBREG	= 7,
    SystemZ_INSERT_SUBREG	= 8,
    SystemZ_IMPLICIT_DEF	= 9,
    SystemZ_SUBREG_TO_REG	= 10,
    SystemZ_COPY_TO_REGCLASS	= 11,
    SystemZ_DBG_VALUE	= 12,
    SystemZ_DBG_LABEL	= 13,
    SystemZ_REG_SEQUENCE	= 14,
    SystemZ_COPY	= 15,
    SystemZ_BUNDLE	= 16,
    SystemZ_LIFETIME_START	= 17,
    SystemZ_LIFETIME_END	= 18,
    SystemZ_STACKMAP	= 19,
    SystemZ_FENTRY_CALL	= 20,
    SystemZ_PATCHPOINT	= 21,
    SystemZ_LOAD_STACK_GUARD	= 22,
    SystemZ_STATEPOINT	= 23,
    SystemZ_LOCAL_ESCAPE	= 24,
    SystemZ_FAULTING_OP	= 25,
    SystemZ_PATCHABLE_OP	= 26,
    SystemZ_PATCHABLE_FUNCTION_ENTER	= 27,
    SystemZ_PATCHABLE_RET	= 28,
    SystemZ_PATCHABLE_FUNCTION_EXIT	= 29,
    SystemZ_PATCHABLE_TAIL_CALL	= 30,
    SystemZ_PATCHABLE_EVENT_CALL	= 31,
    SystemZ_PATCHABLE_TYPED_EVENT_CALL	= 32,
    SystemZ_ICALL_BRANCH_FUNNEL	= 33,
    SystemZ_G_ADD	= 34,
    SystemZ_G_SUB	= 35,
    SystemZ_G_MUL	= 36,
    SystemZ_G_SDIV	= 37,
    SystemZ_G_UDIV	= 38,
    SystemZ_G_SREM	= 39,
    SystemZ_G_UREM	= 40,
    SystemZ_G_AND	= 41,
    SystemZ_G_OR	= 42,
    SystemZ_G_XOR	= 43,
    SystemZ_G_IMPLICIT_DEF	= 44,
    SystemZ_G_PHI	= 45,
    SystemZ_G_FRAME_INDEX	= 46,
    SystemZ_G_GLOBAL_VALUE	= 47,
    SystemZ_G_EXTRACT	= 48,
    SystemZ_G_UNMERGE_VALUES	= 49,
    SystemZ_G_INSERT	= 50,
    SystemZ_G_MERGE_VALUES	= 51,
    SystemZ_G_PTRTOINT	= 52,
    SystemZ_G_INTTOPTR	= 53,
    SystemZ_G_BITCAST	= 54,
    SystemZ_G_LOAD	= 55,
    SystemZ_G_SEXTLOAD	= 56,
    SystemZ_G_ZEXTLOAD	= 57,
    SystemZ_G_STORE	= 58,
    SystemZ_G_ATOMIC_CMPXCHG_WITH_SUCCESS	= 59,
    SystemZ_G_ATOMIC_CMPXCHG	= 60,
    SystemZ_G_ATOMICRMW_XCHG	= 61,
    SystemZ_G_ATOMICRMW_ADD	= 62,
    SystemZ_G_ATOMICRMW_SUB	= 63,
    SystemZ_G_ATOMICRMW_AND	= 64,
    SystemZ_G_ATOMICRMW_NAND	= 65,
    SystemZ_G_ATOMICRMW_OR	= 66,
    SystemZ_G_ATOMICRMW_XOR	= 67,
    SystemZ_G_ATOMICRMW_MAX	= 68,
    SystemZ_G_ATOMICRMW_MIN	= 69,
    SystemZ_G_ATOMICRMW_UMAX	= 70,
    SystemZ_G_ATOMICRMW_UMIN	= 71,
    SystemZ_G_BRCOND	= 72,
    SystemZ_G_BRINDIRECT	= 73,
    SystemZ_G_INTRINSIC	= 74,
    SystemZ_G_INTRINSIC_W_SIDE_EFFECTS	= 75,
    SystemZ_G_ANYEXT	= 76,
    SystemZ_G_TRUNC	= 77,
    SystemZ_G_CONSTANT	= 78,
    SystemZ_G_FCONSTANT	= 79,
    SystemZ_G_VASTART	= 80,
    SystemZ_G_VAARG	= 81,
    SystemZ_G_SEXT	= 82,
    SystemZ_G_ZEXT	= 83,
    SystemZ_G_SHL	= 84,
    SystemZ_G_LSHR	= 85,
    SystemZ_G_ASHR	= 86,
    SystemZ_G_ICMP	= 87,
    SystemZ_G_FCMP	= 88,
    SystemZ_G_SELECT	= 89,
    SystemZ_G_UADDE	= 90,
    SystemZ_G_USUBE	= 91,
    SystemZ_G_SADDO	= 92,
    SystemZ_G_SSUBO	= 93,
    SystemZ_G_UMULO	= 94,
    SystemZ_G_SMULO	= 95,
    SystemZ_G_UMULH	= 96,
    SystemZ_G_SMULH	= 97,
    SystemZ_G_FADD	= 98,
    SystemZ_G_FSUB	= 99,
    SystemZ_G_FMUL	= 100,
    SystemZ_G_FMA	= 101,
    SystemZ_G_FDIV	= 102,
    SystemZ_G_FREM	= 103,
    SystemZ_G_FPOW	= 104,
    SystemZ_G_FEXP	= 105,
    SystemZ_G_FEXP2	= 106,
    SystemZ_G_FLOG	= 107,
    SystemZ_G_FLOG2	= 108,
    SystemZ_G_FNEG	= 109,
    SystemZ_G_FPEXT	= 110,
    SystemZ_G_FPTRUNC	= 111,
    SystemZ_G_FPTOSI	= 112,
    SystemZ_G_FPTOUI	= 113,
    SystemZ_G_SITOFP	= 114,
    SystemZ_G_UITOFP	= 115,
    SystemZ_G_FABS	= 116,
    SystemZ_G_GEP	= 117,
    SystemZ_G_PTR_MASK	= 118,
    SystemZ_G_BR	= 119,
    SystemZ_G_INSERT_VECTOR_ELT	= 120,
    SystemZ_G_EXTRACT_VECTOR_ELT	= 121,
    SystemZ_G_SHUFFLE_VECTOR	= 122,
    SystemZ_G_BSWAP	= 123,
    SystemZ_G_ADDRSPACE_CAST	= 124,
    SystemZ_ADJCALLSTACKDOWN	= 125,
    SystemZ_ADJCALLSTACKUP	= 126,
    SystemZ_ADJDYNALLOC	= 127,
    SystemZ_AEXT128	= 128,
    SystemZ_AFIMux	= 129,
    SystemZ_AHIMux	= 130,
    SystemZ_AHIMuxK	= 131,
    SystemZ_ATOMIC_CMP_SWAPW	= 132,
    SystemZ_ATOMIC_LOADW_AFI	= 133,
    SystemZ_ATOMIC_LOADW_AR	= 134,
    SystemZ_ATOMIC_LOADW_MAX	= 135,
    SystemZ_ATOMIC_LOADW_MIN	= 136,
    SystemZ_ATOMIC_LOADW_NILH	= 137,
    SystemZ_ATOMIC_LOADW_NILHi	= 138,
    SystemZ_ATOMIC_LOADW_NR	= 139,
    SystemZ_ATOMIC_LOADW_NRi	= 140,
    SystemZ_ATOMIC_LOADW_OILH	= 141,
    SystemZ_ATOMIC_LOADW_OR	= 142,
    SystemZ_ATOMIC_LOADW_SR	= 143,
    SystemZ_ATOMIC_LOADW_UMAX	= 144,
    SystemZ_ATOMIC_LOADW_UMIN	= 145,
    SystemZ_ATOMIC_LOADW_XILF	= 146,
    SystemZ_ATOMIC_LOADW_XR	= 147,
    SystemZ_ATOMIC_LOAD_AFI	= 148,
    SystemZ_ATOMIC_LOAD_AGFI	= 149,
    SystemZ_ATOMIC_LOAD_AGHI	= 150,
    SystemZ_ATOMIC_LOAD_AGR	= 151,
    SystemZ_ATOMIC_LOAD_AHI	= 152,
    SystemZ_ATOMIC_LOAD_AR	= 153,
    SystemZ_ATOMIC_LOAD_MAX_32	= 154,
    SystemZ_ATOMIC_LOAD_MAX_64	= 155,
    SystemZ_ATOMIC_LOAD_MIN_32	= 156,
    SystemZ_ATOMIC_LOAD_MIN_64	= 157,
    SystemZ_ATOMIC_LOAD_NGR	= 158,
    SystemZ_ATOMIC_LOAD_NGRi	= 159,
    SystemZ_ATOMIC_LOAD_NIHF64	= 160,
    SystemZ_ATOMIC_LOAD_NIHF64i	= 161,
    SystemZ_ATOMIC_LOAD_NIHH64	= 162,
    SystemZ_ATOMIC_LOAD_NIHH64i	= 163,
    SystemZ_ATOMIC_LOAD_NIHL64	= 164,
    SystemZ_ATOMIC_LOAD_NIHL64i	= 165,
    SystemZ_ATOMIC_LOAD_NILF	= 166,
    SystemZ_ATOMIC_LOAD_NILF64	= 167,
    SystemZ_ATOMIC_LOAD_NILF64i	= 168,
    SystemZ_ATOMIC_LOAD_NILFi	= 169,
    SystemZ_ATOMIC_LOAD_NILH	= 170,
    SystemZ_ATOMIC_LOAD_NILH64	= 171,
    SystemZ_ATOMIC_LOAD_NILH64i	= 172,
    SystemZ_ATOMIC_LOAD_NILHi	= 173,
    SystemZ_ATOMIC_LOAD_NILL	= 174,
    SystemZ_ATOMIC_LOAD_NILL64	= 175,
    SystemZ_ATOMIC_LOAD_NILL64i	= 176,
    SystemZ_ATOMIC_LOAD_NILLi	= 177,
    SystemZ_ATOMIC_LOAD_NR	= 178,
    SystemZ_ATOMIC_LOAD_NRi	= 179,
    SystemZ_ATOMIC_LOAD_OGR	= 180,
    SystemZ_ATOMIC_LOAD_OIHF64	= 181,
    SystemZ_ATOMIC_LOAD_OIHH64	= 182,
    SystemZ_ATOMIC_LOAD_OIHL64	= 183,
    SystemZ_ATOMIC_LOAD_OILF	= 184,
    SystemZ_ATOMIC_LOAD_OILF64	= 185,
    SystemZ_ATOMIC_LOAD_OILH	= 186,
    SystemZ_ATOMIC_LOAD_OILH64	= 187,
    SystemZ_ATOMIC_LOAD_OILL	= 188,
    SystemZ_ATOMIC_LOAD_OILL64	= 189,
    SystemZ_ATOMIC_LOAD_OR	= 190,
    SystemZ_ATOMIC_LOAD_SGR	= 191,
    SystemZ_ATOMIC_LOAD_SR	= 192,
    SystemZ_ATOMIC_LOAD_UMAX_32	= 193,
    SystemZ_ATOMIC_LOAD_UMAX_64	= 194,
    SystemZ_ATOMIC_LOAD_UMIN_32	= 195,
    SystemZ_ATOMIC_LOAD_UMIN_64	= 196,
    SystemZ_ATOMIC_LOAD_XGR	= 197,
    SystemZ_ATOMIC_LOAD_XIHF64	= 198,
    SystemZ_ATOMIC_LOAD_XILF	= 199,
    SystemZ_ATOMIC_LOAD_XILF64	= 200,
    SystemZ_ATOMIC_LOAD_XR	= 201,
    SystemZ_ATOMIC_SWAPW	= 202,
    SystemZ_ATOMIC_SWAP_32	= 203,
    SystemZ_ATOMIC_SWAP_64	= 204,
    SystemZ_CFIMux	= 205,
    SystemZ_CGIBCall	= 206,
    SystemZ_CGIBReturn	= 207,
    SystemZ_CGRBCall	= 208,
    SystemZ_CGRBReturn	= 209,
    SystemZ_CHIMux	= 210,
    SystemZ_CIBCall	= 211,
    SystemZ_CIBReturn	= 212,
    SystemZ_CLCLoop	= 213,
    SystemZ_CLCSequence	= 214,
    SystemZ_CLFIMux	= 215,
    SystemZ_CLGIBCall	= 216,
    SystemZ_CLGIBReturn	= 217,
    SystemZ_CLGRBCall	= 218,
    SystemZ_CLGRBReturn	= 219,
    SystemZ_CLIBCall	= 220,
    SystemZ_CLIBReturn	= 221,
    SystemZ_CLMux	= 222,
    SystemZ_CLRBCall	= 223,
    SystemZ_CLRBReturn	= 224,
    SystemZ_CLSTLoop	= 225,
    SystemZ_CMux	= 226,
    SystemZ_CRBCall	= 227,
    SystemZ_CRBReturn	= 228,
    SystemZ_CallBASR	= 229,
    SystemZ_CallBCR	= 230,
    SystemZ_CallBR	= 231,
    SystemZ_CallBRASL	= 232,
    SystemZ_CallBRCL	= 233,
    SystemZ_CallJG	= 234,
    SystemZ_CondReturn	= 235,
    SystemZ_CondStore16	= 236,
    SystemZ_CondStore16Inv	= 237,
    SystemZ_CondStore16Mux	= 238,
    SystemZ_CondStore16MuxInv	= 239,
    SystemZ_CondStore32	= 240,
    SystemZ_CondStore32Inv	= 241,
    SystemZ_CondStore32Mux	= 242,
    SystemZ_CondStore32MuxInv	= 243,
    SystemZ_CondStore64	= 244,
    SystemZ_CondStore64Inv	= 245,
    SystemZ_CondStore8	= 246,
    SystemZ_CondStore8Inv	= 247,
    SystemZ_CondStore8Mux	= 248,
    SystemZ_CondStore8MuxInv	= 249,
    SystemZ_CondStoreF32	= 250,
    SystemZ_CondStoreF32Inv	= 251,
    SystemZ_CondStoreF64	= 252,
    SystemZ_CondStoreF64Inv	= 253,
    SystemZ_CondTrap	= 254,
    SystemZ_GOT	= 255,
    SystemZ_IIFMux	= 256,
    SystemZ_IIHF64	= 257,
    SystemZ_IIHH64	= 258,
    SystemZ_IIHL64	= 259,
    SystemZ_IIHMux	= 260,
    SystemZ_IILF64	= 261,
    SystemZ_IILH64	= 262,
    SystemZ_IILL64	= 263,
    SystemZ_IILMux	= 264,
    SystemZ_L128	= 265,
    SystemZ_LBMux	= 266,
    SystemZ_LEFR	= 267,
    SystemZ_LFER	= 268,
    SystemZ_LHIMux	= 269,
    SystemZ_LHMux	= 270,
    SystemZ_LLCMux	= 271,
    SystemZ_LLCRMux	= 272,
    SystemZ_LLHMux	= 273,
    SystemZ_LLHRMux	= 274,
    SystemZ_LMux	= 275,
    SystemZ_LOCHIMux	= 276,
    SystemZ_LOCMux	= 277,
    SystemZ_LOCRMux	= 278,
    SystemZ_LRMux	= 279,
    SystemZ_LTDBRCompare_VecPseudo	= 280,
    SystemZ_LTEBRCompare_VecPseudo	= 281,
    SystemZ_LTXBRCompare_VecPseudo	= 282,
    SystemZ_LX	= 283,
    SystemZ_MVCLoop	= 284,
    SystemZ_MVCSequence	= 285,
    SystemZ_MVSTLoop	= 286,
    SystemZ_MemBarrier	= 287,
    SystemZ_NCLoop	= 288,
    SystemZ_NCSequence	= 289,
    SystemZ_NIFMux	= 290,
    SystemZ_NIHF64	= 291,
    SystemZ_NIHH64	= 292,
    SystemZ_NIHL64	= 293,
    SystemZ_NIHMux	= 294,
    SystemZ_NILF64	= 295,
    SystemZ_NILH64	= 296,
    SystemZ_NILL64	= 297,
    SystemZ_NILMux	= 298,
    SystemZ_OCLoop	= 299,
    SystemZ_OCSequence	= 300,
    SystemZ_OIFMux	= 301,
    SystemZ_OIHF64	= 302,
    SystemZ_OIHH64	= 303,
    SystemZ_OIHL64	= 304,
    SystemZ_OIHMux	= 305,
    SystemZ_OILF64	= 306,
    SystemZ_OILH64	= 307,
    SystemZ_OILL64	= 308,
    SystemZ_OILMux	= 309,
    SystemZ_PAIR128	= 310,
    SystemZ_RISBHH	= 311,
    SystemZ_RISBHL	= 312,
    SystemZ_RISBLH	= 313,
    SystemZ_RISBLL	= 314,
    SystemZ_RISBMux	= 315,
    SystemZ_Return	= 316,
    SystemZ_SRSTLoop	= 317,
    SystemZ_ST128	= 318,
    SystemZ_STCMux	= 319,
    SystemZ_STHMux	= 320,
    SystemZ_STMux	= 321,
    SystemZ_STOCMux	= 322,
    SystemZ_STX	= 323,
    SystemZ_Select32	= 324,
    SystemZ_Select64	= 325,
    SystemZ_SelectF128	= 326,
    SystemZ_SelectF32	= 327,
    SystemZ_SelectF64	= 328,
    SystemZ_SelectVR128	= 329,
    SystemZ_SelectVR32	= 330,
    SystemZ_SelectVR64	= 331,
    SystemZ_Serialize	= 332,
    SystemZ_TBEGIN_nofloat	= 333,
    SystemZ_TLS_GDCALL	= 334,
    SystemZ_TLS_LDCALL	= 335,
    SystemZ_TMHH64	= 336,
    SystemZ_TMHL64	= 337,
    SystemZ_TMHMux	= 338,
    SystemZ_TMLH64	= 339,
    SystemZ_TMLL64	= 340,
    SystemZ_TMLMux	= 341,
    SystemZ_Trap	= 342,
    SystemZ_VL32	= 343,
    SystemZ_VL64	= 344,
    SystemZ_VLR32	= 345,
    SystemZ_VLR64	= 346,
    SystemZ_VLVGP32	= 347,
    SystemZ_VST32	= 348,
    SystemZ_VST64	= 349,
    SystemZ_XCLoop	= 350,
    SystemZ_XCSequence	= 351,
    SystemZ_XIFMux	= 352,
    SystemZ_XIHF64	= 353,
    SystemZ_XILF64	= 354,
    SystemZ_ZEXT128	= 355,
    SystemZ_A	= 356,
    SystemZ_AD	= 357,
    SystemZ_ADB	= 358,
    SystemZ_ADBR	= 359,
    SystemZ_ADR	= 360,
    SystemZ_ADTR	= 361,
    SystemZ_ADTRA	= 362,
    SystemZ_AE	= 363,
    SystemZ_AEB	= 364,
    SystemZ_AEBR	= 365,
    SystemZ_AER	= 366,
    SystemZ_AFI	= 367,
    SystemZ_AG	= 368,
    SystemZ_AGF	= 369,
    SystemZ_AGFI	= 370,
    SystemZ_AGFR	= 371,
    SystemZ_AGH	= 372,
    SystemZ_AGHI	= 373,
    SystemZ_AGHIK	= 374,
    SystemZ_AGR	= 375,
    SystemZ_AGRK	= 376,
    SystemZ_AGSI	= 377,
    SystemZ_AH	= 378,
    SystemZ_AHHHR	= 379,
    SystemZ_AHHLR	= 380,
    SystemZ_AHI	= 381,
    SystemZ_AHIK	= 382,
    SystemZ_AHY	= 383,
    SystemZ_AIH	= 384,
    SystemZ_AL	= 385,
    SystemZ_ALC	= 386,
    SystemZ_ALCG	= 387,
    SystemZ_ALCGR	= 388,
    SystemZ_ALCR	= 389,
    SystemZ_ALFI	= 390,
    SystemZ_ALG	= 391,
    SystemZ_ALGF	= 392,
    SystemZ_ALGFI	= 393,
    SystemZ_ALGFR	= 394,
    SystemZ_ALGHSIK	= 395,
    SystemZ_ALGR	= 396,
    SystemZ_ALGRK	= 397,
    SystemZ_ALGSI	= 398,
    SystemZ_ALHHHR	= 399,
    SystemZ_ALHHLR	= 400,
    SystemZ_ALHSIK	= 401,
    SystemZ_ALR	= 402,
    SystemZ_ALRK	= 403,
    SystemZ_ALSI	= 404,
    SystemZ_ALSIH	= 405,
    SystemZ_ALSIHN	= 406,
    SystemZ_ALY	= 407,
    SystemZ_AP	= 408,
    SystemZ_AR	= 409,
    SystemZ_ARK	= 410,
    SystemZ_ASI	= 411,
    SystemZ_AU	= 412,
    SystemZ_AUR	= 413,
    SystemZ_AW	= 414,
    SystemZ_AWR	= 415,
    SystemZ_AXBR	= 416,
    SystemZ_AXR	= 417,
    SystemZ_AXTR	= 418,
    SystemZ_AXTRA	= 419,
    SystemZ_AY	= 420,
    SystemZ_B	= 421,
    SystemZ_BAKR	= 422,
    SystemZ_BAL	= 423,
    SystemZ_BALR	= 424,
    SystemZ_BAS	= 425,
    SystemZ_BASR	= 426,
    SystemZ_BASSM	= 427,
    SystemZ_BAsmE	= 428,
    SystemZ_BAsmH	= 429,
    SystemZ_BAsmHE	= 430,
    SystemZ_BAsmL	= 431,
    SystemZ_BAsmLE	= 432,
    SystemZ_BAsmLH	= 433,
    SystemZ_BAsmM	= 434,
    SystemZ_BAsmNE	= 435,
    SystemZ_BAsmNH	= 436,
    SystemZ_BAsmNHE	= 437,
    SystemZ_BAsmNL	= 438,
    SystemZ_BAsmNLE	= 439,
    SystemZ_BAsmNLH	= 440,
    SystemZ_BAsmNM	= 441,
    SystemZ_BAsmNO	= 442,
    SystemZ_BAsmNP	= 443,
    SystemZ_BAsmNZ	= 444,
    SystemZ_BAsmO	= 445,
    SystemZ_BAsmP	= 446,
    SystemZ_BAsmZ	= 447,
    SystemZ_BC	= 448,
    SystemZ_BCAsm	= 449,
    SystemZ_BCR	= 450,
    SystemZ_BCRAsm	= 451,
    SystemZ_BCT	= 452,
    SystemZ_BCTG	= 453,
    SystemZ_BCTGR	= 454,
    SystemZ_BCTR	= 455,
    SystemZ_BI	= 456,
    SystemZ_BIAsmE	= 457,
    SystemZ_BIAsmH	= 458,
    SystemZ_BIAsmHE	= 459,
    SystemZ_BIAsmL	= 460,
    SystemZ_BIAsmLE	= 461,
    SystemZ_BIAsmLH	= 462,
    SystemZ_BIAsmM	= 463,
    SystemZ_BIAsmNE	= 464,
    SystemZ_BIAsmNH	= 465,
    SystemZ_BIAsmNHE	= 466,
    SystemZ_BIAsmNL	= 467,
    SystemZ_BIAsmNLE	= 468,
    SystemZ_BIAsmNLH	= 469,
    SystemZ_BIAsmNM	= 470,
    SystemZ_BIAsmNO	= 471,
    SystemZ_BIAsmNP	= 472,
    SystemZ_BIAsmNZ	= 473,
    SystemZ_BIAsmO	= 474,
    SystemZ_BIAsmP	= 475,
    SystemZ_BIAsmZ	= 476,
    SystemZ_BIC	= 477,
    SystemZ_BICAsm	= 478,
    SystemZ_BPP	= 479,
    SystemZ_BPRP	= 480,
    SystemZ_BR	= 481,
    SystemZ_BRAS	= 482,
    SystemZ_BRASL	= 483,
    SystemZ_BRAsmE	= 484,
    SystemZ_BRAsmH	= 485,
    SystemZ_BRAsmHE	= 486,
    SystemZ_BRAsmL	= 487,
    SystemZ_BRAsmLE	= 488,
    SystemZ_BRAsmLH	= 489,
    SystemZ_BRAsmM	= 490,
    SystemZ_BRAsmNE	= 491,
    SystemZ_BRAsmNH	= 492,
    SystemZ_BRAsmNHE	= 493,
    SystemZ_BRAsmNL	= 494,
    SystemZ_BRAsmNLE	= 495,
    SystemZ_BRAsmNLH	= 496,
    SystemZ_BRAsmNM	= 497,
    SystemZ_BRAsmNO	= 498,
    SystemZ_BRAsmNP	= 499,
    SystemZ_BRAsmNZ	= 500,
    SystemZ_BRAsmO	= 501,
    SystemZ_BRAsmP	= 502,
    SystemZ_BRAsmZ	= 503,
    SystemZ_BRC	= 504,
    SystemZ_BRCAsm	= 505,
    SystemZ_BRCL	= 506,
    SystemZ_BRCLAsm	= 507,
    SystemZ_BRCT	= 508,
    SystemZ_BRCTG	= 509,
    SystemZ_BRCTH	= 510,
    SystemZ_BRXH	= 511,
    SystemZ_BRXHG	= 512,
    SystemZ_BRXLE	= 513,
    SystemZ_BRXLG	= 514,
    SystemZ_BSA	= 515,
    SystemZ_BSG	= 516,
    SystemZ_BSM	= 517,
    SystemZ_BXH	= 518,
    SystemZ_BXHG	= 519,
    SystemZ_BXLE	= 520,
    SystemZ_BXLEG	= 521,
    SystemZ_C	= 522,
    SystemZ_CD	= 523,
    SystemZ_CDB	= 524,
    SystemZ_CDBR	= 525,
    SystemZ_CDFBR	= 526,
    SystemZ_CDFBRA	= 527,
    SystemZ_CDFR	= 528,
    SystemZ_CDFTR	= 529,
    SystemZ_CDGBR	= 530,
    SystemZ_CDGBRA	= 531,
    SystemZ_CDGR	= 532,
    SystemZ_CDGTR	= 533,
    SystemZ_CDGTRA	= 534,
    SystemZ_CDLFBR	= 535,
    SystemZ_CDLFTR	= 536,
    SystemZ_CDLGBR	= 537,
    SystemZ_CDLGTR	= 538,
    SystemZ_CDPT	= 539,
    SystemZ_CDR	= 540,
    SystemZ_CDS	= 541,
    SystemZ_CDSG	= 542,
    SystemZ_CDSTR	= 543,
    SystemZ_CDSY	= 544,
    SystemZ_CDTR	= 545,
    SystemZ_CDUTR	= 546,
    SystemZ_CDZT	= 547,
    SystemZ_CE	= 548,
    SystemZ_CEB	= 549,
    SystemZ_CEBR	= 550,
    SystemZ_CEDTR	= 551,
    SystemZ_CEFBR	= 552,
    SystemZ_CEFBRA	= 553,
    SystemZ_CEFR	= 554,
    SystemZ_CEGBR	= 555,
    SystemZ_CEGBRA	= 556,
    SystemZ_CEGR	= 557,
    SystemZ_CELFBR	= 558,
    SystemZ_CELGBR	= 559,
    SystemZ_CER	= 560,
    SystemZ_CEXTR	= 561,
    SystemZ_CFC	= 562,
    SystemZ_CFDBR	= 563,
    SystemZ_CFDBRA	= 564,
    SystemZ_CFDR	= 565,
    SystemZ_CFDTR	= 566,
    SystemZ_CFEBR	= 567,
    SystemZ_CFEBRA	= 568,
    SystemZ_CFER	= 569,
    SystemZ_CFI	= 570,
    SystemZ_CFXBR	= 571,
    SystemZ_CFXBRA	= 572,
    SystemZ_CFXR	= 573,
    SystemZ_CFXTR	= 574,
    SystemZ_CG	= 575,
    SystemZ_CGDBR	= 576,
    SystemZ_CGDBRA	= 577,
    SystemZ_CGDR	= 578,
    SystemZ_CGDTR	= 579,
    SystemZ_CGDTRA	= 580,
    SystemZ_CGEBR	= 581,
    SystemZ_CGEBRA	= 582,
    SystemZ_CGER	= 583,
    SystemZ_CGF	= 584,
    SystemZ_CGFI	= 585,
    SystemZ_CGFR	= 586,
    SystemZ_CGFRL	= 587,
    SystemZ_CGH	= 588,
    SystemZ_CGHI	= 589,
    SystemZ_CGHRL	= 590,
    SystemZ_CGHSI	= 591,
    SystemZ_CGIB	= 592,
    SystemZ_CGIBAsm	= 593,
    SystemZ_CGIBAsmE	= 594,
    SystemZ_CGIBAsmH	= 595,
    SystemZ_CGIBAsmHE	= 596,
    SystemZ_CGIBAsmL	= 597,
    SystemZ_CGIBAsmLE	= 598,
    SystemZ_CGIBAsmLH	= 599,
    SystemZ_CGIBAsmNE	= 600,
    SystemZ_CGIBAsmNH	= 601,
    SystemZ_CGIBAsmNHE	= 602,
    SystemZ_CGIBAsmNL	= 603,
    SystemZ_CGIBAsmNLE	= 604,
    SystemZ_CGIBAsmNLH	= 605,
    SystemZ_CGIJ	= 606,
    SystemZ_CGIJAsm	= 607,
    SystemZ_CGIJAsmE	= 608,
    SystemZ_CGIJAsmH	= 609,
    SystemZ_CGIJAsmHE	= 610,
    SystemZ_CGIJAsmL	= 611,
    SystemZ_CGIJAsmLE	= 612,
    SystemZ_CGIJAsmLH	= 613,
    SystemZ_CGIJAsmNE	= 614,
    SystemZ_CGIJAsmNH	= 615,
    SystemZ_CGIJAsmNHE	= 616,
    SystemZ_CGIJAsmNL	= 617,
    SystemZ_CGIJAsmNLE	= 618,
    SystemZ_CGIJAsmNLH	= 619,
    SystemZ_CGIT	= 620,
    SystemZ_CGITAsm	= 621,
    SystemZ_CGITAsmE	= 622,
    SystemZ_CGITAsmH	= 623,
    SystemZ_CGITAsmHE	= 624,
    SystemZ_CGITAsmL	= 625,
    SystemZ_CGITAsmLE	= 626,
    SystemZ_CGITAsmLH	= 627,
    SystemZ_CGITAsmNE	= 628,
    SystemZ_CGITAsmNH	= 629,
    SystemZ_CGITAsmNHE	= 630,
    SystemZ_CGITAsmNL	= 631,
    SystemZ_CGITAsmNLE	= 632,
    SystemZ_CGITAsmNLH	= 633,
    SystemZ_CGR	= 634,
    SystemZ_CGRB	= 635,
    SystemZ_CGRBAsm	= 636,
    SystemZ_CGRBAsmE	= 637,
    SystemZ_CGRBAsmH	= 638,
    SystemZ_CGRBAsmHE	= 639,
    SystemZ_CGRBAsmL	= 640,
    SystemZ_CGRBAsmLE	= 641,
    SystemZ_CGRBAsmLH	= 642,
    SystemZ_CGRBAsmNE	= 643,
    SystemZ_CGRBAsmNH	= 644,
    SystemZ_CGRBAsmNHE	= 645,
    SystemZ_CGRBAsmNL	= 646,
    SystemZ_CGRBAsmNLE	= 647,
    SystemZ_CGRBAsmNLH	= 648,
    SystemZ_CGRJ	= 649,
    SystemZ_CGRJAsm	= 650,
    SystemZ_CGRJAsmE	= 651,
    SystemZ_CGRJAsmH	= 652,
    SystemZ_CGRJAsmHE	= 653,
    SystemZ_CGRJAsmL	= 654,
    SystemZ_CGRJAsmLE	= 655,
    SystemZ_CGRJAsmLH	= 656,
    SystemZ_CGRJAsmNE	= 657,
    SystemZ_CGRJAsmNH	= 658,
    SystemZ_CGRJAsmNHE	= 659,
    SystemZ_CGRJAsmNL	= 660,
    SystemZ_CGRJAsmNLE	= 661,
    SystemZ_CGRJAsmNLH	= 662,
    SystemZ_CGRL	= 663,
    SystemZ_CGRT	= 664,
    SystemZ_CGRTAsm	= 665,
    SystemZ_CGRTAsmE	= 666,
    SystemZ_CGRTAsmH	= 667,
    SystemZ_CGRTAsmHE	= 668,
    SystemZ_CGRTAsmL	= 669,
    SystemZ_CGRTAsmLE	= 670,
    SystemZ_CGRTAsmLH	= 671,
    SystemZ_CGRTAsmNE	= 672,
    SystemZ_CGRTAsmNH	= 673,
    SystemZ_CGRTAsmNHE	= 674,
    SystemZ_CGRTAsmNL	= 675,
    SystemZ_CGRTAsmNLE	= 676,
    SystemZ_CGRTAsmNLH	= 677,
    SystemZ_CGXBR	= 678,
    SystemZ_CGXBRA	= 679,
    SystemZ_CGXR	= 680,
    SystemZ_CGXTR	= 681,
    SystemZ_CGXTRA	= 682,
    SystemZ_CH	= 683,
    SystemZ_CHF	= 684,
    SystemZ_CHHR	= 685,
    SystemZ_CHHSI	= 686,
    SystemZ_CHI	= 687,
    SystemZ_CHLR	= 688,
    SystemZ_CHRL	= 689,
    SystemZ_CHSI	= 690,
    SystemZ_CHY	= 691,
    SystemZ_CIB	= 692,
    SystemZ_CIBAsm	= 693,
    SystemZ_CIBAsmE	= 694,
    SystemZ_CIBAsmH	= 695,
    SystemZ_CIBAsmHE	= 696,
    SystemZ_CIBAsmL	= 697,
    SystemZ_CIBAsmLE	= 698,
    SystemZ_CIBAsmLH	= 699,
    SystemZ_CIBAsmNE	= 700,
    SystemZ_CIBAsmNH	= 701,
    SystemZ_CIBAsmNHE	= 702,
    SystemZ_CIBAsmNL	= 703,
    SystemZ_CIBAsmNLE	= 704,
    SystemZ_CIBAsmNLH	= 705,
    SystemZ_CIH	= 706,
    SystemZ_CIJ	= 707,
    SystemZ_CIJAsm	= 708,
    SystemZ_CIJAsmE	= 709,
    SystemZ_CIJAsmH	= 710,
    SystemZ_CIJAsmHE	= 711,
    SystemZ_CIJAsmL	= 712,
    SystemZ_CIJAsmLE	= 713,
    SystemZ_CIJAsmLH	= 714,
    SystemZ_CIJAsmNE	= 715,
    SystemZ_CIJAsmNH	= 716,
    SystemZ_CIJAsmNHE	= 717,
    SystemZ_CIJAsmNL	= 718,
    SystemZ_CIJAsmNLE	= 719,
    SystemZ_CIJAsmNLH	= 720,
    SystemZ_CIT	= 721,
    SystemZ_CITAsm	= 722,
    SystemZ_CITAsmE	= 723,
    SystemZ_CITAsmH	= 724,
    SystemZ_CITAsmHE	= 725,
    SystemZ_CITAsmL	= 726,
    SystemZ_CITAsmLE	= 727,
    SystemZ_CITAsmLH	= 728,
    SystemZ_CITAsmNE	= 729,
    SystemZ_CITAsmNH	= 730,
    SystemZ_CITAsmNHE	= 731,
    SystemZ_CITAsmNL	= 732,
    SystemZ_CITAsmNLE	= 733,
    SystemZ_CITAsmNLH	= 734,
    SystemZ_CKSM	= 735,
    SystemZ_CL	= 736,
    SystemZ_CLC	= 737,
    SystemZ_CLCL	= 738,
    SystemZ_CLCLE	= 739,
    SystemZ_CLCLU	= 740,
    SystemZ_CLFDBR	= 741,
    SystemZ_CLFDTR	= 742,
    SystemZ_CLFEBR	= 743,
    SystemZ_CLFHSI	= 744,
    SystemZ_CLFI	= 745,
    SystemZ_CLFIT	= 746,
    SystemZ_CLFITAsm	= 747,
    SystemZ_CLFITAsmE	= 748,
    SystemZ_CLFITAsmH	= 749,
    SystemZ_CLFITAsmHE	= 750,
    SystemZ_CLFITAsmL	= 751,
    SystemZ_CLFITAsmLE	= 752,
    SystemZ_CLFITAsmLH	= 753,
    SystemZ_CLFITAsmNE	= 754,
    SystemZ_CLFITAsmNH	= 755,
    SystemZ_CLFITAsmNHE	= 756,
    SystemZ_CLFITAsmNL	= 757,
    SystemZ_CLFITAsmNLE	= 758,
    SystemZ_CLFITAsmNLH	= 759,
    SystemZ_CLFXBR	= 760,
    SystemZ_CLFXTR	= 761,
    SystemZ_CLG	= 762,
    SystemZ_CLGDBR	= 763,
    SystemZ_CLGDTR	= 764,
    SystemZ_CLGEBR	= 765,
    SystemZ_CLGF	= 766,
    SystemZ_CLGFI	= 767,
    SystemZ_CLGFR	= 768,
    SystemZ_CLGFRL	= 769,
    SystemZ_CLGHRL	= 770,
    SystemZ_CLGHSI	= 771,
    SystemZ_CLGIB	= 772,
    SystemZ_CLGIBAsm	= 773,
    SystemZ_CLGIBAsmE	= 774,
    SystemZ_CLGIBAsmH	= 775,
    SystemZ_CLGIBAsmHE	= 776,
    SystemZ_CLGIBAsmL	= 777,
    SystemZ_CLGIBAsmLE	= 778,
    SystemZ_CLGIBAsmLH	= 779,
    SystemZ_CLGIBAsmNE	= 780,
    SystemZ_CLGIBAsmNH	= 781,
    SystemZ_CLGIBAsmNHE	= 782,
    SystemZ_CLGIBAsmNL	= 783,
    SystemZ_CLGIBAsmNLE	= 784,
    SystemZ_CLGIBAsmNLH	= 785,
    SystemZ_CLGIJ	= 786,
    SystemZ_CLGIJAsm	= 787,
    SystemZ_CLGIJAsmE	= 788,
    SystemZ_CLGIJAsmH	= 789,
    SystemZ_CLGIJAsmHE	= 790,
    SystemZ_CLGIJAsmL	= 791,
    SystemZ_CLGIJAsmLE	= 792,
    SystemZ_CLGIJAsmLH	= 793,
    SystemZ_CLGIJAsmNE	= 794,
    SystemZ_CLGIJAsmNH	= 795,
    SystemZ_CLGIJAsmNHE	= 796,
    SystemZ_CLGIJAsmNL	= 797,
    SystemZ_CLGIJAsmNLE	= 798,
    SystemZ_CLGIJAsmNLH	= 799,
    SystemZ_CLGIT	= 800,
    SystemZ_CLGITAsm	= 801,
    SystemZ_CLGITAsmE	= 802,
    SystemZ_CLGITAsmH	= 803,
    SystemZ_CLGITAsmHE	= 804,
    SystemZ_CLGITAsmL	= 805,
    SystemZ_CLGITAsmLE	= 806,
    SystemZ_CLGITAsmLH	= 807,
    SystemZ_CLGITAsmNE	= 808,
    SystemZ_CLGITAsmNH	= 809,
    SystemZ_CLGITAsmNHE	= 810,
    SystemZ_CLGITAsmNL	= 811,
    SystemZ_CLGITAsmNLE	= 812,
    SystemZ_CLGITAsmNLH	= 813,
    SystemZ_CLGR	= 814,
    SystemZ_CLGRB	= 815,
    SystemZ_CLGRBAsm	= 816,
    SystemZ_CLGRBAsmE	= 817,
    SystemZ_CLGRBAsmH	= 818,
    SystemZ_CLGRBAsmHE	= 819,
    SystemZ_CLGRBAsmL	= 820,
    SystemZ_CLGRBAsmLE	= 821,
    SystemZ_CLGRBAsmLH	= 822,
    SystemZ_CLGRBAsmNE	= 823,
    SystemZ_CLGRBAsmNH	= 824,
    SystemZ_CLGRBAsmNHE	= 825,
    SystemZ_CLGRBAsmNL	= 826,
    SystemZ_CLGRBAsmNLE	= 827,
    SystemZ_CLGRBAsmNLH	= 828,
    SystemZ_CLGRJ	= 829,
    SystemZ_CLGRJAsm	= 830,
    SystemZ_CLGRJAsmE	= 831,
    SystemZ_CLGRJAsmH	= 832,
    SystemZ_CLGRJAsmHE	= 833,
    SystemZ_CLGRJAsmL	= 834,
    SystemZ_CLGRJAsmLE	= 835,
    SystemZ_CLGRJAsmLH	= 836,
    SystemZ_CLGRJAsmNE	= 837,
    SystemZ_CLGRJAsmNH	= 838,
    SystemZ_CLGRJAsmNHE	= 839,
    SystemZ_CLGRJAsmNL	= 840,
    SystemZ_CLGRJAsmNLE	= 841,
    SystemZ_CLGRJAsmNLH	= 842,
    SystemZ_CLGRL	= 843,
    SystemZ_CLGRT	= 844,
    SystemZ_CLGRTAsm	= 845,
    SystemZ_CLGRTAsmE	= 846,
    SystemZ_CLGRTAsmH	= 847,
    SystemZ_CLGRTAsmHE	= 848,
    SystemZ_CLGRTAsmL	= 849,
    SystemZ_CLGRTAsmLE	= 850,
    SystemZ_CLGRTAsmLH	= 851,
    SystemZ_CLGRTAsmNE	= 852,
    SystemZ_CLGRTAsmNH	= 853,
    SystemZ_CLGRTAsmNHE	= 854,
    SystemZ_CLGRTAsmNL	= 855,
    SystemZ_CLGRTAsmNLE	= 856,
    SystemZ_CLGRTAsmNLH	= 857,
    SystemZ_CLGT	= 858,
    SystemZ_CLGTAsm	= 859,
    SystemZ_CLGTAsmE	= 860,
    SystemZ_CLGTAsmH	= 861,
    SystemZ_CLGTAsmHE	= 862,
    SystemZ_CLGTAsmL	= 863,
    SystemZ_CLGTAsmLE	= 864,
    SystemZ_CLGTAsmLH	= 865,
    SystemZ_CLGTAsmNE	= 866,
    SystemZ_CLGTAsmNH	= 867,
    SystemZ_CLGTAsmNHE	= 868,
    SystemZ_CLGTAsmNL	= 869,
    SystemZ_CLGTAsmNLE	= 870,
    SystemZ_CLGTAsmNLH	= 871,
    SystemZ_CLGXBR	= 872,
    SystemZ_CLGXTR	= 873,
    SystemZ_CLHF	= 874,
    SystemZ_CLHHR	= 875,
    SystemZ_CLHHSI	= 876,
    SystemZ_CLHLR	= 877,
    SystemZ_CLHRL	= 878,
    SystemZ_CLI	= 879,
    SystemZ_CLIB	= 880,
    SystemZ_CLIBAsm	= 881,
    SystemZ_CLIBAsmE	= 882,
    SystemZ_CLIBAsmH	= 883,
    SystemZ_CLIBAsmHE	= 884,
    SystemZ_CLIBAsmL	= 885,
    SystemZ_CLIBAsmLE	= 886,
    SystemZ_CLIBAsmLH	= 887,
    SystemZ_CLIBAsmNE	= 888,
    SystemZ_CLIBAsmNH	= 889,
    SystemZ_CLIBAsmNHE	= 890,
    SystemZ_CLIBAsmNL	= 891,
    SystemZ_CLIBAsmNLE	= 892,
    SystemZ_CLIBAsmNLH	= 893,
    SystemZ_CLIH	= 894,
    SystemZ_CLIJ	= 895,
    SystemZ_CLIJAsm	= 896,
    SystemZ_CLIJAsmE	= 897,
    SystemZ_CLIJAsmH	= 898,
    SystemZ_CLIJAsmHE	= 899,
    SystemZ_CLIJAsmL	= 900,
    SystemZ_CLIJAsmLE	= 901,
    SystemZ_CLIJAsmLH	= 902,
    SystemZ_CLIJAsmNE	= 903,
    SystemZ_CLIJAsmNH	= 904,
    SystemZ_CLIJAsmNHE	= 905,
    SystemZ_CLIJAsmNL	= 906,
    SystemZ_CLIJAsmNLE	= 907,
    SystemZ_CLIJAsmNLH	= 908,
    SystemZ_CLIY	= 909,
    SystemZ_CLM	= 910,
    SystemZ_CLMH	= 911,
    SystemZ_CLMY	= 912,
    SystemZ_CLR	= 913,
    SystemZ_CLRB	= 914,
    SystemZ_CLRBAsm	= 915,
    SystemZ_CLRBAsmE	= 916,
    SystemZ_CLRBAsmH	= 917,
    SystemZ_CLRBAsmHE	= 918,
    SystemZ_CLRBAsmL	= 919,
    SystemZ_CLRBAsmLE	= 920,
    SystemZ_CLRBAsmLH	= 921,
    SystemZ_CLRBAsmNE	= 922,
    SystemZ_CLRBAsmNH	= 923,
    SystemZ_CLRBAsmNHE	= 924,
    SystemZ_CLRBAsmNL	= 925,
    SystemZ_CLRBAsmNLE	= 926,
    SystemZ_CLRBAsmNLH	= 927,
    SystemZ_CLRJ	= 928,
    SystemZ_CLRJAsm	= 929,
    SystemZ_CLRJAsmE	= 930,
    SystemZ_CLRJAsmH	= 931,
    SystemZ_CLRJAsmHE	= 932,
    SystemZ_CLRJAsmL	= 933,
    SystemZ_CLRJAsmLE	= 934,
    SystemZ_CLRJAsmLH	= 935,
    SystemZ_CLRJAsmNE	= 936,
    SystemZ_CLRJAsmNH	= 937,
    SystemZ_CLRJAsmNHE	= 938,
    SystemZ_CLRJAsmNL	= 939,
    SystemZ_CLRJAsmNLE	= 940,
    SystemZ_CLRJAsmNLH	= 941,
    SystemZ_CLRL	= 942,
    SystemZ_CLRT	= 943,
    SystemZ_CLRTAsm	= 944,
    SystemZ_CLRTAsmE	= 945,
    SystemZ_CLRTAsmH	= 946,
    SystemZ_CLRTAsmHE	= 947,
    SystemZ_CLRTAsmL	= 948,
    SystemZ_CLRTAsmLE	= 949,
    SystemZ_CLRTAsmLH	= 950,
    SystemZ_CLRTAsmNE	= 951,
    SystemZ_CLRTAsmNH	= 952,
    SystemZ_CLRTAsmNHE	= 953,
    SystemZ_CLRTAsmNL	= 954,
    SystemZ_CLRTAsmNLE	= 955,
    SystemZ_CLRTAsmNLH	= 956,
    SystemZ_CLST	= 957,
    SystemZ_CLT	= 958,
    SystemZ_CLTAsm	= 959,
    SystemZ_CLTAsmE	= 960,
    SystemZ_CLTAsmH	= 961,
    SystemZ_CLTAsmHE	= 962,
    SystemZ_CLTAsmL	= 963,
    SystemZ_CLTAsmLE	= 964,
    SystemZ_CLTAsmLH	= 965,
    SystemZ_CLTAsmNE	= 966,
    SystemZ_CLTAsmNH	= 967,
    SystemZ_CLTAsmNHE	= 968,
    SystemZ_CLTAsmNL	= 969,
    SystemZ_CLTAsmNLE	= 970,
    SystemZ_CLTAsmNLH	= 971,
    SystemZ_CLY	= 972,
    SystemZ_CMPSC	= 973,
    SystemZ_CP	= 974,
    SystemZ_CPDT	= 975,
    SystemZ_CPSDRdd	= 976,
    SystemZ_CPSDRds	= 977,
    SystemZ_CPSDRsd	= 978,
    SystemZ_CPSDRss	= 979,
    SystemZ_CPXT	= 980,
    SystemZ_CPYA	= 981,
    SystemZ_CR	= 982,
    SystemZ_CRB	= 983,
    SystemZ_CRBAsm	= 984,
    SystemZ_CRBAsmE	= 985,
    SystemZ_CRBAsmH	= 986,
    SystemZ_CRBAsmHE	= 987,
    SystemZ_CRBAsmL	= 988,
    SystemZ_CRBAsmLE	= 989,
    SystemZ_CRBAsmLH	= 990,
    SystemZ_CRBAsmNE	= 991,
    SystemZ_CRBAsmNH	= 992,
    SystemZ_CRBAsmNHE	= 993,
    SystemZ_CRBAsmNL	= 994,
    SystemZ_CRBAsmNLE	= 995,
    SystemZ_CRBAsmNLH	= 996,
    SystemZ_CRDTE	= 997,
    SystemZ_CRDTEOpt	= 998,
    SystemZ_CRJ	= 999,
    SystemZ_CRJAsm	= 1000,
    SystemZ_CRJAsmE	= 1001,
    SystemZ_CRJAsmH	= 1002,
    SystemZ_CRJAsmHE	= 1003,
    SystemZ_CRJAsmL	= 1004,
    SystemZ_CRJAsmLE	= 1005,
    SystemZ_CRJAsmLH	= 1006,
    SystemZ_CRJAsmNE	= 1007,
    SystemZ_CRJAsmNH	= 1008,
    SystemZ_CRJAsmNHE	= 1009,
    SystemZ_CRJAsmNL	= 1010,
    SystemZ_CRJAsmNLE	= 1011,
    SystemZ_CRJAsmNLH	= 1012,
    SystemZ_CRL	= 1013,
    SystemZ_CRT	= 1014,
    SystemZ_CRTAsm	= 1015,
    SystemZ_CRTAsmE	= 1016,
    SystemZ_CRTAsmH	= 1017,
    SystemZ_CRTAsmHE	= 1018,
    SystemZ_CRTAsmL	= 1019,
    SystemZ_CRTAsmLE	= 1020,
    SystemZ_CRTAsmLH	= 1021,
    SystemZ_CRTAsmNE	= 1022,
    SystemZ_CRTAsmNH	= 1023,
    SystemZ_CRTAsmNHE	= 1024,
    SystemZ_CRTAsmNL	= 1025,
    SystemZ_CRTAsmNLE	= 1026,
    SystemZ_CRTAsmNLH	= 1027,
    SystemZ_CS	= 1028,
    SystemZ_CSCH	= 1029,
    SystemZ_CSDTR	= 1030,
    SystemZ_CSG	= 1031,
    SystemZ_CSP	= 1032,
    SystemZ_CSPG	= 1033,
    SystemZ_CSST	= 1034,
    SystemZ_CSXTR	= 1035,
    SystemZ_CSY	= 1036,
    SystemZ_CU12	= 1037,
    SystemZ_CU12Opt	= 1038,
    SystemZ_CU14	= 1039,
    SystemZ_CU14Opt	= 1040,
    SystemZ_CU21	= 1041,
    SystemZ_CU21Opt	= 1042,
    SystemZ_CU24	= 1043,
    SystemZ_CU24Opt	= 1044,
    SystemZ_CU41	= 1045,
    SystemZ_CU42	= 1046,
    SystemZ_CUDTR	= 1047,
    SystemZ_CUSE	= 1048,
    SystemZ_CUTFU	= 1049,
    SystemZ_CUTFUOpt	= 1050,
    SystemZ_CUUTF	= 1051,
    SystemZ_CUUTFOpt	= 1052,
    SystemZ_CUXTR	= 1053,
    SystemZ_CVB	= 1054,
    SystemZ_CVBG	= 1055,
    SystemZ_CVBY	= 1056,
    SystemZ_CVD	= 1057,
    SystemZ_CVDG	= 1058,
    SystemZ_CVDY	= 1059,
    SystemZ_CXBR	= 1060,
    SystemZ_CXFBR	= 1061,
    SystemZ_CXFBRA	= 1062,
    SystemZ_CXFR	= 1063,
    SystemZ_CXFTR	= 1064,
    SystemZ_CXGBR	= 1065,
    SystemZ_CXGBRA	= 1066,
    SystemZ_CXGR	= 1067,
    SystemZ_CXGTR	= 1068,
    SystemZ_CXGTRA	= 1069,
    SystemZ_CXLFBR	= 1070,
    SystemZ_CXLFTR	= 1071,
    SystemZ_CXLGBR	= 1072,
    SystemZ_CXLGTR	= 1073,
    SystemZ_CXPT	= 1074,
    SystemZ_CXR	= 1075,
    SystemZ_CXSTR	= 1076,
    SystemZ_CXTR	= 1077,
    SystemZ_CXUTR	= 1078,
    SystemZ_CXZT	= 1079,
    SystemZ_CY	= 1080,
    SystemZ_CZDT	= 1081,
    SystemZ_CZXT	= 1082,
    SystemZ_D	= 1083,
    SystemZ_DD	= 1084,
    SystemZ_DDB	= 1085,
    SystemZ_DDBR	= 1086,
    SystemZ_DDR	= 1087,
    SystemZ_DDTR	= 1088,
    SystemZ_DDTRA	= 1089,
    SystemZ_DE	= 1090,
    SystemZ_DEB	= 1091,
    SystemZ_DEBR	= 1092,
    SystemZ_DER	= 1093,
    SystemZ_DIAG	= 1094,
    SystemZ_DIDBR	= 1095,
    SystemZ_DIEBR	= 1096,
    SystemZ_DL	= 1097,
    SystemZ_DLG	= 1098,
    SystemZ_DLGR	= 1099,
    SystemZ_DLR	= 1100,
    SystemZ_DP	= 1101,
    SystemZ_DR	= 1102,
    SystemZ_DSG	= 1103,
    SystemZ_DSGF	= 1104,
    SystemZ_DSGFR	= 1105,
    SystemZ_DSGR	= 1106,
    SystemZ_DXBR	= 1107,
    SystemZ_DXR	= 1108,
    SystemZ_DXTR	= 1109,
    SystemZ_DXTRA	= 1110,
    SystemZ_EAR	= 1111,
    SystemZ_ECAG	= 1112,
    SystemZ_ECCTR	= 1113,
    SystemZ_ECPGA	= 1114,
    SystemZ_ECTG	= 1115,
    SystemZ_ED	= 1116,
    SystemZ_EDMK	= 1117,
    SystemZ_EEDTR	= 1118,
    SystemZ_EEXTR	= 1119,
    SystemZ_EFPC	= 1120,
    SystemZ_EPAIR	= 1121,
    SystemZ_EPAR	= 1122,
    SystemZ_EPCTR	= 1123,
    SystemZ_EPSW	= 1124,
    SystemZ_EREG	= 1125,
    SystemZ_EREGG	= 1126,
    SystemZ_ESAIR	= 1127,
    SystemZ_ESAR	= 1128,
    SystemZ_ESDTR	= 1129,
    SystemZ_ESEA	= 1130,
    SystemZ_ESTA	= 1131,
    SystemZ_ESXTR	= 1132,
    SystemZ_ETND	= 1133,
    SystemZ_EX	= 1134,
    SystemZ_EXRL	= 1135,
    SystemZ_FIDBR	= 1136,
    SystemZ_FIDBRA	= 1137,
    SystemZ_FIDR	= 1138,
    SystemZ_FIDTR	= 1139,
    SystemZ_FIEBR	= 1140,
    SystemZ_FIEBRA	= 1141,
    SystemZ_FIER	= 1142,
    SystemZ_FIXBR	= 1143,
    SystemZ_FIXBRA	= 1144,
    SystemZ_FIXR	= 1145,
    SystemZ_FIXTR	= 1146,
    SystemZ_FLOGR	= 1147,
    SystemZ_HDR	= 1148,
    SystemZ_HER	= 1149,
    SystemZ_HSCH	= 1150,
    SystemZ_IAC	= 1151,
    SystemZ_IC	= 1152,
    SystemZ_IC32	= 1153,
    SystemZ_IC32Y	= 1154,
    SystemZ_ICM	= 1155,
    SystemZ_ICMH	= 1156,
    SystemZ_ICMY	= 1157,
    SystemZ_ICY	= 1158,
    SystemZ_IDTE	= 1159,
    SystemZ_IDTEOpt	= 1160,
    SystemZ_IEDTR	= 1161,
    SystemZ_IEXTR	= 1162,
    SystemZ_IIHF	= 1163,
    SystemZ_IIHH	= 1164,
    SystemZ_IIHL	= 1165,
    SystemZ_IILF	= 1166,
    SystemZ_IILH	= 1167,
    SystemZ_IILL	= 1168,
    SystemZ_IPK	= 1169,
    SystemZ_IPM	= 1170,
    SystemZ_IPTE	= 1171,
    SystemZ_IPTEOpt	= 1172,
    SystemZ_IPTEOptOpt	= 1173,
    SystemZ_IRBM	= 1174,
    SystemZ_ISKE	= 1175,
    SystemZ_IVSK	= 1176,
    SystemZ_InsnE	= 1177,
    SystemZ_InsnRI	= 1178,
    SystemZ_InsnRIE	= 1179,
    SystemZ_InsnRIL	= 1180,
    SystemZ_InsnRILU	= 1181,
    SystemZ_InsnRIS	= 1182,
    SystemZ_InsnRR	= 1183,
    SystemZ_InsnRRE	= 1184,
    SystemZ_InsnRRF	= 1185,
    SystemZ_InsnRRS	= 1186,
    SystemZ_InsnRS	= 1187,
    SystemZ_InsnRSE	= 1188,
    SystemZ_InsnRSI	= 1189,
    SystemZ_InsnRSY	= 1190,
    SystemZ_InsnRX	= 1191,
    SystemZ_InsnRXE	= 1192,
    SystemZ_InsnRXF	= 1193,
    SystemZ_InsnRXY	= 1194,
    SystemZ_InsnS	= 1195,
    SystemZ_InsnSI	= 1196,
    SystemZ_InsnSIL	= 1197,
    SystemZ_InsnSIY	= 1198,
    SystemZ_InsnSS	= 1199,
    SystemZ_InsnSSE	= 1200,
    SystemZ_InsnSSF	= 1201,
    SystemZ_J	= 1202,
    SystemZ_JAsmE	= 1203,
    SystemZ_JAsmH	= 1204,
    SystemZ_JAsmHE	= 1205,
    SystemZ_JAsmL	= 1206,
    SystemZ_JAsmLE	= 1207,
    SystemZ_JAsmLH	= 1208,
    SystemZ_JAsmM	= 1209,
    SystemZ_JAsmNE	= 1210,
    SystemZ_JAsmNH	= 1211,
    SystemZ_JAsmNHE	= 1212,
    SystemZ_JAsmNL	= 1213,
    SystemZ_JAsmNLE	= 1214,
    SystemZ_JAsmNLH	= 1215,
    SystemZ_JAsmNM	= 1216,
    SystemZ_JAsmNO	= 1217,
    SystemZ_JAsmNP	= 1218,
    SystemZ_JAsmNZ	= 1219,
    SystemZ_JAsmO	= 1220,
    SystemZ_JAsmP	= 1221,
    SystemZ_JAsmZ	= 1222,
    SystemZ_JG	= 1223,
    SystemZ_JGAsmE	= 1224,
    SystemZ_JGAsmH	= 1225,
    SystemZ_JGAsmHE	= 1226,
    SystemZ_JGAsmL	= 1227,
    SystemZ_JGAsmLE	= 1228,
    SystemZ_JGAsmLH	= 1229,
    SystemZ_JGAsmM	= 1230,
    SystemZ_JGAsmNE	= 1231,
    SystemZ_JGAsmNH	= 1232,
    SystemZ_JGAsmNHE	= 1233,
    SystemZ_JGAsmNL	= 1234,
    SystemZ_JGAsmNLE	= 1235,
    SystemZ_JGAsmNLH	= 1236,
    SystemZ_JGAsmNM	= 1237,
    SystemZ_JGAsmNO	= 1238,
    SystemZ_JGAsmNP	= 1239,
    SystemZ_JGAsmNZ	= 1240,
    SystemZ_JGAsmO	= 1241,
    SystemZ_JGAsmP	= 1242,
    SystemZ_JGAsmZ	= 1243,
    SystemZ_KDB	= 1244,
    SystemZ_KDBR	= 1245,
    SystemZ_KDTR	= 1246,
    SystemZ_KEB	= 1247,
    SystemZ_KEBR	= 1248,
    SystemZ_KIMD	= 1249,
    SystemZ_KLMD	= 1250,
    SystemZ_KM	= 1251,
    SystemZ_KMA	= 1252,
    SystemZ_KMAC	= 1253,
    SystemZ_KMC	= 1254,
    SystemZ_KMCTR	= 1255,
    SystemZ_KMF	= 1256,
    SystemZ_KMO	= 1257,
    SystemZ_KXBR	= 1258,
    SystemZ_KXTR	= 1259,
    SystemZ_L	= 1260,
    SystemZ_LA	= 1261,
    SystemZ_LAA	= 1262,
    SystemZ_LAAG	= 1263,
    SystemZ_LAAL	= 1264,
    SystemZ_LAALG	= 1265,
    SystemZ_LAE	= 1266,
    SystemZ_LAEY	= 1267,
    SystemZ_LAM	= 1268,
    SystemZ_LAMY	= 1269,
    SystemZ_LAN	= 1270,
    SystemZ_LANG	= 1271,
    SystemZ_LAO	= 1272,
    SystemZ_LAOG	= 1273,
    SystemZ_LARL	= 1274,
    SystemZ_LASP	= 1275,
    SystemZ_LAT	= 1276,
    SystemZ_LAX	= 1277,
    SystemZ_LAXG	= 1278,
    SystemZ_LAY	= 1279,
    SystemZ_LB	= 1280,
    SystemZ_LBH	= 1281,
    SystemZ_LBR	= 1282,
    SystemZ_LCBB	= 1283,
    SystemZ_LCCTL	= 1284,
    SystemZ_LCDBR	= 1285,
    SystemZ_LCDFR	= 1286,
    SystemZ_LCDFR_32	= 1287,
    SystemZ_LCDR	= 1288,
    SystemZ_LCEBR	= 1289,
    SystemZ_LCER	= 1290,
    SystemZ_LCGFR	= 1291,
    SystemZ_LCGR	= 1292,
    SystemZ_LCR	= 1293,
    SystemZ_LCTL	= 1294,
    SystemZ_LCTLG	= 1295,
    SystemZ_LCXBR	= 1296,
    SystemZ_LCXR	= 1297,
    SystemZ_LD	= 1298,
    SystemZ_LDE	= 1299,
    SystemZ_LDE32	= 1300,
    SystemZ_LDEB	= 1301,
    SystemZ_LDEBR	= 1302,
    SystemZ_LDER	= 1303,
    SystemZ_LDETR	= 1304,
    SystemZ_LDGR	= 1305,
    SystemZ_LDR	= 1306,
    SystemZ_LDR32	= 1307,
    SystemZ_LDXBR	= 1308,
    SystemZ_LDXBRA	= 1309,
    SystemZ_LDXR	= 1310,
    SystemZ_LDXTR	= 1311,
    SystemZ_LDY	= 1312,
    SystemZ_LE	= 1313,
    SystemZ_LEDBR	= 1314,
    SystemZ_LEDBRA	= 1315,
    SystemZ_LEDR	= 1316,
    SystemZ_LEDTR	= 1317,
    SystemZ_LER	= 1318,
    SystemZ_LEXBR	= 1319,
    SystemZ_LEXBRA	= 1320,
    SystemZ_LEXR	= 1321,
    SystemZ_LEY	= 1322,
    SystemZ_LFAS	= 1323,
    SystemZ_LFH	= 1324,
    SystemZ_LFHAT	= 1325,
    SystemZ_LFPC	= 1326,
    SystemZ_LG	= 1327,
    SystemZ_LGAT	= 1328,
    SystemZ_LGB	= 1329,
    SystemZ_LGBR	= 1330,
    SystemZ_LGDR	= 1331,
    SystemZ_LGF	= 1332,
    SystemZ_LGFI	= 1333,
    SystemZ_LGFR	= 1334,
    SystemZ_LGFRL	= 1335,
    SystemZ_LGG	= 1336,
    SystemZ_LGH	= 1337,
    SystemZ_LGHI	= 1338,
    SystemZ_LGHR	= 1339,
    SystemZ_LGHRL	= 1340,
    SystemZ_LGR	= 1341,
    SystemZ_LGRL	= 1342,
    SystemZ_LGSC	= 1343,
    SystemZ_LH	= 1344,
    SystemZ_LHH	= 1345,
    SystemZ_LHI	= 1346,
    SystemZ_LHR	= 1347,
    SystemZ_LHRL	= 1348,
    SystemZ_LHY	= 1349,
    SystemZ_LLC	= 1350,
    SystemZ_LLCH	= 1351,
    SystemZ_LLCR	= 1352,
    SystemZ_LLGC	= 1353,
    SystemZ_LLGCR	= 1354,
    SystemZ_LLGF	= 1355,
    SystemZ_LLGFAT	= 1356,
    SystemZ_LLGFR	= 1357,
    SystemZ_LLGFRL	= 1358,
    SystemZ_LLGFSG	= 1359,
    SystemZ_LLGH	= 1360,
    SystemZ_LLGHR	= 1361,
    SystemZ_LLGHRL	= 1362,
    SystemZ_LLGT	= 1363,
    SystemZ_LLGTAT	= 1364,
    SystemZ_LLGTR	= 1365,
    SystemZ_LLH	= 1366,
    SystemZ_LLHH	= 1367,
    SystemZ_LLHR	= 1368,
    SystemZ_LLHRL	= 1369,
    SystemZ_LLIHF	= 1370,
    SystemZ_LLIHH	= 1371,
    SystemZ_LLIHL	= 1372,
    SystemZ_LLILF	= 1373,
    SystemZ_LLILH	= 1374,
    SystemZ_LLILL	= 1375,
    SystemZ_LLZRGF	= 1376,
    SystemZ_LM	= 1377,
    SystemZ_LMD	= 1378,
    SystemZ_LMG	= 1379,
    SystemZ_LMH	= 1380,
    SystemZ_LMY	= 1381,
    SystemZ_LNDBR	= 1382,
    SystemZ_LNDFR	= 1383,
    SystemZ_LNDFR_32	= 1384,
    SystemZ_LNDR	= 1385,
    SystemZ_LNEBR	= 1386,
    SystemZ_LNER	= 1387,
    SystemZ_LNGFR	= 1388,
    SystemZ_LNGR	= 1389,
    SystemZ_LNR	= 1390,
    SystemZ_LNXBR	= 1391,
    SystemZ_LNXR	= 1392,
    SystemZ_LOC	= 1393,
    SystemZ_LOCAsm	= 1394,
    SystemZ_LOCAsmE	= 1395,
    SystemZ_LOCAsmH	= 1396,
    SystemZ_LOCAsmHE	= 1397,
    SystemZ_LOCAsmL	= 1398,
    SystemZ_LOCAsmLE	= 1399,
    SystemZ_LOCAsmLH	= 1400,
    SystemZ_LOCAsmM	= 1401,
    SystemZ_LOCAsmNE	= 1402,
    SystemZ_LOCAsmNH	= 1403,
    SystemZ_LOCAsmNHE	= 1404,
    SystemZ_LOCAsmNL	= 1405,
    SystemZ_LOCAsmNLE	= 1406,
    SystemZ_LOCAsmNLH	= 1407,
    SystemZ_LOCAsmNM	= 1408,
    SystemZ_LOCAsmNO	= 1409,
    SystemZ_LOCAsmNP	= 1410,
    SystemZ_LOCAsmNZ	= 1411,
    SystemZ_LOCAsmO	= 1412,
    SystemZ_LOCAsmP	= 1413,
    SystemZ_LOCAsmZ	= 1414,
    SystemZ_LOCFH	= 1415,
    SystemZ_LOCFHAsm	= 1416,
    SystemZ_LOCFHAsmE	= 1417,
    SystemZ_LOCFHAsmH	= 1418,
    SystemZ_LOCFHAsmHE	= 1419,
    SystemZ_LOCFHAsmL	= 1420,
    SystemZ_LOCFHAsmLE	= 1421,
    SystemZ_LOCFHAsmLH	= 1422,
    SystemZ_LOCFHAsmM	= 1423,
    SystemZ_LOCFHAsmNE	= 1424,
    SystemZ_LOCFHAsmNH	= 1425,
    SystemZ_LOCFHAsmNHE	= 1426,
    SystemZ_LOCFHAsmNL	= 1427,
    SystemZ_LOCFHAsmNLE	= 1428,
    SystemZ_LOCFHAsmNLH	= 1429,
    SystemZ_LOCFHAsmNM	= 1430,
    SystemZ_LOCFHAsmNO	= 1431,
    SystemZ_LOCFHAsmNP	= 1432,
    SystemZ_LOCFHAsmNZ	= 1433,
    SystemZ_LOCFHAsmO	= 1434,
    SystemZ_LOCFHAsmP	= 1435,
    SystemZ_LOCFHAsmZ	= 1436,
    SystemZ_LOCFHR	= 1437,
    SystemZ_LOCFHRAsm	= 1438,
    SystemZ_LOCFHRAsmE	= 1439,
    SystemZ_LOCFHRAsmH	= 1440,
    SystemZ_LOCFHRAsmHE	= 1441,
    SystemZ_LOCFHRAsmL	= 1442,
    SystemZ_LOCFHRAsmLE	= 1443,
    SystemZ_LOCFHRAsmLH	= 1444,
    SystemZ_LOCFHRAsmM	= 1445,
    SystemZ_LOCFHRAsmNE	= 1446,
    SystemZ_LOCFHRAsmNH	= 1447,
    SystemZ_LOCFHRAsmNHE	= 1448,
    SystemZ_LOCFHRAsmNL	= 1449,
    SystemZ_LOCFHRAsmNLE	= 1450,
    SystemZ_LOCFHRAsmNLH	= 1451,
    SystemZ_LOCFHRAsmNM	= 1452,
    SystemZ_LOCFHRAsmNO	= 1453,
    SystemZ_LOCFHRAsmNP	= 1454,
    SystemZ_LOCFHRAsmNZ	= 1455,
    SystemZ_LOCFHRAsmO	= 1456,
    SystemZ_LOCFHRAsmP	= 1457,
    SystemZ_LOCFHRAsmZ	= 1458,
    SystemZ_LOCG	= 1459,
    SystemZ_LOCGAsm	= 1460,
    SystemZ_LOCGAsmE	= 1461,
    SystemZ_LOCGAsmH	= 1462,
    SystemZ_LOCGAsmHE	= 1463,
    SystemZ_LOCGAsmL	= 1464,
    SystemZ_LOCGAsmLE	= 1465,
    SystemZ_LOCGAsmLH	= 1466,
    SystemZ_LOCGAsmM	= 1467,
    SystemZ_LOCGAsmNE	= 1468,
    SystemZ_LOCGAsmNH	= 1469,
    SystemZ_LOCGAsmNHE	= 1470,
    SystemZ_LOCGAsmNL	= 1471,
    SystemZ_LOCGAsmNLE	= 1472,
    SystemZ_LOCGAsmNLH	= 1473,
    SystemZ_LOCGAsmNM	= 1474,
    SystemZ_LOCGAsmNO	= 1475,
    SystemZ_LOCGAsmNP	= 1476,
    SystemZ_LOCGAsmNZ	= 1477,
    SystemZ_LOCGAsmO	= 1478,
    SystemZ_LOCGAsmP	= 1479,
    SystemZ_LOCGAsmZ	= 1480,
    SystemZ_LOCGHI	= 1481,
    SystemZ_LOCGHIAsm	= 1482,
    SystemZ_LOCGHIAsmE	= 1483,
    SystemZ_LOCGHIAsmH	= 1484,
    SystemZ_LOCGHIAsmHE	= 1485,
    SystemZ_LOCGHIAsmL	= 1486,
    SystemZ_LOCGHIAsmLE	= 1487,
    SystemZ_LOCGHIAsmLH	= 1488,
    SystemZ_LOCGHIAsmM	= 1489,
    SystemZ_LOCGHIAsmNE	= 1490,
    SystemZ_LOCGHIAsmNH	= 1491,
    SystemZ_LOCGHIAsmNHE	= 1492,
    SystemZ_LOCGHIAsmNL	= 1493,
    SystemZ_LOCGHIAsmNLE	= 1494,
    SystemZ_LOCGHIAsmNLH	= 1495,
    SystemZ_LOCGHIAsmNM	= 1496,
    SystemZ_LOCGHIAsmNO	= 1497,
    SystemZ_LOCGHIAsmNP	= 1498,
    SystemZ_LOCGHIAsmNZ	= 1499,
    SystemZ_LOCGHIAsmO	= 1500,
    SystemZ_LOCGHIAsmP	= 1501,
    SystemZ_LOCGHIAsmZ	= 1502,
    SystemZ_LOCGR	= 1503,
    SystemZ_LOCGRAsm	= 1504,
    SystemZ_LOCGRAsmE	= 1505,
    SystemZ_LOCGRAsmH	= 1506,
    SystemZ_LOCGRAsmHE	= 1507,
    SystemZ_LOCGRAsmL	= 1508,
    SystemZ_LOCGRAsmLE	= 1509,
    SystemZ_LOCGRAsmLH	= 1510,
    SystemZ_LOCGRAsmM	= 1511,
    SystemZ_LOCGRAsmNE	= 1512,
    SystemZ_LOCGRAsmNH	= 1513,
    SystemZ_LOCGRAsmNHE	= 1514,
    SystemZ_LOCGRAsmNL	= 1515,
    SystemZ_LOCGRAsmNLE	= 1516,
    SystemZ_LOCGRAsmNLH	= 1517,
    SystemZ_LOCGRAsmNM	= 1518,
    SystemZ_LOCGRAsmNO	= 1519,
    SystemZ_LOCGRAsmNP	= 1520,
    SystemZ_LOCGRAsmNZ	= 1521,
    SystemZ_LOCGRAsmO	= 1522,
    SystemZ_LOCGRAsmP	= 1523,
    SystemZ_LOCGRAsmZ	= 1524,
    SystemZ_LOCHHI	= 1525,
    SystemZ_LOCHHIAsm	= 1526,
    SystemZ_LOCHHIAsmE	= 1527,
    SystemZ_LOCHHIAsmH	= 1528,
    SystemZ_LOCHHIAsmHE	= 1529,
    SystemZ_LOCHHIAsmL	= 1530,
    SystemZ_LOCHHIAsmLE	= 1531,
    SystemZ_LOCHHIAsmLH	= 1532,
    SystemZ_LOCHHIAsmM	= 1533,
    SystemZ_LOCHHIAsmNE	= 1534,
    SystemZ_LOCHHIAsmNH	= 1535,
    SystemZ_LOCHHIAsmNHE	= 1536,
    SystemZ_LOCHHIAsmNL	= 1537,
    SystemZ_LOCHHIAsmNLE	= 1538,
    SystemZ_LOCHHIAsmNLH	= 1539,
    SystemZ_LOCHHIAsmNM	= 1540,
    SystemZ_LOCHHIAsmNO	= 1541,
    SystemZ_LOCHHIAsmNP	= 1542,
    SystemZ_LOCHHIAsmNZ	= 1543,
    SystemZ_LOCHHIAsmO	= 1544,
    SystemZ_LOCHHIAsmP	= 1545,
    SystemZ_LOCHHIAsmZ	= 1546,
    SystemZ_LOCHI	= 1547,
    SystemZ_LOCHIAsm	= 1548,
    SystemZ_LOCHIAsmE	= 1549,
    SystemZ_LOCHIAsmH	= 1550,
    SystemZ_LOCHIAsmHE	= 1551,
    SystemZ_LOCHIAsmL	= 1552,
    SystemZ_LOCHIAsmLE	= 1553,
    SystemZ_LOCHIAsmLH	= 1554,
    SystemZ_LOCHIAsmM	= 1555,
    SystemZ_LOCHIAsmNE	= 1556,
    SystemZ_LOCHIAsmNH	= 1557,
    SystemZ_LOCHIAsmNHE	= 1558,
    SystemZ_LOCHIAsmNL	= 1559,
    SystemZ_LOCHIAsmNLE	= 1560,
    SystemZ_LOCHIAsmNLH	= 1561,
    SystemZ_LOCHIAsmNM	= 1562,
    SystemZ_LOCHIAsmNO	= 1563,
    SystemZ_LOCHIAsmNP	= 1564,
    SystemZ_LOCHIAsmNZ	= 1565,
    SystemZ_LOCHIAsmO	= 1566,
    SystemZ_LOCHIAsmP	= 1567,
    SystemZ_LOCHIAsmZ	= 1568,
    SystemZ_LOCR	= 1569,
    SystemZ_LOCRAsm	= 1570,
    SystemZ_LOCRAsmE	= 1571,
    SystemZ_LOCRAsmH	= 1572,
    SystemZ_LOCRAsmHE	= 1573,
    SystemZ_LOCRAsmL	= 1574,
    SystemZ_LOCRAsmLE	= 1575,
    SystemZ_LOCRAsmLH	= 1576,
    SystemZ_LOCRAsmM	= 1577,
    SystemZ_LOCRAsmNE	= 1578,
    SystemZ_LOCRAsmNH	= 1579,
    SystemZ_LOCRAsmNHE	= 1580,
    SystemZ_LOCRAsmNL	= 1581,
    SystemZ_LOCRAsmNLE	= 1582,
    SystemZ_LOCRAsmNLH	= 1583,
    SystemZ_LOCRAsmNM	= 1584,
    SystemZ_LOCRAsmNO	= 1585,
    SystemZ_LOCRAsmNP	= 1586,
    SystemZ_LOCRAsmNZ	= 1587,
    SystemZ_LOCRAsmO	= 1588,
    SystemZ_LOCRAsmP	= 1589,
    SystemZ_LOCRAsmZ	= 1590,
    SystemZ_LPCTL	= 1591,
    SystemZ_LPD	= 1592,
    SystemZ_LPDBR	= 1593,
    SystemZ_LPDFR	= 1594,
    SystemZ_LPDFR_32	= 1595,
    SystemZ_LPDG	= 1596,
    SystemZ_LPDR	= 1597,
    SystemZ_LPEBR	= 1598,
    SystemZ_LPER	= 1599,
    SystemZ_LPGFR	= 1600,
    SystemZ_LPGR	= 1601,
    SystemZ_LPP	= 1602,
    SystemZ_LPQ	= 1603,
    SystemZ_LPR	= 1604,
    SystemZ_LPSW	= 1605,
    SystemZ_LPSWE	= 1606,
    SystemZ_LPTEA	= 1607,
    SystemZ_LPXBR	= 1608,
    SystemZ_LPXR	= 1609,
    SystemZ_LR	= 1610,
    SystemZ_LRA	= 1611,
    SystemZ_LRAG	= 1612,
    SystemZ_LRAY	= 1613,
    SystemZ_LRDR	= 1614,
    SystemZ_LRER	= 1615,
    SystemZ_LRL	= 1616,
    SystemZ_LRV	= 1617,
    SystemZ_LRVG	= 1618,
    SystemZ_LRVGR	= 1619,
    SystemZ_LRVH	= 1620,
    SystemZ_LRVR	= 1621,
    SystemZ_LSCTL	= 1622,
    SystemZ_LT	= 1623,
    SystemZ_LTDBR	= 1624,
    SystemZ_LTDBRCompare	= 1625,
    SystemZ_LTDR	= 1626,
    SystemZ_LTDTR	= 1627,
    SystemZ_LTEBR	= 1628,
    SystemZ_LTEBRCompare	= 1629,
    SystemZ_LTER	= 1630,
    SystemZ_LTG	= 1631,
    SystemZ_LTGF	= 1632,
    SystemZ_LTGFR	= 1633,
    SystemZ_LTGR	= 1634,
    SystemZ_LTR	= 1635,
    SystemZ_LTXBR	= 1636,
    SystemZ_LTXBRCompare	= 1637,
    SystemZ_LTXR	= 1638,
    SystemZ_LTXTR	= 1639,
    SystemZ_LURA	= 1640,
    SystemZ_LURAG	= 1641,
    SystemZ_LXD	= 1642,
    SystemZ_LXDB	= 1643,
    SystemZ_LXDBR	= 1644,
    SystemZ_LXDR	= 1645,
    SystemZ_LXDTR	= 1646,
    SystemZ_LXE	= 1647,
    SystemZ_LXEB	= 1648,
    SystemZ_LXEBR	= 1649,
    SystemZ_LXER	= 1650,
    SystemZ_LXR	= 1651,
    SystemZ_LY	= 1652,
    SystemZ_LZDR	= 1653,
    SystemZ_LZER	= 1654,
    SystemZ_LZRF	= 1655,
    SystemZ_LZRG	= 1656,
    SystemZ_LZXR	= 1657,
    SystemZ_M	= 1658,
    SystemZ_MAD	= 1659,
    SystemZ_MADB	= 1660,
    SystemZ_MADBR	= 1661,
    SystemZ_MADR	= 1662,
    SystemZ_MAE	= 1663,
    SystemZ_MAEB	= 1664,
    SystemZ_MAEBR	= 1665,
    SystemZ_MAER	= 1666,
    SystemZ_MAY	= 1667,
    SystemZ_MAYH	= 1668,
    SystemZ_MAYHR	= 1669,
    SystemZ_MAYL	= 1670,
    SystemZ_MAYLR	= 1671,
    SystemZ_MAYR	= 1672,
    SystemZ_MC	= 1673,
    SystemZ_MD	= 1674,
    SystemZ_MDB	= 1675,
    SystemZ_MDBR	= 1676,
    SystemZ_MDE	= 1677,
    SystemZ_MDEB	= 1678,
    SystemZ_MDEBR	= 1679,
    SystemZ_MDER	= 1680,
    SystemZ_MDR	= 1681,
    SystemZ_MDTR	= 1682,
    SystemZ_MDTRA	= 1683,
    SystemZ_ME	= 1684,
    SystemZ_MEE	= 1685,
    SystemZ_MEEB	= 1686,
    SystemZ_MEEBR	= 1687,
    SystemZ_MEER	= 1688,
    SystemZ_MER	= 1689,
    SystemZ_MFY	= 1690,
    SystemZ_MG	= 1691,
    SystemZ_MGH	= 1692,
    SystemZ_MGHI	= 1693,
    SystemZ_MGRK	= 1694,
    SystemZ_MH	= 1695,
    SystemZ_MHI	= 1696,
    SystemZ_MHY	= 1697,
    SystemZ_ML	= 1698,
    SystemZ_MLG	= 1699,
    SystemZ_MLGR	= 1700,
    SystemZ_MLR	= 1701,
    SystemZ_MP	= 1702,
    SystemZ_MR	= 1703,
    SystemZ_MS	= 1704,
    SystemZ_MSC	= 1705,
    SystemZ_MSCH	= 1706,
    SystemZ_MSD	= 1707,
    SystemZ_MSDB	= 1708,
    SystemZ_MSDBR	= 1709,
    SystemZ_MSDR	= 1710,
    SystemZ_MSE	= 1711,
    SystemZ_MSEB	= 1712,
    SystemZ_MSEBR	= 1713,
    SystemZ_MSER	= 1714,
    SystemZ_MSFI	= 1715,
    SystemZ_MSG	= 1716,
    SystemZ_MSGC	= 1717,
    SystemZ_MSGF	= 1718,
    SystemZ_MSGFI	= 1719,
    SystemZ_MSGFR	= 1720,
    SystemZ_MSGR	= 1721,
    SystemZ_MSGRKC	= 1722,
    SystemZ_MSR	= 1723,
    SystemZ_MSRKC	= 1724,
    SystemZ_MSTA	= 1725,
    SystemZ_MSY	= 1726,
    SystemZ_MVC	= 1727,
    SystemZ_MVCDK	= 1728,
    SystemZ_MVCIN	= 1729,
    SystemZ_MVCK	= 1730,
    SystemZ_MVCL	= 1731,
    SystemZ_MVCLE	= 1732,
    SystemZ_MVCLU	= 1733,
    SystemZ_MVCOS	= 1734,
    SystemZ_MVCP	= 1735,
    SystemZ_MVCS	= 1736,
    SystemZ_MVCSK	= 1737,
    SystemZ_MVGHI	= 1738,
    SystemZ_MVHHI	= 1739,
    SystemZ_MVHI	= 1740,
    SystemZ_MVI	= 1741,
    SystemZ_MVIY	= 1742,
    SystemZ_MVN	= 1743,
    SystemZ_MVO	= 1744,
    SystemZ_MVPG	= 1745,
    SystemZ_MVST	= 1746,
    SystemZ_MVZ	= 1747,
    SystemZ_MXBR	= 1748,
    SystemZ_MXD	= 1749,
    SystemZ_MXDB	= 1750,
    SystemZ_MXDBR	= 1751,
    SystemZ_MXDR	= 1752,
    SystemZ_MXR	= 1753,
    SystemZ_MXTR	= 1754,
    SystemZ_MXTRA	= 1755,
    SystemZ_MY	= 1756,
    SystemZ_MYH	= 1757,
    SystemZ_MYHR	= 1758,
    SystemZ_MYL	= 1759,
    SystemZ_MYLR	= 1760,
    SystemZ_MYR	= 1761,
    SystemZ_N	= 1762,
    SystemZ_NC	= 1763,
    SystemZ_NG	= 1764,
    SystemZ_NGR	= 1765,
    SystemZ_NGRK	= 1766,
    SystemZ_NI	= 1767,
    SystemZ_NIAI	= 1768,
    SystemZ_NIHF	= 1769,
    SystemZ_NIHH	= 1770,
    SystemZ_NIHL	= 1771,
    SystemZ_NILF	= 1772,
    SystemZ_NILH	= 1773,
    SystemZ_NILL	= 1774,
    SystemZ_NIY	= 1775,
    SystemZ_NR	= 1776,
    SystemZ_NRK	= 1777,
    SystemZ_NTSTG	= 1778,
    SystemZ_NY	= 1779,
    SystemZ_O	= 1780,
    SystemZ_OC	= 1781,
    SystemZ_OG	= 1782,
    SystemZ_OGR	= 1783,
    SystemZ_OGRK	= 1784,
    SystemZ_OI	= 1785,
    SystemZ_OIHF	= 1786,
    SystemZ_OIHH	= 1787,
    SystemZ_OIHL	= 1788,
    SystemZ_OILF	= 1789,
    SystemZ_OILH	= 1790,
    SystemZ_OILL	= 1791,
    SystemZ_OIY	= 1792,
    SystemZ_OR	= 1793,
    SystemZ_ORK	= 1794,
    SystemZ_OY	= 1795,
    SystemZ_PACK	= 1796,
    SystemZ_PALB	= 1797,
    SystemZ_PC	= 1798,
    SystemZ_PCC	= 1799,
    SystemZ_PCKMO	= 1800,
    SystemZ_PFD	= 1801,
    SystemZ_PFDRL	= 1802,
    SystemZ_PFMF	= 1803,
    SystemZ_PFPO	= 1804,
    SystemZ_PGIN	= 1805,
    SystemZ_PGOUT	= 1806,
    SystemZ_PKA	= 1807,
    SystemZ_PKU	= 1808,
    SystemZ_PLO	= 1809,
    SystemZ_POPCNT	= 1810,
    SystemZ_PPA	= 1811,
    SystemZ_PPNO	= 1812,
    SystemZ_PR	= 1813,
    SystemZ_PRNO	= 1814,
    SystemZ_PT	= 1815,
    SystemZ_PTF	= 1816,
    SystemZ_PTFF	= 1817,
    SystemZ_PTI	= 1818,
    SystemZ_PTLB	= 1819,
    SystemZ_QADTR	= 1820,
    SystemZ_QAXTR	= 1821,
    SystemZ_QCTRI	= 1822,
    SystemZ_QSI	= 1823,
    SystemZ_RCHP	= 1824,
    SystemZ_RISBG	= 1825,
    SystemZ_RISBG32	= 1826,
    SystemZ_RISBGN	= 1827,
    SystemZ_RISBHG	= 1828,
    SystemZ_RISBLG	= 1829,
    SystemZ_RLL	= 1830,
    SystemZ_RLLG	= 1831,
    SystemZ_RNSBG	= 1832,
    SystemZ_ROSBG	= 1833,
    SystemZ_RP	= 1834,
    SystemZ_RRBE	= 1835,
    SystemZ_RRBM	= 1836,
    SystemZ_RRDTR	= 1837,
    SystemZ_RRXTR	= 1838,
    SystemZ_RSCH	= 1839,
    SystemZ_RXSBG	= 1840,
    SystemZ_S	= 1841,
    SystemZ_SAC	= 1842,
    SystemZ_SACF	= 1843,
    SystemZ_SAL	= 1844,
    SystemZ_SAM24	= 1845,
    SystemZ_SAM31	= 1846,
    SystemZ_SAM64	= 1847,
    SystemZ_SAR	= 1848,
    SystemZ_SCCTR	= 1849,
    SystemZ_SCHM	= 1850,
    SystemZ_SCK	= 1851,
    SystemZ_SCKC	= 1852,
    SystemZ_SCKPF	= 1853,
    SystemZ_SD	= 1854,
    SystemZ_SDB	= 1855,
    SystemZ_SDBR	= 1856,
    SystemZ_SDR	= 1857,
    SystemZ_SDTR	= 1858,
    SystemZ_SDTRA	= 1859,
    SystemZ_SE	= 1860,
    SystemZ_SEB	= 1861,
    SystemZ_SEBR	= 1862,
    SystemZ_SER	= 1863,
    SystemZ_SFASR	= 1864,
    SystemZ_SFPC	= 1865,
    SystemZ_SG	= 1866,
    SystemZ_SGF	= 1867,
    SystemZ_SGFR	= 1868,
    SystemZ_SGH	= 1869,
    SystemZ_SGR	= 1870,
    SystemZ_SGRK	= 1871,
    SystemZ_SH	= 1872,
    SystemZ_SHHHR	= 1873,
    SystemZ_SHHLR	= 1874,
    SystemZ_SHY	= 1875,
    SystemZ_SIE	= 1876,
    SystemZ_SIGA	= 1877,
    SystemZ_SIGP	= 1878,
    SystemZ_SL	= 1879,
    SystemZ_SLA	= 1880,
    SystemZ_SLAG	= 1881,
    SystemZ_SLAK	= 1882,
    SystemZ_SLB	= 1883,
    SystemZ_SLBG	= 1884,
    SystemZ_SLBGR	= 1885,
    SystemZ_SLBR	= 1886,
    SystemZ_SLDA	= 1887,
    SystemZ_SLDL	= 1888,
    SystemZ_SLDT	= 1889,
    SystemZ_SLFI	= 1890,
    SystemZ_SLG	= 1891,
    SystemZ_SLGF	= 1892,
    SystemZ_SLGFI	= 1893,
    SystemZ_SLGFR	= 1894,
    SystemZ_SLGR	= 1895,
    SystemZ_SLGRK	= 1896,
    SystemZ_SLHHHR	= 1897,
    SystemZ_SLHHLR	= 1898,
    SystemZ_SLL	= 1899,
    SystemZ_SLLG	= 1900,
    SystemZ_SLLK	= 1901,
    SystemZ_SLR	= 1902,
    SystemZ_SLRK	= 1903,
    SystemZ_SLXT	= 1904,
    SystemZ_SLY	= 1905,
    SystemZ_SP	= 1906,
    SystemZ_SPCTR	= 1907,
    SystemZ_SPKA	= 1908,
    SystemZ_SPM	= 1909,
    SystemZ_SPT	= 1910,
    SystemZ_SPX	= 1911,
    SystemZ_SQD	= 1912,
    SystemZ_SQDB	= 1913,
    SystemZ_SQDBR	= 1914,
    SystemZ_SQDR	= 1915,
    SystemZ_SQE	= 1916,
    SystemZ_SQEB	= 1917,
    SystemZ_SQEBR	= 1918,
    SystemZ_SQER	= 1919,
    SystemZ_SQXBR	= 1920,
    SystemZ_SQXR	= 1921,
    SystemZ_SR	= 1922,
    SystemZ_SRA	= 1923,
    SystemZ_SRAG	= 1924,
    SystemZ_SRAK	= 1925,
    SystemZ_SRDA	= 1926,
    SystemZ_SRDL	= 1927,
    SystemZ_SRDT	= 1928,
    SystemZ_SRK	= 1929,
    SystemZ_SRL	= 1930,
    SystemZ_SRLG	= 1931,
    SystemZ_SRLK	= 1932,
    SystemZ_SRNM	= 1933,
    SystemZ_SRNMB	= 1934,
    SystemZ_SRNMT	= 1935,
    SystemZ_SRP	= 1936,
    SystemZ_SRST	= 1937,
    SystemZ_SRSTU	= 1938,
    SystemZ_SRXT	= 1939,
    SystemZ_SSAIR	= 1940,
    SystemZ_SSAR	= 1941,
    SystemZ_SSCH	= 1942,
    SystemZ_SSKE	= 1943,
    SystemZ_SSKEOpt	= 1944,
    SystemZ_SSM	= 1945,
    SystemZ_ST	= 1946,
    SystemZ_STAM	= 1947,
    SystemZ_STAMY	= 1948,
    SystemZ_STAP	= 1949,
    SystemZ_STC	= 1950,
    SystemZ_STCH	= 1951,
    SystemZ_STCK	= 1952,
    SystemZ_STCKC	= 1953,
    SystemZ_STCKE	= 1954,
    SystemZ_STCKF	= 1955,
    SystemZ_STCM	= 1956,
    SystemZ_STCMH	= 1957,
    SystemZ_STCMY	= 1958,
    SystemZ_STCPS	= 1959,
    SystemZ_STCRW	= 1960,
    SystemZ_STCTG	= 1961,
    SystemZ_STCTL	= 1962,
    SystemZ_STCY	= 1963,
    SystemZ_STD	= 1964,
    SystemZ_STDY	= 1965,
    SystemZ_STE	= 1966,
    SystemZ_STEY	= 1967,
    SystemZ_STFH	= 1968,
    SystemZ_STFL	= 1969,
    SystemZ_STFLE	= 1970,
    SystemZ_STFPC	= 1971,
    SystemZ_STG	= 1972,
    SystemZ_STGRL	= 1973,
    SystemZ_STGSC	= 1974,
    SystemZ_STH	= 1975,
    SystemZ_STHH	= 1976,
    SystemZ_STHRL	= 1977,
    SystemZ_STHY	= 1978,
    SystemZ_STIDP	= 1979,
    SystemZ_STM	= 1980,
    SystemZ_STMG	= 1981,
    SystemZ_STMH	= 1982,
    SystemZ_STMY	= 1983,
    SystemZ_STNSM	= 1984,
    SystemZ_STOC	= 1985,
    SystemZ_STOCAsm	= 1986,
    SystemZ_STOCAsmE	= 1987,
    SystemZ_STOCAsmH	= 1988,
    SystemZ_STOCAsmHE	= 1989,
    SystemZ_STOCAsmL	= 1990,
    SystemZ_STOCAsmLE	= 1991,
    SystemZ_STOCAsmLH	= 1992,
    SystemZ_STOCAsmM	= 1993,
    SystemZ_STOCAsmNE	= 1994,
    SystemZ_STOCAsmNH	= 1995,
    SystemZ_STOCAsmNHE	= 1996,
    SystemZ_STOCAsmNL	= 1997,
    SystemZ_STOCAsmNLE	= 1998,
    SystemZ_STOCAsmNLH	= 1999,
    SystemZ_STOCAsmNM	= 2000,
    SystemZ_STOCAsmNO	= 2001,
    SystemZ_STOCAsmNP	= 2002,
    SystemZ_STOCAsmNZ	= 2003,
    SystemZ_STOCAsmO	= 2004,
    SystemZ_STOCAsmP	= 2005,
    SystemZ_STOCAsmZ	= 2006,
    SystemZ_STOCFH	= 2007,
    SystemZ_STOCFHAsm	= 2008,
    SystemZ_STOCFHAsmE	= 2009,
    SystemZ_STOCFHAsmH	= 2010,
    SystemZ_STOCFHAsmHE	= 2011,
    SystemZ_STOCFHAsmL	= 2012,
    SystemZ_STOCFHAsmLE	= 2013,
    SystemZ_STOCFHAsmLH	= 2014,
    SystemZ_STOCFHAsmM	= 2015,
    SystemZ_STOCFHAsmNE	= 2016,
    SystemZ_STOCFHAsmNH	= 2017,
    SystemZ_STOCFHAsmNHE	= 2018,
    SystemZ_STOCFHAsmNL	= 2019,
    SystemZ_STOCFHAsmNLE	= 2020,
    SystemZ_STOCFHAsmNLH	= 2021,
    SystemZ_STOCFHAsmNM	= 2022,
    SystemZ_STOCFHAsmNO	= 2023,
    SystemZ_STOCFHAsmNP	= 2024,
    SystemZ_STOCFHAsmNZ	= 2025,
    SystemZ_STOCFHAsmO	= 2026,
    SystemZ_STOCFHAsmP	= 2027,
    SystemZ_STOCFHAsmZ	= 2028,
    SystemZ_STOCG	= 2029,
    SystemZ_STOCGAsm	= 2030,
    SystemZ_STOCGAsmE	= 2031,
    SystemZ_STOCGAsmH	= 2032,
    SystemZ_STOCGAsmHE	= 2033,
    SystemZ_STOCGAsmL	= 2034,
    SystemZ_STOCGAsmLE	= 2035,
    SystemZ_STOCGAsmLH	= 2036,
    SystemZ_STOCGAsmM	= 2037,
    SystemZ_STOCGAsmNE	= 2038,
    SystemZ_STOCGAsmNH	= 2039,
    SystemZ_STOCGAsmNHE	= 2040,
    SystemZ_STOCGAsmNL	= 2041,
    SystemZ_STOCGAsmNLE	= 2042,
    SystemZ_STOCGAsmNLH	= 2043,
    SystemZ_STOCGAsmNM	= 2044,
    SystemZ_STOCGAsmNO	= 2045,
    SystemZ_STOCGAsmNP	= 2046,
    SystemZ_STOCGAsmNZ	= 2047,
    SystemZ_STOCGAsmO	= 2048,
    SystemZ_STOCGAsmP	= 2049,
    SystemZ_STOCGAsmZ	= 2050,
    SystemZ_STOSM	= 2051,
    SystemZ_STPQ	= 2052,
    SystemZ_STPT	= 2053,
    SystemZ_STPX	= 2054,
    SystemZ_STRAG	= 2055,
    SystemZ_STRL	= 2056,
    SystemZ_STRV	= 2057,
    SystemZ_STRVG	= 2058,
    SystemZ_STRVH	= 2059,
    SystemZ_STSCH	= 2060,
    SystemZ_STSI	= 2061,
    SystemZ_STURA	= 2062,
    SystemZ_STURG	= 2063,
    SystemZ_STY	= 2064,
    SystemZ_SU	= 2065,
    SystemZ_SUR	= 2066,
    SystemZ_SVC	= 2067,
    SystemZ_SW	= 2068,
    SystemZ_SWR	= 2069,
    SystemZ_SXBR	= 2070,
    SystemZ_SXR	= 2071,
    SystemZ_SXTR	= 2072,
    SystemZ_SXTRA	= 2073,
    SystemZ_SY	= 2074,
    SystemZ_TABORT	= 2075,
    SystemZ_TAM	= 2076,
    SystemZ_TAR	= 2077,
    SystemZ_TB	= 2078,
    SystemZ_TBDR	= 2079,
    SystemZ_TBEDR	= 2080,
    SystemZ_TBEGIN	= 2081,
    SystemZ_TBEGINC	= 2082,
    SystemZ_TCDB	= 2083,
    SystemZ_TCEB	= 2084,
    SystemZ_TCXB	= 2085,
    SystemZ_TDCDT	= 2086,
    SystemZ_TDCET	= 2087,
    SystemZ_TDCXT	= 2088,
    SystemZ_TDGDT	= 2089,
    SystemZ_TDGET	= 2090,
    SystemZ_TDGXT	= 2091,
    SystemZ_TEND	= 2092,
    SystemZ_THDER	= 2093,
    SystemZ_THDR	= 2094,
    SystemZ_TM	= 2095,
    SystemZ_TMHH	= 2096,
    SystemZ_TMHL	= 2097,
    SystemZ_TMLH	= 2098,
    SystemZ_TMLL	= 2099,
    SystemZ_TMY	= 2100,
    SystemZ_TP	= 2101,
    SystemZ_TPI	= 2102,
    SystemZ_TPROT	= 2103,
    SystemZ_TR	= 2104,
    SystemZ_TRACE	= 2105,
    SystemZ_TRACG	= 2106,
    SystemZ_TRAP2	= 2107,
    SystemZ_TRAP4	= 2108,
    SystemZ_TRE	= 2109,
    SystemZ_TROO	= 2110,
    SystemZ_TROOOpt	= 2111,
    SystemZ_TROT	= 2112,
    SystemZ_TROTOpt	= 2113,
    SystemZ_TRT	= 2114,
    SystemZ_TRTE	= 2115,
    SystemZ_TRTEOpt	= 2116,
    SystemZ_TRTO	= 2117,
    SystemZ_TRTOOpt	= 2118,
    SystemZ_TRTR	= 2119,
    SystemZ_TRTRE	= 2120,
    SystemZ_TRTREOpt	= 2121,
    SystemZ_TRTT	= 2122,
    SystemZ_TRTTOpt	= 2123,
    SystemZ_TS	= 2124,
    SystemZ_TSCH	= 2125,
    SystemZ_UNPK	= 2126,
    SystemZ_UNPKA	= 2127,
    SystemZ_UNPKU	= 2128,
    SystemZ_UPT	= 2129,
    SystemZ_VA	= 2130,
    SystemZ_VAB	= 2131,
    SystemZ_VAC	= 2132,
    SystemZ_VACC	= 2133,
    SystemZ_VACCB	= 2134,
    SystemZ_VACCC	= 2135,
    SystemZ_VACCCQ	= 2136,
    SystemZ_VACCF	= 2137,
    SystemZ_VACCG	= 2138,
    SystemZ_VACCH	= 2139,
    SystemZ_VACCQ	= 2140,
    SystemZ_VACQ	= 2141,
    SystemZ_VAF	= 2142,
    SystemZ_VAG	= 2143,
    SystemZ_VAH	= 2144,
    SystemZ_VAP	= 2145,
    SystemZ_VAQ	= 2146,
    SystemZ_VAVG	= 2147,
    SystemZ_VAVGB	= 2148,
    SystemZ_VAVGF	= 2149,
    SystemZ_VAVGG	= 2150,
    SystemZ_VAVGH	= 2151,
    SystemZ_VAVGL	= 2152,
    SystemZ_VAVGLB	= 2153,
    SystemZ_VAVGLF	= 2154,
    SystemZ_VAVGLG	= 2155,
    SystemZ_VAVGLH	= 2156,
    SystemZ_VBPERM	= 2157,
    SystemZ_VCDG	= 2158,
    SystemZ_VCDGB	= 2159,
    SystemZ_VCDLG	= 2160,
    SystemZ_VCDLGB	= 2161,
    SystemZ_VCEQ	= 2162,
    SystemZ_VCEQB	= 2163,
    SystemZ_VCEQBS	= 2164,
    SystemZ_VCEQF	= 2165,
    SystemZ_VCEQFS	= 2166,
    SystemZ_VCEQG	= 2167,
    SystemZ_VCEQGS	= 2168,
    SystemZ_VCEQH	= 2169,
    SystemZ_VCEQHS	= 2170,
    SystemZ_VCGD	= 2171,
    SystemZ_VCGDB	= 2172,
    SystemZ_VCH	= 2173,
    SystemZ_VCHB	= 2174,
    SystemZ_VCHBS	= 2175,
    SystemZ_VCHF	= 2176,
    SystemZ_VCHFS	= 2177,
    SystemZ_VCHG	= 2178,
    SystemZ_VCHGS	= 2179,
    SystemZ_VCHH	= 2180,
    SystemZ_VCHHS	= 2181,
    SystemZ_VCHL	= 2182,
    SystemZ_VCHLB	= 2183,
    SystemZ_VCHLBS	= 2184,
    SystemZ_VCHLF	= 2185,
    SystemZ_VCHLFS	= 2186,
    SystemZ_VCHLG	= 2187,
    SystemZ_VCHLGS	= 2188,
    SystemZ_VCHLH	= 2189,
    SystemZ_VCHLHS	= 2190,
    SystemZ_VCKSM	= 2191,
    SystemZ_VCLGD	= 2192,
    SystemZ_VCLGDB	= 2193,
    SystemZ_VCLZ	= 2194,
    SystemZ_VCLZB	= 2195,
    SystemZ_VCLZF	= 2196,
    SystemZ_VCLZG	= 2197,
    SystemZ_VCLZH	= 2198,
    SystemZ_VCP	= 2199,
    SystemZ_VCTZ	= 2200,
    SystemZ_VCTZB	= 2201,
    SystemZ_VCTZF	= 2202,
    SystemZ_VCTZG	= 2203,
    SystemZ_VCTZH	= 2204,
    SystemZ_VCVB	= 2205,
    SystemZ_VCVBG	= 2206,
    SystemZ_VCVD	= 2207,
    SystemZ_VCVDG	= 2208,
    SystemZ_VDP	= 2209,
    SystemZ_VEC	= 2210,
    SystemZ_VECB	= 2211,
    SystemZ_VECF	= 2212,
    SystemZ_VECG	= 2213,
    SystemZ_VECH	= 2214,
    SystemZ_VECL	= 2215,
    SystemZ_VECLB	= 2216,
    SystemZ_VECLF	= 2217,
    SystemZ_VECLG	= 2218,
    SystemZ_VECLH	= 2219,
    SystemZ_VERIM	= 2220,
    SystemZ_VERIMB	= 2221,
    SystemZ_VERIMF	= 2222,
    SystemZ_VERIMG	= 2223,
    SystemZ_VERIMH	= 2224,
    SystemZ_VERLL	= 2225,
    SystemZ_VERLLB	= 2226,
    SystemZ_VERLLF	= 2227,
    SystemZ_VERLLG	= 2228,
    SystemZ_VERLLH	= 2229,
    SystemZ_VERLLV	= 2230,
    SystemZ_VERLLVB	= 2231,
    SystemZ_VERLLVF	= 2232,
    SystemZ_VERLLVG	= 2233,
    SystemZ_VERLLVH	= 2234,
    SystemZ_VESL	= 2235,
    SystemZ_VESLB	= 2236,
    SystemZ_VESLF	= 2237,
    SystemZ_VESLG	= 2238,
    SystemZ_VESLH	= 2239,
    SystemZ_VESLV	= 2240,
    SystemZ_VESLVB	= 2241,
    SystemZ_VESLVF	= 2242,
    SystemZ_VESLVG	= 2243,
    SystemZ_VESLVH	= 2244,
    SystemZ_VESRA	= 2245,
    SystemZ_VESRAB	= 2246,
    SystemZ_VESRAF	= 2247,
    SystemZ_VESRAG	= 2248,
    SystemZ_VESRAH	= 2249,
    SystemZ_VESRAV	= 2250,
    SystemZ_VESRAVB	= 2251,
    SystemZ_VESRAVF	= 2252,
    SystemZ_VESRAVG	= 2253,
    SystemZ_VESRAVH	= 2254,
    SystemZ_VESRL	= 2255,
    SystemZ_VESRLB	= 2256,
    SystemZ_VESRLF	= 2257,
    SystemZ_VESRLG	= 2258,
    SystemZ_VESRLH	= 2259,
    SystemZ_VESRLV	= 2260,
    SystemZ_VESRLVB	= 2261,
    SystemZ_VESRLVF	= 2262,
    SystemZ_VESRLVG	= 2263,
    SystemZ_VESRLVH	= 2264,
    SystemZ_VFA	= 2265,
    SystemZ_VFADB	= 2266,
    SystemZ_VFAE	= 2267,
    SystemZ_VFAEB	= 2268,
    SystemZ_VFAEBS	= 2269,
    SystemZ_VFAEF	= 2270,
    SystemZ_VFAEFS	= 2271,
    SystemZ_VFAEH	= 2272,
    SystemZ_VFAEHS	= 2273,
    SystemZ_VFAEZB	= 2274,
    SystemZ_VFAEZBS	= 2275,
    SystemZ_VFAEZF	= 2276,
    SystemZ_VFAEZFS	= 2277,
    SystemZ_VFAEZH	= 2278,
    SystemZ_VFAEZHS	= 2279,
    SystemZ_VFASB	= 2280,
    SystemZ_VFCE	= 2281,
    SystemZ_VFCEDB	= 2282,
    SystemZ_VFCEDBS	= 2283,
    SystemZ_VFCESB	= 2284,
    SystemZ_VFCESBS	= 2285,
    SystemZ_VFCH	= 2286,
    SystemZ_VFCHDB	= 2287,
    SystemZ_VFCHDBS	= 2288,
    SystemZ_VFCHE	= 2289,
    SystemZ_VFCHEDB	= 2290,
    SystemZ_VFCHEDBS	= 2291,
    SystemZ_VFCHESB	= 2292,
    SystemZ_VFCHESBS	= 2293,
    SystemZ_VFCHSB	= 2294,
    SystemZ_VFCHSBS	= 2295,
    SystemZ_VFD	= 2296,
    SystemZ_VFDDB	= 2297,
    SystemZ_VFDSB	= 2298,
    SystemZ_VFEE	= 2299,
    SystemZ_VFEEB	= 2300,
    SystemZ_VFEEBS	= 2301,
    SystemZ_VFEEF	= 2302,
    SystemZ_VFEEFS	= 2303,
    SystemZ_VFEEH	= 2304,
    SystemZ_VFEEHS	= 2305,
    SystemZ_VFEEZB	= 2306,
    SystemZ_VFEEZBS	= 2307,
    SystemZ_VFEEZF	= 2308,
    SystemZ_VFEEZFS	= 2309,
    SystemZ_VFEEZH	= 2310,
    SystemZ_VFEEZHS	= 2311,
    SystemZ_VFENE	= 2312,
    SystemZ_VFENEB	= 2313,
    SystemZ_VFENEBS	= 2314,
    SystemZ_VFENEF	= 2315,
    SystemZ_VFENEFS	= 2316,
    SystemZ_VFENEH	= 2317,
    SystemZ_VFENEHS	= 2318,
    SystemZ_VFENEZB	= 2319,
    SystemZ_VFENEZBS	= 2320,
    SystemZ_VFENEZF	= 2321,
    SystemZ_VFENEZFS	= 2322,
    SystemZ_VFENEZH	= 2323,
    SystemZ_VFENEZHS	= 2324,
    SystemZ_VFI	= 2325,
    SystemZ_VFIDB	= 2326,
    SystemZ_VFISB	= 2327,
    SystemZ_VFKEDB	= 2328,
    SystemZ_VFKEDBS	= 2329,
    SystemZ_VFKESB	= 2330,
    SystemZ_VFKESBS	= 2331,
    SystemZ_VFKHDB	= 2332,
    SystemZ_VFKHDBS	= 2333,
    SystemZ_VFKHEDB	= 2334,
    SystemZ_VFKHEDBS	= 2335,
    SystemZ_VFKHESB	= 2336,
    SystemZ_VFKHESBS	= 2337,
    SystemZ_VFKHSB	= 2338,
    SystemZ_VFKHSBS	= 2339,
    SystemZ_VFLCDB	= 2340,
    SystemZ_VFLCSB	= 2341,
    SystemZ_VFLL	= 2342,
    SystemZ_VFLLS	= 2343,
    SystemZ_VFLNDB	= 2344,
    SystemZ_VFLNSB	= 2345,
    SystemZ_VFLPDB	= 2346,
    SystemZ_VFLPSB	= 2347,
    SystemZ_VFLR	= 2348,
    SystemZ_VFLRD	= 2349,
    SystemZ_VFM	= 2350,
    SystemZ_VFMA	= 2351,
    SystemZ_VFMADB	= 2352,
    SystemZ_VFMASB	= 2353,
    SystemZ_VFMAX	= 2354,
    SystemZ_VFMAXDB	= 2355,
    SystemZ_VFMAXSB	= 2356,
    SystemZ_VFMDB	= 2357,
    SystemZ_VFMIN	= 2358,
    SystemZ_VFMINDB	= 2359,
    SystemZ_VFMINSB	= 2360,
    SystemZ_VFMS	= 2361,
    SystemZ_VFMSB	= 2362,
    SystemZ_VFMSDB	= 2363,
    SystemZ_VFMSSB	= 2364,
    SystemZ_VFNMA	= 2365,
    SystemZ_VFNMADB	= 2366,
    SystemZ_VFNMASB	= 2367,
    SystemZ_VFNMS	= 2368,
    SystemZ_VFNMSDB	= 2369,
    SystemZ_VFNMSSB	= 2370,
    SystemZ_VFPSO	= 2371,
    SystemZ_VFPSODB	= 2372,
    SystemZ_VFPSOSB	= 2373,
    SystemZ_VFS	= 2374,
    SystemZ_VFSDB	= 2375,
    SystemZ_VFSQ	= 2376,
    SystemZ_VFSQDB	= 2377,
    SystemZ_VFSQSB	= 2378,
    SystemZ_VFSSB	= 2379,
    SystemZ_VFTCI	= 2380,
    SystemZ_VFTCIDB	= 2381,
    SystemZ_VFTCISB	= 2382,
    SystemZ_VGBM	= 2383,
    SystemZ_VGEF	= 2384,
    SystemZ_VGEG	= 2385,
    SystemZ_VGFM	= 2386,
    SystemZ_VGFMA	= 2387,
    SystemZ_VGFMAB	= 2388,
    SystemZ_VGFMAF	= 2389,
    SystemZ_VGFMAG	= 2390,
    SystemZ_VGFMAH	= 2391,
    SystemZ_VGFMB	= 2392,
    SystemZ_VGFMF	= 2393,
    SystemZ_VGFMG	= 2394,
    SystemZ_VGFMH	= 2395,
    SystemZ_VGM	= 2396,
    SystemZ_VGMB	= 2397,
    SystemZ_VGMF	= 2398,
    SystemZ_VGMG	= 2399,
    SystemZ_VGMH	= 2400,
    SystemZ_VISTR	= 2401,
    SystemZ_VISTRB	= 2402,
    SystemZ_VISTRBS	= 2403,
    SystemZ_VISTRF	= 2404,
    SystemZ_VISTRFS	= 2405,
    SystemZ_VISTRH	= 2406,
    SystemZ_VISTRHS	= 2407,
    SystemZ_VL	= 2408,
    SystemZ_VLBB	= 2409,
    SystemZ_VLC	= 2410,
    SystemZ_VLCB	= 2411,
    SystemZ_VLCF	= 2412,
    SystemZ_VLCG	= 2413,
    SystemZ_VLCH	= 2414,
    SystemZ_VLDE	= 2415,
    SystemZ_VLDEB	= 2416,
    SystemZ_VLEB	= 2417,
    SystemZ_VLED	= 2418,
    SystemZ_VLEDB	= 2419,
    SystemZ_VLEF	= 2420,
    SystemZ_VLEG	= 2421,
    SystemZ_VLEH	= 2422,
    SystemZ_VLEIB	= 2423,
    SystemZ_VLEIF	= 2424,
    SystemZ_VLEIG	= 2425,
    SystemZ_VLEIH	= 2426,
    SystemZ_VLGV	= 2427,
    SystemZ_VLGVB	= 2428,
    SystemZ_VLGVF	= 2429,
    SystemZ_VLGVG	= 2430,
    SystemZ_VLGVH	= 2431,
    SystemZ_VLIP	= 2432,
    SystemZ_VLL	= 2433,
    SystemZ_VLLEZ	= 2434,
    SystemZ_VLLEZB	= 2435,
    SystemZ_VLLEZF	= 2436,
    SystemZ_VLLEZG	= 2437,
    SystemZ_VLLEZH	= 2438,
    SystemZ_VLLEZLF	= 2439,
    SystemZ_VLM	= 2440,
    SystemZ_VLP	= 2441,
    SystemZ_VLPB	= 2442,
    SystemZ_VLPF	= 2443,
    SystemZ_VLPG	= 2444,
    SystemZ_VLPH	= 2445,
    SystemZ_VLR	= 2446,
    SystemZ_VLREP	= 2447,
    SystemZ_VLREPB	= 2448,
    SystemZ_VLREPF	= 2449,
    SystemZ_VLREPG	= 2450,
    SystemZ_VLREPH	= 2451,
    SystemZ_VLRL	= 2452,
    SystemZ_VLRLR	= 2453,
    SystemZ_VLVG	= 2454,
    SystemZ_VLVGB	= 2455,
    SystemZ_VLVGF	= 2456,
    SystemZ_VLVGG	= 2457,
    SystemZ_VLVGH	= 2458,
    SystemZ_VLVGP	= 2459,
    SystemZ_VMAE	= 2460,
    SystemZ_VMAEB	= 2461,
    SystemZ_VMAEF	= 2462,
    SystemZ_VMAEH	= 2463,
    SystemZ_VMAH	= 2464,
    SystemZ_VMAHB	= 2465,
    SystemZ_VMAHF	= 2466,
    SystemZ_VMAHH	= 2467,
    SystemZ_VMAL	= 2468,
    SystemZ_VMALB	= 2469,
    SystemZ_VMALE	= 2470,
    SystemZ_VMALEB	= 2471,
    SystemZ_VMALEF	= 2472,
    SystemZ_VMALEH	= 2473,
    SystemZ_VMALF	= 2474,
    SystemZ_VMALH	= 2475,
    SystemZ_VMALHB	= 2476,
    SystemZ_VMALHF	= 2477,
    SystemZ_VMALHH	= 2478,
    SystemZ_VMALHW	= 2479,
    SystemZ_VMALO	= 2480,
    SystemZ_VMALOB	= 2481,
    SystemZ_VMALOF	= 2482,
    SystemZ_VMALOH	= 2483,
    SystemZ_VMAO	= 2484,
    SystemZ_VMAOB	= 2485,
    SystemZ_VMAOF	= 2486,
    SystemZ_VMAOH	= 2487,
    SystemZ_VME	= 2488,
    SystemZ_VMEB	= 2489,
    SystemZ_VMEF	= 2490,
    SystemZ_VMEH	= 2491,
    SystemZ_VMH	= 2492,
    SystemZ_VMHB	= 2493,
    SystemZ_VMHF	= 2494,
    SystemZ_VMHH	= 2495,
    SystemZ_VML	= 2496,
    SystemZ_VMLB	= 2497,
    SystemZ_VMLE	= 2498,
    SystemZ_VMLEB	= 2499,
    SystemZ_VMLEF	= 2500,
    SystemZ_VMLEH	= 2501,
    SystemZ_VMLF	= 2502,
    SystemZ_VMLH	= 2503,
    SystemZ_VMLHB	= 2504,
    SystemZ_VMLHF	= 2505,
    SystemZ_VMLHH	= 2506,
    SystemZ_VMLHW	= 2507,
    SystemZ_VMLO	= 2508,
    SystemZ_VMLOB	= 2509,
    SystemZ_VMLOF	= 2510,
    SystemZ_VMLOH	= 2511,
    SystemZ_VMN	= 2512,
    SystemZ_VMNB	= 2513,
    SystemZ_VMNF	= 2514,
    SystemZ_VMNG	= 2515,
    SystemZ_VMNH	= 2516,
    SystemZ_VMNL	= 2517,
    SystemZ_VMNLB	= 2518,
    SystemZ_VMNLF	= 2519,
    SystemZ_VMNLG	= 2520,
    SystemZ_VMNLH	= 2521,
    SystemZ_VMO	= 2522,
    SystemZ_VMOB	= 2523,
    SystemZ_VMOF	= 2524,
    SystemZ_VMOH	= 2525,
    SystemZ_VMP	= 2526,
    SystemZ_VMRH	= 2527,
    SystemZ_VMRHB	= 2528,
    SystemZ_VMRHF	= 2529,
    SystemZ_VMRHG	= 2530,
    SystemZ_VMRHH	= 2531,
    SystemZ_VMRL	= 2532,
    SystemZ_VMRLB	= 2533,
    SystemZ_VMRLF	= 2534,
    SystemZ_VMRLG	= 2535,
    SystemZ_VMRLH	= 2536,
    SystemZ_VMSL	= 2537,
    SystemZ_VMSLG	= 2538,
    SystemZ_VMSP	= 2539,
    SystemZ_VMX	= 2540,
    SystemZ_VMXB	= 2541,
    SystemZ_VMXF	= 2542,
    SystemZ_VMXG	= 2543,
    SystemZ_VMXH	= 2544,
    SystemZ_VMXL	= 2545,
    SystemZ_VMXLB	= 2546,
    SystemZ_VMXLF	= 2547,
    SystemZ_VMXLG	= 2548,
    SystemZ_VMXLH	= 2549,
    SystemZ_VN	= 2550,
    SystemZ_VNC	= 2551,
    SystemZ_VNN	= 2552,
    SystemZ_VNO	= 2553,
    SystemZ_VNX	= 2554,
    SystemZ_VO	= 2555,
    SystemZ_VOC	= 2556,
    SystemZ_VONE	= 2557,
    SystemZ_VPDI	= 2558,
    SystemZ_VPERM	= 2559,
    SystemZ_VPK	= 2560,
    SystemZ_VPKF	= 2561,
    SystemZ_VPKG	= 2562,
    SystemZ_VPKH	= 2563,
    SystemZ_VPKLS	= 2564,
    SystemZ_VPKLSF	= 2565,
    SystemZ_VPKLSFS	= 2566,
    SystemZ_VPKLSG	= 2567,
    SystemZ_VPKLSGS	= 2568,
    SystemZ_VPKLSH	= 2569,
    SystemZ_VPKLSHS	= 2570,
    SystemZ_VPKS	= 2571,
    SystemZ_VPKSF	= 2572,
    SystemZ_VPKSFS	= 2573,
    SystemZ_VPKSG	= 2574,
    SystemZ_VPKSGS	= 2575,
    SystemZ_VPKSH	= 2576,
    SystemZ_VPKSHS	= 2577,
    SystemZ_VPKZ	= 2578,
    SystemZ_VPOPCT	= 2579,
    SystemZ_VPOPCTB	= 2580,
    SystemZ_VPOPCTF	= 2581,
    SystemZ_VPOPCTG	= 2582,
    SystemZ_VPOPCTH	= 2583,
    SystemZ_VPSOP	= 2584,
    SystemZ_VREP	= 2585,
    SystemZ_VREPB	= 2586,
    SystemZ_VREPF	= 2587,
    SystemZ_VREPG	= 2588,
    SystemZ_VREPH	= 2589,
    SystemZ_VREPI	= 2590,
    SystemZ_VREPIB	= 2591,
    SystemZ_VREPIF	= 2592,
    SystemZ_VREPIG	= 2593,
    SystemZ_VREPIH	= 2594,
    SystemZ_VRP	= 2595,
    SystemZ_VS	= 2596,
    SystemZ_VSB	= 2597,
    SystemZ_VSBCBI	= 2598,
    SystemZ_VSBCBIQ	= 2599,
    SystemZ_VSBI	= 2600,
    SystemZ_VSBIQ	= 2601,
    SystemZ_VSCBI	= 2602,
    SystemZ_VSCBIB	= 2603,
    SystemZ_VSCBIF	= 2604,
    SystemZ_VSCBIG	= 2605,
    SystemZ_VSCBIH	= 2606,
    SystemZ_VSCBIQ	= 2607,
    SystemZ_VSCEF	= 2608,
    SystemZ_VSCEG	= 2609,
    SystemZ_VSDP	= 2610,
    SystemZ_VSEG	= 2611,
    SystemZ_VSEGB	= 2612,
    SystemZ_VSEGF	= 2613,
    SystemZ_VSEGH	= 2614,
    SystemZ_VSEL	= 2615,
    SystemZ_VSF	= 2616,
    SystemZ_VSG	= 2617,
    SystemZ_VSH	= 2618,
    SystemZ_VSL	= 2619,
    SystemZ_VSLB	= 2620,
    SystemZ_VSLDB	= 2621,
    SystemZ_VSP	= 2622,
    SystemZ_VSQ	= 2623,
    SystemZ_VSRA	= 2624,
    SystemZ_VSRAB	= 2625,
    SystemZ_VSRL	= 2626,
    SystemZ_VSRLB	= 2627,
    SystemZ_VSRP	= 2628,
    SystemZ_VST	= 2629,
    SystemZ_VSTEB	= 2630,
    SystemZ_VSTEF	= 2631,
    SystemZ_VSTEG	= 2632,
    SystemZ_VSTEH	= 2633,
    SystemZ_VSTL	= 2634,
    SystemZ_VSTM	= 2635,
    SystemZ_VSTRC	= 2636,
    SystemZ_VSTRCB	= 2637,
    SystemZ_VSTRCBS	= 2638,
    SystemZ_VSTRCF	= 2639,
    SystemZ_VSTRCFS	= 2640,
    SystemZ_VSTRCH	= 2641,
    SystemZ_VSTRCHS	= 2642,
    SystemZ_VSTRCZB	= 2643,
    SystemZ_VSTRCZBS	= 2644,
    SystemZ_VSTRCZF	= 2645,
    SystemZ_VSTRCZFS	= 2646,
    SystemZ_VSTRCZH	= 2647,
    SystemZ_VSTRCZHS	= 2648,
    SystemZ_VSTRL	= 2649,
    SystemZ_VSTRLR	= 2650,
    SystemZ_VSUM	= 2651,
    SystemZ_VSUMB	= 2652,
    SystemZ_VSUMG	= 2653,
    SystemZ_VSUMGF	= 2654,
    SystemZ_VSUMGH	= 2655,
    SystemZ_VSUMH	= 2656,
    SystemZ_VSUMQ	= 2657,
    SystemZ_VSUMQF	= 2658,
    SystemZ_VSUMQG	= 2659,
    SystemZ_VTM	= 2660,
    SystemZ_VTP	= 2661,
    SystemZ_VUPH	= 2662,
    SystemZ_VUPHB	= 2663,
    SystemZ_VUPHF	= 2664,
    SystemZ_VUPHH	= 2665,
    SystemZ_VUPKZ	= 2666,
    SystemZ_VUPL	= 2667,
    SystemZ_VUPLB	= 2668,
    SystemZ_VUPLF	= 2669,
    SystemZ_VUPLH	= 2670,
    SystemZ_VUPLHB	= 2671,
    SystemZ_VUPLHF	= 2672,
    SystemZ_VUPLHH	= 2673,
    SystemZ_VUPLHW	= 2674,
    SystemZ_VUPLL	= 2675,
    SystemZ_VUPLLB	= 2676,
    SystemZ_VUPLLF	= 2677,
    SystemZ_VUPLLH	= 2678,
    SystemZ_VX	= 2679,
    SystemZ_VZERO	= 2680,
    SystemZ_WCDGB	= 2681,
    SystemZ_WCDLGB	= 2682,
    SystemZ_WCGDB	= 2683,
    SystemZ_WCLGDB	= 2684,
    SystemZ_WFADB	= 2685,
    SystemZ_WFASB	= 2686,
    SystemZ_WFAXB	= 2687,
    SystemZ_WFC	= 2688,
    SystemZ_WFCDB	= 2689,
    SystemZ_WFCEDB	= 2690,
    SystemZ_WFCEDBS	= 2691,
    SystemZ_WFCESB	= 2692,
    SystemZ_WFCESBS	= 2693,
    SystemZ_WFCEXB	= 2694,
    SystemZ_WFCEXBS	= 2695,
    SystemZ_WFCHDB	= 2696,
    SystemZ_WFCHDBS	= 2697,
    SystemZ_WFCHEDB	= 2698,
    SystemZ_WFCHEDBS	= 2699,
    SystemZ_WFCHESB	= 2700,
    SystemZ_WFCHESBS	= 2701,
    SystemZ_WFCHEXB	= 2702,
    SystemZ_WFCHEXBS	= 2703,
    SystemZ_WFCHSB	= 2704,
    SystemZ_WFCHSBS	= 2705,
    SystemZ_WFCHXB	= 2706,
    SystemZ_WFCHXBS	= 2707,
    SystemZ_WFCSB	= 2708,
    SystemZ_WFCXB	= 2709,
    SystemZ_WFDDB	= 2710,
    SystemZ_WFDSB	= 2711,
    SystemZ_WFDXB	= 2712,
    SystemZ_WFIDB	= 2713,
    SystemZ_WFISB	= 2714,
    SystemZ_WFIXB	= 2715,
    SystemZ_WFK	= 2716,
    SystemZ_WFKDB	= 2717,
    SystemZ_WFKEDB	= 2718,
    SystemZ_WFKEDBS	= 2719,
    SystemZ_WFKESB	= 2720,
    SystemZ_WFKESBS	= 2721,
    SystemZ_WFKEXB	= 2722,
    SystemZ_WFKEXBS	= 2723,
    SystemZ_WFKHDB	= 2724,
    SystemZ_WFKHDBS	= 2725,
    SystemZ_WFKHEDB	= 2726,
    SystemZ_WFKHEDBS	= 2727,
    SystemZ_WFKHESB	= 2728,
    SystemZ_WFKHESBS	= 2729,
    SystemZ_WFKHEXB	= 2730,
    SystemZ_WFKHEXBS	= 2731,
    SystemZ_WFKHSB	= 2732,
    SystemZ_WFKHSBS	= 2733,
    SystemZ_WFKHXB	= 2734,
    SystemZ_WFKHXBS	= 2735,
    SystemZ_WFKSB	= 2736,
    SystemZ_WFKXB	= 2737,
    SystemZ_WFLCDB	= 2738,
    SystemZ_WFLCSB	= 2739,
    SystemZ_WFLCXB	= 2740,
    SystemZ_WFLLD	= 2741,
    SystemZ_WFLLS	= 2742,
    SystemZ_WFLNDB	= 2743,
    SystemZ_WFLNSB	= 2744,
    SystemZ_WFLNXB	= 2745,
    SystemZ_WFLPDB	= 2746,
    SystemZ_WFLPSB	= 2747,
    SystemZ_WFLPXB	= 2748,
    SystemZ_WFLRD	= 2749,
    SystemZ_WFLRX	= 2750,
    SystemZ_WFMADB	= 2751,
    SystemZ_WFMASB	= 2752,
    SystemZ_WFMAXB	= 2753,
    SystemZ_WFMAXDB	= 2754,
    SystemZ_WFMAXSB	= 2755,
    SystemZ_WFMAXXB	= 2756,
    SystemZ_WFMDB	= 2757,
    SystemZ_WFMINDB	= 2758,
    SystemZ_WFMINSB	= 2759,
    SystemZ_WFMINXB	= 2760,
    SystemZ_WFMSB	= 2761,
    SystemZ_WFMSDB	= 2762,
    SystemZ_WFMSSB	= 2763,
    SystemZ_WFMSXB	= 2764,
    SystemZ_WFMXB	= 2765,
    SystemZ_WFNMADB	= 2766,
    SystemZ_WFNMASB	= 2767,
    SystemZ_WFNMAXB	= 2768,
    SystemZ_WFNMSDB	= 2769,
    SystemZ_WFNMSSB	= 2770,
    SystemZ_WFNMSXB	= 2771,
    SystemZ_WFPSODB	= 2772,
    SystemZ_WFPSOSB	= 2773,
    SystemZ_WFPSOXB	= 2774,
    SystemZ_WFSDB	= 2775,
    SystemZ_WFSQDB	= 2776,
    SystemZ_WFSQSB	= 2777,
    SystemZ_WFSQXB	= 2778,
    SystemZ_WFSSB	= 2779,
    SystemZ_WFSXB	= 2780,
    SystemZ_WFTCIDB	= 2781,
    SystemZ_WFTCISB	= 2782,
    SystemZ_WFTCIXB	= 2783,
    SystemZ_WLDEB	= 2784,
    SystemZ_WLEDB	= 2785,
    SystemZ_X	= 2786,
    SystemZ_XC	= 2787,
    SystemZ_XG	= 2788,
    SystemZ_XGR	= 2789,
    SystemZ_XGRK	= 2790,
    SystemZ_XI	= 2791,
    SystemZ_XIHF	= 2792,
    SystemZ_XILF	= 2793,
    SystemZ_XIY	= 2794,
    SystemZ_XR	= 2795,
    SystemZ_XRK	= 2796,
    SystemZ_XSCH	= 2797,
    SystemZ_XY	= 2798,
    SystemZ_ZAP	= 2799,
    SystemZ_INSTRUCTION_LIST_END = 2800
  };

#endif // GET_INSTRINFO_ENUM
