// This is auto-gen data for Capstone engine (www.capstone-engine.org)
// By Nguyen Anh Quynh <aquynh@gmail.com>

{
	SystemZ_A, SYSZ_INS_A,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AD, SYSZ_INS_AD,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ADB, SYSZ_INS_ADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ADBR, SYSZ_INS_ADBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ADR, SYSZ_INS_ADR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ADTR, SYSZ_INS_ADTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ADTRA, SYSZ_INS_ADTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_AE, SYSZ_INS_AE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AEB, SYSZ_INS_AEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AEBR, SYSZ_INS_AEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AER, SYSZ_INS_AER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AFI, SYSZ_INS_AFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AG, SYSZ_INS_AG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGF, SYSZ_INS_AGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGFI, SYSZ_INS_AGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGFR, SYSZ_INS_AGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGH, SYSZ_INS_AGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_AGHI, SYSZ_INS_AGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGHIK, SYSZ_INS_AGHIK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_AGR, SYSZ_INS_AGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AGRK, SYSZ_INS_AGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_AGSI, SYSZ_INS_AGSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AH, SYSZ_INS_AH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AHHHR, SYSZ_INS_AHHHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_AHHLR, SYSZ_INS_AHHLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_AHI, SYSZ_INS_AHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AHIK, SYSZ_INS_AHIK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_AHY, SYSZ_INS_AHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AIH, SYSZ_INS_AIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_AL, SYSZ_INS_AL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALC, SYSZ_INS_ALC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALCG, SYSZ_INS_ALCG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALCGR, SYSZ_INS_ALCGR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALCR, SYSZ_INS_ALCR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALFI, SYSZ_INS_ALFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALG, SYSZ_INS_ALG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGF, SYSZ_INS_ALGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGFI, SYSZ_INS_ALGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGFR, SYSZ_INS_ALGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGHSIK, SYSZ_INS_ALGHSIK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ALGR, SYSZ_INS_ALGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALGRK, SYSZ_INS_ALGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ALGSI, SYSZ_INS_ALGSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALHHHR, SYSZ_INS_ALHHHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_ALHHLR, SYSZ_INS_ALHHLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_ALHSIK, SYSZ_INS_ALHSIK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ALR, SYSZ_INS_ALR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALRK, SYSZ_INS_ALRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ALSI, SYSZ_INS_ALSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ALSIH, SYSZ_INS_ALSIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_ALSIHN, SYSZ_INS_ALSIHN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_ALY, SYSZ_INS_ALY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AP, SYSZ_INS_AP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AR, SYSZ_INS_AR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ARK, SYSZ_INS_ARK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_ASI, SYSZ_INS_ASI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AU, SYSZ_INS_AU,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AUR, SYSZ_INS_AUR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AW, SYSZ_INS_AW,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AWR, SYSZ_INS_AWR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AXBR, SYSZ_INS_AXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AXR, SYSZ_INS_AXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AXTR, SYSZ_INS_AXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_AXTRA, SYSZ_INS_AXTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_AY, SYSZ_INS_AY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_B, SYSZ_INS_B,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAKR, SYSZ_INS_BAKR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BAL, SYSZ_INS_BAL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BALR, SYSZ_INS_BALR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BAS, SYSZ_INS_BAS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BASR, SYSZ_INS_BASR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BASSM, SYSZ_INS_BASSM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BAsmE, SYSZ_INS_BE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmH, SYSZ_INS_BH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmHE, SYSZ_INS_BHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmL, SYSZ_INS_BL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmLE, SYSZ_INS_BLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmLH, SYSZ_INS_BLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmM, SYSZ_INS_BM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNE, SYSZ_INS_BNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNH, SYSZ_INS_BNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNHE, SYSZ_INS_BNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNL, SYSZ_INS_BNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNLE, SYSZ_INS_BNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNLH, SYSZ_INS_BNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNM, SYSZ_INS_BNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNO, SYSZ_INS_BNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNP, SYSZ_INS_BNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmNZ, SYSZ_INS_BNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmO, SYSZ_INS_BO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmP, SYSZ_INS_BP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BAsmZ, SYSZ_INS_BZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BCAsm, SYSZ_INS_BC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BCRAsm, SYSZ_INS_BCR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BCT, SYSZ_INS_BCT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BCTG, SYSZ_INS_BCTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BCTGR, SYSZ_INS_BCTGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BCTR, SYSZ_INS_BCTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BI, SYSZ_INS_BI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmE, SYSZ_INS_BIE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmH, SYSZ_INS_BIH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmHE, SYSZ_INS_BIHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmL, SYSZ_INS_BIL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmLE, SYSZ_INS_BILE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmLH, SYSZ_INS_BILH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmM, SYSZ_INS_BIM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNE, SYSZ_INS_BINE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNH, SYSZ_INS_BINH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNHE, SYSZ_INS_BINHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNL, SYSZ_INS_BINL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNLE, SYSZ_INS_BINLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNLH, SYSZ_INS_BINLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNM, SYSZ_INS_BINM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNO, SYSZ_INS_BINO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNP, SYSZ_INS_BINP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmNZ, SYSZ_INS_BINZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmO, SYSZ_INS_BIO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmP, SYSZ_INS_BIP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BIAsmZ, SYSZ_INS_BIZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BICAsm, SYSZ_INS_BIC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 1, 1
#endif
},
{
	SystemZ_BPP, SYSZ_INS_BPP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_EXECUTIONHINT, 0 }, 0, 0
#endif
},
{
	SystemZ_BPRP, SYSZ_INS_BPRP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_EXECUTIONHINT, 0 }, 0, 0
#endif
},
{
	SystemZ_BR, SYSZ_INS_BR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAS, SYSZ_INS_BRAS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BRASL, SYSZ_INS_BRASL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BRAsmE, SYSZ_INS_BER,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmH, SYSZ_INS_BHR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmHE, SYSZ_INS_BHER,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmL, SYSZ_INS_BLR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmLE, SYSZ_INS_BLER,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmLH, SYSZ_INS_BLHR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmM, SYSZ_INS_BMR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNE, SYSZ_INS_BNER,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNH, SYSZ_INS_BNHR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNHE, SYSZ_INS_BNHER,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNL, SYSZ_INS_BNLR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNLE, SYSZ_INS_BNLER,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNLH, SYSZ_INS_BNLHR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNM, SYSZ_INS_BNMR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNO, SYSZ_INS_BNOR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNP, SYSZ_INS_BNPR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmNZ, SYSZ_INS_BNZR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmO, SYSZ_INS_BOR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmP, SYSZ_INS_BPR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRAsmZ, SYSZ_INS_BZR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_BRCAsm, SYSZ_INS_BRC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRCLAsm, SYSZ_INS_BRCL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRCT, SYSZ_INS_BRCT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRCTG, SYSZ_INS_BRCTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRCTH, SYSZ_INS_BRCTH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 1, 0
#endif
},
{
	SystemZ_BRXH, SYSZ_INS_BRXH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRXHG, SYSZ_INS_BRXHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRXLE, SYSZ_INS_BRXLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BRXLG, SYSZ_INS_BRXLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BSA, SYSZ_INS_BSA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BSG, SYSZ_INS_BSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_BSM, SYSZ_INS_BSM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BXH, SYSZ_INS_BXH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BXHG, SYSZ_INS_BXHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BXLE, SYSZ_INS_BXLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_BXLEG, SYSZ_INS_BXLEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_C, SYSZ_INS_C,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CD, SYSZ_INS_CD,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDB, SYSZ_INS_CDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDBR, SYSZ_INS_CDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDFBR, SYSZ_INS_CDFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDFBRA, SYSZ_INS_CDFBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDFR, SYSZ_INS_CDFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDFTR, SYSZ_INS_CDFTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDGBR, SYSZ_INS_CDGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDGBRA, SYSZ_INS_CDGBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDGR, SYSZ_INS_CDGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDGTR, SYSZ_INS_CDGTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDGTRA, SYSZ_INS_CDGTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDLFBR, SYSZ_INS_CDLFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDLFTR, SYSZ_INS_CDLFTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDLGBR, SYSZ_INS_CDLGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDLGTR, SYSZ_INS_CDLGTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDPT, SYSZ_INS_CDPT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DFPPACKEDCONVERSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CDR, SYSZ_INS_CDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDS, SYSZ_INS_CDS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDSG, SYSZ_INS_CDSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDSTR, SYSZ_INS_CDSTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDSY, SYSZ_INS_CDSY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDTR, SYSZ_INS_CDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDUTR, SYSZ_INS_CDUTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CDZT, SYSZ_INS_CDZT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DFPZONEDCONVERSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CE, SYSZ_INS_CE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEB, SYSZ_INS_CEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEBR, SYSZ_INS_CEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEDTR, SYSZ_INS_CEDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEFBR, SYSZ_INS_CEFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEFBRA, SYSZ_INS_CEFBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CEFR, SYSZ_INS_CEFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEGBR, SYSZ_INS_CEGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEGBRA, SYSZ_INS_CEGBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CEGR, SYSZ_INS_CEGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CELFBR, SYSZ_INS_CELFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CELGBR, SYSZ_INS_CELGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CER, SYSZ_INS_CER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CEXTR, SYSZ_INS_CEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFC, SYSZ_INS_CFC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, SYSZ_REG_2, SYSZ_REG_3, 0 }, { SYSZ_REG_CC, SYSZ_REG_1, SYSZ_REG_2, SYSZ_REG_3, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFDBR, SYSZ_INS_CFDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFDBRA, SYSZ_INS_CFDBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CFDR, SYSZ_INS_CFDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFDTR, SYSZ_INS_CFDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CFEBR, SYSZ_INS_CFEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFEBRA, SYSZ_INS_CFEBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CFER, SYSZ_INS_CFER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFI, SYSZ_INS_CFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFXBR, SYSZ_INS_CFXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFXBRA, SYSZ_INS_CFXBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CFXR, SYSZ_INS_CFXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CFXTR, SYSZ_INS_CFXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CG, SYSZ_INS_CG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGDBR, SYSZ_INS_CGDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGDBRA, SYSZ_INS_CGDBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CGDR, SYSZ_INS_CGDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGDTR, SYSZ_INS_CGDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGDTRA, SYSZ_INS_CGDTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CGEBR, SYSZ_INS_CGEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGEBRA, SYSZ_INS_CGEBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CGER, SYSZ_INS_CGER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGF, SYSZ_INS_CGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGFI, SYSZ_INS_CGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGFR, SYSZ_INS_CGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGFRL, SYSZ_INS_CGFRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGH, SYSZ_INS_CGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGHI, SYSZ_INS_CGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGHRL, SYSZ_INS_CGHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGHSI, SYSZ_INS_CGHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGIBAsm, SYSZ_INS_CGIB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmE, SYSZ_INS_CGIBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmH, SYSZ_INS_CGIBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmHE, SYSZ_INS_CGIBHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmL, SYSZ_INS_CGIBL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmLE, SYSZ_INS_CGIBLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmLH, SYSZ_INS_CGIBLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmNE, SYSZ_INS_CGIBNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmNH, SYSZ_INS_CGIBNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmNHE, SYSZ_INS_CGIBNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmNL, SYSZ_INS_CGIBNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmNLE, SYSZ_INS_CGIBNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIBAsmNLH, SYSZ_INS_CGIBNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGIJAsm, SYSZ_INS_CGIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmE, SYSZ_INS_CGIJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmH, SYSZ_INS_CGIJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmHE, SYSZ_INS_CGIJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmL, SYSZ_INS_CGIJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmLE, SYSZ_INS_CGIJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmLH, SYSZ_INS_CGIJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmNE, SYSZ_INS_CGIJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmNH, SYSZ_INS_CGIJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmNHE, SYSZ_INS_CGIJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmNL, SYSZ_INS_CGIJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmNLE, SYSZ_INS_CGIJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGIJAsmNLH, SYSZ_INS_CGIJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGITAsm, SYSZ_INS_CGIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmE, SYSZ_INS_CGITE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmH, SYSZ_INS_CGITH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmHE, SYSZ_INS_CGITHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmL, SYSZ_INS_CGITL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmLE, SYSZ_INS_CGITLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmLH, SYSZ_INS_CGITLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmNE, SYSZ_INS_CGITNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmNH, SYSZ_INS_CGITNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmNHE, SYSZ_INS_CGITNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmNL, SYSZ_INS_CGITNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmNLE, SYSZ_INS_CGITNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGITAsmNLH, SYSZ_INS_CGITNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGR, SYSZ_INS_CGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRBAsm, SYSZ_INS_CGRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmE, SYSZ_INS_CGRBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmH, SYSZ_INS_CGRBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmHE, SYSZ_INS_CGRBHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmL, SYSZ_INS_CGRBL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmLE, SYSZ_INS_CGRBLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmLH, SYSZ_INS_CGRBLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmNE, SYSZ_INS_CGRBNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmNH, SYSZ_INS_CGRBNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmNHE, SYSZ_INS_CGRBNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmNL, SYSZ_INS_CGRBNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmNLE, SYSZ_INS_CGRBNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRBAsmNLH, SYSZ_INS_CGRBNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CGRJAsm, SYSZ_INS_CGRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmE, SYSZ_INS_CGRJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmH, SYSZ_INS_CGRJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmHE, SYSZ_INS_CGRJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmL, SYSZ_INS_CGRJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmLE, SYSZ_INS_CGRJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmLH, SYSZ_INS_CGRJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmNE, SYSZ_INS_CGRJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmNH, SYSZ_INS_CGRJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmNHE, SYSZ_INS_CGRJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmNL, SYSZ_INS_CGRJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmNLE, SYSZ_INS_CGRJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRJAsmNLH, SYSZ_INS_CGRJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CGRL, SYSZ_INS_CGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsm, SYSZ_INS_CGRT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmE, SYSZ_INS_CGRTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmH, SYSZ_INS_CGRTH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmHE, SYSZ_INS_CGRTHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmL, SYSZ_INS_CGRTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmLE, SYSZ_INS_CGRTLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmLH, SYSZ_INS_CGRTLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmNE, SYSZ_INS_CGRTNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmNH, SYSZ_INS_CGRTNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmNHE, SYSZ_INS_CGRTNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmNL, SYSZ_INS_CGRTNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmNLE, SYSZ_INS_CGRTNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGRTAsmNLH, SYSZ_INS_CGRTNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGXBR, SYSZ_INS_CGXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGXBRA, SYSZ_INS_CGXBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CGXR, SYSZ_INS_CGXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGXTR, SYSZ_INS_CGXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CGXTRA, SYSZ_INS_CGXTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CH, SYSZ_INS_CH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHF, SYSZ_INS_CHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CHHR, SYSZ_INS_CHHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CHHSI, SYSZ_INS_CHHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHI, SYSZ_INS_CHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHLR, SYSZ_INS_CHLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CHRL, SYSZ_INS_CHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHSI, SYSZ_INS_CHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CHY, SYSZ_INS_CHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CIBAsm, SYSZ_INS_CIB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmE, SYSZ_INS_CIBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmH, SYSZ_INS_CIBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmHE, SYSZ_INS_CIBHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmL, SYSZ_INS_CIBL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmLE, SYSZ_INS_CIBLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmLH, SYSZ_INS_CIBLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmNE, SYSZ_INS_CIBNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmNH, SYSZ_INS_CIBNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmNHE, SYSZ_INS_CIBNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmNL, SYSZ_INS_CIBNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmNLE, SYSZ_INS_CIBNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIBAsmNLH, SYSZ_INS_CIBNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CIH, SYSZ_INS_CIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CIJAsm, SYSZ_INS_CIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmE, SYSZ_INS_CIJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmH, SYSZ_INS_CIJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmHE, SYSZ_INS_CIJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmL, SYSZ_INS_CIJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmLE, SYSZ_INS_CIJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmLH, SYSZ_INS_CIJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmNE, SYSZ_INS_CIJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmNH, SYSZ_INS_CIJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmNHE, SYSZ_INS_CIJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmNL, SYSZ_INS_CIJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmNLE, SYSZ_INS_CIJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CIJAsmNLH, SYSZ_INS_CIJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CITAsm, SYSZ_INS_CIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmE, SYSZ_INS_CITE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmH, SYSZ_INS_CITH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmHE, SYSZ_INS_CITHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmL, SYSZ_INS_CITL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmLE, SYSZ_INS_CITLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmLH, SYSZ_INS_CITLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmNE, SYSZ_INS_CITNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmNH, SYSZ_INS_CITNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmNHE, SYSZ_INS_CITNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmNL, SYSZ_INS_CITNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmNLE, SYSZ_INS_CITNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CITAsmNLH, SYSZ_INS_CITNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CKSM, SYSZ_INS_CKSM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CL, SYSZ_INS_CL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLC, SYSZ_INS_CLC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLCL, SYSZ_INS_CLCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLCLE, SYSZ_INS_CLCLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLCLU, SYSZ_INS_CLCLU,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFDBR, SYSZ_INS_CLFDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLFDTR, SYSZ_INS_CLFDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLFEBR, SYSZ_INS_CLFEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLFHSI, SYSZ_INS_CLFHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFI, SYSZ_INS_CLFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsm, SYSZ_INS_CLFIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmE, SYSZ_INS_CLFITE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmH, SYSZ_INS_CLFITH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmHE, SYSZ_INS_CLFITHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmL, SYSZ_INS_CLFITL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmLE, SYSZ_INS_CLFITLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmLH, SYSZ_INS_CLFITLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmNE, SYSZ_INS_CLFITNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmNH, SYSZ_INS_CLFITNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmNHE, SYSZ_INS_CLFITNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmNL, SYSZ_INS_CLFITNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmNLE, SYSZ_INS_CLFITNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFITAsmNLH, SYSZ_INS_CLFITNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLFXBR, SYSZ_INS_CLFXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLFXTR, SYSZ_INS_CLFXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLG, SYSZ_INS_CLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGDBR, SYSZ_INS_CLGDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGDTR, SYSZ_INS_CLGDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGEBR, SYSZ_INS_CLGEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGF, SYSZ_INS_CLGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGFI, SYSZ_INS_CLGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGFR, SYSZ_INS_CLGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGFRL, SYSZ_INS_CLGFRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGHRL, SYSZ_INS_CLGHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGHSI, SYSZ_INS_CLGHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGIBAsm, SYSZ_INS_CLGIB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmE, SYSZ_INS_CLGIBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmH, SYSZ_INS_CLGIBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmHE, SYSZ_INS_CLGIBHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmL, SYSZ_INS_CLGIBL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmLE, SYSZ_INS_CLGIBLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmLH, SYSZ_INS_CLGIBLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmNE, SYSZ_INS_CLGIBNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmNH, SYSZ_INS_CLGIBNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmNHE, SYSZ_INS_CLGIBNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmNL, SYSZ_INS_CLGIBNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmNLE, SYSZ_INS_CLGIBNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIBAsmNLH, SYSZ_INS_CLGIBNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGIJAsm, SYSZ_INS_CLGIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmE, SYSZ_INS_CLGIJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmH, SYSZ_INS_CLGIJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmHE, SYSZ_INS_CLGIJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmL, SYSZ_INS_CLGIJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmLE, SYSZ_INS_CLGIJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmLH, SYSZ_INS_CLGIJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmNE, SYSZ_INS_CLGIJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmNH, SYSZ_INS_CLGIJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmNHE, SYSZ_INS_CLGIJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmNL, SYSZ_INS_CLGIJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmNLE, SYSZ_INS_CLGIJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGIJAsmNLH, SYSZ_INS_CLGIJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGITAsm, SYSZ_INS_CLGIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmE, SYSZ_INS_CLGITE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmH, SYSZ_INS_CLGITH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmHE, SYSZ_INS_CLGITHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmL, SYSZ_INS_CLGITL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmLE, SYSZ_INS_CLGITLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmLH, SYSZ_INS_CLGITLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmNE, SYSZ_INS_CLGITNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmNH, SYSZ_INS_CLGITNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmNHE, SYSZ_INS_CLGITNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmNL, SYSZ_INS_CLGITNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmNLE, SYSZ_INS_CLGITNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGITAsmNLH, SYSZ_INS_CLGITNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGR, SYSZ_INS_CLGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRBAsm, SYSZ_INS_CLGRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmE, SYSZ_INS_CLGRBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmH, SYSZ_INS_CLGRBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmHE, SYSZ_INS_CLGRBHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmL, SYSZ_INS_CLGRBL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmLE, SYSZ_INS_CLGRBLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmLH, SYSZ_INS_CLGRBLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmNE, SYSZ_INS_CLGRBNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmNH, SYSZ_INS_CLGRBNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmNHE, SYSZ_INS_CLGRBNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmNL, SYSZ_INS_CLGRBNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmNLE, SYSZ_INS_CLGRBNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRBAsmNLH, SYSZ_INS_CLGRBNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLGRJAsm, SYSZ_INS_CLGRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmE, SYSZ_INS_CLGRJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmH, SYSZ_INS_CLGRJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmHE, SYSZ_INS_CLGRJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmL, SYSZ_INS_CLGRJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmLE, SYSZ_INS_CLGRJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmLH, SYSZ_INS_CLGRJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmNE, SYSZ_INS_CLGRJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmNH, SYSZ_INS_CLGRJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmNHE, SYSZ_INS_CLGRJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmNL, SYSZ_INS_CLGRJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmNLE, SYSZ_INS_CLGRJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRJAsmNLH, SYSZ_INS_CLGRJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLGRL, SYSZ_INS_CLGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsm, SYSZ_INS_CLGRT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmE, SYSZ_INS_CLGRTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmH, SYSZ_INS_CLGRTH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmHE, SYSZ_INS_CLGRTHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmL, SYSZ_INS_CLGRTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmLE, SYSZ_INS_CLGRTLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmLH, SYSZ_INS_CLGRTLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmNE, SYSZ_INS_CLGRTNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmNH, SYSZ_INS_CLGRTNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmNHE, SYSZ_INS_CLGRTNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmNL, SYSZ_INS_CLGRTNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmNLE, SYSZ_INS_CLGRTNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGRTAsmNLH, SYSZ_INS_CLGRTNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsm, SYSZ_INS_CLGT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmE, SYSZ_INS_CLGTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmH, SYSZ_INS_CLGTH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmHE, SYSZ_INS_CLGTHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmL, SYSZ_INS_CLGTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmLE, SYSZ_INS_CLGTLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmLH, SYSZ_INS_CLGTLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmNE, SYSZ_INS_CLGTNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmNH, SYSZ_INS_CLGTNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmNHE, SYSZ_INS_CLGTNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmNL, SYSZ_INS_CLGTNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmNLE, SYSZ_INS_CLGTNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGTAsmNLH, SYSZ_INS_CLGTNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGXBR, SYSZ_INS_CLGXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLGXTR, SYSZ_INS_CLGXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CLHF, SYSZ_INS_CLHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CLHHR, SYSZ_INS_CLHHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CLHHSI, SYSZ_INS_CLHHSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLHLR, SYSZ_INS_CLHLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CLHRL, SYSZ_INS_CLHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLI, SYSZ_INS_CLI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLIBAsm, SYSZ_INS_CLIB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmE, SYSZ_INS_CLIBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmH, SYSZ_INS_CLIBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmHE, SYSZ_INS_CLIBHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmL, SYSZ_INS_CLIBL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmLE, SYSZ_INS_CLIBLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmLH, SYSZ_INS_CLIBLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmNE, SYSZ_INS_CLIBNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmNH, SYSZ_INS_CLIBNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmNHE, SYSZ_INS_CLIBNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmNL, SYSZ_INS_CLIBNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmNLE, SYSZ_INS_CLIBNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIBAsmNLH, SYSZ_INS_CLIBNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLIH, SYSZ_INS_CLIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_CLIJAsm, SYSZ_INS_CLIJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmE, SYSZ_INS_CLIJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmH, SYSZ_INS_CLIJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmHE, SYSZ_INS_CLIJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmL, SYSZ_INS_CLIJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmLE, SYSZ_INS_CLIJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmLH, SYSZ_INS_CLIJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmNE, SYSZ_INS_CLIJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmNH, SYSZ_INS_CLIJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmNHE, SYSZ_INS_CLIJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmNL, SYSZ_INS_CLIJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmNLE, SYSZ_INS_CLIJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIJAsmNLH, SYSZ_INS_CLIJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLIY, SYSZ_INS_CLIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLM, SYSZ_INS_CLM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLMH, SYSZ_INS_CLMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLMY, SYSZ_INS_CLMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLR, SYSZ_INS_CLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRBAsm, SYSZ_INS_CLRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmE, SYSZ_INS_CLRBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmH, SYSZ_INS_CLRBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmHE, SYSZ_INS_CLRBHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmL, SYSZ_INS_CLRBL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmLE, SYSZ_INS_CLRBLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmLH, SYSZ_INS_CLRBLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmNE, SYSZ_INS_CLRBNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmNH, SYSZ_INS_CLRBNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmNHE, SYSZ_INS_CLRBNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmNL, SYSZ_INS_CLRBNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmNLE, SYSZ_INS_CLRBNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRBAsmNLH, SYSZ_INS_CLRBNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CLRJAsm, SYSZ_INS_CLRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmE, SYSZ_INS_CLRJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmH, SYSZ_INS_CLRJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmHE, SYSZ_INS_CLRJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmL, SYSZ_INS_CLRJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmLE, SYSZ_INS_CLRJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmLH, SYSZ_INS_CLRJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmNE, SYSZ_INS_CLRJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmNH, SYSZ_INS_CLRJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmNHE, SYSZ_INS_CLRJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmNL, SYSZ_INS_CLRJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmNLE, SYSZ_INS_CLRJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRJAsmNLH, SYSZ_INS_CLRJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CLRL, SYSZ_INS_CLRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsm, SYSZ_INS_CLRT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmE, SYSZ_INS_CLRTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmH, SYSZ_INS_CLRTH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmHE, SYSZ_INS_CLRTHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmL, SYSZ_INS_CLRTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmLE, SYSZ_INS_CLRTLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmLH, SYSZ_INS_CLRTLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmNE, SYSZ_INS_CLRTNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmNH, SYSZ_INS_CLRTNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmNHE, SYSZ_INS_CLRTNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmNL, SYSZ_INS_CLRTNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmNLE, SYSZ_INS_CLRTNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLRTAsmNLH, SYSZ_INS_CLRTNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLST, SYSZ_INS_CLST,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsm, SYSZ_INS_CLT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmE, SYSZ_INS_CLTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmH, SYSZ_INS_CLTH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmHE, SYSZ_INS_CLTHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmL, SYSZ_INS_CLTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmLE, SYSZ_INS_CLTLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmLH, SYSZ_INS_CLTLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmNE, SYSZ_INS_CLTNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmNH, SYSZ_INS_CLTNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmNHE, SYSZ_INS_CLTNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmNL, SYSZ_INS_CLTNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmNLE, SYSZ_INS_CLTNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLTAsmNLH, SYSZ_INS_CLTNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_CLY, SYSZ_INS_CLY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CMPSC, SYSZ_INS_CMPSC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, SYSZ_REG_1, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CP, SYSZ_INS_CP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CPDT, SYSZ_INS_CPDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DFPPACKEDCONVERSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CPSDRdd, SYSZ_INS_CPSDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CPXT, SYSZ_INS_CPXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DFPPACKEDCONVERSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CPYA, SYSZ_INS_CPYA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CR, SYSZ_INS_CR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRBAsm, SYSZ_INS_CRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmE, SYSZ_INS_CRBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmH, SYSZ_INS_CRBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmHE, SYSZ_INS_CRBHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmL, SYSZ_INS_CRBL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmLE, SYSZ_INS_CRBLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmLH, SYSZ_INS_CRBLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmNE, SYSZ_INS_CRBNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmNH, SYSZ_INS_CRBNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmNHE, SYSZ_INS_CRBNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmNL, SYSZ_INS_CRBNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmNLE, SYSZ_INS_CRBNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRBAsmNLH, SYSZ_INS_CRBNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	SystemZ_CRDTE, SYSZ_INS_CRDTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_ENHANCEDDAT2, 0 }, 0, 0
#endif
},
{
	SystemZ_CRDTEOpt, SYSZ_INS_CRDTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_ENHANCEDDAT2, 0 }, 0, 0
#endif
},
{
	SystemZ_CRJAsm, SYSZ_INS_CRJ,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmE, SYSZ_INS_CRJE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmH, SYSZ_INS_CRJH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmHE, SYSZ_INS_CRJHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmL, SYSZ_INS_CRJL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmLE, SYSZ_INS_CRJLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmLH, SYSZ_INS_CRJLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmNE, SYSZ_INS_CRJNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmNH, SYSZ_INS_CRJNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmNHE, SYSZ_INS_CRJNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmNL, SYSZ_INS_CRJNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmNLE, SYSZ_INS_CRJNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRJAsmNLH, SYSZ_INS_CRJNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_CRL, SYSZ_INS_CRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsm, SYSZ_INS_CRT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmE, SYSZ_INS_CRTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmH, SYSZ_INS_CRTH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmHE, SYSZ_INS_CRTHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmL, SYSZ_INS_CRTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmLE, SYSZ_INS_CRTLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmLH, SYSZ_INS_CRTLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmNE, SYSZ_INS_CRTNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmNH, SYSZ_INS_CRTNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmNHE, SYSZ_INS_CRTNHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmNL, SYSZ_INS_CRTNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmNLE, SYSZ_INS_CRTNLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CRTAsmNLH, SYSZ_INS_CRTNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CS, SYSZ_INS_CS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSCH, SYSZ_INS_CSCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSDTR, SYSZ_INS_CSDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSG, SYSZ_INS_CSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSP, SYSZ_INS_CSP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSPG, SYSZ_INS_CSPG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSST, SYSZ_INS_CSST,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSXTR, SYSZ_INS_CSXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CSY, SYSZ_INS_CSY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU12, SYSZ_INS_CU12,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU12Opt, SYSZ_INS_CU12,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU14, SYSZ_INS_CU14,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU14Opt, SYSZ_INS_CU14,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU21, SYSZ_INS_CU21,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU21Opt, SYSZ_INS_CU21,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU24, SYSZ_INS_CU24,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU24Opt, SYSZ_INS_CU24,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU41, SYSZ_INS_CU41,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CU42, SYSZ_INS_CU42,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CUDTR, SYSZ_INS_CUDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CUSE, SYSZ_INS_CUSE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CUTFU, SYSZ_INS_CUTFU,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CUTFUOpt, SYSZ_INS_CUTFU,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CUUTF, SYSZ_INS_CUUTF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CUUTFOpt, SYSZ_INS_CUUTF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CUXTR, SYSZ_INS_CUXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CVB, SYSZ_INS_CVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CVBG, SYSZ_INS_CVBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CVBY, SYSZ_INS_CVBY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CVD, SYSZ_INS_CVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CVDG, SYSZ_INS_CVDG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CVDY, SYSZ_INS_CVDY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXBR, SYSZ_INS_CXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXFBR, SYSZ_INS_CXFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXFBRA, SYSZ_INS_CXFBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXFR, SYSZ_INS_CXFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXFTR, SYSZ_INS_CXFTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXGBR, SYSZ_INS_CXGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXGBRA, SYSZ_INS_CXGBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXGR, SYSZ_INS_CXGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXGTR, SYSZ_INS_CXGTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXGTRA, SYSZ_INS_CXGTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXLFBR, SYSZ_INS_CXLFBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXLFTR, SYSZ_INS_CXLFTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXLGBR, SYSZ_INS_CXLGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXLGTR, SYSZ_INS_CXLGTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXPT, SYSZ_INS_CXPT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DFPPACKEDCONVERSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CXR, SYSZ_INS_CXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXSTR, SYSZ_INS_CXSTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXTR, SYSZ_INS_CXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXUTR, SYSZ_INS_CXUTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CXZT, SYSZ_INS_CXZT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DFPZONEDCONVERSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CY, SYSZ_INS_CY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_CZDT, SYSZ_INS_CZDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DFPZONEDCONVERSION, 0 }, 0, 0
#endif
},
{
	SystemZ_CZXT, SYSZ_INS_CZXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DFPZONEDCONVERSION, 0 }, 0, 0
#endif
},
{
	SystemZ_D, SYSZ_INS_D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DD, SYSZ_INS_DD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DDB, SYSZ_INS_DDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DDBR, SYSZ_INS_DDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DDR, SYSZ_INS_DDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DDTR, SYSZ_INS_DDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DDTRA, SYSZ_INS_DDTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_DE, SYSZ_INS_DE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DEB, SYSZ_INS_DEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DEBR, SYSZ_INS_DEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DER, SYSZ_INS_DER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DIAG, SYSZ_INS_DIAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DIDBR, SYSZ_INS_DIDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DIEBR, SYSZ_INS_DIEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DL, SYSZ_INS_DL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DLG, SYSZ_INS_DLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DLGR, SYSZ_INS_DLGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DLR, SYSZ_INS_DLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DP, SYSZ_INS_DP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DR, SYSZ_INS_DR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DSG, SYSZ_INS_DSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DSGF, SYSZ_INS_DSGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DSGFR, SYSZ_INS_DSGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DSGR, SYSZ_INS_DSGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DXBR, SYSZ_INS_DXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DXR, SYSZ_INS_DXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DXTR, SYSZ_INS_DXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_DXTRA, SYSZ_INS_DXTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_EAR, SYSZ_INS_EAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ECAG, SYSZ_INS_ECAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ECCTR, SYSZ_INS_ECCTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ECPGA, SYSZ_INS_ECPGA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ECTG, SYSZ_INS_ECTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_0, SYSZ_REG_1, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ED, SYSZ_INS_ED,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EDMK, SYSZ_INS_EDMK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EEDTR, SYSZ_INS_EEDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EEXTR, SYSZ_INS_EEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EFPC, SYSZ_INS_EFPC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EPAIR, SYSZ_INS_EPAIR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EPAR, SYSZ_INS_EPAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EPCTR, SYSZ_INS_EPCTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EPSW, SYSZ_INS_EPSW,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EREG, SYSZ_INS_EREG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EREGG, SYSZ_INS_EREGG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ESAIR, SYSZ_INS_ESAIR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ESAR, SYSZ_INS_ESAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ESDTR, SYSZ_INS_ESDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ESEA, SYSZ_INS_ESEA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ESTA, SYSZ_INS_ESTA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ESXTR, SYSZ_INS_ESXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ETND, SYSZ_INS_ETND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_TRANSACTIONALEXECUTION, 0 }, 0, 0
#endif
},
{
	SystemZ_EX, SYSZ_INS_EX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_EXRL, SYSZ_INS_EXRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIDBR, SYSZ_INS_FIDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIDBRA, SYSZ_INS_FIDBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_FIDR, SYSZ_INS_FIDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIDTR, SYSZ_INS_FIDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIEBR, SYSZ_INS_FIEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIEBRA, SYSZ_INS_FIEBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_FIER, SYSZ_INS_FIER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIXBR, SYSZ_INS_FIXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIXBRA, SYSZ_INS_FIXBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_FIXR, SYSZ_INS_FIXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FIXTR, SYSZ_INS_FIXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_FLOGR, SYSZ_INS_FLOGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_HDR, SYSZ_INS_HDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_HER, SYSZ_INS_HER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_HSCH, SYSZ_INS_HSCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IAC, SYSZ_INS_IAC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IC, SYSZ_INS_IC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ICM, SYSZ_INS_ICM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ICMH, SYSZ_INS_ICMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ICMY, SYSZ_INS_ICMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ICY, SYSZ_INS_ICY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IDTE, SYSZ_INS_IDTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IDTEOpt, SYSZ_INS_IDTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IEDTR, SYSZ_INS_IEDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IEXTR, SYSZ_INS_IEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IIHF, SYSZ_INS_IIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IIHH, SYSZ_INS_IIHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IIHL, SYSZ_INS_IIHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IILF, SYSZ_INS_IILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IILH, SYSZ_INS_IILH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IILL, SYSZ_INS_IILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IPK, SYSZ_INS_IPK,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_2, 0 }, { SYSZ_REG_2, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IPM, SYSZ_INS_IPM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IPTE, SYSZ_INS_IPTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IPTEOpt, SYSZ_INS_IPTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IPTEOptOpt, SYSZ_INS_IPTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IRBM, SYSZ_INS_IRBM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_INSERTREFERENCEBITSMULTIPLE, 0 }, 0, 0
#endif
},
{
	SystemZ_ISKE, SYSZ_INS_ISKE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_IVSK, SYSZ_INS_IVSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_J, SYSZ_INS_J,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmE, SYSZ_INS_JE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmH, SYSZ_INS_JH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmHE, SYSZ_INS_JHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmL, SYSZ_INS_JL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmLE, SYSZ_INS_JLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmLH, SYSZ_INS_JLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmM, SYSZ_INS_JM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNE, SYSZ_INS_JNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNH, SYSZ_INS_JNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNHE, SYSZ_INS_JNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNL, SYSZ_INS_JNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNLE, SYSZ_INS_JNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNLH, SYSZ_INS_JNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNM, SYSZ_INS_JNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNO, SYSZ_INS_JNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNP, SYSZ_INS_JNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmNZ, SYSZ_INS_JNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmO, SYSZ_INS_JO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmP, SYSZ_INS_JP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JAsmZ, SYSZ_INS_JZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JG, SYSZ_INS_JG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmE, SYSZ_INS_JGE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmH, SYSZ_INS_JGH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmHE, SYSZ_INS_JGHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmL, SYSZ_INS_JGL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmLE, SYSZ_INS_JGLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmLH, SYSZ_INS_JGLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmM, SYSZ_INS_JGM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNE, SYSZ_INS_JGNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNH, SYSZ_INS_JGNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNHE, SYSZ_INS_JGNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNL, SYSZ_INS_JGNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNLE, SYSZ_INS_JGNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNLH, SYSZ_INS_JGNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNM, SYSZ_INS_JGNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNO, SYSZ_INS_JGNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNP, SYSZ_INS_JGNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmNZ, SYSZ_INS_JGNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmO, SYSZ_INS_JGO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmP, SYSZ_INS_JGP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_JGAsmZ, SYSZ_INS_JGZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { 0 }, 1, 0
#endif
},
{
	SystemZ_KDB, SYSZ_INS_KDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KDBR, SYSZ_INS_KDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KDTR, SYSZ_INS_KDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KEB, SYSZ_INS_KEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KEBR, SYSZ_INS_KEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KIMD, SYSZ_INS_KIMD,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KLMD, SYSZ_INS_KLMD,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KM, SYSZ_INS_KM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KMA, SYSZ_INS_KMA,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MESSAGESECURITYASSIST8, 0 }, 0, 0
#endif
},
{
	SystemZ_KMAC, SYSZ_INS_KMAC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KMC, SYSZ_INS_KMC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KMCTR, SYSZ_INS_KMCTR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MESSAGESECURITYASSIST4, 0 }, 0, 0
#endif
},
{
	SystemZ_KMF, SYSZ_INS_KMF,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MESSAGESECURITYASSIST4, 0 }, 0, 0
#endif
},
{
	SystemZ_KMO, SYSZ_INS_KMO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MESSAGESECURITYASSIST4, 0 }, 0, 0
#endif
},
{
	SystemZ_KXBR, SYSZ_INS_KXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_KXTR, SYSZ_INS_KXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_L, SYSZ_INS_L,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LA, SYSZ_INS_LA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LAA, SYSZ_INS_LAA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAAG, SYSZ_INS_LAAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAAL, SYSZ_INS_LAAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAALG, SYSZ_INS_LAALG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAE, SYSZ_INS_LAE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LAEY, SYSZ_INS_LAEY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LAM, SYSZ_INS_LAM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LAMY, SYSZ_INS_LAMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LAN, SYSZ_INS_LAN,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LANG, SYSZ_INS_LANG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAO, SYSZ_INS_LAO,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAOG, SYSZ_INS_LAOG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LARL, SYSZ_INS_LARL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LASP, SYSZ_INS_LASP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LAT, SYSZ_INS_LAT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADANDTRAP, 0 }, 0, 0
#endif
},
{
	SystemZ_LAX, SYSZ_INS_LAX,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAXG, SYSZ_INS_LAXG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LAY, SYSZ_INS_LAY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LB, SYSZ_INS_LB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LBH, SYSZ_INS_LBH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LBR, SYSZ_INS_LBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCBB, SYSZ_INS_LCBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_LCCTL, SYSZ_INS_LCCTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCDBR, SYSZ_INS_LCDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCDFR, SYSZ_INS_LCDFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCDR, SYSZ_INS_LCDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCEBR, SYSZ_INS_LCEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCER, SYSZ_INS_LCER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCGFR, SYSZ_INS_LCGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCGR, SYSZ_INS_LCGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCR, SYSZ_INS_LCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCTL, SYSZ_INS_LCTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCTLG, SYSZ_INS_LCTLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCXBR, SYSZ_INS_LCXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LCXR, SYSZ_INS_LCXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LD, SYSZ_INS_LD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDE, SYSZ_INS_LDE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDEB, SYSZ_INS_LDEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDEBR, SYSZ_INS_LDEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDER, SYSZ_INS_LDER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDETR, SYSZ_INS_LDETR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDGR, SYSZ_INS_LDGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDR, SYSZ_INS_LDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDXBR, SYSZ_INS_LDXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDXBRA, SYSZ_INS_LDXBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_LDXR, SYSZ_INS_LDXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDXTR, SYSZ_INS_LDXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LDY, SYSZ_INS_LDY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LE, SYSZ_INS_LE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEDBR, SYSZ_INS_LEDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEDBRA, SYSZ_INS_LEDBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_LEDR, SYSZ_INS_LEDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEDTR, SYSZ_INS_LEDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LER, SYSZ_INS_LER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEXBR, SYSZ_INS_LEXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEXBRA, SYSZ_INS_LEXBRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_LEXR, SYSZ_INS_LEXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LEY, SYSZ_INS_LEY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LFAS, SYSZ_INS_LFAS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LFH, SYSZ_INS_LFH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LFHAT, SYSZ_INS_LFHAT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADANDTRAP, 0 }, 0, 0
#endif
},
{
	SystemZ_LFPC, SYSZ_INS_LFPC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LG, SYSZ_INS_LG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGAT, SYSZ_INS_LGAT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADANDTRAP, 0 }, 0, 0
#endif
},
{
	SystemZ_LGB, SYSZ_INS_LGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGBR, SYSZ_INS_LGBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGDR, SYSZ_INS_LGDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGF, SYSZ_INS_LGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGFI, SYSZ_INS_LGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGFR, SYSZ_INS_LGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGFRL, SYSZ_INS_LGFRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGG, SYSZ_INS_LGG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_GUARDEDSTORAGE, 0 }, 0, 0
#endif
},
{
	SystemZ_LGH, SYSZ_INS_LGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGHI, SYSZ_INS_LGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGHR, SYSZ_INS_LGHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGHRL, SYSZ_INS_LGHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGR, SYSZ_INS_LGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGRL, SYSZ_INS_LGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LGSC, SYSZ_INS_LGSC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_GUARDEDSTORAGE, 0 }, 0, 0
#endif
},
{
	SystemZ_LH, SYSZ_INS_LH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LHH, SYSZ_INS_LHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LHI, SYSZ_INS_LHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LHR, SYSZ_INS_LHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LHRL, SYSZ_INS_LHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LHY, SYSZ_INS_LHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLC, SYSZ_INS_LLC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLCH, SYSZ_INS_LLCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LLCR, SYSZ_INS_LLCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGC, SYSZ_INS_LLGC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGCR, SYSZ_INS_LLGCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGF, SYSZ_INS_LLGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGFAT, SYSZ_INS_LLGFAT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADANDTRAP, 0 }, 0, 0
#endif
},
{
	SystemZ_LLGFR, SYSZ_INS_LLGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGFRL, SYSZ_INS_LLGFRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGFSG, SYSZ_INS_LLGFSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_GUARDEDSTORAGE, 0 }, 0, 0
#endif
},
{
	SystemZ_LLGH, SYSZ_INS_LLGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGHR, SYSZ_INS_LLGHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGHRL, SYSZ_INS_LLGHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGT, SYSZ_INS_LLGT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLGTAT, SYSZ_INS_LLGTAT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADANDTRAP, 0 }, 0, 0
#endif
},
{
	SystemZ_LLGTR, SYSZ_INS_LLGTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLH, SYSZ_INS_LLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLHH, SYSZ_INS_LLHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_LLHR, SYSZ_INS_LLHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLHRL, SYSZ_INS_LLHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLIHF, SYSZ_INS_LLIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLIHH, SYSZ_INS_LLIHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLIHL, SYSZ_INS_LLIHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLILF, SYSZ_INS_LLILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLILH, SYSZ_INS_LLILH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLILL, SYSZ_INS_LLILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LLZRGF, SYSZ_INS_LLZRGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADANDZERORIGHTMOSTBYTE, 0 }, 0, 0
#endif
},
{
	SystemZ_LM, SYSZ_INS_LM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LMD, SYSZ_INS_LMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LMG, SYSZ_INS_LMG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LMH, SYSZ_INS_LMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LMY, SYSZ_INS_LMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNDBR, SYSZ_INS_LNDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNDFR, SYSZ_INS_LNDFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNDR, SYSZ_INS_LNDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNEBR, SYSZ_INS_LNEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNER, SYSZ_INS_LNER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNGFR, SYSZ_INS_LNGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNGR, SYSZ_INS_LNGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNR, SYSZ_INS_LNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNXBR, SYSZ_INS_LNXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LNXR, SYSZ_INS_LNXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsm, SYSZ_INS_LOC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmE, SYSZ_INS_LOCE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmH, SYSZ_INS_LOCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmHE, SYSZ_INS_LOCHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmL, SYSZ_INS_LOCL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmLE, SYSZ_INS_LOCLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmLH, SYSZ_INS_LOCLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmM, SYSZ_INS_LOCM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNE, SYSZ_INS_LOCNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNH, SYSZ_INS_LOCNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNHE, SYSZ_INS_LOCNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNL, SYSZ_INS_LOCNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNLE, SYSZ_INS_LOCNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNLH, SYSZ_INS_LOCNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNM, SYSZ_INS_LOCNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNO, SYSZ_INS_LOCNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNP, SYSZ_INS_LOCNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmNZ, SYSZ_INS_LOCNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmO, SYSZ_INS_LOCO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmP, SYSZ_INS_LOCP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCAsmZ, SYSZ_INS_LOCZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsm, SYSZ_INS_LOCFH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmE, SYSZ_INS_LOCFHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmH, SYSZ_INS_LOCFHH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmHE, SYSZ_INS_LOCFHHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmL, SYSZ_INS_LOCFHL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmLE, SYSZ_INS_LOCFHLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmLH, SYSZ_INS_LOCFHLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmM, SYSZ_INS_LOCFHM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNE, SYSZ_INS_LOCFHNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNH, SYSZ_INS_LOCFHNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNHE, SYSZ_INS_LOCFHNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNL, SYSZ_INS_LOCFHNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNLE, SYSZ_INS_LOCFHNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNLH, SYSZ_INS_LOCFHNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNM, SYSZ_INS_LOCFHNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNO, SYSZ_INS_LOCFHNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNP, SYSZ_INS_LOCFHNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmNZ, SYSZ_INS_LOCFHNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmO, SYSZ_INS_LOCFHO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmP, SYSZ_INS_LOCFHP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHAsmZ, SYSZ_INS_LOCFHZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsm, SYSZ_INS_LOCFHR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmE, SYSZ_INS_LOCFHRE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmH, SYSZ_INS_LOCFHRH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmHE, SYSZ_INS_LOCFHRHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmL, SYSZ_INS_LOCFHRL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmLE, SYSZ_INS_LOCFHRLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmLH, SYSZ_INS_LOCFHRLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmM, SYSZ_INS_LOCFHRM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNE, SYSZ_INS_LOCFHRNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNH, SYSZ_INS_LOCFHRNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNHE, SYSZ_INS_LOCFHRNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNL, SYSZ_INS_LOCFHRNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNLE, SYSZ_INS_LOCFHRNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNLH, SYSZ_INS_LOCFHRNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNM, SYSZ_INS_LOCFHRNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNO, SYSZ_INS_LOCFHRNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNP, SYSZ_INS_LOCFHRNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmNZ, SYSZ_INS_LOCFHRNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmO, SYSZ_INS_LOCFHRO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmP, SYSZ_INS_LOCFHRP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCFHRAsmZ, SYSZ_INS_LOCFHRZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsm, SYSZ_INS_LOCG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmE, SYSZ_INS_LOCGE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmH, SYSZ_INS_LOCGH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmHE, SYSZ_INS_LOCGHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmL, SYSZ_INS_LOCGL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmLE, SYSZ_INS_LOCGLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmLH, SYSZ_INS_LOCGLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmM, SYSZ_INS_LOCGM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNE, SYSZ_INS_LOCGNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNH, SYSZ_INS_LOCGNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNHE, SYSZ_INS_LOCGNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNL, SYSZ_INS_LOCGNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNLE, SYSZ_INS_LOCGNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNLH, SYSZ_INS_LOCGNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNM, SYSZ_INS_LOCGNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNO, SYSZ_INS_LOCGNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNP, SYSZ_INS_LOCGNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmNZ, SYSZ_INS_LOCGNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmO, SYSZ_INS_LOCGO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmP, SYSZ_INS_LOCGP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGAsmZ, SYSZ_INS_LOCGZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsm, SYSZ_INS_LOCGHI,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmE, SYSZ_INS_LOCGHIE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmH, SYSZ_INS_LOCGHIH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmHE, SYSZ_INS_LOCGHIHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmL, SYSZ_INS_LOCGHIL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmLE, SYSZ_INS_LOCGHILE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmLH, SYSZ_INS_LOCGHILH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmM, SYSZ_INS_LOCGHIM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNE, SYSZ_INS_LOCGHINE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNH, SYSZ_INS_LOCGHINH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNHE, SYSZ_INS_LOCGHINHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNL, SYSZ_INS_LOCGHINL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNLE, SYSZ_INS_LOCGHINLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNLH, SYSZ_INS_LOCGHINLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNM, SYSZ_INS_LOCGHINM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNO, SYSZ_INS_LOCGHINO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNP, SYSZ_INS_LOCGHINP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmNZ, SYSZ_INS_LOCGHINZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmO, SYSZ_INS_LOCGHIO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmP, SYSZ_INS_LOCGHIP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGHIAsmZ, SYSZ_INS_LOCGHIZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsm, SYSZ_INS_LOCGR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmE, SYSZ_INS_LOCGRE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmH, SYSZ_INS_LOCGRH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmHE, SYSZ_INS_LOCGRHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmL, SYSZ_INS_LOCGRL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmLE, SYSZ_INS_LOCGRLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmLH, SYSZ_INS_LOCGRLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmM, SYSZ_INS_LOCGRM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNE, SYSZ_INS_LOCGRNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNH, SYSZ_INS_LOCGRNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNHE, SYSZ_INS_LOCGRNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNL, SYSZ_INS_LOCGRNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNLE, SYSZ_INS_LOCGRNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNLH, SYSZ_INS_LOCGRNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNM, SYSZ_INS_LOCGRNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNO, SYSZ_INS_LOCGRNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNP, SYSZ_INS_LOCGRNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmNZ, SYSZ_INS_LOCGRNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmO, SYSZ_INS_LOCGRO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmP, SYSZ_INS_LOCGRP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCGRAsmZ, SYSZ_INS_LOCGRZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsm, SYSZ_INS_LOCHHI,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmE, SYSZ_INS_LOCHHIE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmH, SYSZ_INS_LOCHHIH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmHE, SYSZ_INS_LOCHHIHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmL, SYSZ_INS_LOCHHIL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmLE, SYSZ_INS_LOCHHILE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmLH, SYSZ_INS_LOCHHILH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmM, SYSZ_INS_LOCHHIM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNE, SYSZ_INS_LOCHHINE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNH, SYSZ_INS_LOCHHINH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNHE, SYSZ_INS_LOCHHINHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNL, SYSZ_INS_LOCHHINL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNLE, SYSZ_INS_LOCHHINLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNLH, SYSZ_INS_LOCHHINLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNM, SYSZ_INS_LOCHHINM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNO, SYSZ_INS_LOCHHINO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNP, SYSZ_INS_LOCHHINP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmNZ, SYSZ_INS_LOCHHINZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmO, SYSZ_INS_LOCHHIO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmP, SYSZ_INS_LOCHHIP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHHIAsmZ, SYSZ_INS_LOCHHIZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsm, SYSZ_INS_LOCHI,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmE, SYSZ_INS_LOCHIE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmH, SYSZ_INS_LOCHIH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmHE, SYSZ_INS_LOCHIHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmL, SYSZ_INS_LOCHIL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmLE, SYSZ_INS_LOCHILE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmLH, SYSZ_INS_LOCHILH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmM, SYSZ_INS_LOCHIM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNE, SYSZ_INS_LOCHINE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNH, SYSZ_INS_LOCHINH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNHE, SYSZ_INS_LOCHINHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNL, SYSZ_INS_LOCHINL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNLE, SYSZ_INS_LOCHINLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNLH, SYSZ_INS_LOCHINLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNM, SYSZ_INS_LOCHINM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNO, SYSZ_INS_LOCHINO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNP, SYSZ_INS_LOCHINP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmNZ, SYSZ_INS_LOCHINZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmO, SYSZ_INS_LOCHIO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmP, SYSZ_INS_LOCHIP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCHIAsmZ, SYSZ_INS_LOCHIZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsm, SYSZ_INS_LOCR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmE, SYSZ_INS_LOCRE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmH, SYSZ_INS_LOCRH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmHE, SYSZ_INS_LOCRHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmL, SYSZ_INS_LOCRL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmLE, SYSZ_INS_LOCRLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmLH, SYSZ_INS_LOCRLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmM, SYSZ_INS_LOCRM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNE, SYSZ_INS_LOCRNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNH, SYSZ_INS_LOCRNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNHE, SYSZ_INS_LOCRNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNL, SYSZ_INS_LOCRNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNLE, SYSZ_INS_LOCRNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNLH, SYSZ_INS_LOCRNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNM, SYSZ_INS_LOCRNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNO, SYSZ_INS_LOCRNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNP, SYSZ_INS_LOCRNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmNZ, SYSZ_INS_LOCRNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmO, SYSZ_INS_LOCRO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmP, SYSZ_INS_LOCRP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LOCRAsmZ, SYSZ_INS_LOCRZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_LPCTL, SYSZ_INS_LPCTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPD, SYSZ_INS_LPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LPDBR, SYSZ_INS_LPDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPDFR, SYSZ_INS_LPDFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPDG, SYSZ_INS_LPDG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_INTERLOCKEDACCESS1, 0 }, 0, 0
#endif
},
{
	SystemZ_LPDR, SYSZ_INS_LPDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPEBR, SYSZ_INS_LPEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPER, SYSZ_INS_LPER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPGFR, SYSZ_INS_LPGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPGR, SYSZ_INS_LPGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPP, SYSZ_INS_LPP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPQ, SYSZ_INS_LPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPR, SYSZ_INS_LPR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPSW, SYSZ_INS_LPSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPSWE, SYSZ_INS_LPSWE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPTEA, SYSZ_INS_LPTEA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPXBR, SYSZ_INS_LPXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LPXR, SYSZ_INS_LPXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LR, SYSZ_INS_LR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRA, SYSZ_INS_LRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRAG, SYSZ_INS_LRAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRAY, SYSZ_INS_LRAY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRDR, SYSZ_INS_LRDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRER, SYSZ_INS_LRER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRL, SYSZ_INS_LRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRV, SYSZ_INS_LRV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRVG, SYSZ_INS_LRVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRVGR, SYSZ_INS_LRVGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRVH, SYSZ_INS_LRVH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LRVR, SYSZ_INS_LRVR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LSCTL, SYSZ_INS_LSCTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LT, SYSZ_INS_LT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTDBR, SYSZ_INS_LTDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTDR, SYSZ_INS_LTDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTDTR, SYSZ_INS_LTDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTEBR, SYSZ_INS_LTEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTER, SYSZ_INS_LTER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTG, SYSZ_INS_LTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTGF, SYSZ_INS_LTGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTGFR, SYSZ_INS_LTGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTGR, SYSZ_INS_LTGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTR, SYSZ_INS_LTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTXBR, SYSZ_INS_LTXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTXR, SYSZ_INS_LTXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LTXTR, SYSZ_INS_LTXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LURA, SYSZ_INS_LURA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LURAG, SYSZ_INS_LURAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXD, SYSZ_INS_LXD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXDB, SYSZ_INS_LXDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXDBR, SYSZ_INS_LXDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXDR, SYSZ_INS_LXDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXDTR, SYSZ_INS_LXDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXE, SYSZ_INS_LXE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXEB, SYSZ_INS_LXEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXEBR, SYSZ_INS_LXEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXER, SYSZ_INS_LXER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LXR, SYSZ_INS_LXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LY, SYSZ_INS_LY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LZDR, SYSZ_INS_LZDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LZER, SYSZ_INS_LZER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_LZRF, SYSZ_INS_LZRF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADANDZERORIGHTMOSTBYTE, 0 }, 0, 0
#endif
},
{
	SystemZ_LZRG, SYSZ_INS_LZRG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_LOADANDZERORIGHTMOSTBYTE, 0 }, 0, 0
#endif
},
{
	SystemZ_LZXR, SYSZ_INS_LZXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_M, SYSZ_INS_M,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAD, SYSZ_INS_MAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MADB, SYSZ_INS_MADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MADBR, SYSZ_INS_MADBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MADR, SYSZ_INS_MADR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAE, SYSZ_INS_MAE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAEB, SYSZ_INS_MAEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAEBR, SYSZ_INS_MAEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAER, SYSZ_INS_MAER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAY, SYSZ_INS_MAY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAYH, SYSZ_INS_MAYH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAYHR, SYSZ_INS_MAYHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAYL, SYSZ_INS_MAYL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAYLR, SYSZ_INS_MAYLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MAYR, SYSZ_INS_MAYR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MC, SYSZ_INS_MC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MD, SYSZ_INS_MD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDB, SYSZ_INS_MDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDBR, SYSZ_INS_MDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDE, SYSZ_INS_MDE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDEB, SYSZ_INS_MDEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDEBR, SYSZ_INS_MDEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDER, SYSZ_INS_MDER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDR, SYSZ_INS_MDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDTR, SYSZ_INS_MDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MDTRA, SYSZ_INS_MDTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_ME, SYSZ_INS_ME,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MEE, SYSZ_INS_MEE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MEEB, SYSZ_INS_MEEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MEEBR, SYSZ_INS_MEEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MEER, SYSZ_INS_MEER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MER, SYSZ_INS_MER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MFY, SYSZ_INS_MFY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MG, SYSZ_INS_MG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_MGH, SYSZ_INS_MGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_MGHI, SYSZ_INS_MGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MGRK, SYSZ_INS_MGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_MH, SYSZ_INS_MH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MHI, SYSZ_INS_MHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MHY, SYSZ_INS_MHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ML, SYSZ_INS_ML,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MLG, SYSZ_INS_MLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MLGR, SYSZ_INS_MLGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MLR, SYSZ_INS_MLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MP, SYSZ_INS_MP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MR, SYSZ_INS_MR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MS, SYSZ_INS_MS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSC, SYSZ_INS_MSC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_MSCH, SYSZ_INS_MSCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSD, SYSZ_INS_MSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSDB, SYSZ_INS_MSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSDBR, SYSZ_INS_MSDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSDR, SYSZ_INS_MSDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSE, SYSZ_INS_MSE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSEB, SYSZ_INS_MSEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSEBR, SYSZ_INS_MSEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSER, SYSZ_INS_MSER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSFI, SYSZ_INS_MSFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSG, SYSZ_INS_MSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGC, SYSZ_INS_MSGC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_MSGF, SYSZ_INS_MSGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGFI, SYSZ_INS_MSGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGFR, SYSZ_INS_MSGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGR, SYSZ_INS_MSGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSGRKC, SYSZ_INS_MSGRKC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_MSR, SYSZ_INS_MSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSRKC, SYSZ_INS_MSRKC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_MSTA, SYSZ_INS_MSTA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MSY, SYSZ_INS_MSY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVC, SYSZ_INS_MVC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCDK, SYSZ_INS_MVCDK,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCIN, SYSZ_INS_MVCIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCK, SYSZ_INS_MVCK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCL, SYSZ_INS_MVCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCLE, SYSZ_INS_MVCLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCLU, SYSZ_INS_MVCLU,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCOS, SYSZ_INS_MVCOS,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCP, SYSZ_INS_MVCP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCS, SYSZ_INS_MVCS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVCSK, SYSZ_INS_MVCSK,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVGHI, SYSZ_INS_MVGHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVHHI, SYSZ_INS_MVHHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVHI, SYSZ_INS_MVHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVI, SYSZ_INS_MVI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVIY, SYSZ_INS_MVIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVN, SYSZ_INS_MVN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVO, SYSZ_INS_MVO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVPG, SYSZ_INS_MVPG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVST, SYSZ_INS_MVST,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MVZ, SYSZ_INS_MVZ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXBR, SYSZ_INS_MXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXD, SYSZ_INS_MXD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXDB, SYSZ_INS_MXDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXDBR, SYSZ_INS_MXDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXDR, SYSZ_INS_MXDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXR, SYSZ_INS_MXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXTR, SYSZ_INS_MXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MXTRA, SYSZ_INS_MXTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_MY, SYSZ_INS_MY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MYH, SYSZ_INS_MYH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MYHR, SYSZ_INS_MYHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MYL, SYSZ_INS_MYL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MYLR, SYSZ_INS_MYLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_MYR, SYSZ_INS_MYR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_N, SYSZ_INS_N,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NC, SYSZ_INS_NC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NG, SYSZ_INS_NG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NGR, SYSZ_INS_NGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NGRK, SYSZ_INS_NGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_NI, SYSZ_INS_NI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NIAI, SYSZ_INS_NIAI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_EXECUTIONHINT, 0 }, 0, 0
#endif
},
{
	SystemZ_NIHF, SYSZ_INS_NIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NIHH, SYSZ_INS_NIHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NIHL, SYSZ_INS_NIHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NILF, SYSZ_INS_NILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NILH, SYSZ_INS_NILH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NILL, SYSZ_INS_NILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NIY, SYSZ_INS_NIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NR, SYSZ_INS_NR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_NRK, SYSZ_INS_NRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_NTSTG, SYSZ_INS_NTSTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_TRANSACTIONALEXECUTION, 0 }, 0, 0
#endif
},
{
	SystemZ_NY, SYSZ_INS_NY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_O, SYSZ_INS_O,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OC, SYSZ_INS_OC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OG, SYSZ_INS_OG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OGR, SYSZ_INS_OGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OGRK, SYSZ_INS_OGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_OI, SYSZ_INS_OI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OIHF, SYSZ_INS_OIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OIHH, SYSZ_INS_OIHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OIHL, SYSZ_INS_OIHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OILF, SYSZ_INS_OILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OILH, SYSZ_INS_OILH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OILL, SYSZ_INS_OILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OIY, SYSZ_INS_OIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_OR, SYSZ_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ORK, SYSZ_INS_ORK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_OY, SYSZ_INS_OY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PACK, SYSZ_INS_PACK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PALB, SYSZ_INS_PALB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PC, SYSZ_INS_PC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PCC, SYSZ_INS_PCC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MESSAGESECURITYASSIST4, 0 }, 0, 0
#endif
},
{
	SystemZ_PCKMO, SYSZ_INS_PCKMO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { 0 }, { SYSZ_GRP_MESSAGESECURITYASSIST3, 0 }, 0, 0
#endif
},
{
	SystemZ_PFD, SYSZ_INS_PFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PFDRL, SYSZ_INS_PFDRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PFMF, SYSZ_INS_PFMF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PFPO, SYSZ_INS_PFPO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_F4Q, 0 }, { SYSZ_REG_CC, SYSZ_REG_1, SYSZ_REG_F0Q, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PGIN, SYSZ_INS_PGIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PGOUT, SYSZ_INS_PGOUT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PKA, SYSZ_INS_PKA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PKU, SYSZ_INS_PKU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PLO, SYSZ_INS_PLO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_POPCNT, SYSZ_INS_POPCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_POPULATIONCOUNT, 0 }, 0, 0
#endif
},
{
	SystemZ_PPA, SYSZ_INS_PPA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_PROCESSORASSIST, 0 }, 0, 0
#endif
},
{
	SystemZ_PPNO, SYSZ_INS_PPNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MESSAGESECURITYASSIST5, 0 }, 0, 0
#endif
},
{
	SystemZ_PR, SYSZ_INS_PR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PRNO, SYSZ_INS_PRNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MESSAGESECURITYASSIST7, 0 }, 0, 0
#endif
},
{
	SystemZ_PT, SYSZ_INS_PT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PTF, SYSZ_INS_PTF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PTFF, SYSZ_INS_PTFF,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PTI, SYSZ_INS_PTI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_PTLB, SYSZ_INS_PTLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_QADTR, SYSZ_INS_QADTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_QAXTR, SYSZ_INS_QAXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_QCTRI, SYSZ_INS_QCTRI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_QSI, SYSZ_INS_QSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RCHP, SYSZ_INS_RCHP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RISBG, SYSZ_INS_RISBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RISBGN, SYSZ_INS_RISBGN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS, 0 }, 0, 0
#endif
},
{
	SystemZ_RISBHG, SYSZ_INS_RISBHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_RISBLG, SYSZ_INS_RISBLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_RLL, SYSZ_INS_RLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RLLG, SYSZ_INS_RLLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RNSBG, SYSZ_INS_RNSBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ROSBG, SYSZ_INS_ROSBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RP, SYSZ_INS_RP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RRBE, SYSZ_INS_RRBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RRBM, SYSZ_INS_RRBM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_RESETREFERENCEBITSMULTIPLE, 0 }, 0, 0
#endif
},
{
	SystemZ_RRDTR, SYSZ_INS_RRDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RRXTR, SYSZ_INS_RRXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RSCH, SYSZ_INS_RSCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_RXSBG, SYSZ_INS_RXSBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_S, SYSZ_INS_S,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SAC, SYSZ_INS_SAC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SACF, SYSZ_INS_SACF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SAL, SYSZ_INS_SAL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SAM24, SYSZ_INS_SAM24,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SAM31, SYSZ_INS_SAM31,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SAM64, SYSZ_INS_SAM64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SAR, SYSZ_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SCCTR, SYSZ_INS_SCCTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SCHM, SYSZ_INS_SCHM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, SYSZ_REG_2, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SCK, SYSZ_INS_SCK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SCKC, SYSZ_INS_SCKC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SCKPF, SYSZ_INS_SCKPF,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SD, SYSZ_INS_SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SDB, SYSZ_INS_SDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SDBR, SYSZ_INS_SDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SDR, SYSZ_INS_SDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SDTR, SYSZ_INS_SDTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SDTRA, SYSZ_INS_SDTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_SE, SYSZ_INS_SE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SEB, SYSZ_INS_SEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SEBR, SYSZ_INS_SEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SER, SYSZ_INS_SER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SFASR, SYSZ_INS_SFASR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SFPC, SYSZ_INS_SFPC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SG, SYSZ_INS_SG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SGF, SYSZ_INS_SGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SGFR, SYSZ_INS_SGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SGH, SYSZ_INS_SGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_MISCELLANEOUSEXTENSIONS2, 0 }, 0, 0
#endif
},
{
	SystemZ_SGR, SYSZ_INS_SGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SGRK, SYSZ_INS_SGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SH, SYSZ_INS_SH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SHHHR, SYSZ_INS_SHHHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_SHHLR, SYSZ_INS_SHHLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_SHY, SYSZ_INS_SHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SIE, SYSZ_INS_SIE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SIGA, SYSZ_INS_SIGA,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, SYSZ_REG_2, SYSZ_REG_3, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SIGP, SYSZ_INS_SIGP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SL, SYSZ_INS_SL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLA, SYSZ_INS_SLA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLAG, SYSZ_INS_SLAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLAK, SYSZ_INS_SLAK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SLB, SYSZ_INS_SLB,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLBG, SYSZ_INS_SLBG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLBGR, SYSZ_INS_SLBGR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLBR, SYSZ_INS_SLBR,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLDA, SYSZ_INS_SLDA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLDL, SYSZ_INS_SLDL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLDT, SYSZ_INS_SLDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLFI, SYSZ_INS_SLFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLG, SYSZ_INS_SLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGF, SYSZ_INS_SLGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGFI, SYSZ_INS_SLGFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGFR, SYSZ_INS_SLGFR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGR, SYSZ_INS_SLGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLGRK, SYSZ_INS_SLGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SLHHHR, SYSZ_INS_SLHHHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_SLHHLR, SYSZ_INS_SLHHLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_SLL, SYSZ_INS_SLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLLG, SYSZ_INS_SLLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLLK, SYSZ_INS_SLLK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SLR, SYSZ_INS_SLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLRK, SYSZ_INS_SLRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SLXT, SYSZ_INS_SLXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SLY, SYSZ_INS_SLY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SP, SYSZ_INS_SP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SPCTR, SYSZ_INS_SPCTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SPKA, SYSZ_INS_SPKA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SPM, SYSZ_INS_SPM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SPT, SYSZ_INS_SPT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SPX, SYSZ_INS_SPX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQD, SYSZ_INS_SQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQDB, SYSZ_INS_SQDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQDBR, SYSZ_INS_SQDBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQDR, SYSZ_INS_SQDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQE, SYSZ_INS_SQE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQEB, SYSZ_INS_SQEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQEBR, SYSZ_INS_SQEBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQER, SYSZ_INS_SQER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQXBR, SYSZ_INS_SQXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SQXR, SYSZ_INS_SQXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SR, SYSZ_INS_SR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRA, SYSZ_INS_SRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRAG, SYSZ_INS_SRAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRAK, SYSZ_INS_SRAK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SRDA, SYSZ_INS_SRDA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRDL, SYSZ_INS_SRDL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRDT, SYSZ_INS_SRDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRK, SYSZ_INS_SRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SRL, SYSZ_INS_SRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRLG, SYSZ_INS_SRLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRLK, SYSZ_INS_SRLK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_SRNM, SYSZ_INS_SRNM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRNMB, SYSZ_INS_SRNMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_SRNMT, SYSZ_INS_SRNMT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRP, SYSZ_INS_SRP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRST, SYSZ_INS_SRST,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRSTU, SYSZ_INS_SRSTU,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SRXT, SYSZ_INS_SRXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SSAIR, SYSZ_INS_SSAIR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SSAR, SYSZ_INS_SSAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SSCH, SYSZ_INS_SSCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SSKE, SYSZ_INS_SSKE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SSKEOpt, SYSZ_INS_SSKE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SSM, SYSZ_INS_SSM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ST, SYSZ_INS_ST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STAM, SYSZ_INS_STAM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STAMY, SYSZ_INS_STAMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STAP, SYSZ_INS_STAP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STC, SYSZ_INS_STC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCH, SYSZ_INS_STCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_STCK, SYSZ_INS_STCK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCKC, SYSZ_INS_STCKC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCKE, SYSZ_INS_STCKE,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCKF, SYSZ_INS_STCKF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCM, SYSZ_INS_STCM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCMH, SYSZ_INS_STCMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCMY, SYSZ_INS_STCMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCPS, SYSZ_INS_STCPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCRW, SYSZ_INS_STCRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCTG, SYSZ_INS_STCTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCTL, SYSZ_INS_STCTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STCY, SYSZ_INS_STCY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STD, SYSZ_INS_STD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STDY, SYSZ_INS_STDY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STE, SYSZ_INS_STE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STEY, SYSZ_INS_STEY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STFH, SYSZ_INS_STFH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_STFL, SYSZ_INS_STFL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STFLE, SYSZ_INS_STFLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { SYSZ_REG_0, SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STFPC, SYSZ_INS_STFPC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STG, SYSZ_INS_STG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STGRL, SYSZ_INS_STGRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STGSC, SYSZ_INS_STGSC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_GUARDEDSTORAGE, 0 }, 0, 0
#endif
},
{
	SystemZ_STH, SYSZ_INS_STH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STHH, SYSZ_INS_STHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_HIGHWORD, 0 }, 0, 0
#endif
},
{
	SystemZ_STHRL, SYSZ_INS_STHRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STHY, SYSZ_INS_STHY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STIDP, SYSZ_INS_STIDP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STM, SYSZ_INS_STM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STMG, SYSZ_INS_STMG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STMH, SYSZ_INS_STMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STMY, SYSZ_INS_STMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STNSM, SYSZ_INS_STNSM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsm, SYSZ_INS_STOC,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmE, SYSZ_INS_STOCE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmH, SYSZ_INS_STOCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmHE, SYSZ_INS_STOCHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmL, SYSZ_INS_STOCL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmLE, SYSZ_INS_STOCLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmLH, SYSZ_INS_STOCLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmM, SYSZ_INS_STOCM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNE, SYSZ_INS_STOCNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNH, SYSZ_INS_STOCNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNHE, SYSZ_INS_STOCNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNL, SYSZ_INS_STOCNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNLE, SYSZ_INS_STOCNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNLH, SYSZ_INS_STOCNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNM, SYSZ_INS_STOCNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNO, SYSZ_INS_STOCNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNP, SYSZ_INS_STOCNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmNZ, SYSZ_INS_STOCNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmO, SYSZ_INS_STOCO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmP, SYSZ_INS_STOCP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCAsmZ, SYSZ_INS_STOCZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsm, SYSZ_INS_STOCFH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmE, SYSZ_INS_STOCFHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmH, SYSZ_INS_STOCFHH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmHE, SYSZ_INS_STOCFHHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmL, SYSZ_INS_STOCFHL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmLE, SYSZ_INS_STOCFHLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmLH, SYSZ_INS_STOCFHLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmM, SYSZ_INS_STOCFHM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNE, SYSZ_INS_STOCFHNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNH, SYSZ_INS_STOCFHNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNHE, SYSZ_INS_STOCFHNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNL, SYSZ_INS_STOCFHNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNLE, SYSZ_INS_STOCFHNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNLH, SYSZ_INS_STOCFHNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNM, SYSZ_INS_STOCFHNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNO, SYSZ_INS_STOCFHNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNP, SYSZ_INS_STOCFHNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmNZ, SYSZ_INS_STOCFHNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmO, SYSZ_INS_STOCFHO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmP, SYSZ_INS_STOCFHP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCFHAsmZ, SYSZ_INS_STOCFHZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND2, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsm, SYSZ_INS_STOCG,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmE, SYSZ_INS_STOCGE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmH, SYSZ_INS_STOCGH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmHE, SYSZ_INS_STOCGHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmL, SYSZ_INS_STOCGL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmLE, SYSZ_INS_STOCGLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmLH, SYSZ_INS_STOCGLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmM, SYSZ_INS_STOCGM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNE, SYSZ_INS_STOCGNE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNH, SYSZ_INS_STOCGNH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNHE, SYSZ_INS_STOCGNHE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNL, SYSZ_INS_STOCGNL,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNLE, SYSZ_INS_STOCGNLE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNLH, SYSZ_INS_STOCGNLH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNM, SYSZ_INS_STOCGNM,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNO, SYSZ_INS_STOCGNO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNP, SYSZ_INS_STOCGNP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmNZ, SYSZ_INS_STOCGNZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmO, SYSZ_INS_STOCGO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmP, SYSZ_INS_STOCGP,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOCGAsmZ, SYSZ_INS_STOCGZ,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_CC, 0 }, { 0 }, { SYSZ_GRP_LOADSTOREONCOND, 0 }, 0, 0
#endif
},
{
	SystemZ_STOSM, SYSZ_INS_STOSM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STPQ, SYSZ_INS_STPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STPT, SYSZ_INS_STPT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STPX, SYSZ_INS_STPX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STRAG, SYSZ_INS_STRAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STRL, SYSZ_INS_STRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STRV, SYSZ_INS_STRV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STRVG, SYSZ_INS_STRVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STRVH, SYSZ_INS_STRVH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STSCH, SYSZ_INS_STSCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STSI, SYSZ_INS_STSI,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_0, SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STURA, SYSZ_INS_STURA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STURG, SYSZ_INS_STURG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_STY, SYSZ_INS_STY,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SU, SYSZ_INS_SU,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SUR, SYSZ_INS_SUR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SVC, SYSZ_INS_SVC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SW, SYSZ_INS_SW,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SWR, SYSZ_INS_SWR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SXBR, SYSZ_INS_SXBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SXR, SYSZ_INS_SXR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SXTR, SYSZ_INS_SXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_SXTRA, SYSZ_INS_SXTRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_FPEXTENSION, 0 }, 0, 0
#endif
},
{
	SystemZ_SY, SYSZ_INS_SY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TABORT, SYSZ_INS_TABORT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_TRANSACTIONALEXECUTION, 0 }, 0, 0
#endif
},
{
	SystemZ_TAM, SYSZ_INS_TAM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TAR, SYSZ_INS_TAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TB, SYSZ_INS_TB,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { SYSZ_REG_0, SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TBDR, SYSZ_INS_TBDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TBEDR, SYSZ_INS_TBEDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TBEGIN, SYSZ_INS_TBEGIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_TRANSACTIONALEXECUTION, 0 }, 0, 0
#endif
},
{
	SystemZ_TBEGINC, SYSZ_INS_TBEGINC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_TRANSACTIONALEXECUTION, 0 }, 0, 0
#endif
},
{
	SystemZ_TCDB, SYSZ_INS_TCDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TCEB, SYSZ_INS_TCEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TCXB, SYSZ_INS_TCXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TDCDT, SYSZ_INS_TDCDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TDCET, SYSZ_INS_TDCET,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TDCXT, SYSZ_INS_TDCXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TDGDT, SYSZ_INS_TDGDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TDGET, SYSZ_INS_TDGET,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TDGXT, SYSZ_INS_TDGXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TEND, SYSZ_INS_TEND,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_TRANSACTIONALEXECUTION, 0 }, 0, 0
#endif
},
{
	SystemZ_THDER, SYSZ_INS_THDER,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_THDR, SYSZ_INS_THDR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TM, SYSZ_INS_TM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMHH, SYSZ_INS_TMHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMHL, SYSZ_INS_TMHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMLH, SYSZ_INS_TMLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMLL, SYSZ_INS_TMLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TMY, SYSZ_INS_TMY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TP, SYSZ_INS_TP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TPI, SYSZ_INS_TPI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TPROT, SYSZ_INS_TPROT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TR, SYSZ_INS_TR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRACE, SYSZ_INS_TRACE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRACG, SYSZ_INS_TRACG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRAP2, SYSZ_INS_TRAP2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRAP4, SYSZ_INS_TRAP4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRE, SYSZ_INS_TRE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TROO, SYSZ_INS_TROO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TROOOpt, SYSZ_INS_TROO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TROT, SYSZ_INS_TROT,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TROTOpt, SYSZ_INS_TROT,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRT, SYSZ_INS_TRT,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, SYSZ_REG_0, SYSZ_REG_1, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTE, SYSZ_INS_TRTE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTEOpt, SYSZ_INS_TRTE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTO, SYSZ_INS_TRTO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTOOpt, SYSZ_INS_TRTO,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTR, SYSZ_INS_TRTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, SYSZ_REG_0, SYSZ_REG_1, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTRE, SYSZ_INS_TRTRE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTREOpt, SYSZ_INS_TRTRE,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTT, SYSZ_INS_TRTT,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TRTTOpt, SYSZ_INS_TRTT,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TS, SYSZ_INS_TS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_TSCH, SYSZ_INS_TSCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_UNPK, SYSZ_INS_UNPK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_UNPKA, SYSZ_INS_UNPKA,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_UNPKU, SYSZ_INS_UNPKU,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_UPT, SYSZ_INS_UPT,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_0, SYSZ_REG_1, SYSZ_REG_2, SYSZ_REG_3, SYSZ_REG_4, SYSZ_REG_5, 0 }, { SYSZ_REG_CC, SYSZ_REG_0, SYSZ_REG_1, SYSZ_REG_2, SYSZ_REG_3, SYSZ_REG_5, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_VA, SYSZ_INS_VA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAB, SYSZ_INS_VAB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAC, SYSZ_INS_VAC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACC, SYSZ_INS_VACC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACCB, SYSZ_INS_VACCB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACCC, SYSZ_INS_VACCC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACCCQ, SYSZ_INS_VACCCQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACCF, SYSZ_INS_VACCF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACCG, SYSZ_INS_VACCG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACCH, SYSZ_INS_VACCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACCQ, SYSZ_INS_VACCQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VACQ, SYSZ_INS_VACQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAF, SYSZ_INS_VAF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAG, SYSZ_INS_VAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAH, SYSZ_INS_VAH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAP, SYSZ_INS_VAP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VAQ, SYSZ_INS_VAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVG, SYSZ_INS_VAVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGB, SYSZ_INS_VAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGF, SYSZ_INS_VAVGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGG, SYSZ_INS_VAVGG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGH, SYSZ_INS_VAVGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGL, SYSZ_INS_VAVGL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGLB, SYSZ_INS_VAVGLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGLF, SYSZ_INS_VAVGLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGLG, SYSZ_INS_VAVGLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VAVGLH, SYSZ_INS_VAVGLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VBPERM, SYSZ_INS_VBPERM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VCDG, SYSZ_INS_VCDG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCDGB, SYSZ_INS_VCDGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCDLG, SYSZ_INS_VCDLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCDLGB, SYSZ_INS_VCDLGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQ, SYSZ_INS_VCEQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQB, SYSZ_INS_VCEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQBS, SYSZ_INS_VCEQBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQF, SYSZ_INS_VCEQF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQFS, SYSZ_INS_VCEQFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQG, SYSZ_INS_VCEQG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQGS, SYSZ_INS_VCEQGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQH, SYSZ_INS_VCEQH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCEQHS, SYSZ_INS_VCEQHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCGD, SYSZ_INS_VCGD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCGDB, SYSZ_INS_VCGDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCH, SYSZ_INS_VCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHB, SYSZ_INS_VCHB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHBS, SYSZ_INS_VCHBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHF, SYSZ_INS_VCHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHFS, SYSZ_INS_VCHFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHG, SYSZ_INS_VCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHGS, SYSZ_INS_VCHGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHH, SYSZ_INS_VCHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHHS, SYSZ_INS_VCHHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHL, SYSZ_INS_VCHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHLB, SYSZ_INS_VCHLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHLBS, SYSZ_INS_VCHLBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHLF, SYSZ_INS_VCHLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHLFS, SYSZ_INS_VCHLFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHLG, SYSZ_INS_VCHLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHLGS, SYSZ_INS_VCHLGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHLH, SYSZ_INS_VCHLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCHLHS, SYSZ_INS_VCHLHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCKSM, SYSZ_INS_VCKSM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCLGD, SYSZ_INS_VCLGD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCLGDB, SYSZ_INS_VCLGDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCLZ, SYSZ_INS_VCLZ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCLZB, SYSZ_INS_VCLZB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCLZF, SYSZ_INS_VCLZF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCLZG, SYSZ_INS_VCLZG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCLZH, SYSZ_INS_VCLZH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCP, SYSZ_INS_VCP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VCTZ, SYSZ_INS_VCTZ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCTZB, SYSZ_INS_VCTZB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCTZF, SYSZ_INS_VCTZF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCTZG, SYSZ_INS_VCTZG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCTZH, SYSZ_INS_VCTZH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VCVB, SYSZ_INS_VCVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VCVBG, SYSZ_INS_VCVBG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VCVD, SYSZ_INS_VCVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VCVDG, SYSZ_INS_VCVDG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VDP, SYSZ_INS_VDP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VEC, SYSZ_INS_VEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECB, SYSZ_INS_VECB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECF, SYSZ_INS_VECF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECG, SYSZ_INS_VECG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECH, SYSZ_INS_VECH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECL, SYSZ_INS_VECL,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECLB, SYSZ_INS_VECLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECLF, SYSZ_INS_VECLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECLG, SYSZ_INS_VECLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VECLH, SYSZ_INS_VECLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERIM, SYSZ_INS_VERIM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERIMB, SYSZ_INS_VERIMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERIMF, SYSZ_INS_VERIMF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERIMG, SYSZ_INS_VERIMG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERIMH, SYSZ_INS_VERIMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLL, SYSZ_INS_VERLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLB, SYSZ_INS_VERLLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLF, SYSZ_INS_VERLLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLG, SYSZ_INS_VERLLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLH, SYSZ_INS_VERLLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLV, SYSZ_INS_VERLLV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLVB, SYSZ_INS_VERLLVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLVF, SYSZ_INS_VERLLVF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLVG, SYSZ_INS_VERLLVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VERLLVH, SYSZ_INS_VERLLVH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESL, SYSZ_INS_VESL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLB, SYSZ_INS_VESLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLF, SYSZ_INS_VESLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLG, SYSZ_INS_VESLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLH, SYSZ_INS_VESLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLV, SYSZ_INS_VESLV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLVB, SYSZ_INS_VESLVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLVF, SYSZ_INS_VESLVF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLVG, SYSZ_INS_VESLVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESLVH, SYSZ_INS_VESLVH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRA, SYSZ_INS_VESRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAB, SYSZ_INS_VESRAB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAF, SYSZ_INS_VESRAF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAG, SYSZ_INS_VESRAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAH, SYSZ_INS_VESRAH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAV, SYSZ_INS_VESRAV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAVB, SYSZ_INS_VESRAVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAVF, SYSZ_INS_VESRAVF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAVG, SYSZ_INS_VESRAVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRAVH, SYSZ_INS_VESRAVH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRL, SYSZ_INS_VESRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLB, SYSZ_INS_VESRLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLF, SYSZ_INS_VESRLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLG, SYSZ_INS_VESRLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLH, SYSZ_INS_VESRLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLV, SYSZ_INS_VESRLV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLVB, SYSZ_INS_VESRLVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLVF, SYSZ_INS_VESRLVF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLVG, SYSZ_INS_VESRLVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VESRLVH, SYSZ_INS_VESRLVH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFA, SYSZ_INS_VFA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFADB, SYSZ_INS_VFADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAE, SYSZ_INS_VFAE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEB, SYSZ_INS_VFAEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEBS, SYSZ_INS_VFAEBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEF, SYSZ_INS_VFAEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEFS, SYSZ_INS_VFAEFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEH, SYSZ_INS_VFAEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEHS, SYSZ_INS_VFAEHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEZB, SYSZ_INS_VFAEZB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEZBS, SYSZ_INS_VFAEZBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEZF, SYSZ_INS_VFAEZF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEZFS, SYSZ_INS_VFAEZFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEZH, SYSZ_INS_VFAEZH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFAEZHS, SYSZ_INS_VFAEZHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFASB, SYSZ_INS_VFASB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCE, SYSZ_INS_VFCE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCEDB, SYSZ_INS_VFCEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCEDBS, SYSZ_INS_VFCEDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCESB, SYSZ_INS_VFCESB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCESBS, SYSZ_INS_VFCESBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCH, SYSZ_INS_VFCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHDB, SYSZ_INS_VFCHDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHDBS, SYSZ_INS_VFCHDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHE, SYSZ_INS_VFCHE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHEDB, SYSZ_INS_VFCHEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHEDBS, SYSZ_INS_VFCHEDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHESB, SYSZ_INS_VFCHESB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHESBS, SYSZ_INS_VFCHESBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHSB, SYSZ_INS_VFCHSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFCHSBS, SYSZ_INS_VFCHSBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFD, SYSZ_INS_VFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFDDB, SYSZ_INS_VFDDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFDSB, SYSZ_INS_VFDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEE, SYSZ_INS_VFEE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEB, SYSZ_INS_VFEEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEBS, SYSZ_INS_VFEEBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEF, SYSZ_INS_VFEEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEFS, SYSZ_INS_VFEEFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEH, SYSZ_INS_VFEEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEHS, SYSZ_INS_VFEEHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEZB, SYSZ_INS_VFEEZB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEZBS, SYSZ_INS_VFEEZBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEZF, SYSZ_INS_VFEEZF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEZFS, SYSZ_INS_VFEEZFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEZH, SYSZ_INS_VFEEZH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFEEZHS, SYSZ_INS_VFEEZHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENE, SYSZ_INS_VFENE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEB, SYSZ_INS_VFENEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEBS, SYSZ_INS_VFENEBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEF, SYSZ_INS_VFENEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEFS, SYSZ_INS_VFENEFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEH, SYSZ_INS_VFENEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEHS, SYSZ_INS_VFENEHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEZB, SYSZ_INS_VFENEZB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEZBS, SYSZ_INS_VFENEZBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEZF, SYSZ_INS_VFENEZF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEZFS, SYSZ_INS_VFENEZFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEZH, SYSZ_INS_VFENEZH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFENEZHS, SYSZ_INS_VFENEZHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFI, SYSZ_INS_VFI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFIDB, SYSZ_INS_VFIDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFISB, SYSZ_INS_VFISB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKEDB, SYSZ_INS_VFKEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKEDBS, SYSZ_INS_VFKEDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKESB, SYSZ_INS_VFKESB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKESBS, SYSZ_INS_VFKESBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKHDB, SYSZ_INS_VFKHDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKHDBS, SYSZ_INS_VFKHDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKHEDB, SYSZ_INS_VFKHEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKHEDBS, SYSZ_INS_VFKHEDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKHESB, SYSZ_INS_VFKHESB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKHESBS, SYSZ_INS_VFKHESBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKHSB, SYSZ_INS_VFKHSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFKHSBS, SYSZ_INS_VFKHSBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLCDB, SYSZ_INS_VFLCDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLCSB, SYSZ_INS_VFLCSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLL, SYSZ_INS_VFLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLLS, SYSZ_INS_VFLLS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLNDB, SYSZ_INS_VFLNDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLNSB, SYSZ_INS_VFLNSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLPDB, SYSZ_INS_VFLPDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLPSB, SYSZ_INS_VFLPSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLR, SYSZ_INS_VFLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFLRD, SYSZ_INS_VFLRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFM, SYSZ_INS_VFM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMA, SYSZ_INS_VFMA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMADB, SYSZ_INS_VFMADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMASB, SYSZ_INS_VFMASB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMAX, SYSZ_INS_VFMAX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMAXDB, SYSZ_INS_VFMAXDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMAXSB, SYSZ_INS_VFMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMDB, SYSZ_INS_VFMDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMIN, SYSZ_INS_VFMIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMINDB, SYSZ_INS_VFMINDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMINSB, SYSZ_INS_VFMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMS, SYSZ_INS_VFMS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMSB, SYSZ_INS_VFMSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMSDB, SYSZ_INS_VFMSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFMSSB, SYSZ_INS_VFMSSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFNMA, SYSZ_INS_VFNMA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFNMADB, SYSZ_INS_VFNMADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFNMASB, SYSZ_INS_VFNMASB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFNMS, SYSZ_INS_VFNMS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFNMSDB, SYSZ_INS_VFNMSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFNMSSB, SYSZ_INS_VFNMSSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFPSO, SYSZ_INS_VFPSO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFPSODB, SYSZ_INS_VFPSODB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFPSOSB, SYSZ_INS_VFPSOSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFS, SYSZ_INS_VFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFSDB, SYSZ_INS_VFSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFSQ, SYSZ_INS_VFSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFSQDB, SYSZ_INS_VFSQDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFSQSB, SYSZ_INS_VFSQSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFSSB, SYSZ_INS_VFSSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VFTCI, SYSZ_INS_VFTCI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFTCIDB, SYSZ_INS_VFTCIDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VFTCISB, SYSZ_INS_VFTCISB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VGBM, SYSZ_INS_VGBM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGEF, SYSZ_INS_VGEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGEG, SYSZ_INS_VGEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFM, SYSZ_INS_VGFM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMA, SYSZ_INS_VGFMA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMAB, SYSZ_INS_VGFMAB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMAF, SYSZ_INS_VGFMAF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMAG, SYSZ_INS_VGFMAG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMAH, SYSZ_INS_VGFMAH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMB, SYSZ_INS_VGFMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMF, SYSZ_INS_VGFMF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMG, SYSZ_INS_VGFMG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGFMH, SYSZ_INS_VGFMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGM, SYSZ_INS_VGM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGMB, SYSZ_INS_VGMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGMF, SYSZ_INS_VGMF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGMG, SYSZ_INS_VGMG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VGMH, SYSZ_INS_VGMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VISTR, SYSZ_INS_VISTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VISTRB, SYSZ_INS_VISTRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VISTRBS, SYSZ_INS_VISTRBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VISTRF, SYSZ_INS_VISTRF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VISTRFS, SYSZ_INS_VISTRFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VISTRH, SYSZ_INS_VISTRH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VISTRHS, SYSZ_INS_VISTRHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VL, SYSZ_INS_VL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLBB, SYSZ_INS_VLBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLC, SYSZ_INS_VLC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLCB, SYSZ_INS_VLCB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLCF, SYSZ_INS_VLCF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLCG, SYSZ_INS_VLCG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLCH, SYSZ_INS_VLCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLDE, SYSZ_INS_VLDE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLDEB, SYSZ_INS_VLDEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEB, SYSZ_INS_VLEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLED, SYSZ_INS_VLED,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEDB, SYSZ_INS_VLEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEF, SYSZ_INS_VLEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEG, SYSZ_INS_VLEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEH, SYSZ_INS_VLEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEIB, SYSZ_INS_VLEIB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEIF, SYSZ_INS_VLEIF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEIG, SYSZ_INS_VLEIG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLEIH, SYSZ_INS_VLEIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLGV, SYSZ_INS_VLGV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLGVB, SYSZ_INS_VLGVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLGVF, SYSZ_INS_VLGVF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLGVG, SYSZ_INS_VLGVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLGVH, SYSZ_INS_VLGVH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLIP, SYSZ_INS_VLIP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VLL, SYSZ_INS_VLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLLEZ, SYSZ_INS_VLLEZ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLLEZB, SYSZ_INS_VLLEZB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLLEZF, SYSZ_INS_VLLEZF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLLEZG, SYSZ_INS_VLLEZG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLLEZH, SYSZ_INS_VLLEZH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLLEZLF, SYSZ_INS_VLLEZLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VLM, SYSZ_INS_VLM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLP, SYSZ_INS_VLP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLPB, SYSZ_INS_VLPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLPF, SYSZ_INS_VLPF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLPG, SYSZ_INS_VLPG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLPH, SYSZ_INS_VLPH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLR, SYSZ_INS_VLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLREP, SYSZ_INS_VLREP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLREPB, SYSZ_INS_VLREPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLREPF, SYSZ_INS_VLREPF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLREPG, SYSZ_INS_VLREPG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLREPH, SYSZ_INS_VLREPH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLRL, SYSZ_INS_VLRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VLRLR, SYSZ_INS_VLRLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VLVG, SYSZ_INS_VLVG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLVGB, SYSZ_INS_VLVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLVGF, SYSZ_INS_VLVGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLVGG, SYSZ_INS_VLVGG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLVGH, SYSZ_INS_VLVGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VLVGP, SYSZ_INS_VLVGP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAE, SYSZ_INS_VMAE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAEB, SYSZ_INS_VMAEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAEF, SYSZ_INS_VMAEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAEH, SYSZ_INS_VMAEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAH, SYSZ_INS_VMAH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAHB, SYSZ_INS_VMAHB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAHF, SYSZ_INS_VMAHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAHH, SYSZ_INS_VMAHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAL, SYSZ_INS_VMAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALB, SYSZ_INS_VMALB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALE, SYSZ_INS_VMALE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALEB, SYSZ_INS_VMALEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALEF, SYSZ_INS_VMALEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALEH, SYSZ_INS_VMALEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALF, SYSZ_INS_VMALF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALH, SYSZ_INS_VMALH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALHB, SYSZ_INS_VMALHB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALHF, SYSZ_INS_VMALHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALHH, SYSZ_INS_VMALHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALHW, SYSZ_INS_VMALHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALO, SYSZ_INS_VMALO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALOB, SYSZ_INS_VMALOB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALOF, SYSZ_INS_VMALOF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMALOH, SYSZ_INS_VMALOH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAO, SYSZ_INS_VMAO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAOB, SYSZ_INS_VMAOB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAOF, SYSZ_INS_VMAOF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMAOH, SYSZ_INS_VMAOH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VME, SYSZ_INS_VME,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMEB, SYSZ_INS_VMEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMEF, SYSZ_INS_VMEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMEH, SYSZ_INS_VMEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMH, SYSZ_INS_VMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMHB, SYSZ_INS_VMHB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMHF, SYSZ_INS_VMHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMHH, SYSZ_INS_VMHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VML, SYSZ_INS_VML,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLB, SYSZ_INS_VMLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLE, SYSZ_INS_VMLE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLEB, SYSZ_INS_VMLEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLEF, SYSZ_INS_VMLEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLEH, SYSZ_INS_VMLEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLF, SYSZ_INS_VMLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLH, SYSZ_INS_VMLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLHB, SYSZ_INS_VMLHB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLHF, SYSZ_INS_VMLHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLHH, SYSZ_INS_VMLHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLHW, SYSZ_INS_VMLHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLO, SYSZ_INS_VMLO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLOB, SYSZ_INS_VMLOB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLOF, SYSZ_INS_VMLOF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMLOH, SYSZ_INS_VMLOH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMN, SYSZ_INS_VMN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNB, SYSZ_INS_VMNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNF, SYSZ_INS_VMNF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNG, SYSZ_INS_VMNG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNH, SYSZ_INS_VMNH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNL, SYSZ_INS_VMNL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNLB, SYSZ_INS_VMNLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNLF, SYSZ_INS_VMNLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNLG, SYSZ_INS_VMNLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMNLH, SYSZ_INS_VMNLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMO, SYSZ_INS_VMO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMOB, SYSZ_INS_VMOB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMOF, SYSZ_INS_VMOF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMOH, SYSZ_INS_VMOH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMP, SYSZ_INS_VMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRH, SYSZ_INS_VMRH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRHB, SYSZ_INS_VMRHB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRHF, SYSZ_INS_VMRHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRHG, SYSZ_INS_VMRHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRHH, SYSZ_INS_VMRHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRL, SYSZ_INS_VMRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRLB, SYSZ_INS_VMRLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRLF, SYSZ_INS_VMRLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRLG, SYSZ_INS_VMRLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMRLH, SYSZ_INS_VMRLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMSL, SYSZ_INS_VMSL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VMSLG, SYSZ_INS_VMSLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VMSP, SYSZ_INS_VMSP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VMX, SYSZ_INS_VMX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXB, SYSZ_INS_VMXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXF, SYSZ_INS_VMXF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXG, SYSZ_INS_VMXG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXH, SYSZ_INS_VMXH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXL, SYSZ_INS_VMXL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXLB, SYSZ_INS_VMXLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXLF, SYSZ_INS_VMXLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXLG, SYSZ_INS_VMXLG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VMXLH, SYSZ_INS_VMXLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VN, SYSZ_INS_VN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VNC, SYSZ_INS_VNC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VNN, SYSZ_INS_VNN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VNO, SYSZ_INS_VNO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VNX, SYSZ_INS_VNX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VO, SYSZ_INS_VO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VOC, SYSZ_INS_VOC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VONE, SYSZ_INS_VONE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPDI, SYSZ_INS_VPDI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPERM, SYSZ_INS_VPERM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPK, SYSZ_INS_VPK,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKF, SYSZ_INS_VPKF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKG, SYSZ_INS_VPKG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKH, SYSZ_INS_VPKH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKLS, SYSZ_INS_VPKLS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKLSF, SYSZ_INS_VPKLSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKLSFS, SYSZ_INS_VPKLSFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKLSG, SYSZ_INS_VPKLSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKLSGS, SYSZ_INS_VPKLSGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKLSH, SYSZ_INS_VPKLSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKLSHS, SYSZ_INS_VPKLSHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKS, SYSZ_INS_VPKS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKSF, SYSZ_INS_VPKSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKSFS, SYSZ_INS_VPKSFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKSG, SYSZ_INS_VPKSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKSGS, SYSZ_INS_VPKSGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKSH, SYSZ_INS_VPKSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKSHS, SYSZ_INS_VPKSHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPKZ, SYSZ_INS_VPKZ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VPOPCT, SYSZ_INS_VPOPCT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VPOPCTB, SYSZ_INS_VPOPCTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VPOPCTF, SYSZ_INS_VPOPCTF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VPOPCTG, SYSZ_INS_VPOPCTG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VPOPCTH, SYSZ_INS_VPOPCTH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_VPSOP, SYSZ_INS_VPSOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VREP, SYSZ_INS_VREP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPB, SYSZ_INS_VREPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPF, SYSZ_INS_VREPF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPG, SYSZ_INS_VREPG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPH, SYSZ_INS_VREPH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPI, SYSZ_INS_VREPI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPIB, SYSZ_INS_VREPIB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPIF, SYSZ_INS_VREPIF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPIG, SYSZ_INS_VREPIG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VREPIH, SYSZ_INS_VREPIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VRP, SYSZ_INS_VRP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VS, SYSZ_INS_VS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSB, SYSZ_INS_VSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSBCBI, SYSZ_INS_VSBCBI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSBCBIQ, SYSZ_INS_VSBCBIQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSBI, SYSZ_INS_VSBI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSBIQ, SYSZ_INS_VSBIQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSCBI, SYSZ_INS_VSCBI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSCBIB, SYSZ_INS_VSCBIB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSCBIF, SYSZ_INS_VSCBIF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSCBIG, SYSZ_INS_VSCBIG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSCBIH, SYSZ_INS_VSCBIH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSCBIQ, SYSZ_INS_VSCBIQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSCEF, SYSZ_INS_VSCEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSCEG, SYSZ_INS_VSCEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSDP, SYSZ_INS_VSDP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VSEG, SYSZ_INS_VSEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSEGB, SYSZ_INS_VSEGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSEGF, SYSZ_INS_VSEGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSEGH, SYSZ_INS_VSEGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSEL, SYSZ_INS_VSEL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSF, SYSZ_INS_VSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSG, SYSZ_INS_VSG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSH, SYSZ_INS_VSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSL, SYSZ_INS_VSL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSLB, SYSZ_INS_VSLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSLDB, SYSZ_INS_VSLDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSP, SYSZ_INS_VSP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VSQ, SYSZ_INS_VSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSRA, SYSZ_INS_VSRA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSRAB, SYSZ_INS_VSRAB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSRL, SYSZ_INS_VSRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSRLB, SYSZ_INS_VSRLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSRP, SYSZ_INS_VSRP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VST, SYSZ_INS_VST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTEB, SYSZ_INS_VSTEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTEF, SYSZ_INS_VSTEF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTEG, SYSZ_INS_VSTEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTEH, SYSZ_INS_VSTEH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTL, SYSZ_INS_VSTL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTM, SYSZ_INS_VSTM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRC, SYSZ_INS_VSTRC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCB, SYSZ_INS_VSTRCB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCBS, SYSZ_INS_VSTRCBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCF, SYSZ_INS_VSTRCF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCFS, SYSZ_INS_VSTRCFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCH, SYSZ_INS_VSTRCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCHS, SYSZ_INS_VSTRCHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCZB, SYSZ_INS_VSTRCZB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCZBS, SYSZ_INS_VSTRCZBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCZF, SYSZ_INS_VSTRCZF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCZFS, SYSZ_INS_VSTRCZFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCZH, SYSZ_INS_VSTRCZH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRCZHS, SYSZ_INS_VSTRCZHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRL, SYSZ_INS_VSTRL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VSTRLR, SYSZ_INS_VSTRLR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUM, SYSZ_INS_VSUM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUMB, SYSZ_INS_VSUMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUMG, SYSZ_INS_VSUMG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUMGF, SYSZ_INS_VSUMGF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUMGH, SYSZ_INS_VSUMGH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUMH, SYSZ_INS_VSUMH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUMQ, SYSZ_INS_VSUMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUMQF, SYSZ_INS_VSUMQF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VSUMQG, SYSZ_INS_VSUMQG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VTM, SYSZ_INS_VTM,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VTP, SYSZ_INS_VTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPH, SYSZ_INS_VUPH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPHB, SYSZ_INS_VUPHB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPHF, SYSZ_INS_VUPHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPHH, SYSZ_INS_VUPHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPKZ, SYSZ_INS_VUPKZ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORPACKEDDECIMAL, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPL, SYSZ_INS_VUPL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLB, SYSZ_INS_VUPLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLF, SYSZ_INS_VUPLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLH, SYSZ_INS_VUPLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLHB, SYSZ_INS_VUPLHB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLHF, SYSZ_INS_VUPLHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLHH, SYSZ_INS_VUPLHH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLHW, SYSZ_INS_VUPLHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLL, SYSZ_INS_VUPLL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLLB, SYSZ_INS_VUPLLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLLF, SYSZ_INS_VUPLLF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VUPLLH, SYSZ_INS_VUPLLH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VX, SYSZ_INS_VX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_VZERO, SYSZ_INS_VZERO,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WCDGB, SYSZ_INS_WCDGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WCDLGB, SYSZ_INS_WCDLGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WCGDB, SYSZ_INS_WCGDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WCLGDB, SYSZ_INS_WCLGDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFADB, SYSZ_INS_WFADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFASB, SYSZ_INS_WFASB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFAXB, SYSZ_INS_WFAXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFC, SYSZ_INS_WFC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCDB, SYSZ_INS_WFCDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCEDB, SYSZ_INS_WFCEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCEDBS, SYSZ_INS_WFCEDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCESB, SYSZ_INS_WFCESB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCESBS, SYSZ_INS_WFCESBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCEXB, SYSZ_INS_WFCEXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCEXBS, SYSZ_INS_WFCEXBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHDB, SYSZ_INS_WFCHDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHDBS, SYSZ_INS_WFCHDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHEDB, SYSZ_INS_WFCHEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHEDBS, SYSZ_INS_WFCHEDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHESB, SYSZ_INS_WFCHESB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHESBS, SYSZ_INS_WFCHESBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHEXB, SYSZ_INS_WFCHEXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHEXBS, SYSZ_INS_WFCHEXBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHSB, SYSZ_INS_WFCHSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHSBS, SYSZ_INS_WFCHSBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHXB, SYSZ_INS_WFCHXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCHXBS, SYSZ_INS_WFCHXBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCSB, SYSZ_INS_WFCSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFCXB, SYSZ_INS_WFCXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFDDB, SYSZ_INS_WFDDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFDSB, SYSZ_INS_WFDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFDXB, SYSZ_INS_WFDXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFIDB, SYSZ_INS_WFIDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFISB, SYSZ_INS_WFISB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFIXB, SYSZ_INS_WFIXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFK, SYSZ_INS_WFK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKDB, SYSZ_INS_WFKDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKEDB, SYSZ_INS_WFKEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKEDBS, SYSZ_INS_WFKEDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKESB, SYSZ_INS_WFKESB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKESBS, SYSZ_INS_WFKESBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKEXB, SYSZ_INS_WFKEXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKEXBS, SYSZ_INS_WFKEXBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHDB, SYSZ_INS_WFKHDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHDBS, SYSZ_INS_WFKHDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHEDB, SYSZ_INS_WFKHEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHEDBS, SYSZ_INS_WFKHEDBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHESB, SYSZ_INS_WFKHESB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHESBS, SYSZ_INS_WFKHESBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHEXB, SYSZ_INS_WFKHEXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHEXBS, SYSZ_INS_WFKHEXBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHSB, SYSZ_INS_WFKHSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHSBS, SYSZ_INS_WFKHSBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHXB, SYSZ_INS_WFKHXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKHXBS, SYSZ_INS_WFKHXBS,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKSB, SYSZ_INS_WFKSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFKXB, SYSZ_INS_WFKXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLCDB, SYSZ_INS_WFLCDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLCSB, SYSZ_INS_WFLCSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLCXB, SYSZ_INS_WFLCXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLLD, SYSZ_INS_WFLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLLS, SYSZ_INS_WFLLS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLNDB, SYSZ_INS_WFLNDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLNSB, SYSZ_INS_WFLNSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLNXB, SYSZ_INS_WFLNXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLPDB, SYSZ_INS_WFLPDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLPSB, SYSZ_INS_WFLPSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLPXB, SYSZ_INS_WFLPXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLRD, SYSZ_INS_WFLRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFLRX, SYSZ_INS_WFLRX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMADB, SYSZ_INS_WFMADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMASB, SYSZ_INS_WFMASB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMAXB, SYSZ_INS_WFMAXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMAXDB, SYSZ_INS_WFMAXDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMAXSB, SYSZ_INS_WFMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMAXXB, SYSZ_INS_WFMAXXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMDB, SYSZ_INS_WFMDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMINDB, SYSZ_INS_WFMINDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMINSB, SYSZ_INS_WFMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMINXB, SYSZ_INS_WFMINXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMSB, SYSZ_INS_WFMSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMSDB, SYSZ_INS_WFMSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMSSB, SYSZ_INS_WFMSSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMSXB, SYSZ_INS_WFMSXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFMXB, SYSZ_INS_WFMXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFNMADB, SYSZ_INS_WFNMADB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFNMASB, SYSZ_INS_WFNMASB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFNMAXB, SYSZ_INS_WFNMAXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFNMSDB, SYSZ_INS_WFNMSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFNMSSB, SYSZ_INS_WFNMSSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFNMSXB, SYSZ_INS_WFNMSXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFPSODB, SYSZ_INS_WFPSODB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFPSOSB, SYSZ_INS_WFPSOSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFPSOXB, SYSZ_INS_WFPSOXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFSDB, SYSZ_INS_WFSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFSQDB, SYSZ_INS_WFSQDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFSQSB, SYSZ_INS_WFSQSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFSQXB, SYSZ_INS_WFSQXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFSSB, SYSZ_INS_WFSSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFSXB, SYSZ_INS_WFSXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFTCIDB, SYSZ_INS_WFTCIDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WFTCISB, SYSZ_INS_WFTCISB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WFTCIXB, SYSZ_INS_WFTCIXB,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_VECTORENHANCEMENTS1, 0 }, 0, 0
#endif
},
{
	SystemZ_WLDEB, SYSZ_INS_WLDEB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_WLEDB, SYSZ_INS_WLEDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { SYSZ_GRP_VECTOR, 0 }, 0, 0
#endif
},
{
	SystemZ_X, SYSZ_INS_X,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XC, SYSZ_INS_XC,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XG, SYSZ_INS_XG,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XGR, SYSZ_INS_XGR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XGRK, SYSZ_INS_XGRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_XI, SYSZ_INS_XI,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XIHF, SYSZ_INS_XIHF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XILF, SYSZ_INS_XILF,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XIY, SYSZ_INS_XIY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XR, SYSZ_INS_XR,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XRK, SYSZ_INS_XRK,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { SYSZ_GRP_DISTINCTOPS, 0 }, 0, 0
#endif
},
{
	SystemZ_XSCH, SYSZ_INS_XSCH,
#ifndef CAPSTONE_DIET
	{ SYSZ_REG_1, 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_XY, SYSZ_INS_XY,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
{
	SystemZ_ZAP, SYSZ_INS_ZAP,
#ifndef CAPSTONE_DIET
	{ 0 }, { SYSZ_REG_CC, 0 }, { 0 }, 0, 0
#endif
},
