/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

static const unsigned char index_x86DisassemblerOneByteOpcodes[] = {
  1,
  2,
  3,
  4,
  5,
  6,
  7,
  0,
  0,
  0,
  0,
  8,
  9,
  10,
  11,
  12,
  13,
  14,
  0,
  0,
  15,
  16,
  17,
  18,
  19,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86DisassemblerOneByteOpcodes[] = {
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 11 },
    { MODRM_ONEENTRY, 12 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 23 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 34 },
    { MODRM_ONEENTRY, 35 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 46 },
    { MODRM_ONEENTRY, 47 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 96 },
    { MODRM_ONEENTRY, 97 },
    { MODRM_SPLITRM, 98 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 103 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 106 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 211 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 215 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 237 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 290 },
    { MODRM_ONEENTRY, 291 },
    { MODRM_SPLITRM, 292 },
    { MODRM_SPLITRM, 294 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 329 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 334 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 400 },
    { MODRM_ONEENTRY, 401 },
    { MODRM_ONEENTRY, 402 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 479 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 484 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 486 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 552 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 573 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 594 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 596 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 602 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 618 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 620 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 622 },
    { MODRM_ONEENTRY, 623 },
    { MODRM_ONEENTRY, 624 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 625 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 627 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 629 },
    { MODRM_ONEENTRY, 630 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 631 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 633 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 635 },
    { MODRM_ONEENTRY, 636 },
    { MODRM_ONEENTRY, 637 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 638 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 640 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 642 },
    { MODRM_ONEENTRY, 643 },
    { MODRM_ONEENTRY, 644 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 645 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 647 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 650 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 652 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 654 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 655 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 657 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 660 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 662 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 664 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 669 },
    { MODRM_ONEENTRY, 670 },
    { MODRM_SPLITRM, 671 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 673 },
    { MODRM_SPLITRM, 674 },
    { MODRM_ONEENTRY, 676 },
    { MODRM_SPLITRM, 677 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 679 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 680 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 681 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 697 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 713 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 715 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 717 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 719 },
    { MODRM_SPLITRM, 721 },
    { MODRM_SPLITRM, 723 },
    { MODRM_SPLITRM, 725 },
    { MODRM_SPLITREG, 727 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 744 },
    { MODRM_ONEENTRY, 745 },
    { MODRM_ONEENTRY, 746 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 747 },
    { MODRM_ONEENTRY, 748 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 749 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 750 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 751 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 752 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 753 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 754 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 755 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 756 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 758 },
    { MODRM_ONEENTRY, 774 },
    { MODRM_ONEENTRY, 775 },
    { MODRM_SPLITRM, 776 },
    { MODRM_SPLITRM, 778 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 780 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 329 },
    { MODRM_ONEENTRY, 796 },
    { MODRM_ONEENTRY, 797 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 334 },
    { MODRM_ONEENTRY, 798 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 799 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 815 },
    { MODRM_ONEENTRY, 400 },
    { MODRM_ONEENTRY, 401 },
    { MODRM_ONEENTRY, 402 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 479 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 831 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 832 },
    { MODRM_ONEENTRY, 833 },
    { MODRM_ONEENTRY, 834 },
    { MODRM_ONEENTRY, 835 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 836 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 837 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 838 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 854 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 11 },
    { MODRM_ONEENTRY, 12 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 23 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 34 },
    { MODRM_ONEENTRY, 35 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 46 },
    { MODRM_ONEENTRY, 47 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 96 },
    { MODRM_ONEENTRY, 97 },
    { MODRM_SPLITRM, 98 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 103 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 106 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 211 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 215 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 237 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 870 },
    { MODRM_ONEENTRY, 871 },
    { MODRM_ONEENTRY, 872 },
    { MODRM_ONEENTRY, 873 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 290 },
    { MODRM_ONEENTRY, 291 },
    { MODRM_SPLITRM, 292 },
    { MODRM_SPLITRM, 294 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 329 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 334 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 400 },
    { MODRM_ONEENTRY, 401 },
    { MODRM_ONEENTRY, 402 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 874 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 484 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 486 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 552 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 618 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 620 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 622 },
    { MODRM_ONEENTRY, 623 },
    { MODRM_ONEENTRY, 624 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 625 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 627 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 629 },
    { MODRM_ONEENTRY, 630 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 631 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 633 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 635 },
    { MODRM_ONEENTRY, 636 },
    { MODRM_ONEENTRY, 637 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 638 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 640 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 642 },
    { MODRM_ONEENTRY, 643 },
    { MODRM_ONEENTRY, 644 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 645 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 647 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 650 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 652 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 654 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 655 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 657 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 660 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 662 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 664 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 665 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 666 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 669 },
    { MODRM_ONEENTRY, 670 },
    { MODRM_SPLITRM, 671 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 673 },
    { MODRM_SPLITRM, 674 },
    { MODRM_ONEENTRY, 676 },
    { MODRM_SPLITRM, 677 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 679 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 680 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 681 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 697 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 713 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 715 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 717 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 719 },
    { MODRM_SPLITRM, 721 },
    { MODRM_SPLITRM, 723 },
    { MODRM_SPLITRM, 725 },
    { MODRM_SPLITREG, 727 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 744 },
    { MODRM_ONEENTRY, 745 },
    { MODRM_ONEENTRY, 746 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 747 },
    { MODRM_ONEENTRY, 748 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 870 },
    { MODRM_ONEENTRY, 875 },
    { MODRM_ONEENTRY, 872 },
    { MODRM_ONEENTRY, 876 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 751 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 752 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 753 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 754 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 755 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 756 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 758 },
    { MODRM_ONEENTRY, 774 },
    { MODRM_ONEENTRY, 775 },
    { MODRM_SPLITRM, 776 },
    { MODRM_SPLITRM, 778 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 780 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 329 },
    { MODRM_ONEENTRY, 796 },
    { MODRM_ONEENTRY, 797 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 334 },
    { MODRM_ONEENTRY, 798 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 799 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 815 },
    { MODRM_ONEENTRY, 400 },
    { MODRM_ONEENTRY, 401 },
    { MODRM_ONEENTRY, 402 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 874 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 831 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 832 },
    { MODRM_ONEENTRY, 833 },
    { MODRM_ONEENTRY, 834 },
    { MODRM_ONEENTRY, 835 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 836 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 837 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 838 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 854 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 11 },
    { MODRM_ONEENTRY, 12 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 23 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 34 },
    { MODRM_ONEENTRY, 35 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 46 },
    { MODRM_ONEENTRY, 47 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 96 },
    { MODRM_ONEENTRY, 97 },
    { MODRM_SPLITRM, 98 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 103 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 106 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 211 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 215 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 237 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 290 },
    { MODRM_ONEENTRY, 291 },
    { MODRM_SPLITRM, 292 },
    { MODRM_SPLITRM, 294 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 329 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 334 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 400 },
    { MODRM_ONEENTRY, 401 },
    { MODRM_ONEENTRY, 402 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 479 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 484 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 486 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 552 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 11 },
    { MODRM_ONEENTRY, 12 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 23 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 34 },
    { MODRM_ONEENTRY, 35 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 46 },
    { MODRM_ONEENTRY, 47 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 96 },
    { MODRM_ONEENTRY, 97 },
    { MODRM_SPLITRM, 98 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 103 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 106 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 211 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 215 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 237 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 290 },
    { MODRM_ONEENTRY, 291 },
    { MODRM_SPLITRM, 292 },
    { MODRM_SPLITRM, 294 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 329 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 334 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 400 },
    { MODRM_ONEENTRY, 401 },
    { MODRM_ONEENTRY, 402 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 479 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 484 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 486 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 552 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 877 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 879 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 882 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 884 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 886 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 887 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 889 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 892 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 894 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 896 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 897 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 899 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 902 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 904 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 906 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 907 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 909 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 912 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 914 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 916 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 917 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 919 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 921 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 939 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 955 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 957 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 959 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 961 },
    { MODRM_SPLITRM, 963 },
    { MODRM_SPLITRM, 965 },
    { MODRM_SPLITRM, 967 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 970 },
    { MODRM_ONEENTRY, 971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 972 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 973 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 974 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 975 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 976 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 977 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 978 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 981 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 997 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 1013 },
    { MODRM_ONEENTRY, 1014 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1015 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 1016 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 1032 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 1048 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 1064 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 877 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 879 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 882 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 884 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 886 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 887 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 889 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 892 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 894 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 896 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 897 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 899 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 902 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 904 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 906 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 907 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 909 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 912 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 914 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 916 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 917 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 673 },
    { MODRM_SPLITRM, 919 },
    { MODRM_ONEENTRY, 676 },
    { MODRM_SPLITRM, 921 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 679 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 680 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 939 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 955 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 957 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 959 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 961 },
    { MODRM_SPLITRM, 963 },
    { MODRM_SPLITRM, 965 },
    { MODRM_SPLITRM, 967 },
    { MODRM_SPLITREG, 727 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 970 },
    { MODRM_ONEENTRY, 971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 747 },
    { MODRM_ONEENTRY, 748 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 1080 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 1081 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 974 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 975 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 976 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 977 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 978 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 981 },
    { MODRM_ONEENTRY, 774 },
    { MODRM_ONEENTRY, 775 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 997 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 1013 },
    { MODRM_ONEENTRY, 1014 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1015 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 1016 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 1032 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 831 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 832 },
    { MODRM_ONEENTRY, 833 },
    { MODRM_ONEENTRY, 834 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 836 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 837 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 1048 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 1082 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 618 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 620 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 622 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 625 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 627 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 631 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 633 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 638 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 640 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 642 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 645 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 647 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 650 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 652 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 654 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 655 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 657 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 660 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 662 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 664 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 673 },
    { MODRM_SPLITRM, 674 },
    { MODRM_ONEENTRY, 676 },
    { MODRM_SPLITRM, 677 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 679 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 680 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 681 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 697 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 713 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 715 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 717 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 719 },
    { MODRM_SPLITRM, 721 },
    { MODRM_SPLITRM, 723 },
    { MODRM_SPLITRM, 725 },
    { MODRM_SPLITREG, 727 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 744 },
    { MODRM_ONEENTRY, 745 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 747 },
    { MODRM_ONEENTRY, 748 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 1098 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 1099 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 751 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 752 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 753 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 754 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 755 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 756 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 758 },
    { MODRM_ONEENTRY, 774 },
    { MODRM_ONEENTRY, 775 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 780 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 796 },
    { MODRM_ONEENTRY, 797 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 798 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 799 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 831 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 832 },
    { MODRM_ONEENTRY, 833 },
    { MODRM_ONEENTRY, 834 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 836 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 837 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 838 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 1100 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 573 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 479 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 602 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 618 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 620 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 622 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 625 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 627 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 631 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 633 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 638 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 640 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 642 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 645 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 647 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 650 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 652 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 654 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 655 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 657 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 660 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 662 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 664 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 673 },
    { MODRM_SPLITRM, 674 },
    { MODRM_ONEENTRY, 676 },
    { MODRM_SPLITRM, 677 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 679 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 680 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 681 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 697 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 713 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 715 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 717 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 719 },
    { MODRM_SPLITRM, 721 },
    { MODRM_SPLITRM, 723 },
    { MODRM_SPLITRM, 725 },
    { MODRM_SPLITREG, 727 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 743 },
    { MODRM_ONEENTRY, 744 },
    { MODRM_ONEENTRY, 745 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 747 },
    { MODRM_ONEENTRY, 748 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 749 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 750 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 751 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 752 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 753 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 754 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 755 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 756 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_ONEENTRY, 757 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 758 },
    { MODRM_ONEENTRY, 774 },
    { MODRM_ONEENTRY, 775 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 780 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 796 },
    { MODRM_ONEENTRY, 797 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 798 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 799 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 831 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 832 },
    { MODRM_ONEENTRY, 833 },
    { MODRM_ONEENTRY, 834 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 836 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 837 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 838 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 1100 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 573 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 594 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 596 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 602 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 573 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 594 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 596 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 602 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 573 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 594 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 596 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 602 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 573 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 594 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 596 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 274 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 312 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 330 },
    { MODRM_ONEENTRY, 331 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 335 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 352 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 384 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 514 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 602 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 877 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 879 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 882 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 884 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 886 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 887 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 889 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 892 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 894 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 896 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 897 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 899 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 902 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 904 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 906 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 907 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 909 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 912 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 914 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 916 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 917 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 919 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 921 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 939 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 955 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 957 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 959 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 961 },
    { MODRM_SPLITRM, 963 },
    { MODRM_SPLITRM, 965 },
    { MODRM_SPLITRM, 967 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 970 },
    { MODRM_ONEENTRY, 971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 972 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 973 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 974 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 975 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 976 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 977 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 978 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 981 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 997 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 1013 },
    { MODRM_ONEENTRY, 1014 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1015 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 1016 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 1032 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 1048 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 1064 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 877 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 879 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 882 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 884 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 886 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 887 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 889 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 892 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 894 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 896 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 897 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 899 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 902 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 904 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 906 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 907 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 909 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 912 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 914 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 916 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 569 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 917 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 571 },
    { MODRM_SPLITRM, 919 },
    { MODRM_ONEENTRY, 572 },
    { MODRM_SPLITRM, 921 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 939 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 955 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 957 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 959 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 961 },
    { MODRM_SPLITRM, 963 },
    { MODRM_SPLITRM, 965 },
    { MODRM_SPLITRM, 967 },
    { MODRM_SPLITREG, 575 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 970 },
    { MODRM_ONEENTRY, 971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 591 },
    { MODRM_ONEENTRY, 592 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 972 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 973 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 974 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 975 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 976 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 977 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 978 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 981 },
    { MODRM_ONEENTRY, 597 },
    { MODRM_ONEENTRY, 598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 997 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 1013 },
    { MODRM_ONEENTRY, 1014 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1015 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 1016 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 1032 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 481 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 483 },
    { MODRM_ONEENTRY, 601 },
    { MODRM_ONEENTRY, 485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 489 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 491 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 1048 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 1064 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 877 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 879 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 882 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 884 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 886 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 887 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 889 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 892 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 894 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 896 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 897 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 899 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 902 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 904 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 906 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 907 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 909 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 912 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 914 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 916 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 568 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 667 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 668 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 917 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 673 },
    { MODRM_SPLITRM, 919 },
    { MODRM_ONEENTRY, 676 },
    { MODRM_SPLITRM, 921 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 679 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 680 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 939 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 955 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 957 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 959 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 961 },
    { MODRM_SPLITRM, 963 },
    { MODRM_SPLITRM, 965 },
    { MODRM_SPLITRM, 967 },
    { MODRM_SPLITREG, 727 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 969 },
    { MODRM_ONEENTRY, 970 },
    { MODRM_ONEENTRY, 971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 747 },
    { MODRM_ONEENTRY, 748 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 593 },
    { MODRM_ONEENTRY, 972 },
    { MODRM_ONEENTRY, 595 },
    { MODRM_ONEENTRY, 973 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 974 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 975 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 976 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 977 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 978 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_SPLITREG, 258 },
    { MODRM_SPLITREG, 981 },
    { MODRM_ONEENTRY, 774 },
    { MODRM_ONEENTRY, 775 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 296 },
    { MODRM_SPLITREG, 997 },
    { MODRM_ONEENTRY, 328 },
    { MODRM_ONEENTRY, 599 },
    { MODRM_ONEENTRY, 1013 },
    { MODRM_ONEENTRY, 1014 },
    { MODRM_ONEENTRY, 332 },
    { MODRM_ONEENTRY, 333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1015 },
    { MODRM_SPLITREG, 336 },
    { MODRM_SPLITREG, 1016 },
    { MODRM_SPLITREG, 368 },
    { MODRM_SPLITREG, 1032 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 404 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 476 },
    { MODRM_ONEENTRY, 477 },
    { MODRM_ONEENTRY, 478 },
    { MODRM_ONEENTRY, 600 },
    { MODRM_ONEENTRY, 480 },
    { MODRM_ONEENTRY, 831 },
    { MODRM_ONEENTRY, 482 },
    { MODRM_ONEENTRY, 832 },
    { MODRM_ONEENTRY, 833 },
    { MODRM_ONEENTRY, 834 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 487 },
    { MODRM_ONEENTRY, 488 },
    { MODRM_ONEENTRY, 836 },
    { MODRM_ONEENTRY, 490 },
    { MODRM_ONEENTRY, 837 },
    { MODRM_ONEENTRY, 492 },
    { MODRM_ONEENTRY, 493 },
    { MODRM_ONEENTRY, 494 },
    { MODRM_ONEENTRY, 495 },
    { MODRM_ONEENTRY, 496 },
    { MODRM_ONEENTRY, 497 },
    { MODRM_SPLITREG, 498 },
    { MODRM_SPLITREG, 1048 },
    { MODRM_ONEENTRY, 530 },
    { MODRM_ONEENTRY, 531 },
    { MODRM_ONEENTRY, 532 },
    { MODRM_ONEENTRY, 533 },
    { MODRM_ONEENTRY, 534 },
    { MODRM_ONEENTRY, 535 },
    { MODRM_SPLITREG, 536 },
    { MODRM_SPLITREG, 1082 },
  } },
};

static const unsigned char index_x86DisassemblerTwoByteOpcodes[] = {
  1,
  2,
  3,
  4,
  5,
  6,
  7,
  0,
  8,
  0,
  9,
  10,
  11,
  12,
  13,
  14,
  15,
  16,
  0,
  17,
  18,
  19,
  20,
  21,
  22,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86DisassemblerTwoByteOpcodes[] = {
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 1132 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1254 },
    { MODRM_SPLITRM, 1256 },
    { MODRM_SPLITRM, 1258 },
    { MODRM_SPLITRM, 1260 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1301 },
    { MODRM_SPLITRM, 1303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1353 },
    { MODRM_ONEENTRY, 1354 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1506 },
    { MODRM_ONEENTRY, 1507 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 1515 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_SPLITRM, 1568 },
    { MODRM_SPLITRM, 1570 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1580 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 1598 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1678 },
    { MODRM_SPLITRM, 1680 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 1515 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_SPLITRM, 1568 },
    { MODRM_SPLITRM, 1570 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1580 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1686 },
    { MODRM_SPLITMISC, 1702 },
    { MODRM_SPLITRM, 1774 },
    { MODRM_SPLITRM, 1776 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1778 },
    { MODRM_SPLITRM, 1794 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1796 },
    { MODRM_SPLITRM, 1798 },
    { MODRM_SPLITRM, 1800 },
    { MODRM_SPLITRM, 1802 },
    { MODRM_SPLITRM, 1254 },
    { MODRM_SPLITRM, 1256 },
    { MODRM_SPLITRM, 1258 },
    { MODRM_SPLITRM, 1260 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1804 },
    { MODRM_SPLITRM, 1806 },
    { MODRM_SPLITRM, 1808 },
    { MODRM_SPLITRM, 1810 },
    { MODRM_SPLITRM, 1812 },
    { MODRM_SPLITRM, 1814 },
    { MODRM_SPLITRM, 1816 },
    { MODRM_SPLITRM, 1818 },
    { MODRM_SPLITRM, 1820 },
    { MODRM_SPLITRM, 1822 },
    { MODRM_SPLITRM, 1824 },
    { MODRM_SPLITRM, 1826 },
    { MODRM_SPLITRM, 1828 },
    { MODRM_SPLITRM, 1830 },
    { MODRM_SPLITRM, 1832 },
    { MODRM_SPLITRM, 1834 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1836 },
    { MODRM_ONEENTRY, 1837 },
    { MODRM_ONEENTRY, 1838 },
    { MODRM_ONEENTRY, 1839 },
    { MODRM_ONEENTRY, 1840 },
    { MODRM_ONEENTRY, 1841 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 1848 },
    { MODRM_ONEENTRY, 1849 },
    { MODRM_ONEENTRY, 1850 },
    { MODRM_ONEENTRY, 1851 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1852 },
    { MODRM_ONEENTRY, 1853 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1854 },
    { MODRM_SPLITRM, 1856 },
    { MODRM_SPLITRM, 1858 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1860 },
    { MODRM_ONEENTRY, 1861 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1862 },
    { MODRM_SPLITRM, 1864 },
    { MODRM_SPLITRM, 1866 },
    { MODRM_SPLITREG, 1868 },
    { MODRM_SPLITRM, 1884 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1886 },
    { MODRM_SPLITRM, 1888 },
    { MODRM_SPLITRM, 1890 },
    { MODRM_SPLITRM, 1892 },
    { MODRM_SPLITRM, 1894 },
    { MODRM_SPLITRM, 1896 },
    { MODRM_SPLITRM, 1898 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1900 },
    { MODRM_SPLITRM, 1916 },
    { MODRM_SPLITRM, 1918 },
    { MODRM_SPLITRM, 1920 },
    { MODRM_SPLITRM, 1922 },
    { MODRM_SPLITRM, 1924 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1926 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1928 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 1132 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1254 },
    { MODRM_SPLITRM, 1256 },
    { MODRM_SPLITRM, 1258 },
    { MODRM_SPLITRM, 1260 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1301 },
    { MODRM_SPLITRM, 1303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1353 },
    { MODRM_ONEENTRY, 1354 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1506 },
    { MODRM_ONEENTRY, 1507 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 1515 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_SPLITRM, 1568 },
    { MODRM_SPLITRM, 1570 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1580 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1686 },
    { MODRM_SPLITMISC, 1702 },
    { MODRM_SPLITRM, 1774 },
    { MODRM_SPLITRM, 1776 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1778 },
    { MODRM_SPLITRM, 1794 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1796 },
    { MODRM_SPLITRM, 1798 },
    { MODRM_SPLITRM, 1800 },
    { MODRM_SPLITRM, 1802 },
    { MODRM_SPLITRM, 1254 },
    { MODRM_SPLITRM, 1256 },
    { MODRM_SPLITRM, 1258 },
    { MODRM_SPLITRM, 1260 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1804 },
    { MODRM_SPLITRM, 1806 },
    { MODRM_SPLITRM, 1808 },
    { MODRM_SPLITRM, 1810 },
    { MODRM_SPLITRM, 1812 },
    { MODRM_SPLITRM, 1814 },
    { MODRM_SPLITRM, 1816 },
    { MODRM_SPLITRM, 1818 },
    { MODRM_SPLITRM, 1820 },
    { MODRM_SPLITRM, 1822 },
    { MODRM_SPLITRM, 1824 },
    { MODRM_SPLITRM, 1826 },
    { MODRM_SPLITRM, 1828 },
    { MODRM_SPLITRM, 1830 },
    { MODRM_SPLITRM, 1832 },
    { MODRM_SPLITRM, 1834 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1301 },
    { MODRM_SPLITRM, 1303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1836 },
    { MODRM_ONEENTRY, 1837 },
    { MODRM_ONEENTRY, 1838 },
    { MODRM_ONEENTRY, 1839 },
    { MODRM_ONEENTRY, 1840 },
    { MODRM_ONEENTRY, 1841 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 1848 },
    { MODRM_ONEENTRY, 1849 },
    { MODRM_ONEENTRY, 1850 },
    { MODRM_ONEENTRY, 1851 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1852 },
    { MODRM_ONEENTRY, 1853 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1854 },
    { MODRM_SPLITRM, 1856 },
    { MODRM_SPLITRM, 1858 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1860 },
    { MODRM_ONEENTRY, 1861 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1862 },
    { MODRM_SPLITRM, 1864 },
    { MODRM_SPLITRM, 1866 },
    { MODRM_SPLITREG, 1945 },
    { MODRM_SPLITRM, 1884 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1886 },
    { MODRM_SPLITRM, 1888 },
    { MODRM_SPLITRM, 1890 },
    { MODRM_SPLITRM, 1892 },
    { MODRM_SPLITRM, 1894 },
    { MODRM_SPLITRM, 1896 },
    { MODRM_SPLITRM, 1898 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1900 },
    { MODRM_SPLITRM, 1916 },
    { MODRM_SPLITRM, 1918 },
    { MODRM_SPLITRM, 1920 },
    { MODRM_SPLITRM, 1922 },
    { MODRM_SPLITRM, 1924 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1926 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1961 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 1132 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1254 },
    { MODRM_SPLITRM, 1256 },
    { MODRM_SPLITRM, 1258 },
    { MODRM_SPLITRM, 1260 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1353 },
    { MODRM_ONEENTRY, 1354 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1506 },
    { MODRM_ONEENTRY, 1507 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 1977 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1993 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 2009 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 2081 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITMISC, 2082 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1254 },
    { MODRM_SPLITRM, 1256 },
    { MODRM_SPLITRM, 1258 },
    { MODRM_SPLITRM, 1260 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1353 },
    { MODRM_ONEENTRY, 1354 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1506 },
    { MODRM_ONEENTRY, 1507 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 2154 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_SPLITRM, 2170 },
    { MODRM_SPLITRM, 2172 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2174 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2190 },
    { MODRM_SPLITRM, 2192 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2194 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITREG, 2210 },
    { MODRM_SPLITMISC, 2226 },
    { MODRM_SPLITRM, 2298 },
    { MODRM_SPLITRM, 2300 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 2302 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 2303 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 2305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2306 },
    { MODRM_SPLITRM, 2308 },
    { MODRM_SPLITRM, 2310 },
    { MODRM_SPLITRM, 2312 },
    { MODRM_SPLITRM, 2314 },
    { MODRM_SPLITRM, 2316 },
    { MODRM_SPLITRM, 2318 },
    { MODRM_SPLITRM, 2320 },
    { MODRM_SPLITRM, 2322 },
    { MODRM_SPLITRM, 2324 },
    { MODRM_SPLITRM, 2326 },
    { MODRM_SPLITRM, 2328 },
    { MODRM_SPLITRM, 2330 },
    { MODRM_SPLITRM, 2332 },
    { MODRM_SPLITRM, 2334 },
    { MODRM_SPLITRM, 2336 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1678 },
    { MODRM_SPLITRM, 1680 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 2338 },
    { MODRM_SPLITRM, 2340 },
    { MODRM_SPLITRM, 2342 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 2344 },
    { MODRM_SPLITRM, 2346 },
    { MODRM_SPLITRM, 2348 },
    { MODRM_SPLITREG, 2350 },
    { MODRM_SPLITRM, 2366 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 2368 },
    { MODRM_SPLITRM, 2370 },
    { MODRM_SPLITRM, 2372 },
    { MODRM_SPLITRM, 2374 },
    { MODRM_SPLITRM, 2376 },
    { MODRM_SPLITRM, 2378 },
    { MODRM_SPLITRM, 2380 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 2382 },
    { MODRM_SPLITRM, 2398 },
    { MODRM_SPLITRM, 2400 },
    { MODRM_SPLITRM, 2402 },
    { MODRM_SPLITRM, 2404 },
    { MODRM_SPLITRM, 2406 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 2408 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2410 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 2210 },
    { MODRM_SPLITMISC, 2226 },
    { MODRM_SPLITRM, 2298 },
    { MODRM_SPLITRM, 2300 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 2302 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1778 },
    { MODRM_SPLITRM, 1794 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1796 },
    { MODRM_SPLITRM, 1798 },
    { MODRM_SPLITRM, 1800 },
    { MODRM_SPLITRM, 2303 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 2305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2306 },
    { MODRM_SPLITRM, 2308 },
    { MODRM_SPLITRM, 2310 },
    { MODRM_SPLITRM, 2312 },
    { MODRM_SPLITRM, 2314 },
    { MODRM_SPLITRM, 2316 },
    { MODRM_SPLITRM, 2318 },
    { MODRM_SPLITRM, 2320 },
    { MODRM_SPLITRM, 2322 },
    { MODRM_SPLITRM, 2324 },
    { MODRM_SPLITRM, 2326 },
    { MODRM_SPLITRM, 2328 },
    { MODRM_SPLITRM, 2330 },
    { MODRM_SPLITRM, 2332 },
    { MODRM_SPLITRM, 2334 },
    { MODRM_SPLITRM, 2336 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1678 },
    { MODRM_SPLITRM, 1680 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1836 },
    { MODRM_ONEENTRY, 1837 },
    { MODRM_ONEENTRY, 1838 },
    { MODRM_ONEENTRY, 1839 },
    { MODRM_ONEENTRY, 1840 },
    { MODRM_ONEENTRY, 1841 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 1848 },
    { MODRM_ONEENTRY, 1849 },
    { MODRM_ONEENTRY, 1850 },
    { MODRM_ONEENTRY, 1851 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1852 },
    { MODRM_ONEENTRY, 1853 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 2338 },
    { MODRM_SPLITRM, 2340 },
    { MODRM_SPLITRM, 2342 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1860 },
    { MODRM_ONEENTRY, 1861 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 2344 },
    { MODRM_SPLITRM, 2346 },
    { MODRM_SPLITRM, 2348 },
    { MODRM_SPLITREG, 2427 },
    { MODRM_SPLITRM, 2366 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 2368 },
    { MODRM_SPLITRM, 2370 },
    { MODRM_SPLITRM, 2372 },
    { MODRM_SPLITRM, 2374 },
    { MODRM_SPLITRM, 2376 },
    { MODRM_SPLITRM, 2378 },
    { MODRM_SPLITRM, 2380 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 2382 },
    { MODRM_SPLITRM, 2398 },
    { MODRM_SPLITRM, 2400 },
    { MODRM_SPLITRM, 2402 },
    { MODRM_SPLITRM, 2404 },
    { MODRM_SPLITRM, 2406 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 2408 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2443 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1686 },
    { MODRM_SPLITMISC, 2459 },
    { MODRM_SPLITRM, 1774 },
    { MODRM_SPLITRM, 1776 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1778 },
    { MODRM_SPLITRM, 1794 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1796 },
    { MODRM_SPLITRM, 1798 },
    { MODRM_SPLITRM, 1800 },
    { MODRM_SPLITRM, 1802 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1804 },
    { MODRM_SPLITRM, 1806 },
    { MODRM_SPLITRM, 1808 },
    { MODRM_SPLITRM, 1810 },
    { MODRM_SPLITRM, 1812 },
    { MODRM_SPLITRM, 1814 },
    { MODRM_SPLITRM, 1816 },
    { MODRM_SPLITRM, 1818 },
    { MODRM_SPLITRM, 1820 },
    { MODRM_SPLITRM, 1822 },
    { MODRM_SPLITRM, 1824 },
    { MODRM_SPLITRM, 1826 },
    { MODRM_SPLITRM, 1828 },
    { MODRM_SPLITRM, 1830 },
    { MODRM_SPLITRM, 1832 },
    { MODRM_SPLITRM, 1834 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1836 },
    { MODRM_ONEENTRY, 1837 },
    { MODRM_ONEENTRY, 1838 },
    { MODRM_ONEENTRY, 1839 },
    { MODRM_ONEENTRY, 1840 },
    { MODRM_ONEENTRY, 1841 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 1848 },
    { MODRM_ONEENTRY, 1849 },
    { MODRM_ONEENTRY, 1850 },
    { MODRM_ONEENTRY, 1851 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1852 },
    { MODRM_ONEENTRY, 1853 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1854 },
    { MODRM_SPLITRM, 1856 },
    { MODRM_SPLITRM, 1858 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1860 },
    { MODRM_ONEENTRY, 1861 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1862 },
    { MODRM_SPLITRM, 1864 },
    { MODRM_SPLITRM, 1866 },
    { MODRM_SPLITREG, 1868 },
    { MODRM_SPLITRM, 1884 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1886 },
    { MODRM_SPLITRM, 1888 },
    { MODRM_SPLITRM, 1890 },
    { MODRM_SPLITRM, 1892 },
    { MODRM_SPLITRM, 1894 },
    { MODRM_SPLITRM, 1896 },
    { MODRM_SPLITRM, 1898 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1900 },
    { MODRM_SPLITRM, 1916 },
    { MODRM_SPLITRM, 1918 },
    { MODRM_SPLITRM, 1920 },
    { MODRM_SPLITRM, 1922 },
    { MODRM_SPLITRM, 1924 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1926 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1928 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 1598 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1678 },
    { MODRM_SPLITRM, 1680 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 1515 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_SPLITRM, 1568 },
    { MODRM_SPLITRM, 1570 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1580 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1686 },
    { MODRM_SPLITMISC, 2459 },
    { MODRM_SPLITRM, 1774 },
    { MODRM_SPLITRM, 1776 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1778 },
    { MODRM_SPLITRM, 1794 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1796 },
    { MODRM_SPLITRM, 1798 },
    { MODRM_SPLITRM, 1800 },
    { MODRM_SPLITRM, 1802 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1804 },
    { MODRM_SPLITRM, 1806 },
    { MODRM_SPLITRM, 1808 },
    { MODRM_SPLITRM, 1810 },
    { MODRM_SPLITRM, 1812 },
    { MODRM_SPLITRM, 1814 },
    { MODRM_SPLITRM, 1816 },
    { MODRM_SPLITRM, 1818 },
    { MODRM_SPLITRM, 1820 },
    { MODRM_SPLITRM, 1822 },
    { MODRM_SPLITRM, 1824 },
    { MODRM_SPLITRM, 1826 },
    { MODRM_SPLITRM, 1828 },
    { MODRM_SPLITRM, 1830 },
    { MODRM_SPLITRM, 1832 },
    { MODRM_SPLITRM, 1834 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1678 },
    { MODRM_SPLITRM, 1680 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1836 },
    { MODRM_ONEENTRY, 1837 },
    { MODRM_ONEENTRY, 1838 },
    { MODRM_ONEENTRY, 1839 },
    { MODRM_ONEENTRY, 1840 },
    { MODRM_ONEENTRY, 1841 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 1848 },
    { MODRM_ONEENTRY, 1849 },
    { MODRM_ONEENTRY, 1850 },
    { MODRM_ONEENTRY, 1851 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1852 },
    { MODRM_ONEENTRY, 1853 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1854 },
    { MODRM_SPLITRM, 1856 },
    { MODRM_SPLITRM, 1858 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1860 },
    { MODRM_ONEENTRY, 1861 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1862 },
    { MODRM_SPLITRM, 1864 },
    { MODRM_SPLITRM, 1866 },
    { MODRM_SPLITREG, 1945 },
    { MODRM_SPLITRM, 1884 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1886 },
    { MODRM_SPLITRM, 1888 },
    { MODRM_SPLITRM, 1890 },
    { MODRM_SPLITRM, 1892 },
    { MODRM_SPLITRM, 1894 },
    { MODRM_SPLITRM, 1896 },
    { MODRM_SPLITRM, 1898 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1900 },
    { MODRM_SPLITRM, 1916 },
    { MODRM_SPLITRM, 1918 },
    { MODRM_SPLITRM, 1920 },
    { MODRM_SPLITRM, 1922 },
    { MODRM_SPLITRM, 1924 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1926 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1961 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 1944 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 1598 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 1977 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1993 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 2531 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 2081 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITMISC, 2082 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 2603 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_SPLITRM, 2170 },
    { MODRM_SPLITRM, 2172 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2619 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2190 },
    { MODRM_SPLITRM, 2192 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 1598 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 1977 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1993 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 1116 },
    { MODRM_SPLITMISC, 2531 },
    { MODRM_SPLITRM, 1204 },
    { MODRM_SPLITRM, 1206 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 1210 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 2081 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITMISC, 2082 },
    { MODRM_SPLITRM, 1252 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 1267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1269 },
    { MODRM_SPLITRM, 1271 },
    { MODRM_SPLITRM, 1273 },
    { MODRM_SPLITRM, 1275 },
    { MODRM_SPLITRM, 1277 },
    { MODRM_SPLITRM, 1279 },
    { MODRM_SPLITRM, 1281 },
    { MODRM_SPLITRM, 1283 },
    { MODRM_SPLITRM, 1285 },
    { MODRM_SPLITRM, 1287 },
    { MODRM_SPLITRM, 1289 },
    { MODRM_SPLITRM, 1291 },
    { MODRM_SPLITRM, 1293 },
    { MODRM_SPLITRM, 1295 },
    { MODRM_SPLITRM, 1297 },
    { MODRM_SPLITRM, 1299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 1356 },
    { MODRM_SPLITRM, 1358 },
    { MODRM_SPLITRM, 1360 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 1509 },
    { MODRM_SPLITRM, 1511 },
    { MODRM_SPLITRM, 1513 },
    { MODRM_SPLITREG, 2635 },
    { MODRM_SPLITRM, 1531 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 1535 },
    { MODRM_SPLITRM, 1537 },
    { MODRM_SPLITRM, 1539 },
    { MODRM_SPLITRM, 1541 },
    { MODRM_SPLITRM, 1543 },
    { MODRM_SPLITRM, 1545 },
    { MODRM_SPLITRM, 1547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 1550 },
    { MODRM_SPLITRM, 1566 },
    { MODRM_SPLITRM, 2170 },
    { MODRM_SPLITRM, 2172 },
    { MODRM_SPLITRM, 1572 },
    { MODRM_SPLITRM, 1574 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 1578 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2619 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 1596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 2210 },
    { MODRM_SPLITMISC, 2651 },
    { MODRM_SPLITRM, 2298 },
    { MODRM_SPLITRM, 2300 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 2302 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 2081 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITMISC, 2723 },
    { MODRM_SPLITRM, 2303 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 2305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2306 },
    { MODRM_SPLITRM, 2308 },
    { MODRM_SPLITRM, 2310 },
    { MODRM_SPLITRM, 2312 },
    { MODRM_SPLITRM, 2314 },
    { MODRM_SPLITRM, 2316 },
    { MODRM_SPLITRM, 2318 },
    { MODRM_SPLITRM, 2320 },
    { MODRM_SPLITRM, 2322 },
    { MODRM_SPLITRM, 2324 },
    { MODRM_SPLITRM, 2326 },
    { MODRM_SPLITRM, 2328 },
    { MODRM_SPLITRM, 2330 },
    { MODRM_SPLITRM, 2332 },
    { MODRM_SPLITRM, 2334 },
    { MODRM_SPLITRM, 2336 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1678 },
    { MODRM_SPLITRM, 1680 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 2338 },
    { MODRM_SPLITRM, 2340 },
    { MODRM_SPLITRM, 2342 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 2344 },
    { MODRM_SPLITRM, 2346 },
    { MODRM_SPLITRM, 2348 },
    { MODRM_SPLITREG, 2795 },
    { MODRM_SPLITRM, 2366 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 2368 },
    { MODRM_SPLITRM, 2370 },
    { MODRM_SPLITRM, 2372 },
    { MODRM_SPLITRM, 2374 },
    { MODRM_SPLITRM, 2376 },
    { MODRM_SPLITRM, 2378 },
    { MODRM_SPLITRM, 2380 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 2382 },
    { MODRM_SPLITRM, 2398 },
    { MODRM_SPLITRM, 2811 },
    { MODRM_SPLITRM, 2813 },
    { MODRM_SPLITRM, 2404 },
    { MODRM_SPLITRM, 2406 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 2408 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2815 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 2210 },
    { MODRM_SPLITMISC, 2226 },
    { MODRM_SPLITRM, 2298 },
    { MODRM_SPLITRM, 2300 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 2302 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1214 },
    { MODRM_SPLITRM, 1230 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1232 },
    { MODRM_SPLITRM, 1248 },
    { MODRM_SPLITRM, 1250 },
    { MODRM_SPLITRM, 2303 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 2305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2306 },
    { MODRM_SPLITRM, 2308 },
    { MODRM_SPLITRM, 2310 },
    { MODRM_SPLITRM, 2312 },
    { MODRM_SPLITRM, 2314 },
    { MODRM_SPLITRM, 2316 },
    { MODRM_SPLITRM, 2318 },
    { MODRM_SPLITRM, 2320 },
    { MODRM_SPLITRM, 2322 },
    { MODRM_SPLITRM, 2324 },
    { MODRM_SPLITRM, 2326 },
    { MODRM_SPLITRM, 2328 },
    { MODRM_SPLITRM, 2330 },
    { MODRM_SPLITRM, 2332 },
    { MODRM_SPLITRM, 2334 },
    { MODRM_SPLITRM, 2336 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1678 },
    { MODRM_SPLITRM, 1680 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1305 },
    { MODRM_ONEENTRY, 1306 },
    { MODRM_ONEENTRY, 1307 },
    { MODRM_ONEENTRY, 1308 },
    { MODRM_ONEENTRY, 1309 },
    { MODRM_ONEENTRY, 1310 },
    { MODRM_ONEENTRY, 1311 },
    { MODRM_ONEENTRY, 1312 },
    { MODRM_ONEENTRY, 1313 },
    { MODRM_ONEENTRY, 1314 },
    { MODRM_ONEENTRY, 1315 },
    { MODRM_ONEENTRY, 1316 },
    { MODRM_ONEENTRY, 1317 },
    { MODRM_ONEENTRY, 1318 },
    { MODRM_ONEENTRY, 1319 },
    { MODRM_ONEENTRY, 1320 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1682 },
    { MODRM_ONEENTRY, 1683 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 2338 },
    { MODRM_SPLITRM, 2340 },
    { MODRM_SPLITRM, 2342 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1684 },
    { MODRM_ONEENTRY, 1685 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 2344 },
    { MODRM_SPLITRM, 2346 },
    { MODRM_SPLITRM, 2348 },
    { MODRM_SPLITREG, 2831 },
    { MODRM_SPLITRM, 2366 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 2368 },
    { MODRM_SPLITRM, 2370 },
    { MODRM_SPLITRM, 2372 },
    { MODRM_SPLITRM, 2374 },
    { MODRM_SPLITRM, 2376 },
    { MODRM_SPLITRM, 2378 },
    { MODRM_SPLITRM, 2380 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 2382 },
    { MODRM_SPLITRM, 2398 },
    { MODRM_SPLITRM, 1568 },
    { MODRM_SPLITRM, 1570 },
    { MODRM_SPLITRM, 2404 },
    { MODRM_SPLITRM, 2406 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 2408 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2847 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
  { {
    { MODRM_SPLITREG, 2210 },
    { MODRM_SPLITMISC, 2226 },
    { MODRM_SPLITRM, 2298 },
    { MODRM_SPLITRM, 2300 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1208 },
    { MODRM_ONEENTRY, 1209 },
    { MODRM_ONEENTRY, 2302 },
    { MODRM_ONEENTRY, 1211 },
    { MODRM_ONEENTRY, 1212 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1778 },
    { MODRM_SPLITRM, 1794 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1796 },
    { MODRM_SPLITRM, 1798 },
    { MODRM_SPLITRM, 1800 },
    { MODRM_SPLITRM, 2303 },
    { MODRM_SPLITRM, 1670 },
    { MODRM_SPLITRM, 1672 },
    { MODRM_SPLITRM, 1674 },
    { MODRM_SPLITRM, 1676 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1262 },
    { MODRM_ONEENTRY, 1263 },
    { MODRM_ONEENTRY, 1264 },
    { MODRM_ONEENTRY, 1265 },
    { MODRM_ONEENTRY, 1266 },
    { MODRM_ONEENTRY, 2305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1268 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2306 },
    { MODRM_SPLITRM, 2308 },
    { MODRM_SPLITRM, 2310 },
    { MODRM_SPLITRM, 2312 },
    { MODRM_SPLITRM, 2314 },
    { MODRM_SPLITRM, 2316 },
    { MODRM_SPLITRM, 2318 },
    { MODRM_SPLITRM, 2320 },
    { MODRM_SPLITRM, 2322 },
    { MODRM_SPLITRM, 2324 },
    { MODRM_SPLITRM, 2326 },
    { MODRM_SPLITRM, 2328 },
    { MODRM_SPLITRM, 2330 },
    { MODRM_SPLITRM, 2332 },
    { MODRM_SPLITRM, 2334 },
    { MODRM_SPLITRM, 2336 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1678 },
    { MODRM_SPLITRM, 1680 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1836 },
    { MODRM_ONEENTRY, 1837 },
    { MODRM_ONEENTRY, 1838 },
    { MODRM_ONEENTRY, 1839 },
    { MODRM_ONEENTRY, 1840 },
    { MODRM_ONEENTRY, 1841 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 1848 },
    { MODRM_ONEENTRY, 1849 },
    { MODRM_ONEENTRY, 1850 },
    { MODRM_ONEENTRY, 1851 },
    { MODRM_SPLITRM, 1321 },
    { MODRM_SPLITRM, 1323 },
    { MODRM_SPLITRM, 1325 },
    { MODRM_SPLITRM, 1327 },
    { MODRM_SPLITRM, 1329 },
    { MODRM_SPLITRM, 1331 },
    { MODRM_SPLITRM, 1333 },
    { MODRM_SPLITRM, 1335 },
    { MODRM_SPLITRM, 1337 },
    { MODRM_SPLITRM, 1339 },
    { MODRM_SPLITRM, 1341 },
    { MODRM_SPLITRM, 1343 },
    { MODRM_SPLITRM, 1345 },
    { MODRM_SPLITRM, 1347 },
    { MODRM_SPLITRM, 1349 },
    { MODRM_SPLITRM, 1351 },
    { MODRM_ONEENTRY, 1852 },
    { MODRM_ONEENTRY, 1853 },
    { MODRM_ONEENTRY, 1355 },
    { MODRM_SPLITRM, 2338 },
    { MODRM_SPLITRM, 2340 },
    { MODRM_SPLITRM, 2342 },
    { MODRM_SPLITMISC, 1362 },
    { MODRM_SPLITMISC, 1434 },
    { MODRM_ONEENTRY, 1860 },
    { MODRM_ONEENTRY, 1861 },
    { MODRM_ONEENTRY, 1508 },
    { MODRM_SPLITRM, 2344 },
    { MODRM_SPLITRM, 2346 },
    { MODRM_SPLITRM, 2348 },
    { MODRM_SPLITREG, 1945 },
    { MODRM_SPLITRM, 2366 },
    { MODRM_SPLITRM, 1533 },
    { MODRM_SPLITRM, 2368 },
    { MODRM_SPLITRM, 2370 },
    { MODRM_SPLITRM, 2372 },
    { MODRM_SPLITRM, 2374 },
    { MODRM_SPLITRM, 2376 },
    { MODRM_SPLITRM, 2378 },
    { MODRM_SPLITRM, 2380 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1549 },
    { MODRM_SPLITREG, 2382 },
    { MODRM_SPLITRM, 2398 },
    { MODRM_SPLITRM, 1918 },
    { MODRM_SPLITRM, 1920 },
    { MODRM_SPLITRM, 2404 },
    { MODRM_SPLITRM, 2406 },
    { MODRM_SPLITRM, 1576 },
    { MODRM_SPLITRM, 2408 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 2863 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 2426 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1597 },
  } },
};

static const unsigned char index_x86DisassemblerThreeByte38Opcodes[] = {
  1,
  2,
  3,
  4,
  5,
  6,
  7,
  0,
  0,
  0,
  0,
  8,
  9,
  10,
  11,
  12,
  13,
  14,
  0,
  0,
  15,
  16,
  17,
  18,
  19,
  20,
  21,
  22,
  23,
  24,
  25,
  26,
  27,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86DisassemblerThreeByte38Opcodes[] = {
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2879 },
    { MODRM_SPLITRM, 2881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2879 },
    { MODRM_SPLITRM, 2881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2887 },
    { MODRM_SPLITRM, 2889 },
    { MODRM_SPLITRM, 2891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2893 },
    { MODRM_SPLITRM, 2895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2897 },
    { MODRM_SPLITRM, 2899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2901 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2879 },
    { MODRM_SPLITRM, 2881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2887 },
    { MODRM_SPLITRM, 2889 },
    { MODRM_SPLITRM, 2891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2893 },
    { MODRM_SPLITRM, 2895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2897 },
    { MODRM_SPLITRM, 2899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2903 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2905 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2907 },
    { MODRM_SPLITRM, 2909 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2915 },
    { MODRM_SPLITRM, 2917 },
    { MODRM_SPLITRM, 2919 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2907 },
    { MODRM_SPLITRM, 2909 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2897 },
    { MODRM_SPLITRM, 2921 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2901 },
    { MODRM_SPLITRM, 2913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2915 },
    { MODRM_SPLITRM, 2917 },
    { MODRM_SPLITRM, 2919 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2893 },
    { MODRM_SPLITRM, 2895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2897 },
    { MODRM_SPLITRM, 2899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2923 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2879 },
    { MODRM_SPLITRM, 2881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2915 },
    { MODRM_SPLITRM, 2917 },
    { MODRM_SPLITRM, 2919 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2893 },
    { MODRM_SPLITRM, 2895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2897 },
    { MODRM_SPLITRM, 2899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2901 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2905 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2905 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2879 },
    { MODRM_SPLITRM, 2881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2925 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2879 },
    { MODRM_SPLITRM, 2881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2915 },
    { MODRM_SPLITRM, 2917 },
    { MODRM_SPLITRM, 2919 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2893 },
    { MODRM_SPLITRM, 2895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2927 },
    { MODRM_SPLITRM, 2929 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2923 },
    { MODRM_SPLITRM, 2913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2931 },
    { MODRM_SPLITREG, 2933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2957 },
    { MODRM_SPLITRM, 2959 },
    { MODRM_SPLITRM, 2961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2965 },
    { MODRM_SPLITREG, 2967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2985 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2987 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2989 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2991 },
    { MODRM_SPLITRM, 2993 },
    { MODRM_SPLITRM, 2995 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2997 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

static const unsigned char index_x86DisassemblerThreeByte3AOpcodes[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  0,
  0,
  0,
  2,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86DisassemblerThreeByte3AOpcodes[] = {
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

