/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* This is auto-gen data for Capstone disassembly engine (www.capstone-engine.org) */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */


{	/* X86_AAA, X86_INS_AAA: aaa */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ 0 }
},

{	/* X86_AAD8i8, X86_INS_AAD: aad */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_AAM8i8, X86_INS_AAM: aam */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_AAS, X86_INS_AAS: aas */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ 0 }
},

{	/* X86_ABS_F, X86_INS_FABS: fabs */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_ABS_Fp32, X86_INS_FABS: fabs */
	0,
	{ 0 }
},

{	/* X86_ABS_Fp64, X86_INS_FABS: fabs */
	0,
	{ 0 }
},

{	/* X86_ABS_Fp80, X86_INS_FABS: fabs */
	0,
	{ 0 }
},

{	/* X86_ADC16i16, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC16mi, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC16mi8, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC16mr, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC16ri, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC16ri8, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC16rm, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC16rr, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC16rr_REV, X86_INS_ADC: adc{w}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC32i32, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC32mi, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC32mi8, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC32mr, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC32ri, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC32ri8, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC32rm, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC32rr, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC32rr_REV, X86_INS_ADC: adc{l}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC64i32, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC64mi32, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC64mi8, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC64mr, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC64ri32, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC64ri8, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC64rm, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC64rr, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC64rr_REV, X86_INS_ADC: adc{q}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC8i8, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC8mi, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC8mi8, X86_INS_ADC: adc{b}	$dst $src */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC8mr, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC8ri, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC8ri8, X86_INS_ADC: adc{b}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADC8rm, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC8rr, X86_INS_ADC: adc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADC8rr_REV, X86_INS_ADC: adc{b}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADCX32rm, X86_INS_ADCX: adcx */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADCX32rr, X86_INS_ADCX: adcx */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADCX64rm, X86_INS_ADCX: adcx */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADCX64rr, X86_INS_ADCX: adcx */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD16i16, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD16mi, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD16mi8, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD16mr, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD16ri, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD16ri8, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD16rm, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD16rr, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD16rr_REV, X86_INS_ADD: add{w}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD32i32, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD32mi, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD32mi8, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD32mr, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD32ri, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD32ri8, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD32rm, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD32rr, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD32rr_REV, X86_INS_ADD: add{l}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD64i32, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD64mi32, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD64mi8, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD64mr, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD64ri32, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD64ri8, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD64rm, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD64rr, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD64rr_REV, X86_INS_ADD: add{q}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD8i8, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD8mi, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD8mi8, X86_INS_ADD: add{b}	$dst $src */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD8mr, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD8ri, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD8ri8, X86_INS_ADD: add{b}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADD8rm, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD8rr, X86_INS_ADD: add */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD8rr_REV, X86_INS_ADD: add{b}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDPDrm, X86_INS_ADDPD: addpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDPDrr, X86_INS_ADDPD: addpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDPSrm, X86_INS_ADDPS: addps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDPSrr, X86_INS_ADDPS: addps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSDrm, X86_INS_ADDSD: addsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSDrm_Int, X86_INS_ADDSD: addsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADDSDrr, X86_INS_ADDSD: addsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSDrr_Int, X86_INS_ADDSD: addsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSSrm, X86_INS_ADDSS: addss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSSrm_Int, X86_INS_ADDSS: addss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ADDSSrr, X86_INS_ADDSS: addss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSSrr_Int, X86_INS_ADDSS: addss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSUBPDrm, X86_INS_ADDSUBPD: addsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSUBPDrr, X86_INS_ADDSUBPD: addsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSUBPSrm, X86_INS_ADDSUBPS: addsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADDSUBPSrr, X86_INS_ADDSUBPS: addsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADD_F32m, X86_INS_FADD: fadd */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ADD_F64m, X86_INS_FADD: fadd */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ADD_FI16m, X86_INS_FIADD: fiadd */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ADD_FI32m, X86_INS_FIADD: fiadd */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ADD_FPrST0, X86_INS_FADD: faddp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ADD_FST0r, X86_INS_FADD: fadd */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ADD_Fp32, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_Fp32m, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_Fp64, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_Fp64m, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_Fp64m32, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_Fp80, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_Fp80m32, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_Fp80m64, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_FpI16m32, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_FpI16m64, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_FpI16m80, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_FpI32m32, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_FpI32m64, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_FpI32m80, X86_INS_FADD: fadd */
	0,
	{ 0 }
},

{	/* X86_ADD_FrST0, X86_INS_FADD: fadd */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ADOX32rm, X86_INS_ADOX: adox */
	X86_EFLAGS_MODIFY_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADOX32rr, X86_INS_ADOX: adox */
	X86_EFLAGS_MODIFY_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADOX64rm, X86_INS_ADOX: adox */
	X86_EFLAGS_MODIFY_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ADOX64rr, X86_INS_ADOX: adox */
	X86_EFLAGS_MODIFY_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESDECLASTrm, X86_INS_AESDECLAST: aesdeclast */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESDECLASTrr, X86_INS_AESDECLAST: aesdeclast */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESDECrm, X86_INS_AESDEC: aesdec */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESDECrr, X86_INS_AESDEC: aesdec */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESENCLASTrm, X86_INS_AESENCLAST: aesenclast */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESENCLASTrr, X86_INS_AESENCLAST: aesenclast */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESENCrm, X86_INS_AESENC: aesenc */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESENCrr, X86_INS_AESENC: aesenc */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESIMCrm, X86_INS_AESIMC: aesimc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESIMCrr, X86_INS_AESIMC: aesimc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AESKEYGENASSIST128rm, X86_INS_AESKEYGENASSIST: aeskeygenassist */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_AESKEYGENASSIST128rr, X86_INS_AESKEYGENASSIST: aeskeygenassist */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_AND16i16, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND16mi, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND16mi8, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND16mr, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND16ri, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND16ri8, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND16rm, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND16rr, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND16rr_REV, X86_INS_AND: and{w}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND32i32, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND32mi, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND32mi8, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND32mr, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND32ri, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND32ri8, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND32rm, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND32rr, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND32rr_REV, X86_INS_AND: and{l}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND64i32, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND64mi32, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND64mi8, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND64mr, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND64ri32, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND64ri8, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND64rm, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND64rr, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND64rr_REV, X86_INS_AND: and{q}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND8i8, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND8mi, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND8mi8, X86_INS_AND: and{b}	$dst $src */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND8mr, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND8ri, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND8ri8, X86_INS_AND: and{b}	$src1 $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_AND8rm, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND8rr, X86_INS_AND: and */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_AND8rr_REV, X86_INS_AND: and{b}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ANDN32rm, X86_INS_ANDN: andn */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_CF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ANDN32rr, X86_INS_ANDN: andn */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_CF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ANDN64rm, X86_INS_ANDN: andn */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_CF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ANDN64rr, X86_INS_ANDN: andn */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_CF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ANDNPDrm, X86_INS_ANDNPD: andnpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ANDNPDrr, X86_INS_ANDNPD: andnpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ANDNPSrm, X86_INS_ANDNPS: andnps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ANDNPSrr, X86_INS_ANDNPS: andnps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ANDPDrm, X86_INS_ANDPD: andpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ANDPDrr, X86_INS_ANDPD: andpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ANDPSrm, X86_INS_ANDPS: andps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ANDPSrr, X86_INS_ANDPS: andps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ARPL16mr, X86_INS_ARPL: arpl */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ARPL16rr, X86_INS_ARPL: arpl */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BEXTR32rm, X86_INS_BEXTR: bextr */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_TF | X86_EFLAGS_RESET_IF | X86_EFLAGS_RESET_DF | X86_EFLAGS_RESET_NT | X86_EFLAGS_RESET_RF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BEXTR32rr, X86_INS_BEXTR: bextr */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_TF | X86_EFLAGS_RESET_IF | X86_EFLAGS_RESET_DF | X86_EFLAGS_RESET_NT | X86_EFLAGS_RESET_RF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BEXTR64rm, X86_INS_BEXTR: bextr */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_TF | X86_EFLAGS_RESET_IF | X86_EFLAGS_RESET_DF | X86_EFLAGS_RESET_NT | X86_EFLAGS_RESET_RF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BEXTR64rr, X86_INS_BEXTR: bextr */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_TF | X86_EFLAGS_RESET_IF | X86_EFLAGS_RESET_DF | X86_EFLAGS_RESET_NT | X86_EFLAGS_RESET_RF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BEXTRI32mi, X86_INS_BEXTR: bextr */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_TF | X86_EFLAGS_RESET_IF | X86_EFLAGS_RESET_DF | X86_EFLAGS_RESET_NT | X86_EFLAGS_RESET_RF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BEXTRI32ri, X86_INS_BEXTR: bextr */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_TF | X86_EFLAGS_RESET_IF | X86_EFLAGS_RESET_DF | X86_EFLAGS_RESET_NT | X86_EFLAGS_RESET_RF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BEXTRI64mi, X86_INS_BEXTR: bextr */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_TF | X86_EFLAGS_RESET_IF | X86_EFLAGS_RESET_DF | X86_EFLAGS_RESET_NT | X86_EFLAGS_RESET_RF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BEXTRI64ri, X86_INS_BEXTR: bextr */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_TF | X86_EFLAGS_RESET_IF | X86_EFLAGS_RESET_DF | X86_EFLAGS_RESET_NT | X86_EFLAGS_RESET_RF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BLCFILL32rm, X86_INS_BLCFILL: blcfill */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCFILL32rr, X86_INS_BLCFILL: blcfill */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCFILL64rm, X86_INS_BLCFILL: blcfill */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCFILL64rr, X86_INS_BLCFILL: blcfill */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCI32rm, X86_INS_BLCI: blci */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCI32rr, X86_INS_BLCI: blci */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCI64rm, X86_INS_BLCI: blci */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCI64rr, X86_INS_BLCI: blci */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCIC32rm, X86_INS_BLCIC: blcic */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCIC32rr, X86_INS_BLCIC: blcic */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCIC64rm, X86_INS_BLCIC: blcic */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCIC64rr, X86_INS_BLCIC: blcic */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCMSK32rm, X86_INS_BLCMSK: blcmsk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCMSK32rr, X86_INS_BLCMSK: blcmsk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCMSK64rm, X86_INS_BLCMSK: blcmsk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCMSK64rr, X86_INS_BLCMSK: blcmsk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCS32rm, X86_INS_BLCS: blcs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCS32rr, X86_INS_BLCS: blcs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCS64rm, X86_INS_BLCS: blcs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLCS64rr, X86_INS_BLCS: blcs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLENDPDrmi, X86_INS_BLENDPD: blendpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BLENDPDrri, X86_INS_BLENDPD: blendpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BLENDPSrmi, X86_INS_BLENDPS: blendps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BLENDPSrri, X86_INS_BLENDPS: blendps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BLENDVPDrm0, X86_INS_BLENDVPD: blendvpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLENDVPDrr0, X86_INS_BLENDVPD: blendvpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLENDVPSrm0, X86_INS_BLENDVPS: blendvps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLENDVPSrr0, X86_INS_BLENDVPS: blendvps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSFILL32rm, X86_INS_BLSFILL: blsfill */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSFILL32rr, X86_INS_BLSFILL: blsfill */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSFILL64rm, X86_INS_BLSFILL: blsfill */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSFILL64rr, X86_INS_BLSFILL: blsfill */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSI32rm, X86_INS_BLSI: blsi */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSI32rr, X86_INS_BLSI: blsi */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSI64rm, X86_INS_BLSI: blsi */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSI64rr, X86_INS_BLSI: blsi */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSIC32rm, X86_INS_BLSIC: blsic */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSIC32rr, X86_INS_BLSIC: blsic */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSIC64rm, X86_INS_BLSIC: blsic */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSIC64rr, X86_INS_BLSIC: blsic */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSMSK32rm, X86_INS_BLSMSK: blsmsk */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSMSK32rr, X86_INS_BLSMSK: blsmsk */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSMSK64rm, X86_INS_BLSMSK: blsmsk */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSMSK64rr, X86_INS_BLSMSK: blsmsk */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSR32rm, X86_INS_BLSR: blsr */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSR32rr, X86_INS_BLSR: blsr */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSR64rm, X86_INS_BLSR: blsr */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BLSR64rr, X86_INS_BLSR: blsr */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDCL32rm, X86_INS_BNDCL: bndcl */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCL32rr, X86_INS_BNDCL: bndcl */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCL64rm, X86_INS_BNDCL: bndcl */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCL64rr, X86_INS_BNDCL: bndcl */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCN32rm, X86_INS_BNDCN: bndcn */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCN32rr, X86_INS_BNDCN: bndcn */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCN64rm, X86_INS_BNDCN: bndcn */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCN64rr, X86_INS_BNDCN: bndcn */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCU32rm, X86_INS_BNDCU: bndcu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCU32rr, X86_INS_BNDCU: bndcu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCU64rm, X86_INS_BNDCU: bndcu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDCU64rr, X86_INS_BNDCU: bndcu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BNDLDXrm, X86_INS_BNDLDX: bndldx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDMK32rm, X86_INS_BNDMK: bndmk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDMK64rm, X86_INS_BNDMK: bndmk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDMOV32mr, X86_INS_BNDMOV: bndmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDMOV32rm, X86_INS_BNDMOV: bndmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDMOV64mr, X86_INS_BNDMOV: bndmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDMOV64rm, X86_INS_BNDMOV: bndmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDMOVrr, X86_INS_BNDMOV: bndmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDMOVrr_REV, X86_INS_BNDMOV: bndmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BNDSTXmr, X86_INS_BNDSTX: bndstx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BOUNDS16rm, X86_INS_BOUND: bound */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BOUNDS32rm, X86_INS_BOUND: bound */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSF16rm, X86_INS_BSF: bsf */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSF16rr, X86_INS_BSF: bsf */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSF32rm, X86_INS_BSF: bsf */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSF32rr, X86_INS_BSF: bsf */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSF64rm, X86_INS_BSF: bsf */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSF64rr, X86_INS_BSF: bsf */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSR16rm, X86_INS_BSR: bsr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSR16rr, X86_INS_BSR: bsr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSR32rm, X86_INS_BSR: bsr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSR32rr, X86_INS_BSR: bsr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSR64rm, X86_INS_BSR: bsr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSR64rr, X86_INS_BSR: bsr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BSWAP16r_BAD, X86_INS_BSWAP: bswap */
	0,
	{ 0 }
},

{	/* X86_BSWAP32r, X86_INS_BSWAP: bswap */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_BSWAP64r, X86_INS_BSWAP: bswap */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_BT16mi8, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BT16mr, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BT16ri8, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BT16rr, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BT32mi8, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BT32mr, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BT32ri8, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BT32rr, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BT64mi8, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BT64mr, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BT64ri8, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_BT64rr, X86_INS_BT: bt */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BTC16mi8, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTC16mr, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTC16ri8, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTC16rr, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTC32mi8, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTC32mr, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTC32ri8, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTC32rr, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTC64mi8, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTC64mr, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTC64ri8, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTC64rr, X86_INS_BTC: btc */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTR16mi8, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTR16mr, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTR16ri8, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTR16rr, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTR32mi8, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTR32mr, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTR32ri8, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTR32rr, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTR64mi8, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTR64mr, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTR64ri8, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTR64rr, X86_INS_BTR: btr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTS16mi8, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTS16mr, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTS16ri8, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTS16rr, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTS32mi8, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTS32mr, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTS32ri8, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTS32rr, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTS64mi8, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTS64mr, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BTS64ri8, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_BTS64rr, X86_INS_BTS: bts */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_BZHI32rm, X86_INS_BZHI: bzhi */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BZHI32rr, X86_INS_BZHI: bzhi */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BZHI64rm, X86_INS_BZHI: bzhi */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_BZHI64rr, X86_INS_BZHI: bzhi */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_RESET_OF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CALL16m, X86_INS_CALL: call */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CALL16m_NT, X86_INS_CALL: call */
	0,
	{ 0 }
},

{	/* X86_CALL16r, X86_INS_CALL: call */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CALL16r_NT, X86_INS_CALL: call */
	0,
	{ 0 }
},

{	/* X86_CALL32m, X86_INS_CALL: call */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CALL32m_NT, X86_INS_CALL: call */
	0,
	{ 0 }
},

{	/* X86_CALL32r, X86_INS_CALL: call */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CALL32r_NT, X86_INS_CALL: call */
	0,
	{ 0 }
},

{	/* X86_CALL64m, X86_INS_CALL: call */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CALL64m_NT, X86_INS_CALL: call */
	0,
	{ 0 }
},

{	/* X86_CALL64pcrel32, X86_INS_CALL: call */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_CALL64r, X86_INS_CALL: call */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CALL64r_NT, X86_INS_CALL: call */
	0,
	{ 0 }
},

{	/* X86_CALLpcrel16, X86_INS_CALL: call */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_CALLpcrel32, X86_INS_CALL: call */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_CBW, X86_INS_CBW: cbw */
	0,
	{ 0 }
},

{	/* X86_CDQ, X86_INS_CDQ: cdq */
	0,
	{ 0 }
},

{	/* X86_CDQE, X86_INS_CDQE: cdqe */
	0,
	{ 0 }
},

{	/* X86_CHS_F, X86_INS_FCHS: fchs */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_CHS_Fp32, X86_INS_FCHS: fchs */
	0,
	{ 0 }
},

{	/* X86_CHS_Fp64, X86_INS_FCHS: fchs */
	0,
	{ 0 }
},

{	/* X86_CHS_Fp80, X86_INS_FCHS: fchs */
	0,
	{ 0 }
},

{	/* X86_CLAC, X86_INS_CLAC: clac */
	X86_EFLAGS_RESET_AC,
	{ 0 }
},

{	/* X86_CLC, X86_INS_CLC: clc */
	X86_EFLAGS_RESET_CF,
	{ 0 }
},

{	/* X86_CLD, X86_INS_CLD: cld */
	X86_EFLAGS_RESET_DF,
	{ 0 }
},

{	/* X86_CLDEMOTE, X86_INS_CLDEMOTE: cldemote */
	0,
	{ 0 }
},

{	/* X86_CLFLUSH, X86_INS_CLFLUSH: clflush */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CLFLUSHOPT, X86_INS_CLFLUSHOPT: clflushopt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CLGI, X86_INS_CLGI: clgi */
	0,
	{ 0 }
},

{	/* X86_CLI, X86_INS_CLI: cli */
	X86_EFLAGS_RESET_IF,
	{ 0 }
},

{	/* X86_CLRSSBSY, X86_INS_CLRSSBSY: clrssbsy */
	0,
	{ 0 }
},

{	/* X86_CLTS, X86_INS_CLTS: clts */
	0,
	{ 0 }
},

{	/* X86_CLWB, X86_INS_CLWB: clwb */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_CLZEROr, X86_INS_CLZERO: clzero */
	0,
	{ 0 }
},

{	/* X86_CMC, X86_INS_CMC: cmc */
	X86_EFLAGS_MODIFY_CF,
	{ 0 }
},

{	/* X86_CMOVA16rm, X86_INS_CMOVA: cmova */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVA16rr, X86_INS_CMOVA: cmova */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVA32rm, X86_INS_CMOVA: cmova */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVA32rr, X86_INS_CMOVA: cmova */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVA64rm, X86_INS_CMOVA: cmova */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVA64rr, X86_INS_CMOVA: cmova */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVAE16rm, X86_INS_CMOVAE: cmovae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVAE16rr, X86_INS_CMOVAE: cmovae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVAE32rm, X86_INS_CMOVAE: cmovae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVAE32rr, X86_INS_CMOVAE: cmovae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVAE64rm, X86_INS_CMOVAE: cmovae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVAE64rr, X86_INS_CMOVAE: cmovae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVB16rm, X86_INS_CMOVB: cmovb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVB16rr, X86_INS_CMOVB: cmovb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVB32rm, X86_INS_CMOVB: cmovb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVB32rr, X86_INS_CMOVB: cmovb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVB64rm, X86_INS_CMOVB: cmovb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVB64rr, X86_INS_CMOVB: cmovb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVBE16rm, X86_INS_CMOVBE: cmovbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVBE16rr, X86_INS_CMOVBE: cmovbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVBE32rm, X86_INS_CMOVBE: cmovbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVBE32rr, X86_INS_CMOVBE: cmovbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVBE64rm, X86_INS_CMOVBE: cmovbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVBE64rr, X86_INS_CMOVBE: cmovbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVBE_F, X86_INS_FCMOVBE: fcmovbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_CMOVBE_Fp32, X86_INS_FCMOVBE: fcmovbe */
	0,
	{ 0 }
},

{	/* X86_CMOVBE_Fp64, X86_INS_FCMOVBE: fcmovbe */
	0,
	{ 0 }
},

{	/* X86_CMOVBE_Fp80, X86_INS_FCMOVBE: fcmovbe */
	0,
	{ 0 }
},

{	/* X86_CMOVB_F, X86_INS_FCMOVB: fcmovb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_CMOVB_Fp32, X86_INS_FCMOVB: fcmovb */
	0,
	{ 0 }
},

{	/* X86_CMOVB_Fp64, X86_INS_FCMOVB: fcmovb */
	0,
	{ 0 }
},

{	/* X86_CMOVB_Fp80, X86_INS_FCMOVB: fcmovb */
	0,
	{ 0 }
},

{	/* X86_CMOVE16rm, X86_INS_CMOVE: cmove */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVE16rr, X86_INS_CMOVE: cmove */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVE32rm, X86_INS_CMOVE: cmove */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVE32rr, X86_INS_CMOVE: cmove */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVE64rm, X86_INS_CMOVE: cmove */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVE64rr, X86_INS_CMOVE: cmove */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVE_F, X86_INS_FCMOVE: fcmove */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_CMOVE_Fp32, X86_INS_FCMOVE: fcmove */
	0,
	{ 0 }
},

{	/* X86_CMOVE_Fp64, X86_INS_FCMOVE: fcmove */
	0,
	{ 0 }
},

{	/* X86_CMOVE_Fp80, X86_INS_FCMOVE: fcmove */
	0,
	{ 0 }
},

{	/* X86_CMOVG16rm, X86_INS_CMOVG: cmovg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVG16rr, X86_INS_CMOVG: cmovg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVG32rm, X86_INS_CMOVG: cmovg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVG32rr, X86_INS_CMOVG: cmovg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVG64rm, X86_INS_CMOVG: cmovg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVG64rr, X86_INS_CMOVG: cmovg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVGE16rm, X86_INS_CMOVGE: cmovge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVGE16rr, X86_INS_CMOVGE: cmovge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVGE32rm, X86_INS_CMOVGE: cmovge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVGE32rr, X86_INS_CMOVGE: cmovge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVGE64rm, X86_INS_CMOVGE: cmovge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVGE64rr, X86_INS_CMOVGE: cmovge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVL16rm, X86_INS_CMOVL: cmovl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVL16rr, X86_INS_CMOVL: cmovl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVL32rm, X86_INS_CMOVL: cmovl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVL32rr, X86_INS_CMOVL: cmovl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVL64rm, X86_INS_CMOVL: cmovl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVL64rr, X86_INS_CMOVL: cmovl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVLE16rm, X86_INS_CMOVLE: cmovle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVLE16rr, X86_INS_CMOVLE: cmovle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVLE32rm, X86_INS_CMOVLE: cmovle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVLE32rr, X86_INS_CMOVLE: cmovle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVLE64rm, X86_INS_CMOVLE: cmovle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVLE64rr, X86_INS_CMOVLE: cmovle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNBE_F, X86_INS_FCMOVNBE: fcmovnbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_CMOVNBE_Fp32, X86_INS_FCMOVNBE: fcmovnbe */
	0,
	{ 0 }
},

{	/* X86_CMOVNBE_Fp64, X86_INS_FCMOVNBE: fcmovnbe */
	0,
	{ 0 }
},

{	/* X86_CMOVNBE_Fp80, X86_INS_FCMOVNBE: fcmovnbe */
	0,
	{ 0 }
},

{	/* X86_CMOVNB_F, X86_INS_FCMOVNB: fcmovnb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_CMOVNB_Fp32, X86_INS_FCMOVNB: fcmovnb */
	0,
	{ 0 }
},

{	/* X86_CMOVNB_Fp64, X86_INS_FCMOVNB: fcmovnb */
	0,
	{ 0 }
},

{	/* X86_CMOVNB_Fp80, X86_INS_FCMOVNB: fcmovnb */
	0,
	{ 0 }
},

{	/* X86_CMOVNE16rm, X86_INS_CMOVNE: cmovne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNE16rr, X86_INS_CMOVNE: cmovne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNE32rm, X86_INS_CMOVNE: cmovne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNE32rr, X86_INS_CMOVNE: cmovne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNE64rm, X86_INS_CMOVNE: cmovne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNE64rr, X86_INS_CMOVNE: cmovne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNE_F, X86_INS_FCMOVNE: fcmovne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_CMOVNE_Fp32, X86_INS_FCMOVNE: fcmovne */
	0,
	{ 0 }
},

{	/* X86_CMOVNE_Fp64, X86_INS_FCMOVNE: fcmovne */
	0,
	{ 0 }
},

{	/* X86_CMOVNE_Fp80, X86_INS_FCMOVNE: fcmovne */
	0,
	{ 0 }
},

{	/* X86_CMOVNO16rm, X86_INS_CMOVNO: cmovno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNO16rr, X86_INS_CMOVNO: cmovno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNO32rm, X86_INS_CMOVNO: cmovno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNO32rr, X86_INS_CMOVNO: cmovno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNO64rm, X86_INS_CMOVNO: cmovno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNO64rr, X86_INS_CMOVNO: cmovno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNP16rm, X86_INS_CMOVNP: cmovnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNP16rr, X86_INS_CMOVNP: cmovnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNP32rm, X86_INS_CMOVNP: cmovnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNP32rr, X86_INS_CMOVNP: cmovnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNP64rm, X86_INS_CMOVNP: cmovnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNP64rr, X86_INS_CMOVNP: cmovnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNP_F, X86_INS_FCMOVNU: fcmovnu */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_CMOVNP_Fp32, X86_INS_FCMOVNP: fcmovnp */
	0,
	{ 0 }
},

{	/* X86_CMOVNP_Fp64, X86_INS_FCMOVNU: fcmovnu */
	0,
	{ 0 }
},

{	/* X86_CMOVNP_Fp80, X86_INS_FCMOVNU: fcmovnu */
	0,
	{ 0 }
},

{	/* X86_CMOVNS16rm, X86_INS_CMOVNS: cmovns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNS16rr, X86_INS_CMOVNS: cmovns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNS32rm, X86_INS_CMOVNS: cmovns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNS32rr, X86_INS_CMOVNS: cmovns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNS64rm, X86_INS_CMOVNS: cmovns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVNS64rr, X86_INS_CMOVNS: cmovns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVO16rm, X86_INS_CMOVO: cmovo */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVO16rr, X86_INS_CMOVO: cmovo */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVO32rm, X86_INS_CMOVO: cmovo */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVO32rr, X86_INS_CMOVO: cmovo */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVO64rm, X86_INS_CMOVO: cmovo */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVO64rr, X86_INS_CMOVO: cmovo */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVP16rm, X86_INS_CMOVP: cmovp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVP16rr, X86_INS_CMOVP: cmovp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVP32rm, X86_INS_CMOVP: cmovp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVP32rr, X86_INS_CMOVP: cmovp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVP64rm, X86_INS_CMOVP: cmovp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVP64rr, X86_INS_CMOVP: cmovp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVP_F, X86_INS_FCMOVU: fcmovu */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_CMOVP_Fp32, X86_INS_FCMOVU: fcmovu */
	0,
	{ 0 }
},

{	/* X86_CMOVP_Fp64, X86_INS_FCMOVU: fcmovu */
	0,
	{ 0 }
},

{	/* X86_CMOVP_Fp80, X86_INS_FCMOVU: fcmovu */
	0,
	{ 0 }
},

{	/* X86_CMOVS16rm, X86_INS_CMOVS: cmovs */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVS16rr, X86_INS_CMOVS: cmovs */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVS32rm, X86_INS_CMOVS: cmovs */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVS32rr, X86_INS_CMOVS: cmovs */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVS64rm, X86_INS_CMOVS: cmovs */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMOVS64rr, X86_INS_CMOVS: cmovs */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMP16i16, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP16mi, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP16mi8, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP16mr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP16ri, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP16ri8, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP16rm, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP16rr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP16rr_REV, X86_INS_CMP: cmp{w}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP32i32, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP32mi, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP32mi8, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP32mr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP32ri, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP32ri8, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP32rm, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP32rr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP32rr_REV, X86_INS_CMP: cmp{l}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP64i32, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP64mi32, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP64mi8, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP64mr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP64ri32, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP64ri8, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP64rm, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP64rr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP64rr_REV, X86_INS_CMP: cmp{q}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP8i8, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP8mi, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP8mi8, X86_INS_CMP: cmp{b}	$dst $src */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP8mr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP8ri, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP8ri8, X86_INS_CMP: cmp{b}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMP8rm, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP8rr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMP8rr_REV, X86_INS_CMP: cmp{b}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPPDrmi, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPPDrmi_alt, X86_INS_CMPPD: cmppd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPPDrri, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPPDrri_alt, X86_INS_CMPPD: cmppd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPPSrmi, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPPSrmi_alt, X86_INS_CMPPS: cmpps */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPPSrri, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPPSrri_alt, X86_INS_CMPPS: cmpps */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPSB, X86_INS_CMPSB: cmpsb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPSDrm, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPSDrm_Int, X86_INS_CMPSD: cmpsd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPSDrm_alt, X86_INS_CMPSD: cmpsd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPSDrr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPSDrr_Int, X86_INS_CMPSD: cmpsd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPSDrr_alt, X86_INS_CMPSD: cmpsd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPSL, X86_INS_CMPSD: cmpsd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_IGNORE, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPSQ, X86_INS_CMPSQ: cmpsq */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPSSrm, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPSSrm_Int, X86_INS_CMPSS: cmpss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPSSrm_alt, X86_INS_CMPSS: cmpss */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPSSrr, X86_INS_CMP: cmp */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPSSrr_Int, X86_INS_CMP: cmp */
	0,
	{ 0 }
},

{	/* X86_CMPSSrr_alt, X86_INS_CMPSS: cmpss */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_CMPSW, X86_INS_CMPSW: cmpsw */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG16B, X86_INS_CMPXCHG16B: cmpxchg16b */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG16rm, X86_INS_CMPXCHG: cmpxchg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG16rr, X86_INS_CMPXCHG: cmpxchg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG32rm, X86_INS_CMPXCHG: cmpxchg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG32rr, X86_INS_CMPXCHG: cmpxchg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG64rm, X86_INS_CMPXCHG: cmpxchg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG64rr, X86_INS_CMPXCHG: cmpxchg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG8B, X86_INS_CMPXCHG8B: cmpxchg8b */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG8rm, X86_INS_CMPXCHG: cmpxchg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_CMPXCHG8rr, X86_INS_CMPXCHG: cmpxchg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_COMISDrm, X86_INS_COMISD: comisd */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_COMISDrm_Int, X86_INS_COMISD: comisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_COMISDrr, X86_INS_COMISD: comisd */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_COMISDrr_Int, X86_INS_COMISD: comisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_COMISSrm, X86_INS_COMISS: comiss */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_COMISSrm_Int, X86_INS_COMISS: comiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_COMISSrr, X86_INS_COMISS: comiss */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_COMISSrr_Int, X86_INS_COMISS: comiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_COMP_FST0r, X86_INS_FCOMP: fcomp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_COM_FIPr, X86_INS_FCOMPI: fcompi */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_COM_FIr, X86_INS_FCOMI: fcomi */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_COM_FST0r, X86_INS_FCOM: fcom */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_COS_F, X86_INS_FCOS: fcos */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_COS_Fp32, X86_INS_FCOS: fcos */
	0,
	{ 0 }
},

{	/* X86_COS_Fp64, X86_INS_FCOS: fcos */
	0,
	{ 0 }
},

{	/* X86_COS_Fp80, X86_INS_FCOS: fcos */
	0,
	{ 0 }
},

{	/* X86_CPUID, X86_INS_CPUID: cpuid */
	0,
	{ 0 }
},

{	/* X86_CQO, X86_INS_CQO: cqo */
	0,
	{ 0 }
},

{	/* X86_CRC32r32m16, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r32m32, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r32m8, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r32r16, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r32r32, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r32r8, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r64m64, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r64m8, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r64r64, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CRC32r64r8, X86_INS_CRC32: crc32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTDQ2PDrm, X86_INS_CVTDQ2PD: cvtdq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTDQ2PDrr, X86_INS_CVTDQ2PD: cvtdq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTDQ2PSrm, X86_INS_CVTDQ2PS: cvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTDQ2PSrr, X86_INS_CVTDQ2PS: cvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTPD2DQrm, X86_INS_CVTPD2DQ: cvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTPD2DQrr, X86_INS_CVTPD2DQ: cvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTPD2PSrm, X86_INS_CVTPD2PS: cvtpd2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTPD2PSrr, X86_INS_CVTPD2PS: cvtpd2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTPS2DQrm, X86_INS_CVTPS2DQ: cvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTPS2DQrr, X86_INS_CVTPS2DQ: cvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTPS2PDrm, X86_INS_CVTPS2PD: cvtps2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTPS2PDrr, X86_INS_CVTPS2PD: cvtps2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSD2SI64rm_Int, X86_INS_CVTSD2SI: cvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSD2SI64rr_Int, X86_INS_CVTSD2SI: cvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSD2SIrm_Int, X86_INS_CVTSD2SI: cvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSD2SIrr_Int, X86_INS_CVTSD2SI: cvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSD2SSrm, X86_INS_CVTSD2SS: cvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSD2SSrm_Int, X86_INS_CVTSD2SS: cvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSD2SSrr, X86_INS_CVTSD2SS: cvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSD2SSrr_Int, X86_INS_CVTSD2SS: cvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI2SDrm, X86_INS_CVTSI2SD: cvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI2SDrm_Int, X86_INS_CVTSI2SD: cvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI2SDrr, X86_INS_CVTSI2SD: cvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI2SDrr_Int, X86_INS_CVTSI2SD: cvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI2SSrm, X86_INS_CVTSI2SS: cvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI2SSrm_Int, X86_INS_CVTSI2SS: cvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI2SSrr, X86_INS_CVTSI2SS: cvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI2SSrr_Int, X86_INS_CVTSI2SS: cvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI642SDrm, X86_INS_CVTSI2SD: cvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI642SDrm_Int, X86_INS_CVTSI2SD: cvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI642SDrr, X86_INS_CVTSI2SD: cvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI642SDrr_Int, X86_INS_CVTSI2SD: cvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI642SSrm, X86_INS_CVTSI2SS: cvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI642SSrm_Int, X86_INS_CVTSI2SS: cvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI642SSrr, X86_INS_CVTSI2SS: cvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSI642SSrr_Int, X86_INS_CVTSI2SS: cvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSS2SDrm, X86_INS_CVTSS2SD: cvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSS2SDrm_Int, X86_INS_CVTSS2SD: cvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSS2SDrr, X86_INS_CVTSS2SD: cvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSS2SDrr_Int, X86_INS_CVTSS2SD: cvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSS2SI64rm_Int, X86_INS_CVTSS2SI: cvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSS2SI64rr_Int, X86_INS_CVTSS2SI: cvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSS2SIrm_Int, X86_INS_CVTSS2SI: cvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTSS2SIrr_Int, X86_INS_CVTSS2SI: cvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTPD2DQrm, X86_INS_CVTTPD2DQ: cvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTPD2DQrr, X86_INS_CVTTPD2DQ: cvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTPS2DQrm, X86_INS_CVTTPS2DQ: cvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTPS2DQrr, X86_INS_CVTTPS2DQ: cvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSD2SI64rm, X86_INS_CVTTSD2SI: cvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSD2SI64rm_Int, X86_INS_CVTTSD2SI: cvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSD2SI64rr, X86_INS_CVTTSD2SI: cvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSD2SI64rr_Int, X86_INS_CVTTSD2SI: cvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSD2SIrm, X86_INS_CVTTSD2SI: cvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSD2SIrm_Int, X86_INS_CVTTSD2SI: cvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSD2SIrr, X86_INS_CVTTSD2SI: cvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSD2SIrr_Int, X86_INS_CVTTSD2SI: cvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSS2SI64rm, X86_INS_CVTTSS2SI: cvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSS2SI64rm_Int, X86_INS_CVTTSS2SI: cvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSS2SI64rr, X86_INS_CVTTSS2SI: cvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSS2SI64rr_Int, X86_INS_CVTTSS2SI: cvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSS2SIrm, X86_INS_CVTTSS2SI: cvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSS2SIrm_Int, X86_INS_CVTTSS2SI: cvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSS2SIrr, X86_INS_CVTTSS2SI: cvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CVTTSS2SIrr_Int, X86_INS_CVTTSS2SI: cvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_CWD, X86_INS_CWD: cwd */
	0,
	{ 0 }
},

{	/* X86_CWDE, X86_INS_CWDE: cwde */
	0,
	{ 0 }
},

{	/* X86_DAA, X86_INS_DAA: daa */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ 0 }
},

{	/* X86_DAS, X86_INS_DAS: das */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ 0 }
},

{	/* X86_DATA16_PREFIX, X86_INS_DATA16: data16 */
	0,
	{ 0 }
},

{	/* X86_DEC16m, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC16r, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC16r_alt, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC32m, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC32r, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC32r_alt, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC64m, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC64r, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC8m, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DEC8r, X86_INS_DEC: dec */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_DIV16m, X86_INS_DIV: div */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV16r, X86_INS_DIV: div */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV32m, X86_INS_DIV: div */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV32r, X86_INS_DIV: div */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV64m, X86_INS_DIV: div */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV64r, X86_INS_DIV: div */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV8m, X86_INS_DIV: div */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV8r, X86_INS_DIV: div */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIVPDrm, X86_INS_DIVPD: divpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVPDrr, X86_INS_DIVPD: divpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVPSrm, X86_INS_DIVPS: divps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVPSrr, X86_INS_DIVPS: divps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVR_F32m, X86_INS_FDIVR: fdivr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIVR_F64m, X86_INS_FDIVR: fdivr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIVR_FI16m, X86_INS_FIDIVR: fidivr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIVR_FI32m, X86_INS_FIDIVR: fidivr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIVR_FPrST0, X86_INS_FDIVRP: fdivrp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIVR_FST0r, X86_INS_FDIVR: fdivr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIVR_Fp32m, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_Fp64m, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_Fp64m32, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_Fp80m32, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_Fp80m64, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_FpI16m32, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_FpI16m64, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_FpI16m80, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_FpI32m32, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_FpI32m64, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_FpI32m80, X86_INS_FDIVR: fdivr */
	0,
	{ 0 }
},

{	/* X86_DIVR_FrST0, X86_INS_FDIVR: fdivr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_DIVSDrm, X86_INS_DIVSD: divsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVSDrm_Int, X86_INS_DIVSD: divsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_DIVSDrr, X86_INS_DIVSD: divsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVSDrr_Int, X86_INS_DIVSD: divsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVSSrm, X86_INS_DIVSS: divss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVSSrm_Int, X86_INS_DIVSS: divss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_DIVSSrr, X86_INS_DIVSS: divss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIVSSrr_Int, X86_INS_DIVSS: divss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_DIV_F32m, X86_INS_FDIV: fdiv */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV_F64m, X86_INS_FDIV: fdiv */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV_FI16m, X86_INS_FIDIV: fidiv */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV_FI32m, X86_INS_FIDIV: fidiv */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV_FPrST0, X86_INS_FDIVP: fdivp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV_FST0r, X86_INS_FDIV: fdiv */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_DIV_Fp32, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_Fp32m, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_Fp64, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_Fp64m, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_Fp64m32, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_Fp80, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_Fp80m32, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_Fp80m64, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_FpI16m32, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_FpI16m64, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_FpI16m80, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_FpI32m32, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_FpI32m64, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_FpI32m80, X86_INS_FDIV: fdiv */
	0,
	{ 0 }
},

{	/* X86_DIV_FrST0, X86_INS_FDIV: fdiv */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_DPPDrmi, X86_INS_DPPD: dppd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_DPPDrri, X86_INS_DPPD: dppd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_DPPSrmi, X86_INS_DPPS: dpps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_DPPSrri, X86_INS_DPPS: dpps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ENCLS, X86_INS_ENCLS: encls */
	0,
	{ 0 }
},

{	/* X86_ENCLU, X86_INS_ENCLU: enclu */
	0,
	{ 0 }
},

{	/* X86_ENCLV, X86_INS_ENCLV: enclv */
	0,
	{ 0 }
},

{	/* X86_ENDBR32, X86_INS_ENDBR32: endbr32 */
	0,
	{ 0 }
},

{	/* X86_ENDBR64, X86_INS_ENDBR64: endbr64 */
	0,
	{ 0 }
},

{	/* X86_ENTER, X86_INS_ENTER: enter */
	0,
	{ CS_AC_IGNORE, CS_AC_IGNORE, 0 }
},

{	/* X86_EXTRACTPSmr, X86_INS_EXTRACTPS: extractps */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_EXTRACTPSrr, X86_INS_EXTRACTPS: extractps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_EXTRQ, X86_INS_EXTRQ: extrq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_EXTRQI, X86_INS_EXTRQ: extrq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, CS_AC_IGNORE, 0 }
},

{	/* X86_F2XM1, X86_INS_F2XM1: f2xm1 */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FARCALL16i, X86_INS_LCALL: lcall{w}	$seg : $off */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_FARCALL16m, X86_INS_LCALL: lcall */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_FARCALL32i, X86_INS_LCALL: lcall{l}	$seg : $off */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_FARCALL32m, X86_INS_CALL: call */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_FARCALL64, X86_INS_LCALL: lcall */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_FARJMP16i, X86_INS_LJMP: ljmp{w}	$seg : $off */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_FARJMP16m, X86_INS_LJMP: ljmp{w}	{*}$dst */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_FARJMP32i, X86_INS_LJMP: ljmp{l}	$seg : $off */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_FARJMP32m, X86_INS_JMP: jmp */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_FARJMP64, X86_INS_LJMP: ljmp */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_FBLDm, X86_INS_FBLD: fbld */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FBSTPm, X86_INS_FBSTP: fbstp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_FCOM32m, X86_INS_FCOM: fcom */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FCOM64m, X86_INS_FCOM: fcom */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FCOMP32m, X86_INS_FCOMP: fcomp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FCOMP64m, X86_INS_FCOMP: fcomp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FCOMPP, X86_INS_FCOMPP: fcompp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ 0 }
},

{	/* X86_FDECSTP, X86_INS_FDECSTP: fdecstp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FDISI8087_NOP, X86_INS_FDISI8087_NOP: fdisi8087_nop */
	0,
	{ 0 }
},

{	/* X86_FEMMS, X86_INS_FEMMS: femms */
	0,
	{ 0 }
},

{	/* X86_FENI8087_NOP, X86_INS_FENI8087_NOP: feni8087_nop */
	0,
	{ 0 }
},

{	/* X86_FFREE, X86_INS_FFREE: ffree */
	X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FFREEP, X86_INS_FFREEP: ffreep */
	0,
	{ 0 }
},

{	/* X86_FICOM16m, X86_INS_FICOM: ficom */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FICOM32m, X86_INS_FICOM: ficom */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FICOMP16m, X86_INS_FICOMP: ficomp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FICOMP32m, X86_INS_FICOMP: ficomp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FINCSTP, X86_INS_FINCSTP: fincstp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FLDCW16m, X86_INS_FLDCW: fldcw */
	X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FLDENVm, X86_INS_FLDENV: fldenv */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_FLDL2E, X86_INS_FLDL2E: fldl2e */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FLDL2T, X86_INS_FLDL2T: fldl2t */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FLDLG2, X86_INS_FLDLG2: fldlg2 */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FLDLN2, X86_INS_FLDLN2: fldln2 */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FLDPI, X86_INS_FLDPI: fldpi */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FNCLEX, X86_INS_FNCLEX: fnclex */
	X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FNINIT, X86_INS_FNINIT: fninit */
	X86_FPU_FLAGS_RESET_C0 | X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_RESET_C2 | X86_FPU_FLAGS_RESET_C3,
	{ 0 }
},

{	/* X86_FNOP, X86_INS_FNOP: fnop */
	X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FNSTCW16m, X86_INS_FNSTCW: fnstcw */
	X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_FNSTSW16r, X86_INS_FNSTSW: fnstsw */
	X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_FNSTSWm, X86_INS_FNSTSW: fnstsw */
	X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_FPATAN, X86_INS_FPATAN: fpatan */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FPNCEST0r, X86_INS_FSTPNCE: fstpnce */
	0,
	{ 0 }
},

{	/* X86_FPREM, X86_INS_FPREM: fprem */
	X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ 0 }
},

{	/* X86_FPREM1, X86_INS_FPREM1: fprem1 */
	X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ 0 }
},

{	/* X86_FPTAN, X86_INS_FPTAN: fptan */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FRNDINT, X86_INS_FRNDINT: frndint */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FRSTORm, X86_INS_FRSTOR: frstor */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_FSAVEm, X86_INS_FNSAVE: fnsave */
	X86_FPU_FLAGS_RESET_C0 | X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_RESET_C2 | X86_FPU_FLAGS_RESET_C3,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_FSCALE, X86_INS_FSCALE: fscale */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FSETPM, X86_INS_FSETPM: fsetpm */
	0,
	{ 0 }
},

{	/* X86_FSINCOS, X86_INS_FSINCOS: fsincos */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FSTENVm, X86_INS_FNSTENV: fnstenv */
	X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_FXAM, X86_INS_FXAM: fxam */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ 0 }
},

{	/* X86_FXRSTOR, X86_INS_FXRSTOR: fxrstor */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_FXRSTOR64, X86_INS_FXRSTOR64: fxrstor64 */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_FXSAVE, X86_INS_FXSAVE: fxsave */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_FXSAVE64, X86_INS_FXSAVE64: fxsave64 */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_FXTRACT, X86_INS_FXTRACT: fxtract */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FYL2X, X86_INS_FYL2X: fyl2x */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_FYL2XP1, X86_INS_FYL2XP1: fyl2xp1 */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_GETSEC, X86_INS_GETSEC: getsec */
	0,
	{ 0 }
},

{	/* X86_GF2P8AFFINEINVQBrmi, X86_INS_GF2P8AFFINEINVQB: gf2p8affineinvqb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_GF2P8AFFINEINVQBrri, X86_INS_GF2P8AFFINEINVQB: gf2p8affineinvqb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_GF2P8AFFINEQBrmi, X86_INS_GF2P8AFFINEQB: gf2p8affineqb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_GF2P8AFFINEQBrri, X86_INS_GF2P8AFFINEQB: gf2p8affineqb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_GF2P8MULBrm, X86_INS_GF2P8MULB: gf2p8mulb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_GF2P8MULBrr, X86_INS_GF2P8MULB: gf2p8mulb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_HADDPDrm, X86_INS_HADDPD: haddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_HADDPDrr, X86_INS_HADDPD: haddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_HADDPSrm, X86_INS_HADDPS: haddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_HADDPSrr, X86_INS_HADDPS: haddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_HLT, X86_INS_HLT: hlt */
	0,
	{ 0 }
},

{	/* X86_HSUBPDrm, X86_INS_HSUBPD: hsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_HSUBPDrr, X86_INS_HSUBPD: hsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_HSUBPSrm, X86_INS_HSUBPS: hsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_HSUBPSrr, X86_INS_HSUBPS: hsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IDIV16m, X86_INS_IDIV: idiv */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IDIV16r, X86_INS_IDIV: idiv */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IDIV32m, X86_INS_IDIV: idiv */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IDIV32r, X86_INS_IDIV: idiv */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IDIV64m, X86_INS_IDIV: idiv */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IDIV64r, X86_INS_IDIV: idiv */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IDIV8m, X86_INS_IDIV: idiv */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IDIV8r, X86_INS_IDIV: idiv */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_F16m, X86_INS_FILD: fild */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_F32m, X86_INS_FILD: fild */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_F64m, X86_INS_FILD: fild */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp16m32, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp16m64, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp16m80, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp32m32, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp32m64, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp32m80, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp64m32, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp64m64, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_ILD_Fp64m80, X86_INS_FILD: fild */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_IMUL16m, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IMUL16r, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IMUL16rm, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IMUL16rmi, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL16rmi8, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL16rr, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IMUL16rri, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL16rri8, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL32m, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IMUL32r, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IMUL32rm, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IMUL32rmi, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL32rmi8, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL32rr, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IMUL32rri, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL32rri8, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL64m, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IMUL64r, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IMUL64rm, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IMUL64rmi32, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL64rmi8, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL64rr, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IMUL64rri32, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL64rri8, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_IMUL8m, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IMUL8r, X86_INS_IMUL: imul */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_IN16ri, X86_INS_IN: in */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_IN16rr, X86_INS_IN: in */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IN32ri, X86_INS_IN: in */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_IN32rr, X86_INS_IN: in */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_IN8ri, X86_INS_IN: in */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_IN8rr, X86_INS_IN: in */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_INC16m, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC16r, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC16r_alt, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC32m, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC32r, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC32r_alt, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC64m, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC64r, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC8m, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INC8r, X86_INS_INC: inc */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_INCSSPD, X86_INS_INCSSPD: incsspd */
	0,
	{ 0 }
},

{	/* X86_INCSSPQ, X86_INS_INCSSPQ: incsspq */
	0,
	{ 0 }
},

{	/* X86_INSB, X86_INS_INSB: insb */
	0,
	{ CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_INSERTPSrm, X86_INS_INSERTPS: insertps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_INSERTPSrr, X86_INS_INSERTPS: insertps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_INSERTQ, X86_INS_INSERTQ: insertq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_INSERTQI, X86_INS_INSERTQ: insertq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_IGNORE, 0 }
},

{	/* X86_INSL, X86_INS_INSD: insd */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_INSW, X86_INS_INSW: insw */
	0,
	{ CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_INT, X86_INS_INT: int */
	X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_INT1, X86_INS_INT1: int1 */
	X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_INT3, X86_INS_INT3: int3 */
	X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_INTO, X86_INS_INTO: into */
	X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_INVD, X86_INS_INVD: invd */
	0,
	{ 0 }
},

{	/* X86_INVEPT32, X86_INS_INVEPT: invept */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_INVEPT64, X86_INS_INVEPT: invept */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_INVLPG, X86_INS_INVLPG: invlpg */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_INVLPGA32, X86_INS_INVLPGA: invlpga */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_INVLPGA64, X86_INS_INVLPGA: invlpga */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_INVPCID32, X86_INS_INVPCID: invpcid */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_INVPCID64, X86_INS_INVPCID: invpcid */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_INVVPID32, X86_INS_INVVPID: invvpid */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_INVVPID64, X86_INS_INVVPID: invvpid */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_IRET16, X86_INS_IRET: iret */
	X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IRET32, X86_INS_IRETD: iretd */
	X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IRET64, X86_INS_IRETQ: iretq */
	X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_ISTT_FP16m, X86_INS_FISTTP: fisttp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ISTT_FP32m, X86_INS_FISTTP: fisttp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ISTT_FP64m, X86_INS_FISTTP: fisttp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ISTT_Fp16m32, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ISTT_Fp16m64, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ISTT_Fp16m80, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ISTT_Fp32m32, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ISTT_Fp32m64, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ISTT_Fp32m80, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ISTT_Fp64m32, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ISTT_Fp64m64, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ISTT_Fp64m80, X86_INS_FISTTP: fisttp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_F16m, X86_INS_FIST: fist */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_IST_F32m, X86_INS_FIST: fist */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_IST_FP16m, X86_INS_FISTP: fistp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_IST_FP32m, X86_INS_FISTP: fistp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_IST_FP64m, X86_INS_FISTP: fistp */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp16m32, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp16m64, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp16m80, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp32m32, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp32m64, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp32m80, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp64m32, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp64m64, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_IST_Fp64m80, X86_INS_FISTP: fistp */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_JAE_1, X86_INS_JAE: jae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JAE_2, X86_INS_JAE: jae	$dst */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JAE_4, X86_INS_JAE: jae	$dst */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JA_1, X86_INS_JA: ja */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JA_2, X86_INS_JA: ja	$dst */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JA_4, X86_INS_JA: ja	$dst */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JBE_1, X86_INS_JBE: jbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JBE_2, X86_INS_JBE: jbe	$dst */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JBE_4, X86_INS_JBE: jbe	$dst */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JB_1, X86_INS_JB: jb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JB_2, X86_INS_JB: jb	$dst */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JB_4, X86_INS_JB: jb	$dst */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JCXZ, X86_INS_JCXZ: jcxz */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JECXZ, X86_INS_JECXZ: jecxz */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JE_1, X86_INS_JE: je */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JE_2, X86_INS_JE: je	$dst */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JE_4, X86_INS_JE: je	$dst */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JGE_1, X86_INS_JGE: jge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JGE_2, X86_INS_JGE: jge	$dst */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JGE_4, X86_INS_JGE: jge	$dst */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JG_1, X86_INS_JG: jg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JG_2, X86_INS_JG: jg	$dst */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JG_4, X86_INS_JG: jg	$dst */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JLE_1, X86_INS_JLE: jle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JLE_2, X86_INS_JLE: jle	$dst */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JLE_4, X86_INS_JLE: jle	$dst */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JL_1, X86_INS_JL: jl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JL_2, X86_INS_JL: jl	$dst */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JL_4, X86_INS_JL: jl	$dst */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JMP16m, X86_INS_JMP: jmp */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_JMP16m_NT, X86_INS_JMP: jmp */
	0,
	{ 0 }
},

{	/* X86_JMP16r, X86_INS_JMP: jmp */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_JMP16r_NT, X86_INS_JMP: jmp */
	0,
	{ 0 }
},

{	/* X86_JMP32m, X86_INS_JMP: jmp */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_JMP32m_NT, X86_INS_JMP: jmp */
	0,
	{ 0 }
},

{	/* X86_JMP32r, X86_INS_JMP: jmp */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_JMP32r_NT, X86_INS_JMP: jmp */
	0,
	{ 0 }
},

{	/* X86_JMP64m, X86_INS_JMP: jmp */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_JMP64m_NT, X86_INS_JMP: jmp */
	0,
	{ 0 }
},

{	/* X86_JMP64r, X86_INS_JMP: jmp */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_JMP64r_NT, X86_INS_JMP: jmp */
	0,
	{ 0 }
},

{	/* X86_JMP_1, X86_INS_JMP: jmp */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JMP_2, X86_INS_JMP: jmp	$dst */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JMP_4, X86_INS_JMP: jmp	$dst */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNE_1, X86_INS_JNE: jne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNE_2, X86_INS_JNE: jne	$dst */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNE_4, X86_INS_JNE: jne	$dst */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNO_1, X86_INS_JNO: jno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNO_2, X86_INS_JNO: jno	$dst */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNO_4, X86_INS_JNO: jno	$dst */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNP_1, X86_INS_JNP: jnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNP_2, X86_INS_JNP: jnp	$dst */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNP_4, X86_INS_JNP: jnp	$dst */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNS_1, X86_INS_JNS: jns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNS_2, X86_INS_JNS: jns	$dst */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JNS_4, X86_INS_JNS: jns	$dst */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JO_1, X86_INS_JO: jo */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JO_2, X86_INS_JO: jo	$dst */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JO_4, X86_INS_JO: jo	$dst */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JP_1, X86_INS_JP: jp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JP_2, X86_INS_JP: jp	$dst */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JP_4, X86_INS_JP: jp	$dst */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JRCXZ, X86_INS_JRCXZ: jrcxz */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JS_1, X86_INS_JS: js */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JS_2, X86_INS_JS: js	$dst */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_JS_4, X86_INS_JS: js	$dst */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_KADDBrr, X86_INS_KADDB: kaddb */
	0,
	{ 0 }
},

{	/* X86_KADDDrr, X86_INS_KADDD: kaddd */
	0,
	{ 0 }
},

{	/* X86_KADDQrr, X86_INS_KADDQ: kaddq */
	0,
	{ 0 }
},

{	/* X86_KADDWrr, X86_INS_KADDW: kaddw */
	0,
	{ 0 }
},

{	/* X86_KANDBrr, X86_INS_KANDB: kandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KANDDrr, X86_INS_KANDD: kandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KANDNBrr, X86_INS_KANDNB: kandnb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KANDNDrr, X86_INS_KANDND: kandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KANDNQrr, X86_INS_KANDNQ: kandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KANDNWrr, X86_INS_KANDNW: kandnw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KANDQrr, X86_INS_KANDQ: kandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KANDWrr, X86_INS_KANDW: kandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KMOVBkk, X86_INS_KMOVB: kmovb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVBkm, X86_INS_KMOVB: kmovb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVBkr, X86_INS_KMOVB: kmovb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVBmk, X86_INS_KMOVB: kmovb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KMOVBrk, X86_INS_KMOVB: kmovb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVDkk, X86_INS_KMOVD: kmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVDkm, X86_INS_KMOVD: kmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVDkr, X86_INS_KMOVD: kmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVDmk, X86_INS_KMOVD: kmovd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KMOVDrk, X86_INS_KMOVD: kmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVQkk, X86_INS_KMOVQ: kmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVQkm, X86_INS_KMOVQ: kmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVQkr, X86_INS_KMOVQ: kmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVQmk, X86_INS_KMOVQ: kmovq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KMOVQrk, X86_INS_KMOVQ: kmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVWkk, X86_INS_KMOVW: kmovw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVWkm, X86_INS_KMOVW: kmovw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVWkr, X86_INS_KMOVW: kmovw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KMOVWmk, X86_INS_KMOVW: kmovw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KMOVWrk, X86_INS_KMOVW: kmovw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KNOTBrr, X86_INS_KNOTB: knotb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KNOTDrr, X86_INS_KNOTD: knotd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KNOTQrr, X86_INS_KNOTQ: knotq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KNOTWrr, X86_INS_KNOTW: knotw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_KORBrr, X86_INS_KORB: korb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KORDrr, X86_INS_KORD: kord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KORQrr, X86_INS_KORQ: korq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KORTESTBrr, X86_INS_KORTESTB: kortestb */
	X86_REG_EFLAGS,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KORTESTDrr, X86_INS_KORTESTD: kortestd */
	X86_REG_EFLAGS,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KORTESTQrr, X86_INS_KORTESTQ: kortestq */
	X86_REG_EFLAGS,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KORTESTWrr, X86_INS_KORTESTW: kortestw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KORWrr, X86_INS_KORW: korw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KSHIFTLBri, X86_INS_KSHIFTLB: kshiftlb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_KSHIFTLDri, X86_INS_KSHIFTLD: kshiftld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_KSHIFTLQri, X86_INS_KSHIFTLQ: kshiftlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_KSHIFTLWri, X86_INS_KSHIFTLW: kshiftlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_KSHIFTRBri, X86_INS_KSHIFTRB: kshiftrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_KSHIFTRDri, X86_INS_KSHIFTRD: kshiftrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_KSHIFTRQri, X86_INS_KSHIFTRQ: kshiftrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_KSHIFTRWri, X86_INS_KSHIFTRW: kshiftrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_KTESTBrr, X86_INS_KTESTB: ktestb */
	0,
	{ 0 }
},

{	/* X86_KTESTDrr, X86_INS_KTESTD: ktestd */
	0,
	{ 0 }
},

{	/* X86_KTESTQrr, X86_INS_KTESTQ: ktestq */
	0,
	{ 0 }
},

{	/* X86_KTESTWrr, X86_INS_KTESTW: ktestw */
	0,
	{ 0 }
},

{	/* X86_KUNPCKBWrr, X86_INS_KUNPCKBW: kunpckbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KUNPCKDQrr, X86_INS_KUNPCKDQ: kunpckdq */
	0,
	{ 0 }
},

{	/* X86_KUNPCKWDrr, X86_INS_KUNPCKWD: kunpckwd */
	0,
	{ 0 }
},

{	/* X86_KXNORBrr, X86_INS_KXNORB: kxnorb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KXNORDrr, X86_INS_KXNORD: kxnord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KXNORQrr, X86_INS_KXNORQ: kxnorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KXNORWrr, X86_INS_KXNORW: kxnorw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KXORBrr, X86_INS_KXORB: kxorb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KXORDrr, X86_INS_KXORD: kxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KXORQrr, X86_INS_KXORQ: kxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_KXORWrr, X86_INS_KXORW: kxorw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_LAHF, X86_INS_LAHF: lahf */
	0,
	{ 0 }
},

{	/* X86_LAR16rm, X86_INS_LAR: lar */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LAR16rr, X86_INS_LAR: lar */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LAR32rm, X86_INS_LAR: lar */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LAR32rr, X86_INS_LAR: lar */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LAR64rm, X86_INS_LAR: lar */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LAR64rr, X86_INS_LAR: lar */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LDDQUrm, X86_INS_LDDQU: lddqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LDMXCSR, X86_INS_LDMXCSR: ldmxcsr */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LDS16rm, X86_INS_LDS: lds */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LDS32rm, X86_INS_LDS: lds */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LD_F0, X86_INS_FLDZ: fldz */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_LD_F1, X86_INS_FLD1: fld1 */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_LD_F32m, X86_INS_FLD: fld */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_F64m, X86_INS_FLD: fld */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_F80m, X86_INS_FLD: fld */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp032, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp064, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp080, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp132, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp164, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp180, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp32m, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp32m64, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp32m80, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp64m, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp64m80, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Fp80m, X86_INS_FLD: fld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LD_Frr, X86_INS_FLD: fld */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_LEA16r, X86_INS_LEA: lea */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LEA32r, X86_INS_LEA: lea */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LEA64_32r, X86_INS_LEA: lea */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LEA64r, X86_INS_LEA: lea */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LEAVE, X86_INS_LEAVE: leave */
	0,
	{ 0 }
},

{	/* X86_LEAVE64, X86_INS_LEAVE: leave */
	0,
	{ 0 }
},

{	/* X86_LES16rm, X86_INS_LES: les */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LES32rm, X86_INS_LES: les */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LFENCE, X86_INS_LFENCE: lfence */
	0,
	{ 0 }
},

{	/* X86_LFS16rm, X86_INS_LFS: lfs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LFS32rm, X86_INS_LFS: lfs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LFS64rm, X86_INS_LFS: lfs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LGDT16m, X86_INS_LGDT: lgdt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LGDT32m, X86_INS_LGDT: lgdt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LGDT64m, X86_INS_LGDT: lgdt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LGS16rm, X86_INS_LGS: lgs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LGS32rm, X86_INS_LGS: lgs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LGS64rm, X86_INS_LGS: lgs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LIDT16m, X86_INS_LIDT: lidt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LIDT32m, X86_INS_LIDT: lidt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LIDT64m, X86_INS_LIDT: lidt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LLDT16m, X86_INS_LLDT: lldt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LLDT16r, X86_INS_LLDT: lldt */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LLWPCB, X86_INS_LLWPCB: llwpcb */
	0,
	{ 0 }
},

{	/* X86_LLWPCB64, X86_INS_LLWPCB: llwpcb */
	0,
	{ 0 }
},

{	/* X86_LMSW16m, X86_INS_LMSW: lmsw */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LMSW16r, X86_INS_LMSW: lmsw */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LOCK_PREFIX, X86_INS_LOCK: lock */
	0,
	{ 0 }
},

{	/* X86_LODSB, X86_INS_LODSB: lodsb */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LODSL, X86_INS_LODSD: lodsd */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LODSQ, X86_INS_LODSQ: lodsq */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LODSW, X86_INS_LODSW: lodsw */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LOOP, X86_INS_LOOP: loop */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_LOOPE, X86_INS_LOOPE: loope */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_LOOPNE, X86_INS_LOOPNE: loopne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_LRETIL, X86_INS_RETF: retf */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_LRETIQ, X86_INS_RETFQ: retfq */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_LRETIW, X86_INS_RETF: retf */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_LRETL, X86_INS_RETF: retf */
	0,
	{ 0 }
},

{	/* X86_LRETQ, X86_INS_RETFQ: retfq */
	0,
	{ 0 }
},

{	/* X86_LRETW, X86_INS_RETF: retf */
	0,
	{ 0 }
},

{	/* X86_LSL16rm, X86_INS_LSL: lsl */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LSL16rr, X86_INS_LSL: lsl */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LSL32rm, X86_INS_LSL: lsl */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LSL32rr, X86_INS_LSL: lsl */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LSL64rm, X86_INS_LSL: lsl */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LSL64rr, X86_INS_LSL: lsl */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LSS16rm, X86_INS_LSS: lss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LSS32rm, X86_INS_LSS: lss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LSS64rm, X86_INS_LSS: lss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LTRm, X86_INS_LTR: ltr */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LTRr, X86_INS_LTR: ltr */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_LWPINS32rmi, X86_INS_LWPINS: lwpins */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_LWPINS32rri, X86_INS_LWPINS: lwpins */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_LWPINS64rmi, X86_INS_LWPINS: lwpins */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_LWPINS64rri, X86_INS_LWPINS: lwpins */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_LWPVAL32rmi, X86_INS_LWPVAL: lwpval */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_LWPVAL32rri, X86_INS_LWPVAL: lwpval */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_LWPVAL64rmi, X86_INS_LWPVAL: lwpval */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_LWPVAL64rri, X86_INS_LWPVAL: lwpval */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_LZCNT16rm, X86_INS_LZCNT: lzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LZCNT16rr, X86_INS_LZCNT: lzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LZCNT32rm, X86_INS_LZCNT: lzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LZCNT32rr, X86_INS_LZCNT: lzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LZCNT64rm, X86_INS_LZCNT: lzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_LZCNT64rr, X86_INS_LZCNT: lzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MASKMOVDQU, X86_INS_MASKMOVDQU: maskmovdqu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MASKMOVDQU64, X86_INS_MASKMOVDQU: maskmovdqu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MAXCPDrm, X86_INS_MAXPD: maxpd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXCPDrr, X86_INS_MAXPD: maxpd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXCPSrm, X86_INS_MAXPS: maxps	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXCPSrr, X86_INS_MAXPS: maxps	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXCSDrm, X86_INS_MAXSD: maxsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXCSDrr, X86_INS_MAXSD: maxsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXCSSrm, X86_INS_MAXSS: maxss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXCSSrr, X86_INS_MAXSS: maxss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXPDrm, X86_INS_MAXPD: maxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXPDrr, X86_INS_MAXPD: maxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXPSrm, X86_INS_MAXPS: maxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXPSrr, X86_INS_MAXPS: maxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXSDrm, X86_INS_MAXSD: maxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXSDrm_Int, X86_INS_MAXSD: maxsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MAXSDrr, X86_INS_MAXSD: maxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXSDrr_Int, X86_INS_MAXSD: maxsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXSSrm, X86_INS_MAXSS: maxss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXSSrm_Int, X86_INS_MAXSS: maxss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MAXSSrr, X86_INS_MAXSS: maxss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MAXSSrr_Int, X86_INS_MAXSS: maxss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MFENCE, X86_INS_MFENCE: mfence */
	0,
	{ 0 }
},

{	/* X86_MINCPDrm, X86_INS_MINPD: minpd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINCPDrr, X86_INS_MINPD: minpd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINCPSrm, X86_INS_MINPS: minps	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINCPSrr, X86_INS_MINPS: minps	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINCSDrm, X86_INS_MINSD: minsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINCSDrr, X86_INS_MINSD: minsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINCSSrm, X86_INS_MINSS: minss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINCSSrr, X86_INS_MINSS: minss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINPDrm, X86_INS_MINPD: minpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINPDrr, X86_INS_MINPD: minpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINPSrm, X86_INS_MINPS: minps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINPSrr, X86_INS_MINPS: minps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINSDrm, X86_INS_MINSD: minsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINSDrm_Int, X86_INS_MINSD: minsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MINSDrr, X86_INS_MINSD: minsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINSDrr_Int, X86_INS_MINSD: minsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINSSrm, X86_INS_MINSS: minss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINSSrm_Int, X86_INS_MINSS: minss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MINSSrr, X86_INS_MINSS: minss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MINSSrr_Int, X86_INS_MINSS: minss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTPD2PIirm, X86_INS_CVTPD2PI: cvtpd2pi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTPD2PIirr, X86_INS_CVTPD2PI: cvtpd2pi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTPI2PDirm, X86_INS_CVTPI2PD: cvtpi2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTPI2PDirr, X86_INS_CVTPI2PD: cvtpi2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTPI2PSirm, X86_INS_CVTPI2PS: cvtpi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTPI2PSirr, X86_INS_CVTPI2PS: cvtpi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTPS2PIirm, X86_INS_CVTPS2PI: cvtps2pi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTPS2PIirr, X86_INS_CVTPS2PI: cvtps2pi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTTPD2PIirm, X86_INS_CVTTPD2PI: cvttpd2pi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTTPD2PIirr, X86_INS_CVTTPD2PI: cvttpd2pi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTTPS2PIirm, X86_INS_CVTTPS2PI: cvttps2pi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_CVTTPS2PIirr, X86_INS_CVTTPS2PI: cvttps2pi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_EMMS, X86_INS_EMMS: emms */
	0,
	{ 0 }
},

{	/* X86_MMX_MASKMOVQ, X86_INS_MASKMOVQ: maskmovq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MMX_MASKMOVQ64, X86_INS_MASKMOVQ: maskmovq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVD64from64rm, X86_INS_MOVD: movd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVD64from64rr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVD64grr, X86_INS_MOVD: movd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVD64mr, X86_INS_MOVD: movd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVD64rm, X86_INS_MOVD: movd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVD64rr, X86_INS_MOVD: movd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVD64to64rm, X86_INS_MOVD: movd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVD64to64rr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVDQ2Qrr, X86_INS_MOVDQ2Q: movdq2q */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVFR642Qrr, X86_INS_MOVDQ2Q: movdq2q	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVNTQmr, X86_INS_MOVNTQ: movntq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVQ2DQrr, X86_INS_MOVQ2DQ: movq2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVQ2FR64rr, X86_INS_MOVQ2DQ: movq2dq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVQ64mr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVQ64rm, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVQ64rr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_MOVQ64rr_REV, X86_INS_MOVQ: movq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PABSBrm, X86_INS_PABSB: pabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PABSBrr, X86_INS_PABSB: pabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PABSDrm, X86_INS_PABSD: pabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PABSDrr, X86_INS_PABSD: pabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PABSWrm, X86_INS_PABSW: pabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PABSWrr, X86_INS_PABSW: pabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PACKSSDWirm, X86_INS_PACKSSDW: packssdw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PACKSSDWirr, X86_INS_PACKSSDW: packssdw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PACKSSWBirm, X86_INS_PACKSSWB: packsswb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PACKSSWBirr, X86_INS_PACKSSWB: packsswb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PACKUSWBirm, X86_INS_PACKUSWB: packuswb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PACKUSWBirr, X86_INS_PACKUSWB: packuswb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDBirm, X86_INS_PADDB: paddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDBirr, X86_INS_PADDB: paddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDDirm, X86_INS_PADDD: paddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDDirr, X86_INS_PADDD: paddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDQirm, X86_INS_PADDQ: paddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDQirr, X86_INS_PADDQ: paddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDSBirm, X86_INS_PADDSB: paddsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDSBirr, X86_INS_PADDSB: paddsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDSWirm, X86_INS_PADDSW: paddsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDSWirr, X86_INS_PADDSW: paddsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDUSBirm, X86_INS_PADDUSB: paddusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDUSBirr, X86_INS_PADDUSB: paddusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDUSWirm, X86_INS_PADDUSW: paddusw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDUSWirr, X86_INS_PADDUSW: paddusw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDWirm, X86_INS_PADDW: paddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PADDWirr, X86_INS_PADDW: paddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PALIGNRrmi, X86_INS_PALIGNR: palignr */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PALIGNRrri, X86_INS_PALIGNR: palignr */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PANDNirm, X86_INS_PANDN: pandn */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PANDNirr, X86_INS_PANDN: pandn */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PANDirm, X86_INS_PAND: pand */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PANDirr, X86_INS_PAND: pand */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PAVGBirm, X86_INS_PAVGB: pavgb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PAVGBirr, X86_INS_PAVGB: pavgb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PAVGWirm, X86_INS_PAVGW: pavgw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PAVGWirr, X86_INS_PAVGW: pavgw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPEQBirm, X86_INS_PCMPEQB: pcmpeqb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPEQBirr, X86_INS_PCMPEQB: pcmpeqb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPEQDirm, X86_INS_PCMPEQD: pcmpeqd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPEQDirr, X86_INS_PCMPEQD: pcmpeqd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPEQWirm, X86_INS_PCMPEQW: pcmpeqw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPEQWirr, X86_INS_PCMPEQW: pcmpeqw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPGTBirm, X86_INS_PCMPGTB: pcmpgtb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPGTBirr, X86_INS_PCMPGTB: pcmpgtb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPGTDirm, X86_INS_PCMPGTD: pcmpgtd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPGTDirr, X86_INS_PCMPGTD: pcmpgtd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPGTWirm, X86_INS_PCMPGTW: pcmpgtw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PCMPGTWirr, X86_INS_PCMPGTW: pcmpgtw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PEXTRWrr, X86_INS_PEXTRW: pextrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHADDDrm, X86_INS_PHADDD: phaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHADDDrr, X86_INS_PHADDD: phaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHADDSWrm, X86_INS_PHADDSW: phaddsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHADDSWrr, X86_INS_PHADDSW: phaddsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHADDWrm, X86_INS_PHADDW: phaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHADDWrr, X86_INS_PHADDW: phaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHSUBDrm, X86_INS_PHSUBD: phsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHSUBDrr, X86_INS_PHSUBD: phsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHSUBSWrm, X86_INS_PHSUBSW: phsubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHSUBSWrr, X86_INS_PHSUBSW: phsubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHSUBWrm, X86_INS_PHSUBW: phsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PHSUBWrr, X86_INS_PHSUBW: phsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PINSRWrm, X86_INS_PINSRW: pinsrw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MMX_PINSRWrr, X86_INS_PINSRW: pinsrw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMADDUBSWrm, X86_INS_PMADDUBSW: pmaddubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMADDUBSWrr, X86_INS_PMADDUBSW: pmaddubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMADDWDirm, X86_INS_PMADDWD: pmaddwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMADDWDirr, X86_INS_PMADDWD: pmaddwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMAXSWirm, X86_INS_PMAXSW: pmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMAXSWirr, X86_INS_PMAXSW: pmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMAXUBirm, X86_INS_PMAXUB: pmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMAXUBirr, X86_INS_PMAXUB: pmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMINSWirm, X86_INS_PMINSW: pminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMINSWirr, X86_INS_PMINSW: pminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMINUBirm, X86_INS_PMINUB: pminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMINUBirr, X86_INS_PMINUB: pminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMOVMSKBrr, X86_INS_PMOVMSKB: pmovmskb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULHRSWrm, X86_INS_PMULHRSW: pmulhrsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULHRSWrr, X86_INS_PMULHRSW: pmulhrsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULHUWirm, X86_INS_PMULHUW: pmulhuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULHUWirr, X86_INS_PMULHUW: pmulhuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULHWirm, X86_INS_PMULHW: pmulhw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULHWirr, X86_INS_PMULHW: pmulhw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULLWirm, X86_INS_PMULLW: pmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULLWirr, X86_INS_PMULLW: pmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULUDQirm, X86_INS_PMULUDQ: pmuludq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PMULUDQirr, X86_INS_PMULUDQ: pmuludq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PORirm, X86_INS_POR: por */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PORirr, X86_INS_POR: por */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSADBWirm, X86_INS_PSADBW: psadbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSADBWirr, X86_INS_PSADBW: psadbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSHUFBrm, X86_INS_PSHUFB: pshufb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSHUFBrr, X86_INS_PSHUFB: pshufb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSHUFWmi, X86_INS_PSHUFW: pshufw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSHUFWri, X86_INS_PSHUFW: pshufw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSIGNBrm, X86_INS_PSIGNB: psignb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSIGNBrr, X86_INS_PSIGNB: psignb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSIGNDrm, X86_INS_PSIGND: psignd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSIGNDrr, X86_INS_PSIGND: psignd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSIGNWrm, X86_INS_PSIGNW: psignw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSIGNWrr, X86_INS_PSIGNW: psignw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSLLDri, X86_INS_PSLLD: pslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSLLDrm, X86_INS_PSLLD: pslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSLLDrr, X86_INS_PSLLD: pslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSLLQri, X86_INS_PSLLQ: psllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSLLQrm, X86_INS_PSLLQ: psllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSLLQrr, X86_INS_PSLLQ: psllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSLLWri, X86_INS_PSLLW: psllw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSLLWrm, X86_INS_PSLLW: psllw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSLLWrr, X86_INS_PSLLW: psllw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRADri, X86_INS_PSRAD: psrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSRADrm, X86_INS_PSRAD: psrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRADrr, X86_INS_PSRAD: psrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRAWri, X86_INS_PSRAW: psraw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSRAWrm, X86_INS_PSRAW: psraw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRAWrr, X86_INS_PSRAW: psraw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRLDri, X86_INS_PSRLD: psrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSRLDrm, X86_INS_PSRLD: psrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRLDrr, X86_INS_PSRLD: psrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRLQri, X86_INS_PSRLQ: psrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSRLQrm, X86_INS_PSRLQ: psrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRLQrr, X86_INS_PSRLQ: psrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRLWri, X86_INS_PSRLW: psrlw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MMX_PSRLWrm, X86_INS_PSRLW: psrlw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSRLWrr, X86_INS_PSRLW: psrlw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBBirm, X86_INS_PSUBB: psubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBBirr, X86_INS_PSUBB: psubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBDirm, X86_INS_PSUBD: psubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBDirr, X86_INS_PSUBD: psubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBQirm, X86_INS_PSUBQ: psubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBQirr, X86_INS_PSUBQ: psubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBSBirm, X86_INS_PSUBSB: psubsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBSBirr, X86_INS_PSUBSB: psubsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBSWirm, X86_INS_PSUBSW: psubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBSWirr, X86_INS_PSUBSW: psubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBUSBirm, X86_INS_PSUBUSB: psubusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBUSBirr, X86_INS_PSUBUSB: psubusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBUSWirm, X86_INS_PSUBUSW: psubusw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBUSWirr, X86_INS_PSUBUSW: psubusw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBWirm, X86_INS_PSUBW: psubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PSUBWirr, X86_INS_PSUBW: psubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKHBWirm, X86_INS_PUNPCKHBW: punpckhbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKHBWirr, X86_INS_PUNPCKHBW: punpckhbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKHDQirm, X86_INS_PUNPCKHDQ: punpckhdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKHDQirr, X86_INS_PUNPCKHDQ: punpckhdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKHWDirm, X86_INS_PUNPCKHWD: punpckhwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKHWDirr, X86_INS_PUNPCKHWD: punpckhwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKLBWirm, X86_INS_PUNPCKLBW: punpcklbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKLBWirr, X86_INS_PUNPCKLBW: punpcklbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKLDQirm, X86_INS_PUNPCKLDQ: punpckldq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKLDQirr, X86_INS_PUNPCKLDQ: punpckldq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKLWDirm, X86_INS_PUNPCKLWD: punpcklwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PUNPCKLWDirr, X86_INS_PUNPCKLWD: punpcklwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PXORirm, X86_INS_PXOR: pxor */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MMX_PXORirr, X86_INS_PXOR: pxor */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MONITORXrrr, X86_INS_MONITORX: monitorx */
	0,
	{ 0 }
},

{	/* X86_MONITORrrr, X86_INS_MONITOR: monitor */
	0,
	{ 0 }
},

{	/* X86_MONTMUL, X86_INS_MONTMUL: montmul */
	0,
	{ 0 }
},

{	/* X86_MOV16ao16, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16ao32, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16ao64, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16mi, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV16mr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16ms, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16o16a, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16o32a, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16o64a, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16ri, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV16ri_alt, X86_INS_MOV: mov{w}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV16rm, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16rr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16rr_REV, X86_INS_MOV: mov{w}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16rs, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16sm, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV16sr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32ao16, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32ao32, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32ao64, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32cr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32dr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32mi, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV32mr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32o16a, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32o32a, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32o64a, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32rc, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32rd, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32ri, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV32ri_alt, X86_INS_MOV: mov{l}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV32rm, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32rr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32rr_REV, X86_INS_MOV: mov{l}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32rs, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV32sr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64ao32, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64ao64, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64cr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64dr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64mi32, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV64mr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64o32a, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64o64a, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64rc, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64rd, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64ri, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV64ri32, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV64rm, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64rr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64rr_REV, X86_INS_MOV: mov{q}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64rs, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64sr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64toPQIrm, X86_INS_MOVQ: mov{d|q}	{$src $dst|$dst $src} */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64toPQIrr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64toSDrm, X86_INS_MOVQ: movq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV64toSDrr, X86_INS_MOVQ: mov{d|q}	{$src $dst|$dst $src} */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8ao16, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8ao32, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8ao64, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8mi, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV8mr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8mr_NOREX, X86_INS_MOV: mov{b}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8o16a, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8o32a, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8o64a, X86_INS_MOVABS: movabs */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8ri, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV8ri_alt, X86_INS_MOV: mov{b}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MOV8rm, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8rm_NOREX, X86_INS_MOV: mov{b}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8rr, X86_INS_MOV: mov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8rr_NOREX, X86_INS_MOV: mov{b}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOV8rr_REV, X86_INS_MOV: mov{b}	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVAPDmr, X86_INS_MOVAPD: movapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVAPDrm, X86_INS_MOVAPD: movapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVAPDrr, X86_INS_MOVAPD: movapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVAPDrr_REV, X86_INS_MOVAPD: movapd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVAPSmr, X86_INS_MOVAPS: movaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVAPSrm, X86_INS_MOVAPS: movaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVAPSrr, X86_INS_MOVAPS: movaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVAPSrr_REV, X86_INS_MOVAPS: movaps	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVBE16mr, X86_INS_MOVBE: movbe */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVBE16rm, X86_INS_MOVBE: movbe */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVBE32mr, X86_INS_MOVBE: movbe */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVBE32rm, X86_INS_MOVBE: movbe */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVBE64mr, X86_INS_MOVBE: movbe */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVBE64rm, X86_INS_MOVBE: movbe */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDDUPrm, X86_INS_MOVDDUP: movddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDDUPrr, X86_INS_MOVDDUP: movddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDI2PDIrm, X86_INS_MOVD: movd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDI2PDIrr, X86_INS_MOVD: movd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDI2SSrm, X86_INS_MOVD: movd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDI2SSrr, X86_INS_MOVD: movd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDIR64B16, X86_INS_MOVDIR64B: movdir64b */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_MOVDIR64B32, X86_INS_MOVDIR64B: movdir64b */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_MOVDIR64B64, X86_INS_MOVDIR64B: movdir64b */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_WRITE, 0 }
},

{	/* X86_MOVDIRI32, X86_INS_MOVDIRI: movdiri */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDIRI64, X86_INS_MOVDIRI: movdiri */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDQAmr, X86_INS_MOVDQA: movdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDQArm, X86_INS_MOVDQA: movdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDQArr, X86_INS_MOVDQA: movdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDQArr_REV, X86_INS_MOVDQA: movdqa	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDQUmr, X86_INS_MOVDQU: movdqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDQUrm, X86_INS_MOVDQU: movdqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDQUrr, X86_INS_MOVDQU: movdqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVDQUrr_REV, X86_INS_MOVDQU: movdqu	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVHLPSrr, X86_INS_MOVHLPS: movhlps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVHPDmr, X86_INS_MOVHPD: movhpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVHPDrm, X86_INS_MOVHPD: movhpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVHPSmr, X86_INS_MOVHPS: movhps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVHPSrm, X86_INS_MOVHPS: movhps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVLHPSrr, X86_INS_MOVLHPS: movlhps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVLPDmr, X86_INS_MOVLPD: movlpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVLPDrm, X86_INS_MOVLPD: movlpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVLPSmr, X86_INS_MOVLPS: movlps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVLPSrm, X86_INS_MOVLPS: movlps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVMSKPDrr, X86_INS_MOVMSKPD: movmskpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVMSKPSrr, X86_INS_MOVMSKPS: movmskps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVNTDQArm, X86_INS_MOVNTDQA: movntdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVNTDQmr, X86_INS_MOVNTDQ: movntdq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVNTI_64mr, X86_INS_MOVNTI: movnti */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVNTImr, X86_INS_MOVNTI: movnti */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVNTPDmr, X86_INS_MOVNTPD: movntpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVNTPSmr, X86_INS_MOVNTPS: movntps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVNTSD, X86_INS_MOVNTSD: movntsd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVNTSS, X86_INS_MOVNTSS: movntss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVPDI2DImr, X86_INS_MOVD: movd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVPDI2DIrr, X86_INS_MOVD: movd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVPQI2QImr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVPQI2QIrr, X86_INS_MOVQ: movq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVPQIto64mr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVPQIto64rr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVQI2PQIrm, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSB, X86_INS_MOVSB: movsb */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSDmr, X86_INS_MOVSD: movsd */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSDrm, X86_INS_MOVSD: movsd */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSDrr, X86_INS_MOVSD: movsd */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSDrr_REV, X86_INS_MOVSD: movsd	$dst $src2 */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSDto64mr, X86_INS_MOVQ: movq	$dst $src */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVSDto64rr, X86_INS_MOVQ: mov{d|q}	{$src $dst|$dst $src} */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSHDUPrm, X86_INS_MOVSHDUP: movshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSHDUPrr, X86_INS_MOVSHDUP: movshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSL, X86_INS_MOVSD: movsd */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSLDUPrm, X86_INS_MOVSLDUP: movsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSLDUPrr, X86_INS_MOVSLDUP: movsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSQ, X86_INS_MOVSQ: movsq */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSS2DImr, X86_INS_MOVD: movd	$dst $src */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVSS2DIrr, X86_INS_MOVD: movd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSSmr, X86_INS_MOVSS: movss */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSSrm, X86_INS_MOVSS: movss */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSSrr, X86_INS_MOVSS: movss */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSSrr_REV, X86_INS_MOVSS: movss	$dst $src2 */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSW, X86_INS_MOVSW: movsw */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX16rm16, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX16rm8, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX16rr16, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX16rr8, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX32rm16, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX32rm8, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX32rm8_NOREX, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX32rr16, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX32rr8, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX32rr8_NOREX, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX64rm16, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX64rm32, X86_INS_MOVSXD: movsxd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX64rm8, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX64rr16, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX64rr32, X86_INS_MOVSXD: movsxd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVSX64rr8, X86_INS_MOVSX: movsx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVUPDmr, X86_INS_MOVUPD: movupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVUPDrm, X86_INS_MOVUPD: movupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVUPDrr, X86_INS_MOVUPD: movupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVUPDrr_REV, X86_INS_MOVUPD: movupd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVUPSmr, X86_INS_MOVUPS: movups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MOVUPSrm, X86_INS_MOVUPS: movups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVUPSrr, X86_INS_MOVUPS: movups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVUPSrr_REV, X86_INS_MOVUPS: movups	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZPQILo2PQIrr, X86_INS_MOVQ: movq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX16rm16, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX16rm8, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX16rr16, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX16rr8, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX32rm16, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX32rm8, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX32rm8_NOREX, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX32rr16, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX32rr8, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX32rr8_NOREX, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX64rm16, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX64rm8, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX64rr16, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MOVZX64rr8, X86_INS_MOVZX: movzx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MPSADBWrmi, X86_INS_MPSADBW: mpsadbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_MPSADBWrri, X86_INS_MPSADBW: mpsadbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_MUL16m, X86_INS_MUL: mul */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL16r, X86_INS_MUL: mul */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL32m, X86_INS_MUL: mul */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL32r, X86_INS_MUL: mul */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL64m, X86_INS_MUL: mul */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL64r, X86_INS_MUL: mul */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL8m, X86_INS_MUL: mul */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL8r, X86_INS_MUL: mul */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_MULPDrm, X86_INS_MULPD: mulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULPDrr, X86_INS_MULPD: mulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULPSrm, X86_INS_MULPS: mulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULPSrr, X86_INS_MULPS: mulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULSDrm, X86_INS_MULSD: mulsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULSDrm_Int, X86_INS_MULSD: mulsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MULSDrr, X86_INS_MULSD: mulsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULSDrr_Int, X86_INS_MULSD: mulsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULSSrm, X86_INS_MULSS: mulss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULSSrm_Int, X86_INS_MULSS: mulss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_MULSSrr, X86_INS_MULSS: mulss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULSSrr_Int, X86_INS_MULSS: mulss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULX32rm, X86_INS_MULX: mulx */
	0,
	{ CS_AC_WRITE, CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULX32rr, X86_INS_MULX: mulx */
	0,
	{ CS_AC_WRITE, CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULX64rm, X86_INS_MULX: mulx */
	0,
	{ CS_AC_WRITE, CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MULX64rr, X86_INS_MULX: mulx */
	0,
	{ CS_AC_WRITE, CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_MUL_F32m, X86_INS_FMUL: fmul */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL_F64m, X86_INS_FMUL: fmul */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL_FI16m, X86_INS_FIMUL: fimul */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL_FI32m, X86_INS_FIMUL: fimul */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL_FPrST0, X86_INS_FMULP: fmulp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL_FST0r, X86_INS_FMUL: fmul */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_MUL_Fp32, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_Fp32m, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_Fp64, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_Fp64m, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_Fp64m32, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_Fp80, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_Fp80m32, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_Fp80m64, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_FpI16m32, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_FpI16m64, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_FpI16m80, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_FpI32m32, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_FpI32m64, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_FpI32m80, X86_INS_FMUL: fmul */
	0,
	{ 0 }
},

{	/* X86_MUL_FrST0, X86_INS_FMUL: fmul */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_MWAITXrrr, X86_INS_MWAITX: mwaitx */
	0,
	{ 0 }
},

{	/* X86_MWAITrr, X86_INS_MWAIT: mwait */
	0,
	{ 0 }
},

{	/* X86_NEG16m, X86_INS_NEG: neg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NEG16r, X86_INS_NEG: neg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NEG32m, X86_INS_NEG: neg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NEG32r, X86_INS_NEG: neg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NEG64m, X86_INS_NEG: neg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NEG64r, X86_INS_NEG: neg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NEG8m, X86_INS_NEG: neg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NEG8r, X86_INS_NEG: neg */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NOOP, X86_INS_NOP: nop */
	0,
	{ 0 }
},

{	/* X86_NOOP18_16m4, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_16m5, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_16m6, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_16m7, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_16r4, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_16r5, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_16r6, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_16r7, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_m4, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_m5, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_m6, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_m7, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_r4, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_r5, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_r6, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP18_r7, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOP19rr, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_NOOPL, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPL_19, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPL_1d, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPL_1e, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPLr, X86_INS_NOP: nop */
	0,
	{ 0 }
},

{	/* X86_NOOPQ, X86_INS_NOP: nop */
	0,
	{ 0 }
},

{	/* X86_NOOPQr, X86_INS_NOP: nop */
	0,
	{ 0 }
},

{	/* X86_NOOPW, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPW_19, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPW_1c, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPW_1d, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPW_1e, X86_INS_NOP: nop */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_NOOPWr, X86_INS_NOP: nop */
	0,
	{ 0 }
},

{	/* X86_NOT16m, X86_INS_NOT: not */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NOT16r, X86_INS_NOT: not */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NOT32m, X86_INS_NOT: not */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NOT32r, X86_INS_NOT: not */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NOT64m, X86_INS_NOT: not */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NOT64r, X86_INS_NOT: not */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NOT8m, X86_INS_NOT: not */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_NOT8r, X86_INS_NOT: not */
	0,
	{ CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_OR16i16, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR16mi, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR16mi8, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR16mr, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR16ri, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR16ri8, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR16rm, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR16rr, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR16rr_REV, X86_INS_OR: or{w}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR32i32, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR32mi, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR32mi8, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR32mr, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR32ri, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR32ri8, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR32rm, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR32rr, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR32rr_REV, X86_INS_OR: or{l}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR64i32, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR64mi32, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR64mi8, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR64mr, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR64ri32, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR64ri8, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR64rm, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR64rr, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR64rr_REV, X86_INS_OR: or{q}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR8i8, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR8mi, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR8mi8, X86_INS_OR: or{b}	$dst $src */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR8mr, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR8ri, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR8ri8, X86_INS_OR: or{b}	$src1 $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_OR8rm, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR8rr, X86_INS_OR: or */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OR8rr_REV, X86_INS_OR: or{b}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ORPDrm, X86_INS_ORPD: orpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ORPDrr, X86_INS_ORPD: orpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ORPSrm, X86_INS_ORPS: orps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ORPSrr, X86_INS_ORPS: orps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_OUT16ir, X86_INS_OUT: out */
	0,
	{ CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_OUT16rr, X86_INS_OUT: out */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_OUT32ir, X86_INS_OUT: out */
	0,
	{ CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_OUT32rr, X86_INS_OUT: out */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_OUT8ir, X86_INS_OUT: out */
	0,
	{ CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_OUT8rr, X86_INS_OUT: out */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_OUTSB, X86_INS_OUTSB: outsb */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_OUTSL, X86_INS_OUTSD: outsd */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_OUTSW, X86_INS_OUTSW: outsw */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PABSBrm, X86_INS_PABSB: pabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PABSBrr, X86_INS_PABSB: pabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PABSDrm, X86_INS_PABSD: pabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PABSDrr, X86_INS_PABSD: pabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PABSWrm, X86_INS_PABSW: pabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PABSWrr, X86_INS_PABSW: pabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PACKSSDWrm, X86_INS_PACKSSDW: packssdw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PACKSSDWrr, X86_INS_PACKSSDW: packssdw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PACKSSWBrm, X86_INS_PACKSSWB: packsswb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PACKSSWBrr, X86_INS_PACKSSWB: packsswb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PACKUSDWrm, X86_INS_PACKUSDW: packusdw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PACKUSDWrr, X86_INS_PACKUSDW: packusdw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PACKUSWBrm, X86_INS_PACKUSWB: packuswb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PACKUSWBrr, X86_INS_PACKUSWB: packuswb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDBrm, X86_INS_PADDB: paddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDBrr, X86_INS_PADDB: paddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDDrm, X86_INS_PADDD: paddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDDrr, X86_INS_PADDD: paddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDQrm, X86_INS_PADDQ: paddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDQrr, X86_INS_PADDQ: paddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDSBrm, X86_INS_PADDSB: paddsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDSBrr, X86_INS_PADDSB: paddsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDSWrm, X86_INS_PADDSW: paddsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDSWrr, X86_INS_PADDSW: paddsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDUSBrm, X86_INS_PADDUSB: paddusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDUSBrr, X86_INS_PADDUSB: paddusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDUSWrm, X86_INS_PADDUSW: paddusw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDUSWrr, X86_INS_PADDUSW: paddusw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDWrm, X86_INS_PADDW: paddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PADDWrr, X86_INS_PADDW: paddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PALIGNRrmi, X86_INS_PALIGNR: palignr */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PALIGNRrri, X86_INS_PALIGNR: palignr */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PANDNrm, X86_INS_PANDN: pandn */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PANDNrr, X86_INS_PANDN: pandn */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PANDrm, X86_INS_PAND: pand */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PANDrr, X86_INS_PAND: pand */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PAUSE, X86_INS_PAUSE: pause */
	0,
	{ 0 }
},

{	/* X86_PAVGBrm, X86_INS_PAVGB: pavgb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PAVGBrr, X86_INS_PAVGB: pavgb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PAVGUSBrm, X86_INS_PAVGUSB: pavgusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PAVGUSBrr, X86_INS_PAVGUSB: pavgusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PAVGWrm, X86_INS_PAVGW: pavgw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PAVGWrr, X86_INS_PAVGW: pavgw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PBLENDVBrm0, X86_INS_PBLENDVB: pblendvb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PBLENDVBrr0, X86_INS_PBLENDVB: pblendvb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PBLENDWrmi, X86_INS_PBLENDW: pblendw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PBLENDWrri, X86_INS_PBLENDW: pblendw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PCLMULQDQrm, X86_INS_PCLMULQDQ: pclmulqdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PCLMULQDQrr, X86_INS_PCLMULQDQ: pclmulqdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PCMPEQBrm, X86_INS_PCMPEQB: pcmpeqb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPEQBrr, X86_INS_PCMPEQB: pcmpeqb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPEQDrm, X86_INS_PCMPEQD: pcmpeqd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPEQDrr, X86_INS_PCMPEQD: pcmpeqd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPEQQrm, X86_INS_PCMPEQQ: pcmpeqq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPEQQrr, X86_INS_PCMPEQQ: pcmpeqq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPEQWrm, X86_INS_PCMPEQW: pcmpeqw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPEQWrr, X86_INS_PCMPEQW: pcmpeqw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPESTRIrm, X86_INS_PCMPESTRI: pcmpestri */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PCMPESTRIrr, X86_INS_PCMPESTRI: pcmpestri */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PCMPESTRMrm, X86_INS_PCMPESTRM: pcmpestrm */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PCMPESTRMrr, X86_INS_PCMPESTRM: pcmpestrm */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PCMPGTBrm, X86_INS_PCMPGTB: pcmpgtb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPGTBrr, X86_INS_PCMPGTB: pcmpgtb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPGTDrm, X86_INS_PCMPGTD: pcmpgtd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPGTDrr, X86_INS_PCMPGTD: pcmpgtd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPGTQrm, X86_INS_PCMPGTQ: pcmpgtq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPGTQrr, X86_INS_PCMPGTQ: pcmpgtq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPGTWrm, X86_INS_PCMPGTW: pcmpgtw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPGTWrr, X86_INS_PCMPGTW: pcmpgtw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PCMPISTRIrm, X86_INS_PCMPISTRI: pcmpistri */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PCMPISTRIrr, X86_INS_PCMPISTRI: pcmpistri */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PCMPISTRMrm, X86_INS_PCMPISTRM: pcmpistrm */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PCMPISTRMrr, X86_INS_PCMPISTRM: pcmpistrm */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PCONFIG, X86_INS_PCONFIG: pconfig */
	0,
	{ 0 }
},

{	/* X86_PDEP32rm, X86_INS_PDEP: pdep */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PDEP32rr, X86_INS_PDEP: pdep */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PDEP64rm, X86_INS_PDEP: pdep */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PDEP64rr, X86_INS_PDEP: pdep */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PEXT32rm, X86_INS_PEXT: pext */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PEXT32rr, X86_INS_PEXT: pext */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PEXT64rm, X86_INS_PEXT: pext */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PEXT64rr, X86_INS_PEXT: pext */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PEXTRBmr, X86_INS_PEXTRB: pextrb */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PEXTRBrr, X86_INS_PEXTRB: pextrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PEXTRDmr, X86_INS_PEXTRD: pextrd */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PEXTRDrr, X86_INS_PEXTRD: pextrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PEXTRQmr, X86_INS_PEXTRQ: pextrq */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PEXTRQrr, X86_INS_PEXTRQ: pextrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PEXTRWmr, X86_INS_PEXTRW: pextrw */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PEXTRWrr, X86_INS_PEXTRW: pextrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PEXTRWrr_REV, X86_INS_PEXTRW: pextrw	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PF2IDrm, X86_INS_PF2ID: pf2id */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PF2IDrr, X86_INS_PF2ID: pf2id */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PF2IWrm, X86_INS_PF2IW: pf2iw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PF2IWrr, X86_INS_PF2IW: pf2iw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFACCrm, X86_INS_PFACC: pfacc */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFACCrr, X86_INS_PFACC: pfacc */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFADDrm, X86_INS_PFADD: pfadd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFADDrr, X86_INS_PFADD: pfadd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFCMPEQrm, X86_INS_PFCMPEQ: pfcmpeq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFCMPEQrr, X86_INS_PFCMPEQ: pfcmpeq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFCMPGErm, X86_INS_PFCMPGE: pfcmpge */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFCMPGErr, X86_INS_PFCMPGE: pfcmpge */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFCMPGTrm, X86_INS_PFCMPGT: pfcmpgt */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFCMPGTrr, X86_INS_PFCMPGT: pfcmpgt */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFMAXrm, X86_INS_PFMAX: pfmax */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFMAXrr, X86_INS_PFMAX: pfmax */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFMINrm, X86_INS_PFMIN: pfmin */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFMINrr, X86_INS_PFMIN: pfmin */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFMULrm, X86_INS_PFMUL: pfmul */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFMULrr, X86_INS_PFMUL: pfmul */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFNACCrm, X86_INS_PFNACC: pfnacc */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFNACCrr, X86_INS_PFNACC: pfnacc */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFPNACCrm, X86_INS_PFPNACC: pfpnacc */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFPNACCrr, X86_INS_PFPNACC: pfpnacc */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRCPIT1rm, X86_INS_PFRCPIT1: pfrcpit1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRCPIT1rr, X86_INS_PFRCPIT1: pfrcpit1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRCPIT2rm, X86_INS_PFRCPIT2: pfrcpit2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRCPIT2rr, X86_INS_PFRCPIT2: pfrcpit2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRCPrm, X86_INS_PFRCP: pfrcp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRCPrr, X86_INS_PFRCP: pfrcp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRSQIT1rm, X86_INS_PFRSQIT1: pfrsqit1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRSQIT1rr, X86_INS_PFRSQIT1: pfrsqit1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRSQRTrm, X86_INS_PFRSQRT: pfrsqrt */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFRSQRTrr, X86_INS_PFRSQRT: pfrsqrt */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFSUBRrm, X86_INS_PFSUBR: pfsubr */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFSUBRrr, X86_INS_PFSUBR: pfsubr */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFSUBrm, X86_INS_PFSUB: pfsub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PFSUBrr, X86_INS_PFSUB: pfsub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHADDDrm, X86_INS_PHADDD: phaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHADDDrr, X86_INS_PHADDD: phaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHADDSWrm, X86_INS_PHADDSW: phaddsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHADDSWrr, X86_INS_PHADDSW: phaddsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHADDWrm, X86_INS_PHADDW: phaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHADDWrr, X86_INS_PHADDW: phaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHMINPOSUWrm, X86_INS_PHMINPOSUW: phminposuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHMINPOSUWrr, X86_INS_PHMINPOSUW: phminposuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHSUBDrm, X86_INS_PHSUBD: phsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHSUBDrr, X86_INS_PHSUBD: phsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHSUBSWrm, X86_INS_PHSUBSW: phsubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHSUBSWrr, X86_INS_PHSUBSW: phsubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHSUBWrm, X86_INS_PHSUBW: phsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PHSUBWrr, X86_INS_PHSUBW: phsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PI2FDrm, X86_INS_PI2FD: pi2fd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PI2FDrr, X86_INS_PI2FD: pi2fd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PI2FWrm, X86_INS_PI2FW: pi2fw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PI2FWrr, X86_INS_PI2FW: pi2fw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PINSRBrm, X86_INS_PINSRB: pinsrb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PINSRBrr, X86_INS_PINSRB: pinsrb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PINSRDrm, X86_INS_PINSRD: pinsrd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PINSRDrr, X86_INS_PINSRD: pinsrd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PINSRQrm, X86_INS_PINSRQ: pinsrq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PINSRQrr, X86_INS_PINSRQ: pinsrq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PINSRWrm, X86_INS_PINSRW: pinsrw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PINSRWrr, X86_INS_PINSRW: pinsrw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PMADDUBSWrm, X86_INS_PMADDUBSW: pmaddubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMADDUBSWrr, X86_INS_PMADDUBSW: pmaddubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMADDWDrm, X86_INS_PMADDWD: pmaddwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMADDWDrr, X86_INS_PMADDWD: pmaddwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXSBrm, X86_INS_PMAXSB: pmaxsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXSBrr, X86_INS_PMAXSB: pmaxsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXSDrm, X86_INS_PMAXSD: pmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXSDrr, X86_INS_PMAXSD: pmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXSWrm, X86_INS_PMAXSW: pmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXSWrr, X86_INS_PMAXSW: pmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXUBrm, X86_INS_PMAXUB: pmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXUBrr, X86_INS_PMAXUB: pmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXUDrm, X86_INS_PMAXUD: pmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXUDrr, X86_INS_PMAXUD: pmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXUWrm, X86_INS_PMAXUW: pmaxuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMAXUWrr, X86_INS_PMAXUW: pmaxuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINSBrm, X86_INS_PMINSB: pminsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINSBrr, X86_INS_PMINSB: pminsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINSDrm, X86_INS_PMINSD: pminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINSDrr, X86_INS_PMINSD: pminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINSWrm, X86_INS_PMINSW: pminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINSWrr, X86_INS_PMINSW: pminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINUBrm, X86_INS_PMINUB: pminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINUBrr, X86_INS_PMINUB: pminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINUDrm, X86_INS_PMINUD: pminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINUDrr, X86_INS_PMINUD: pminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINUWrm, X86_INS_PMINUW: pminuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMINUWrr, X86_INS_PMINUW: pminuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVMSKBrr, X86_INS_PMOVMSKB: pmovmskb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXBDrm, X86_INS_PMOVSXBD: pmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXBDrr, X86_INS_PMOVSXBD: pmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXBQrm, X86_INS_PMOVSXBQ: pmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXBQrr, X86_INS_PMOVSXBQ: pmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXBWrm, X86_INS_PMOVSXBW: pmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXBWrr, X86_INS_PMOVSXBW: pmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXDQrm, X86_INS_PMOVSXDQ: pmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXDQrr, X86_INS_PMOVSXDQ: pmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXWDrm, X86_INS_PMOVSXWD: pmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXWDrr, X86_INS_PMOVSXWD: pmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXWQrm, X86_INS_PMOVSXWQ: pmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVSXWQrr, X86_INS_PMOVSXWQ: pmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXBDrm, X86_INS_PMOVZXBD: pmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXBDrr, X86_INS_PMOVZXBD: pmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXBQrm, X86_INS_PMOVZXBQ: pmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXBQrr, X86_INS_PMOVZXBQ: pmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXBWrm, X86_INS_PMOVZXBW: pmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXBWrr, X86_INS_PMOVZXBW: pmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXDQrm, X86_INS_PMOVZXDQ: pmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXDQrr, X86_INS_PMOVZXDQ: pmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXWDrm, X86_INS_PMOVZXWD: pmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXWDrr, X86_INS_PMOVZXWD: pmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXWQrm, X86_INS_PMOVZXWQ: pmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMOVZXWQrr, X86_INS_PMOVZXWQ: pmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULDQrm, X86_INS_PMULDQ: pmuldq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULDQrr, X86_INS_PMULDQ: pmuldq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULHRSWrm, X86_INS_PMULHRSW: pmulhrsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULHRSWrr, X86_INS_PMULHRSW: pmulhrsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULHRWrm, X86_INS_PMULHRW: pmulhrw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULHRWrr, X86_INS_PMULHRW: pmulhrw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULHUWrm, X86_INS_PMULHUW: pmulhuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULHUWrr, X86_INS_PMULHUW: pmulhuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULHWrm, X86_INS_PMULHW: pmulhw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULHWrr, X86_INS_PMULHW: pmulhw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULLDrm, X86_INS_PMULLD: pmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULLDrr, X86_INS_PMULLD: pmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULLWrm, X86_INS_PMULLW: pmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULLWrr, X86_INS_PMULLW: pmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULUDQrm, X86_INS_PMULUDQ: pmuludq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PMULUDQrr, X86_INS_PMULUDQ: pmuludq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_POP16r, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POP16rmm, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POP16rmr, X86_INS_POP: pop{w}	$reg */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POP32r, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POP32rmm, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POP32rmr, X86_INS_POP: pop{l}	$reg */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POP64r, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POP64rmm, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POP64rmr, X86_INS_POP: pop{q}	$reg */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPA16, X86_INS_POPAW: popaw */
	0,
	{ 0 }
},

{	/* X86_POPA32, X86_INS_POPAL: popal */
	0,
	{ 0 }
},

{	/* X86_POPCNT16rm, X86_INS_POPCNT: popcnt */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_POPCNT16rr, X86_INS_POPCNT: popcnt */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_POPCNT32rm, X86_INS_POPCNT: popcnt */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_POPCNT32rr, X86_INS_POPCNT: popcnt */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_POPCNT64rm, X86_INS_POPCNT: popcnt */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_POPCNT64rr, X86_INS_POPCNT: popcnt */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_POPDS16, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPDS32, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPES16, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPES32, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPF16, X86_INS_POPF: popf */
	X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_POPF32, X86_INS_POPFD: popfd */
	X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_POPF64, X86_INS_POPFQ: popfq */
	X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_POPFS16, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPFS32, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPFS64, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPGS16, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPGS32, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPGS64, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPSS16, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_POPSS32, X86_INS_POP: pop */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_PORrm, X86_INS_POR: por */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PORrr, X86_INS_POR: por */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PREFETCH, X86_INS_PREFETCH: prefetch */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PREFETCHNTA, X86_INS_PREFETCHNTA: prefetchnta */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PREFETCHT0, X86_INS_PREFETCHT0: prefetcht0 */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PREFETCHT1, X86_INS_PREFETCHT1: prefetcht1 */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PREFETCHT2, X86_INS_PREFETCHT2: prefetcht2 */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PREFETCHW, X86_INS_PREFETCHW: prefetchw */
	X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ CS_AC_READ, 0 }
},

{	/* X86_PREFETCHWT1, X86_INS_PREFETCHWT1: prefetchwt1 */
	0,
	{ 0 }
},

{	/* X86_PSADBWrm, X86_INS_PSADBW: psadbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSADBWrr, X86_INS_PSADBW: psadbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSHUFBrm, X86_INS_PSHUFB: pshufb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSHUFBrr, X86_INS_PSHUFB: pshufb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSHUFDmi, X86_INS_PSHUFD: pshufd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PSHUFDri, X86_INS_PSHUFD: pshufd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PSHUFHWmi, X86_INS_PSHUFHW: pshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PSHUFHWri, X86_INS_PSHUFHW: pshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PSHUFLWmi, X86_INS_PSHUFLW: pshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PSHUFLWri, X86_INS_PSHUFLW: pshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_PSIGNBrm, X86_INS_PSIGNB: psignb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSIGNBrr, X86_INS_PSIGNB: psignb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSIGNDrm, X86_INS_PSIGND: psignd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSIGNDrr, X86_INS_PSIGND: psignd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSIGNWrm, X86_INS_PSIGNW: psignw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSIGNWrr, X86_INS_PSIGNW: psignw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSLLDQri, X86_INS_PSLLDQ: pslldq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSLLDri, X86_INS_PSLLD: pslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSLLDrm, X86_INS_PSLLD: pslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSLLDrr, X86_INS_PSLLD: pslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSLLQri, X86_INS_PSLLQ: psllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSLLQrm, X86_INS_PSLLQ: psllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSLLQrr, X86_INS_PSLLQ: psllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSLLWri, X86_INS_PSLLW: psllw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSLLWrm, X86_INS_PSLLW: psllw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSLLWrr, X86_INS_PSLLW: psllw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRADri, X86_INS_PSRAD: psrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSRADrm, X86_INS_PSRAD: psrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRADrr, X86_INS_PSRAD: psrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRAWri, X86_INS_PSRAW: psraw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSRAWrm, X86_INS_PSRAW: psraw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRAWrr, X86_INS_PSRAW: psraw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRLDQri, X86_INS_PSRLDQ: psrldq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSRLDri, X86_INS_PSRLD: psrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSRLDrm, X86_INS_PSRLD: psrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRLDrr, X86_INS_PSRLD: psrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRLQri, X86_INS_PSRLQ: psrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSRLQrm, X86_INS_PSRLQ: psrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRLQrr, X86_INS_PSRLQ: psrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRLWri, X86_INS_PSRLW: psrlw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_PSRLWrm, X86_INS_PSRLW: psrlw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSRLWrr, X86_INS_PSRLW: psrlw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBBrm, X86_INS_PSUBB: psubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBBrr, X86_INS_PSUBB: psubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBDrm, X86_INS_PSUBD: psubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBDrr, X86_INS_PSUBD: psubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBQrm, X86_INS_PSUBQ: psubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBQrr, X86_INS_PSUBQ: psubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBSBrm, X86_INS_PSUBSB: psubsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBSBrr, X86_INS_PSUBSB: psubsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBSWrm, X86_INS_PSUBSW: psubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBSWrr, X86_INS_PSUBSW: psubsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBUSBrm, X86_INS_PSUBUSB: psubusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBUSBrr, X86_INS_PSUBUSB: psubusb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBUSWrm, X86_INS_PSUBUSW: psubusw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBUSWrr, X86_INS_PSUBUSW: psubusw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBWrm, X86_INS_PSUBW: psubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSUBWrr, X86_INS_PSUBW: psubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSWAPDrm, X86_INS_PSWAPD: pswapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PSWAPDrr, X86_INS_PSWAPD: pswapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PTESTrm, X86_INS_PTEST: ptest */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PTESTrr, X86_INS_PTEST: ptest */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_PTWRITE64m, X86_INS_PTWRITE: ptwrite */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PTWRITE64r, X86_INS_PTWRITE: ptwrite */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PTWRITEm, X86_INS_PTWRITE: ptwrite */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PTWRITEr, X86_INS_PTWRITE: ptwrite */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUNPCKHBWrm, X86_INS_PUNPCKHBW: punpckhbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKHBWrr, X86_INS_PUNPCKHBW: punpckhbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKHDQrm, X86_INS_PUNPCKHDQ: punpckhdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKHDQrr, X86_INS_PUNPCKHDQ: punpckhdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKHQDQrm, X86_INS_PUNPCKHQDQ: punpckhqdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKHQDQrr, X86_INS_PUNPCKHQDQ: punpckhqdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKHWDrm, X86_INS_PUNPCKHWD: punpckhwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKHWDrr, X86_INS_PUNPCKHWD: punpckhwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKLBWrm, X86_INS_PUNPCKLBW: punpcklbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKLBWrr, X86_INS_PUNPCKLBW: punpcklbw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKLDQrm, X86_INS_PUNPCKLDQ: punpckldq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKLDQrr, X86_INS_PUNPCKLDQ: punpckldq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKLQDQrm, X86_INS_PUNPCKLQDQ: punpcklqdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKLQDQrr, X86_INS_PUNPCKLQDQ: punpcklqdq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKLWDrm, X86_INS_PUNPCKLWD: punpcklwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUNPCKLWDrr, X86_INS_PUNPCKLWD: punpcklwd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PUSH16i8, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSH16r, X86_INS_PUSH: push */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSH16rmm, X86_INS_PUSH: push */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSH16rmr, X86_INS_PUSH: push{w}	$reg */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSH32i8, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSH32r, X86_INS_PUSH: push */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSH32rmm, X86_INS_PUSH: push */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSH32rmr, X86_INS_PUSH: push{l}	$reg */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSH64i32, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSH64i8, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSH64r, X86_INS_PUSH: push */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSH64rmm, X86_INS_PUSH: push */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSH64rmr, X86_INS_PUSH: push{q}	$reg */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_PUSHA16, X86_INS_PUSHAW: pushaw */
	0,
	{ 0 }
},

{	/* X86_PUSHA32, X86_INS_PUSHAL: pushal */
	0,
	{ 0 }
},

{	/* X86_PUSHCS16, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHCS32, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHDS16, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHDS32, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHES16, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHES32, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHF16, X86_INS_PUSHF: pushf */
	0,
	{ 0 }
},

{	/* X86_PUSHF32, X86_INS_PUSHFD: pushfd */
	0,
	{ 0 }
},

{	/* X86_PUSHF64, X86_INS_PUSHFQ: pushfq */
	0,
	{ 0 }
},

{	/* X86_PUSHFS16, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHFS32, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHFS64, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHGS16, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHGS32, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHGS64, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHSS16, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHSS32, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHi16, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PUSHi32, X86_INS_PUSH: push */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_PXORrm, X86_INS_PXOR: pxor */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_PXORrr, X86_INS_PXOR: pxor */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCL16m1, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL16mCL, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_RCL16mi, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL16r1, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL16rCL, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCL16ri, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL32m1, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL32mCL, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_RCL32mi, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL32r1, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL32rCL, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCL32ri, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL64m1, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL64mCL, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_RCL64mi, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL64r1, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL64rCL, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCL64ri, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL8m1, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL8mCL, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_RCL8mi, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL8r1, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCL8rCL, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCL8ri, X86_INS_RCL: rcl */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCPPSm, X86_INS_RCPPS: rcpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCPPSr, X86_INS_RCPPS: rcpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCPSSm, X86_INS_RCPSS: rcpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCPSSm_Int, X86_INS_RCPSS: rcpss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCPSSr, X86_INS_RCPSS: rcpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCPSSr_Int, X86_INS_RCPSS: rcpss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCR16m1, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR16mCL, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_RCR16mi, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR16r1, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR16rCL, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCR16ri, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR32m1, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR32mCL, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_RCR32mi, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR32r1, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR32rCL, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCR32ri, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR64m1, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR64mCL, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_RCR64mi, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR64r1, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR64rCL, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCR64ri, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR8m1, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR8mCL, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_RCR8mi, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR8r1, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RCR8rCL, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RCR8ri, X86_INS_RCR: rcr */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RDFSBASE, X86_INS_RDFSBASE: rdfsbase */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDFSBASE64, X86_INS_RDFSBASE: rdfsbase */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDGSBASE, X86_INS_RDGSBASE: rdgsbase */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDGSBASE64, X86_INS_RDGSBASE: rdgsbase */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDMSR, X86_INS_RDMSR: rdmsr */
	0,
	{ 0 }
},

{	/* X86_RDPID32, X86_INS_RDPID: rdpid */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDPID64, X86_INS_RDPID: rdpid */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDPKRUr, X86_INS_RDPKRU: rdpkru */
	0,
	{ 0 }
},

{	/* X86_RDPMC, X86_INS_RDPMC: rdpmc */
	0,
	{ 0 }
},

{	/* X86_RDRAND16r, X86_INS_RDRAND: rdrand */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDRAND32r, X86_INS_RDRAND: rdrand */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDRAND64r, X86_INS_RDRAND: rdrand */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDSEED16r, X86_INS_RDSEED: rdseed */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDSEED32r, X86_INS_RDSEED: rdseed */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDSEED64r, X86_INS_RDSEED: rdseed */
	X86_EFLAGS_MODIFY_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_RESET_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_RDSSPD, X86_INS_RDSSPD: rdsspd */
	0,
	{ 0 }
},

{	/* X86_RDSSPQ, X86_INS_RDSSPQ: rdsspq */
	0,
	{ 0 }
},

{	/* X86_RDTSC, X86_INS_RDTSC: rdtsc */
	0,
	{ 0 }
},

{	/* X86_RDTSCP, X86_INS_RDTSCP: rdtscp */
	0,
	{ 0 }
},

{	/* X86_REPNE_PREFIX, X86_INS_REPNE: repne */
	0,
	{ 0 }
},

{	/* X86_REP_PREFIX, X86_INS_REP: rep */
	0,
	{ 0 }
},

{	/* X86_RETIL, X86_INS_RET: ret */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_RETIQ, X86_INS_RET: ret */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_RETIW, X86_INS_RET: ret */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_RETL, X86_INS_RET: ret */
	0,
	{ 0 }
},

{	/* X86_RETQ, X86_INS_RET: ret */
	0,
	{ 0 }
},

{	/* X86_RETW, X86_INS_RET: ret */
	0,
	{ 0 }
},

{	/* X86_REX64_PREFIX, X86_INS_REX64: rex64 */
	0,
	{ 0 }
},

{	/* X86_ROL16m1, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL16mCL, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROL16mi, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL16r1, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL16rCL, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ROL16ri, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL32m1, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL32mCL, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROL32mi, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL32r1, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL32rCL, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ROL32ri, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL64m1, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL64mCL, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROL64mi, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL64r1, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL64rCL, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ROL64ri, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL8m1, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL8mCL, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROL8mi, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL8r1, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROL8rCL, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ROL8ri, X86_INS_ROL: rol */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR16m1, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR16mCL, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROR16mi, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR16r1, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR16rCL, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ROR16ri, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR32m1, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR32mCL, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROR32mi, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR32r1, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR32rCL, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ROR32ri, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR64m1, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR64mCL, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROR64mi, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR64r1, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR64rCL, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ROR64ri, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR8m1, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR8mCL, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROR8mi, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR8r1, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROR8rCL, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_ROR8ri, X86_INS_ROR: ror */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RORX32mi, X86_INS_RORX: rorx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RORX32ri, X86_INS_RORX: rorx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RORX64mi, X86_INS_RORX: rorx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RORX64ri, X86_INS_RORX: rorx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDPDm, X86_INS_ROUNDPD: roundpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDPDr, X86_INS_ROUNDPD: roundpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDPSm, X86_INS_ROUNDPS: roundps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDPSr, X86_INS_ROUNDPS: roundps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDSDm, X86_INS_ROUNDSD: roundsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDSDm_Int, X86_INS_ROUNDSD: roundsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROUNDSDr, X86_INS_ROUNDSD: roundsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDSDr_Int, X86_INS_ROUNDSD: roundsd	$dst $src2 $src3 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDSSm, X86_INS_ROUNDSS: roundss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDSSm_Int, X86_INS_ROUNDSS: roundss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_ROUNDSSr, X86_INS_ROUNDSS: roundss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_ROUNDSSr_Int, X86_INS_ROUNDSS: roundss	$dst $src2 $src3 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_RSM, X86_INS_RSM: rsm */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_RSQRTPSm, X86_INS_RSQRTPS: rsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RSQRTPSr, X86_INS_RSQRTPS: rsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RSQRTSSm, X86_INS_RSQRTSS: rsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RSQRTSSm_Int, X86_INS_RSQRTSS: rsqrtss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_RSQRTSSr, X86_INS_RSQRTSS: rsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RSQRTSSr_Int, X86_INS_RSQRTSS: rsqrtss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_RSTORSSP, X86_INS_RSTORSSP: rstorssp */
	0,
	{ 0 }
},

{	/* X86_SAHF, X86_INS_SAHF: sahf */
	X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ 0 }
},

{	/* X86_SAL16m1, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL16mCL, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAL16mi, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL16r1, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL16rCL, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAL16ri, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL32m1, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL32mCL, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAL32mi, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL32r1, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL32rCL, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAL32ri, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL64m1, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL64mCL, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAL64mi, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL64r1, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL64rCL, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAL64ri, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL8m1, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL8mCL, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAL8mi, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL8r1, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAL8rCL, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAL8ri, X86_INS_SAL: sal */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SALC, X86_INS_SALC: salc */
	0,
	{ 0 }
},

{	/* X86_SAR16m1, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR16mCL, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAR16mi, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR16r1, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR16rCL, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAR16ri, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR32m1, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR32mCL, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAR32mi, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR32r1, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR32rCL, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAR32ri, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR64m1, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR64mCL, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAR64mi, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR64r1, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR64rCL, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAR64ri, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR8m1, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR8mCL, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAR8mi, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR8r1, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SAR8rCL, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SAR8ri, X86_INS_SAR: sar */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SARX32rm, X86_INS_SARX: sarx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SARX32rr, X86_INS_SARX: sarx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SARX64rm, X86_INS_SARX: sarx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SARX64rr, X86_INS_SARX: sarx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SAVEPREVSSP, X86_INS_SAVEPREVSSP: saveprevssp */
	0,
	{ 0 }
},

{	/* X86_SBB16i16, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB16mi, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB16mi8, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB16mr, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB16ri, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB16ri8, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB16rm, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB16rr, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB16rr_REV, X86_INS_SBB: sbb{w}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB32i32, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB32mi, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB32mi8, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB32mr, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB32ri, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB32ri8, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB32rm, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB32rr, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB32rr_REV, X86_INS_SBB: sbb{l}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB64i32, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB64mi32, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB64mi8, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB64mr, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB64ri32, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB64ri8, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB64rm, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB64rr, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB64rr_REV, X86_INS_SBB: sbb{q}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB8i8, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB8mi, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB8mi8, X86_INS_SBB: sbb{b}	$dst $src */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB8mr, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB8ri, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB8ri8, X86_INS_SBB: sbb{b}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SBB8rm, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB8rr, X86_INS_SBB: sbb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SBB8rr_REV, X86_INS_SBB: sbb{b}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SCASB, X86_INS_SCASB: scasb */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SCASL, X86_INS_SCASD: scasd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SCASQ, X86_INS_SCASQ: scasq */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SCASW, X86_INS_SCASW: scasw */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SETAEm, X86_INS_SETAE: setae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETAEr, X86_INS_SETAE: setae */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETAm, X86_INS_SETA: seta */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETAr, X86_INS_SETA: seta */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETBEm, X86_INS_SETBE: setbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETBEr, X86_INS_SETBE: setbe */
	X86_EFLAGS_TEST_ZF | X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETBm, X86_INS_SETB: setb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETBr, X86_INS_SETB: setb */
	X86_EFLAGS_TEST_CF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETEm, X86_INS_SETE: sete */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETEr, X86_INS_SETE: sete */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETGEm, X86_INS_SETGE: setge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETGEr, X86_INS_SETGE: setge */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETGm, X86_INS_SETG: setg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETGr, X86_INS_SETG: setg */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETLEm, X86_INS_SETLE: setle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETLEr, X86_INS_SETLE: setle */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF | X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETLm, X86_INS_SETL: setl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETLr, X86_INS_SETL: setl */
	X86_EFLAGS_TEST_OF | X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETNEm, X86_INS_SETNE: setne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETNEr, X86_INS_SETNE: setne */
	X86_EFLAGS_TEST_ZF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETNOm, X86_INS_SETNO: setno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETNOr, X86_INS_SETNO: setno */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETNPm, X86_INS_SETNP: setnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETNPr, X86_INS_SETNP: setnp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETNSm, X86_INS_SETNS: setns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETNSr, X86_INS_SETNS: setns */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETOm, X86_INS_SETO: seto */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETOr, X86_INS_SETO: seto */
	X86_EFLAGS_TEST_OF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETPm, X86_INS_SETP: setp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETPr, X86_INS_SETP: setp */
	X86_EFLAGS_TEST_PF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SETSSBSY, X86_INS_SETSSBSY: setssbsy */
	0,
	{ 0 }
},

{	/* X86_SETSm, X86_INS_SETS: sets */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_READ, 0 }
},

{	/* X86_SETSr, X86_INS_SETS: sets */
	X86_EFLAGS_TEST_SF,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SFENCE, X86_INS_SFENCE: sfence */
	0,
	{ 0 }
},

{	/* X86_SGDT16m, X86_INS_SGDT: sgdt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SGDT32m, X86_INS_SGDT: sgdt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SGDT64m, X86_INS_SGDT: sgdt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SHA1MSG1rm, X86_INS_SHA1MSG1: sha1msg1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA1MSG1rr, X86_INS_SHA1MSG1: sha1msg1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA1MSG2rm, X86_INS_SHA1MSG2: sha1msg2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA1MSG2rr, X86_INS_SHA1MSG2: sha1msg2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA1NEXTErm, X86_INS_SHA1NEXTE: sha1nexte */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA1NEXTErr, X86_INS_SHA1NEXTE: sha1nexte */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA1RNDS4rmi, X86_INS_SHA1RNDS4: sha1rnds4 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHA1RNDS4rri, X86_INS_SHA1RNDS4: sha1rnds4 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHA256MSG1rm, X86_INS_SHA256MSG1: sha256msg1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA256MSG1rr, X86_INS_SHA256MSG1: sha256msg1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA256MSG2rm, X86_INS_SHA256MSG2: sha256msg2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA256MSG2rr, X86_INS_SHA256MSG2: sha256msg2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA256RNDS2rm, X86_INS_SHA256RNDS2: sha256rnds2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHA256RNDS2rr, X86_INS_SHA256RNDS2: sha256rnds2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL16m1, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL16mCL, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL16mi, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL16r1, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL16rCL, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL16ri, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL32m1, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL32mCL, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL32mi, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL32r1, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL32rCL, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL32ri, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL64m1, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL64mCL, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL64mi, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL64r1, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL64rCL, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL64ri, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL8m1, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL8mCL, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL8mi, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL8r1, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHL8rCL, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHL8ri, X86_INS_SHL: shl */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHLD16mrCL, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLD16mri8, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHLD16rrCL, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLD16rri8, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHLD32mrCL, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLD32mri8, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHLD32rrCL, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLD32rri8, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHLD64mrCL, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLD64mri8, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHLD64rrCL, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLD64rri8, X86_INS_SHLD: shld */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHLX32rm, X86_INS_SHLX: shlx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLX32rr, X86_INS_SHLX: shlx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLX64rm, X86_INS_SHLX: shlx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHLX64rr, X86_INS_SHLX: shlx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHR16m1, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR16mCL, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHR16mi, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR16r1, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR16rCL, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHR16ri, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR32m1, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR32mCL, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHR32mi, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR32r1, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR32rCL, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHR32ri, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR64m1, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR64mCL, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHR64mi, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR64r1, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR64rCL, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHR64ri, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR8m1, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR8mCL, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHR8mi, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR8r1, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHR8rCL, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SHR8ri, X86_INS_SHR: shr */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SHRD16mrCL, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRD16mri8, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHRD16rrCL, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRD16rri8, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHRD32mrCL, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRD32mri8, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHRD32rrCL, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRD32rri8, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHRD64mrCL, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRD64mri8, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHRD64rrCL, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRD64rri8, X86_INS_SHRD: shrd */
	X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHRX32rm, X86_INS_SHRX: shrx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRX32rr, X86_INS_SHRX: shrx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRX64rm, X86_INS_SHRX: shrx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHRX64rr, X86_INS_SHRX: shrx */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SHUFPDrmi, X86_INS_SHUFPD: shufpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHUFPDrri, X86_INS_SHUFPD: shufpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHUFPSrmi, X86_INS_SHUFPS: shufps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SHUFPSrri, X86_INS_SHUFPS: shufps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_SIDT16m, X86_INS_SIDT: sidt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SIDT32m, X86_INS_SIDT: sidt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SIDT64m, X86_INS_SIDT: sidt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SIN_F, X86_INS_FSIN: fsin */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_SIN_Fp32, X86_INS_FSIN: fsin */
	0,
	{ 0 }
},

{	/* X86_SIN_Fp64, X86_INS_FSIN: fsin */
	0,
	{ 0 }
},

{	/* X86_SIN_Fp80, X86_INS_FSIN: fsin */
	0,
	{ 0 }
},

{	/* X86_SKINIT, X86_INS_SKINIT: skinit */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_SLDT16m, X86_INS_SLDT: sldt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SLDT16r, X86_INS_SLDT: sldt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SLDT32r, X86_INS_SLDT: sldt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SLDT64r, X86_INS_SLDT: sldt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SLWPCB, X86_INS_SLWPCB: slwpcb */
	0,
	{ 0 }
},

{	/* X86_SLWPCB64, X86_INS_SLWPCB: slwpcb */
	0,
	{ 0 }
},

{	/* X86_SMSW16m, X86_INS_SMSW: smsw */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SMSW16r, X86_INS_SMSW: smsw */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SMSW32r, X86_INS_SMSW: smsw */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SMSW64r, X86_INS_SMSW: smsw */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_SQRTPDm, X86_INS_SQRTPD: sqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTPDr, X86_INS_SQRTPD: sqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTPSm, X86_INS_SQRTPS: sqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTPSr, X86_INS_SQRTPS: sqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTSDm, X86_INS_SQRTSD: sqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTSDm_Int, X86_INS_SQRTSD: sqrtsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SQRTSDr, X86_INS_SQRTSD: sqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTSDr_Int, X86_INS_SQRTSD: sqrtsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTSSm, X86_INS_SQRTSS: sqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTSSm_Int, X86_INS_SQRTSS: sqrtss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SQRTSSr, X86_INS_SQRTSS: sqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRTSSr_Int, X86_INS_SQRTSS: sqrtss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SQRT_F, X86_INS_FSQRT: fsqrt */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_SQRT_Fp32, X86_INS_FSQRT: fsqrt */
	0,
	{ 0 }
},

{	/* X86_SQRT_Fp64, X86_INS_FSQRT: fsqrt */
	0,
	{ 0 }
},

{	/* X86_SQRT_Fp80, X86_INS_FSQRT: fsqrt */
	0,
	{ 0 }
},

{	/* X86_STAC, X86_INS_STAC: stac */
	0,
	{ 0 }
},

{	/* X86_STC, X86_INS_STC: stc */
	X86_EFLAGS_SET_CF,
	{ 0 }
},

{	/* X86_STD, X86_INS_STD: std */
	X86_EFLAGS_SET_DF,
	{ 0 }
},

{	/* X86_STGI, X86_INS_STGI: stgi */
	0,
	{ 0 }
},

{	/* X86_STI, X86_INS_STI: sti */
	X86_EFLAGS_SET_IF,
	{ 0 }
},

{	/* X86_STMXCSR, X86_INS_STMXCSR: stmxcsr */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_STOSB, X86_INS_STOSB: stosb */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_STOSL, X86_INS_STOSD: stosd */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_STOSQ, X86_INS_STOSQ: stosq */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_STOSW, X86_INS_STOSW: stosw */
	X86_EFLAGS_TEST_DF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_STR16r, X86_INS_STR: str */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_STR32r, X86_INS_STR: str */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_STR64r, X86_INS_STR: str */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_STRm, X86_INS_STR: str */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_F32m, X86_INS_FST: fst */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ST_F64m, X86_INS_FST: fst */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ST_FP32m, X86_INS_FSTP: fstp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ST_FP64m, X86_INS_FSTP: fstp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_ST_FP80m, X86_INS_FSTP: fstp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_FPrr, X86_INS_FSTP: fstp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_Fp32m, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_Fp64m, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_Fp64m32, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_Fp80m32, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_Fp80m64, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_FpP32m, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_FpP64m, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_FpP64m32, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_FpP80m, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_FpP80m32, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_FpP80m64, X86_INS_FST: fst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_ST_Frr, X86_INS_FST: fst */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUB16i16, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB16mi, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB16mi8, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB16mr, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB16ri, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB16ri8, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB16rm, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB16rr, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB16rr_REV, X86_INS_SUB: sub{w}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB32i32, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB32mi, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB32mi8, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB32mr, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB32ri, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB32ri8, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB32rm, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB32rr, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB32rr_REV, X86_INS_SUB: sub{l}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB64i32, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB64mi32, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB64mi8, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB64mr, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB64ri32, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB64ri8, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB64rm, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB64rr, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB64rr_REV, X86_INS_SUB: sub{q}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB8i8, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB8mi, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB8mi8, X86_INS_SUB: sub{b}	$dst $src */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB8mr, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB8ri, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB8ri8, X86_INS_SUB: sub{b}	$src1 $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUB8rm, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB8rr, X86_INS_SUB: sub */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB8rr_REV, X86_INS_SUB: sub{b}	$dst $src2 */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBPDrm, X86_INS_SUBPD: subpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBPDrr, X86_INS_SUBPD: subpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBPSrm, X86_INS_SUBPS: subps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBPSrr, X86_INS_SUBPS: subps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBR_F32m, X86_INS_FSUBR: fsubr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUBR_F64m, X86_INS_FSUBR: fsubr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUBR_FI16m, X86_INS_FISUBR: fisubr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUBR_FI32m, X86_INS_FISUBR: fisubr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUBR_FPrST0, X86_INS_FSUBRP: fsubrp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUBR_FST0r, X86_INS_FSUBR: fsubr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUBR_Fp32m, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_Fp64m, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_Fp64m32, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_Fp80m32, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_Fp80m64, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_FpI16m32, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_FpI16m64, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_FpI16m80, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_FpI32m32, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_FpI32m64, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_FpI32m80, X86_INS_FSUBR: fsubr */
	0,
	{ 0 }
},

{	/* X86_SUBR_FrST0, X86_INS_FSUBR: fsubr */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SUBSDrm, X86_INS_SUBSD: subsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBSDrm_Int, X86_INS_SUBSD: subsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUBSDrr, X86_INS_SUBSD: subsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBSDrr_Int, X86_INS_SUBSD: subsd	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBSSrm, X86_INS_SUBSS: subss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBSSrm_Int, X86_INS_SUBSS: subss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_SUBSSrr, X86_INS_SUBSS: subss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUBSSrr_Int, X86_INS_SUBSS: subss	$dst $src2 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_SUB_F32m, X86_INS_FSUB: fsub */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUB_F64m, X86_INS_FSUB: fsub */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUB_FI16m, X86_INS_FISUB: fisub */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUB_FI32m, X86_INS_FISUB: fisub */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUB_FPrST0, X86_INS_FSUBP: fsubp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUB_FST0r, X86_INS_FSUB: fsub */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_SUB_Fp32, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_Fp32m, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_Fp64, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_Fp64m, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_Fp64m32, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_Fp80, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_Fp80m32, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_Fp80m64, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_FpI16m32, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_FpI16m64, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_FpI16m80, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_FpI32m32, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_FpI32m64, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_FpI32m80, X86_INS_FSUB: fsub */
	0,
	{ 0 }
},

{	/* X86_SUB_FrST0, X86_INS_FSUB: fsub */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_SWAPGS, X86_INS_SWAPGS: swapgs */
	0,
	{ 0 }
},

{	/* X86_SYSCALL, X86_INS_SYSCALL: syscall */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_SYSENTER, X86_INS_SYSENTER: sysenter */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_SYSEXIT, X86_INS_SYSEXIT: sysexit */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_SYSEXIT64, X86_INS_SYSEXITQ: sysexitq */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_SYSRET, X86_INS_SYSRET: sysret */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_SYSRET64, X86_INS_SYSRETQ: sysretq */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_MODIFY_TF | X86_EFLAGS_MODIFY_IF | X86_EFLAGS_MODIFY_DF | X86_EFLAGS_MODIFY_NT | X86_EFLAGS_MODIFY_RF,
	{ 0 }
},

{	/* X86_T1MSKC32rm, X86_INS_T1MSKC: t1mskc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_T1MSKC32rr, X86_INS_T1MSKC: t1mskc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_T1MSKC64rm, X86_INS_T1MSKC: t1mskc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_T1MSKC64rr, X86_INS_T1MSKC: t1mskc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TEST16i16, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST16mi, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST16mi_alt, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST16mr, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST16ri, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST16ri_alt, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST16rr, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_TEST32i32, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST32mi, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST32mi_alt, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST32mr, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST32ri, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST32ri_alt, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST32rr, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_TEST64i32, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST64mi32, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST64mi32_alt, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST64mr, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_TEST64ri32, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST64ri32_alt, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST64rr, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_TEST8i8, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST8mi, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST8mi_alt, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST8mr, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST8ri, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_TEST8ri_alt, X86_INS_TEST: test */
	0,
	{ 0 }
},

{	/* X86_TEST8rr, X86_INS_TEST: test */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_TPAUSE, X86_INS_TPAUSE: tpause */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_TST_F, X86_INS_FTST: ftst */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ 0 }
},

{	/* X86_TST_Fp32, X86_INS_FTST: ftst */
	0,
	{ 0 }
},

{	/* X86_TST_Fp64, X86_INS_FTST: ftst */
	0,
	{ 0 }
},

{	/* X86_TST_Fp80, X86_INS_FTST: ftst */
	0,
	{ 0 }
},

{	/* X86_TZCNT16rm, X86_INS_TZCNT: tzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZCNT16rr, X86_INS_TZCNT: tzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZCNT32rm, X86_INS_TZCNT: tzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZCNT32rr, X86_INS_TZCNT: tzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZCNT64rm, X86_INS_TZCNT: tzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZCNT64rr, X86_INS_TZCNT: tzcnt */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF | X86_EFLAGS_UNDEFINED_OF | X86_EFLAGS_UNDEFINED_SF | X86_EFLAGS_UNDEFINED_PF | X86_EFLAGS_UNDEFINED_AF,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZMSK32rm, X86_INS_TZMSK: tzmsk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZMSK32rr, X86_INS_TZMSK: tzmsk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZMSK64rm, X86_INS_TZMSK: tzmsk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_TZMSK64rr, X86_INS_TZMSK: tzmsk */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_UCOMISDrm, X86_INS_UCOMISD: ucomisd */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UCOMISDrm_Int, X86_INS_UCOMISD: ucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UCOMISDrr, X86_INS_UCOMISD: ucomisd */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UCOMISDrr_Int, X86_INS_UCOMISD: ucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UCOMISSrm, X86_INS_UCOMISS: ucomiss */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UCOMISSrm_Int, X86_INS_UCOMISS: ucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UCOMISSrr, X86_INS_UCOMISS: ucomiss */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UCOMISSrr_Int, X86_INS_UCOMISS: ucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UCOM_FIPr, X86_INS_FUCOMPI: fucompi */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_UCOM_FIr, X86_INS_FUCOMI: fucomi */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_UCOM_FPPr, X86_INS_FUCOMPP: fucompp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ 0 }
},

{	/* X86_UCOM_FPr, X86_INS_FUCOMP: fucomp */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_UCOM_FpIr32, X86_INS_FUCOMP: fucomp */
	0,
	{ 0 }
},

{	/* X86_UCOM_FpIr64, X86_INS_FUCOMP: fucomp */
	0,
	{ 0 }
},

{	/* X86_UCOM_FpIr80, X86_INS_FUCOMP: fucomp */
	0,
	{ 0 }
},

{	/* X86_UCOM_Fpr32, X86_INS_FUCOMP: fucomp */
	0,
	{ 0 }
},

{	/* X86_UCOM_Fpr64, X86_INS_FUCOMP: fucomp */
	0,
	{ 0 }
},

{	/* X86_UCOM_Fpr80, X86_INS_FUCOMP: fucomp */
	0,
	{ 0 }
},

{	/* X86_UCOM_Fr, X86_INS_FUCOM: fucom */
	X86_FPU_FLAGS_MODIFY_C1 | X86_FPU_FLAGS_MODIFY_C0 | X86_FPU_FLAGS_MODIFY_C2 | X86_FPU_FLAGS_MODIFY_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_UD0, X86_INS_UD0: ud0 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UD1, X86_INS_UD1: ud1 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_UD2, X86_INS_UD2: ud2 */
	0,
	{ 0 }
},

{	/* X86_UMONITOR16, X86_INS_UMONITOR: umonitor */
	0,
	{ 0 }
},

{	/* X86_UMONITOR32, X86_INS_UMONITOR: umonitor */
	0,
	{ 0 }
},

{	/* X86_UMONITOR64, X86_INS_UMONITOR: umonitor */
	0,
	{ 0 }
},

{	/* X86_UMWAIT, X86_INS_UMWAIT: umwait */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_UNPCKHPDrm, X86_INS_UNPCKHPD: unpckhpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_UNPCKHPDrr, X86_INS_UNPCKHPD: unpckhpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_UNPCKHPSrm, X86_INS_UNPCKHPS: unpckhps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_UNPCKHPSrr, X86_INS_UNPCKHPS: unpckhps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_UNPCKLPDrm, X86_INS_UNPCKLPD: unpcklpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_UNPCKLPDrr, X86_INS_UNPCKLPD: unpcklpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_UNPCKLPSrm, X86_INS_UNPCKLPS: unpcklps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_UNPCKLPSrr, X86_INS_UNPCKLPS: unpcklps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_V4FMADDPSrm, X86_INS_V4FMADDPS: v4fmaddps */
	0,
	{ 0 }
},

{	/* X86_V4FMADDPSrmk, X86_INS_V4FMADDPS: v4fmaddps */
	0,
	{ 0 }
},

{	/* X86_V4FMADDPSrmkz, X86_INS_V4FMADDPS: v4fmaddps */
	0,
	{ 0 }
},

{	/* X86_V4FMADDSSrm, X86_INS_V4FMADDSS: v4fmaddss */
	0,
	{ 0 }
},

{	/* X86_V4FMADDSSrmk, X86_INS_V4FMADDSS: v4fmaddss */
	0,
	{ 0 }
},

{	/* X86_V4FMADDSSrmkz, X86_INS_V4FMADDSS: v4fmaddss */
	0,
	{ 0 }
},

{	/* X86_V4FNMADDPSrm, X86_INS_V4FNMADDPS: v4fnmaddps */
	0,
	{ 0 }
},

{	/* X86_V4FNMADDPSrmk, X86_INS_V4FNMADDPS: v4fnmaddps */
	0,
	{ 0 }
},

{	/* X86_V4FNMADDPSrmkz, X86_INS_V4FNMADDPS: v4fnmaddps */
	0,
	{ 0 }
},

{	/* X86_V4FNMADDSSrm, X86_INS_V4FNMADDSS: v4fnmaddss */
	0,
	{ 0 }
},

{	/* X86_V4FNMADDSSrmk, X86_INS_V4FNMADDSS: v4fnmaddss */
	0,
	{ 0 }
},

{	/* X86_V4FNMADDSSrmkz, X86_INS_V4FNMADDSS: v4fnmaddss */
	0,
	{ 0 }
},

{	/* X86_VADDPDYrm, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDYrr, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rm, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rmb, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rmbk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rmbkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rmk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rmkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rr, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rrk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ128rrkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rm, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rmb, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rmbk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rmbkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rmk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rmkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rr, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rrk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZ256rrkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrm, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrmb, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrmbk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrmbkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrmk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrmkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrr, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrrb, X86_INS_VADDPD: vaddpd */
	0,
	{ 0 }
},

{	/* X86_VADDPDZrrbk, X86_INS_VADDPD: vaddpd */
	0,
	{ 0 }
},

{	/* X86_VADDPDZrrbkz, X86_INS_VADDPD: vaddpd */
	0,
	{ 0 }
},

{	/* X86_VADDPDZrrk, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDZrrkz, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDrm, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPDrr, X86_INS_VADDPD: vaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSYrm, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSYrr, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rm, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rmb, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rmbk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rmbkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rmk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rmkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rr, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rrk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ128rrkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rm, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rmb, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rmbk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rmbkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rmk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rmkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rr, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rrk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZ256rrkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrm, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrmb, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrmbk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrmbkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrmk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrmkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrr, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrrb, X86_INS_VADDPS: vaddps */
	0,
	{ 0 }
},

{	/* X86_VADDPSZrrbk, X86_INS_VADDPS: vaddps */
	0,
	{ 0 }
},

{	/* X86_VADDPSZrrbkz, X86_INS_VADDPS: vaddps */
	0,
	{ 0 }
},

{	/* X86_VADDPSZrrk, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSZrrkz, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSrm, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDPSrr, X86_INS_VADDPS: vaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrm, X86_INS_VADDSD: vaddsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrm_Int, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrm_Intk, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrm_Intkz, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrr, X86_INS_VADDSD: vaddsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrr_Int, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrr_Intk, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrr_Intkz, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrrb_Int, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrrb_Intk, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDZrrb_Intkz, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDrm, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDrm_Int, X86_INS_VADDSD: vaddsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VADDSDrr, X86_INS_VADDSD: vaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSDrr_Int, X86_INS_VADDSD: vaddsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrm, X86_INS_VADDSS: vaddss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrm_Int, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrm_Intk, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrm_Intkz, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrr, X86_INS_VADDSS: vaddss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrr_Int, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrr_Intk, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrr_Intkz, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrrb_Int, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrrb_Intk, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSZrrb_Intkz, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSrm, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSrm_Int, X86_INS_VADDSS: vaddss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VADDSSrr, X86_INS_VADDSS: vaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSSrr_Int, X86_INS_VADDSS: vaddss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSUBPDYrm, X86_INS_VADDSUBPD: vaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSUBPDYrr, X86_INS_VADDSUBPD: vaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSUBPDrm, X86_INS_VADDSUBPD: vaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSUBPDrr, X86_INS_VADDSUBPD: vaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSUBPSYrm, X86_INS_VADDSUBPS: vaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSUBPSYrr, X86_INS_VADDSUBPS: vaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSUBPSrm, X86_INS_VADDSUBPS: vaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VADDSUBPSrr, X86_INS_VADDSUBPS: vaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTYrm, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTYrr, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTZ128rm, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTZ128rr, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTZ256rm, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTZ256rr, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTZrm, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTZrr, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTrm, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECLASTrr, X86_INS_VAESDECLAST: vaesdeclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECYrm, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECYrr, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECZ128rm, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECZ128rr, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECZ256rm, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECZ256rr, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECZrm, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECZrr, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECrm, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESDECrr, X86_INS_VAESDEC: vaesdec */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTYrm, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTYrr, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTZ128rm, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTZ128rr, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTZ256rm, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTZ256rr, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTZrm, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTZrr, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTrm, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCLASTrr, X86_INS_VAESENCLAST: vaesenclast */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCYrm, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCYrr, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCZ128rm, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCZ128rr, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCZ256rm, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCZ256rr, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCZrm, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCZrr, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCrm, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESENCrr, X86_INS_VAESENC: vaesenc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VAESIMCrm, X86_INS_VAESIMC: vaesimc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VAESIMCrr, X86_INS_VAESIMC: vaesimc */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VAESKEYGENASSIST128rm, X86_INS_VAESKEYGENASSIST: vaeskeygenassist */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VAESKEYGENASSIST128rr, X86_INS_VAESKEYGENASSIST: vaeskeygenassist */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNDZ128rmbi, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ128rmbik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ128rmbikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ128rmi, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ128rmik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ128rmikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ128rri, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ128rrik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ128rrikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rmbi, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rmbik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rmbikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rmi, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rmik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rmikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rri, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rrik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZ256rrikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrmbi, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrmbik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrmbikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrmi, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrmik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrmikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrri, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrrik, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNDZrrikz, X86_INS_VALIGND: valignd */
	0,
	{ 0 }
},

{	/* X86_VALIGNQZ128rmbi, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ128rmbik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ128rmbikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ128rmi, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ128rmik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ128rmikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ128rri, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ128rrik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ128rrikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rmbi, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rmbik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rmbikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rmi, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rmik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rmikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rri, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rrik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZ256rrikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrmbi, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrmbik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrmbikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrmi, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrmik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrmikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrri, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrrik, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VALIGNQZrrikz, X86_INS_VALIGNQ: valignq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VANDNPDYrm, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDYrr, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rm, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rmb, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rmbk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rmbkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rmk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rmkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rr, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rrk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ128rrkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rm, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rmb, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rmbk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rmbkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rmk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rmkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rr, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rrk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZ256rrkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrm, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrmb, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrmbk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrmbkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrmk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrmkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrr, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrrk, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDZrrkz, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDrm, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPDrr, X86_INS_VANDNPD: vandnpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSYrm, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSYrr, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rm, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rmb, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rmbk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rmbkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rmk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rmkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rr, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rrk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ128rrkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rm, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rmb, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rmbk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rmbkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rmk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rmkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rr, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rrk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZ256rrkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrm, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrmb, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrmbk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrmbkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrmk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrmkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrr, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrrk, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSZrrkz, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSrm, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDNPSrr, X86_INS_VANDNPS: vandnps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDYrm, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDYrr, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rm, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rmb, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rmbk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rmbkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rmk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rmkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rr, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rrk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ128rrkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rm, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rmb, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rmbk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rmbkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rmk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rmkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rr, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rrk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZ256rrkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrm, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrmb, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrmbk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrmbkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrmk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrmkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrr, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrrk, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDZrrkz, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDrm, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPDrr, X86_INS_VANDPD: vandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSYrm, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSYrr, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rm, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rmb, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rmbk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rmbkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rmk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rmkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rr, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rrk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ128rrkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rm, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rmb, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rmbk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rmbkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rmk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rmkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rr, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rrk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZ256rrkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrm, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrmb, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrmbk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrmbkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrmk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrmkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrr, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrrk, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSZrrkz, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSrm, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VANDPSrr, X86_INS_VANDPS: vandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ128rm, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ128rmb, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ128rmbk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ128rmbkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ 0 }
},

{	/* X86_VBLENDMPDZ128rmk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ128rmkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ128rr, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ128rrk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ128rrkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ256rm, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ256rmb, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ256rmbk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ256rmbkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ 0 }
},

{	/* X86_VBLENDMPDZ256rmk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ256rmkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ256rr, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ256rrk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZ256rrkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZrm, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZrmb, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZrmbk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZrmbkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ 0 }
},

{	/* X86_VBLENDMPDZrmk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZrmkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZrr, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZrrk, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPDZrrkz, X86_INS_VBLENDMPD: vblendmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ128rm, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ128rmb, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ128rmbk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ128rmbkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ 0 }
},

{	/* X86_VBLENDMPSZ128rmk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ128rmkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ128rr, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ128rrk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ128rrkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ256rm, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ256rmb, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ256rmbk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ256rmbkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ 0 }
},

{	/* X86_VBLENDMPSZ256rmk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ256rmkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ256rr, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ256rrk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZ256rrkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZrm, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZrmb, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZrmbk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZrmbkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ 0 }
},

{	/* X86_VBLENDMPSZrmk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZrmkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZrr, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZrrk, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDMPSZrrkz, X86_INS_VBLENDMPS: vblendmps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDPDYrmi, X86_INS_VBLENDPD: vblendpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VBLENDPDYrri, X86_INS_VBLENDPD: vblendpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VBLENDPDrmi, X86_INS_VBLENDPD: vblendpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VBLENDPDrri, X86_INS_VBLENDPD: vblendpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VBLENDPSYrmi, X86_INS_VBLENDPS: vblendps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VBLENDPSYrri, X86_INS_VBLENDPS: vblendps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VBLENDPSrmi, X86_INS_VBLENDPS: vblendps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VBLENDPSrri, X86_INS_VBLENDPS: vblendps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VBLENDVPDYrm, X86_INS_VBLENDVPD: vblendvpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDVPDYrr, X86_INS_VBLENDVPD: vblendvpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDVPDrm, X86_INS_VBLENDVPD: vblendvpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDVPDrr, X86_INS_VBLENDVPD: vblendvpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDVPSYrm, X86_INS_VBLENDVPS: vblendvps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDVPSYrr, X86_INS_VBLENDVPS: vblendvps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDVPSrm, X86_INS_VBLENDVPS: vblendvps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBLENDVPSrr, X86_INS_VBLENDVPS: vblendvps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF128, X86_INS_VBROADCASTF128: vbroadcastf128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Z256m, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Z256mk, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Z256mkz, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Z256r, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Z256rk, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Z256rkz, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Zm, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Zmk, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Zmkz, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Zr, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Zrk, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X2Zrkz, X86_INS_VBROADCASTF32X2: vbroadcastf32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF32X4Z256rm, X86_INS_VBROADCASTF32X4: vbroadcastf32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF32X4Z256rmk, X86_INS_VBROADCASTF32X4: vbroadcastf32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF32X4Z256rmkz, X86_INS_VBROADCASTF32X4: vbroadcastf32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF32X4rm, X86_INS_VBROADCASTF32X4: vbroadcastf32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF32X4rmk, X86_INS_VBROADCASTF32X4: vbroadcastf32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF32X4rmkz, X86_INS_VBROADCASTF32X4: vbroadcastf32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF32X8rm, X86_INS_VBROADCASTF32X8: vbroadcastf32x8 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF32X8rmk, X86_INS_VBROADCASTF32X8: vbroadcastf32x8 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF32X8rmkz, X86_INS_VBROADCASTF32X8: vbroadcastf32x8 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF64X2Z128rm, X86_INS_VBROADCASTF64X2: vbroadcastf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF64X2Z128rmk, X86_INS_VBROADCASTF64X2: vbroadcastf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF64X2Z128rmkz, X86_INS_VBROADCASTF64X2: vbroadcastf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF64X2rm, X86_INS_VBROADCASTF64X2: vbroadcastf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF64X2rmk, X86_INS_VBROADCASTF64X2: vbroadcastf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF64X2rmkz, X86_INS_VBROADCASTF64X2: vbroadcastf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTF64X4rm, X86_INS_VBROADCASTF64X4: vbroadcastf64x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF64X4rmk, X86_INS_VBROADCASTF64X4: vbroadcastf64x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTF64X4rmkz, X86_INS_VBROADCASTF64X4: vbroadcastf64x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI128, X86_INS_VBROADCASTI128: vbroadcasti128 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI32X2Z128m, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z128mk, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z128mkz, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z128r, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z128rk, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z128rkz, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z256m, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z256mk, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z256mkz, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z256r, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z256rk, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Z256rkz, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Zm, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Zmk, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Zmkz, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Zr, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Zrk, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X2Zrkz, X86_INS_VBROADCASTI32X2: vbroadcasti32x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X4Z256rm, X86_INS_VBROADCASTI32X4: vbroadcasti32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI32X4Z256rmk, X86_INS_VBROADCASTI32X4: vbroadcasti32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI32X4Z256rmkz, X86_INS_VBROADCASTI32X4: vbroadcasti32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI32X4rm, X86_INS_VBROADCASTI32X4: vbroadcasti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI32X4rmk, X86_INS_VBROADCASTI32X4: vbroadcasti32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI32X4rmkz, X86_INS_VBROADCASTI32X4: vbroadcasti32x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI32X8rm, X86_INS_VBROADCASTI32X8: vbroadcasti32x8 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI32X8rmk, X86_INS_VBROADCASTI32X8: vbroadcasti32x8 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI32X8rmkz, X86_INS_VBROADCASTI32X8: vbroadcasti32x8 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI64X2Z128rm, X86_INS_VBROADCASTI64X2: vbroadcasti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI64X2Z128rmk, X86_INS_VBROADCASTI64X2: vbroadcasti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI64X2Z128rmkz, X86_INS_VBROADCASTI64X2: vbroadcasti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI64X2rm, X86_INS_VBROADCASTI64X2: vbroadcasti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI64X2rmk, X86_INS_VBROADCASTI64X2: vbroadcasti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI64X2rmkz, X86_INS_VBROADCASTI64X2: vbroadcasti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI64X4rm, X86_INS_VBROADCASTI64X4: vbroadcasti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTI64X4rmk, X86_INS_VBROADCASTI64X4: vbroadcasti64x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTI64X4rmkz, X86_INS_VBROADCASTI64X4: vbroadcasti64x4 */
	0,
	{ 0 }
},

{	/* X86_VBROADCASTSDYrm, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDYrr, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZ256m, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZ256mk, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZ256mkz, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZ256r, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZ256rk, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZ256rkz, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZm, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZmk, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZmkz, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZr, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZrk, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSDZrkz, X86_INS_VBROADCASTSD: vbroadcastsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSYrm, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSYrr, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ128m, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ128mk, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ128mkz, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ128r, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ128rk, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ128rkz, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ256m, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ256mk, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ256mkz, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ256r, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ256rk, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZ256rkz, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZm, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZmk, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZmkz, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZr, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZrk, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSZrkz, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSrm, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VBROADCASTSSrr, X86_INS_VBROADCASTSS: vbroadcastss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCMPPDYrmi, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPDYrmi_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPDYrri, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPDYrri_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPDZ128rmbi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rmbi_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rmbi_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rmbik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rmi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rmi_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rmi_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rmik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rri, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rri_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rri_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ128rrik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rmbi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rmbi_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rmbi_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rmbik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rmi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rmi_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rmi_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rmik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rri, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rri_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rri_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZ256rrik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrmbi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrmbi_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrmbi_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrmbik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrmi, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPDZrmi_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPDZrmi_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrmik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrri, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPDZrri_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPDZrri_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrrib, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPDZrrib_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPDZrrib_altk, X86_INS_VCMPPD: vcmppd */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrribk, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDZrrik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPDrmi, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPDrmi_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPDrri, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPDrri_alt, X86_INS_VCMPPD: vcmppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPSYrmi, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPSYrmi_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPSYrri, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPSYrri_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPSZ128rmbi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rmbi_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rmbi_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rmbik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rmi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rmi_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rmi_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rmik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rri, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rri_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rri_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ128rrik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rmbi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rmbi_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rmbi_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rmbik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rmi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rmi_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rmi_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rmik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rri, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rri_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rri_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZ256rrik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrmbi, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrmbi_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrmbi_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrmbik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrmi, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPSZrmi_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPSZrmi_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrmik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrri, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPSZrri_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPSZrri_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrrib, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPSZrrib_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPSZrrib_altk, X86_INS_VCMPPS: vcmpps */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrribk, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSZrrik, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPPSrmi, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPSrmi_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPPSrri, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPPSrri_alt, X86_INS_VCMPPS: vcmpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPSDZrm, X86_INS_VCMPSD: vcmp${cc}sd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPSDZrm_Int, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrm_Intk, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrmi_alt, X86_INS_VCMPSD: vcmpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPSDZrmi_altk, X86_INS_VCMPSD: vcmpsd */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrr, X86_INS_VCMPSD: vcmp${cc}sd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPSDZrr_Int, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrr_Intk, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrrb_Int, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrrb_Intk, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrrb_alt, X86_INS_VCMPSD: vcmpsd */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrrb_altk, X86_INS_VCMPSD: vcmpsd */
	0,
	{ 0 }
},

{	/* X86_VCMPSDZrri_alt, X86_INS_VCMPSD: vcmpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPSDZrri_altk, X86_INS_VCMPSD: vcmpsd */
	0,
	{ 0 }
},

{	/* X86_VCMPSDrm, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPSDrm_Int, X86_INS_VCMPSD: vcmpsd */
	0,
	{ 0 }
},

{	/* X86_VCMPSDrm_alt, X86_INS_VCMPSD: vcmpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPSDrr, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPSDrr_Int, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSDrr_alt, X86_INS_VCMPSD: vcmpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPSSZrm, X86_INS_VCMPSS: vcmp${cc}ss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPSSZrm_Int, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrm_Intk, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrmi_alt, X86_INS_VCMPSS: vcmpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPSSZrmi_altk, X86_INS_VCMPSS: vcmpss */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrr, X86_INS_VCMPSS: vcmp${cc}ss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPSSZrr_Int, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrr_Intk, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrrb_Int, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrrb_Intk, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrrb_alt, X86_INS_VCMPSS: vcmpss */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrrb_altk, X86_INS_VCMPSS: vcmpss */
	0,
	{ 0 }
},

{	/* X86_VCMPSSZrri_alt, X86_INS_VCMPSS: vcmpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPSSZrri_altk, X86_INS_VCMPSS: vcmpss */
	0,
	{ 0 }
},

{	/* X86_VCMPSSrm, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPSSrm_Int, X86_INS_VCMPSS: vcmpss */
	0,
	{ 0 }
},

{	/* X86_VCMPSSrm_alt, X86_INS_VCMPSS: vcmpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCMPSSrr, X86_INS_VCMP: vcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCMPSSrr_Int, X86_INS_VCMP: vcmp */
	0,
	{ 0 }
},

{	/* X86_VCMPSSrr_alt, X86_INS_VCMPSS: vcmpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCOMISDZrm, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISDZrm_Int, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISDZrr, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISDZrr_Int, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISDZrrb, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISDrm, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISDrm_Int, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISDrr, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISDrr_Int, X86_INS_VCOMISD: vcomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSZrm, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSZrm_Int, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSZrr, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSZrr_Int, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSZrrb, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSrm, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSrm_Int, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSrr, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMISSrr_Int, X86_INS_VCOMISS: vcomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ128mr, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ128mrk, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ128rr, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ128rrk, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ128rrkz, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ256mr, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ256mrk, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ256rr, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ256rrk, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZ256rrkz, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZmr, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZmrk, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZrr, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZrrk, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPDZrrkz, X86_INS_VCOMPRESSPD: vcompresspd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ128mr, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ128mrk, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ128rr, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ128rrk, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ128rrkz, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ256mr, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ256mrk, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ256rr, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ256rrk, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZ256rrkz, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZmr, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZmrk, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZrr, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZrrk, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCOMPRESSPSZrrkz, X86_INS_VCOMPRESSPS: vcompressps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PDYrm, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PDYrr, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PDZ128rm, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ128rmb, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ128rmbk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ128rmbkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ128rmk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ128rmkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ128rr, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ128rrk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ128rrkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rm, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rmb, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rmbk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rmbkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rmk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rmkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rr, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rrk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZ256rrkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZrm, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PDZrmb, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZrmbk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZrmbkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZrmk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZrmkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZrr, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PDZrrk, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDZrrkz, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTDQ2PDrm, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PDrr, X86_INS_VCVTDQ2PD: vcvtdq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSYrm, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSYrr, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rm, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rmb, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rmbk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rmbkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rmk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rmkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rr, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rrk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ128rrkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rm, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rmb, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rmbk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rmbkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rmk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rmkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rr, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rrk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZ256rrkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrm, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrmb, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrmbk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrmbkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrmk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrmkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrr, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrrb, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTDQ2PSZrrbk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrrbkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrrk, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSZrrkz, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSrm, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTDQ2PSrr, X86_INS_VCVTDQ2PS: vcvtdq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQYrm, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQYrr, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rm, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rmb, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rmbk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rmbkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rmk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rmkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rr, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rrk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ128rrkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rm, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rmb, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rmbk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rmbkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rmk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rmkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rr, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rrk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZ256rrkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrm, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrmb, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrmbk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrmbkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrmk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrmkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrr, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrrb, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPD2DQZrrbk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrrbkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrrk, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQZrrkz, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQrm, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2DQrr, X86_INS_VCVTPD2DQ: vcvtpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2PSYrm, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2PSYrr, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2PSZ128rm, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ128rmb, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ128rmbk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ128rmbkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ128rmk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ128rmkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ128rr, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ128rrk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ128rrkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rm, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rmb, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rmbk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rmbkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rmk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rmkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rr, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rrk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZ256rrkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrm, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2PSZrmb, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrmbk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrmbkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrmk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrmkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrr, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2PSZrrb, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPD2PSZrrbk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrrbkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrrk, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSZrrkz, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSrm, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ 0 }
},

{	/* X86_VCVTPD2PSrr, X86_INS_VCVTPD2PS: vcvtpd2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rm, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rmb, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rmbk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rmbkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rmk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rmkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rr, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rrk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ128rrkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rm, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rmb, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rmbk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rmbkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rmk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rmkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rr, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rrk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZ256rrkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrm, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrmb, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrmbk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrmbkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrmk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrmkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrr, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrrb, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrrbk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrrbkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrrk, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2QQZrrkz, X86_INS_VCVTPD2QQ: vcvtpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rm, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rmb, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rmbk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rmbkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rmk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rmkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rr, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rrk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ128rrkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rm, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rmb, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rmbk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rmbkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rmk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rmkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rr, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rrk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZ256rrkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrm, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrmb, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrmbk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrmbkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrmk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrmkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrr, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrrb, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPD2UDQZrrbk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrrbkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrrk, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UDQZrrkz, X86_INS_VCVTPD2UDQ: vcvtpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rm, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rmb, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rmbk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rmbkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rmk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rmkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rr, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rrk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ128rrkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rm, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rmb, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rmbk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rmbkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rmk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rmkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rr, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rrk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZ256rrkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrm, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrmb, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrmbk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrmbkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrmk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrmkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrr, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrrb, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrrbk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrrbkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrrk, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPD2UQQZrrkz, X86_INS_VCVTPD2UQQ: vcvtpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSYrm, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSYrr, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ128rm, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ128rmk, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ128rmkz, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ128rr, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ128rrk, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ128rrkz, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ256rm, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ256rmk, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ256rmkz, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ256rr, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ256rrk, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZ256rrkz, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrm, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrmk, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrmkz, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrr, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrrb, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrrbk, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrrbkz, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrrk, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSZrrkz, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSrm, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPH2PSrr, X86_INS_VCVTPH2PS: vcvtph2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQYrm, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQYrr, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rm, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rmb, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rmbk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rmbkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rmk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rmkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rr, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rrk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ128rrkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rm, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rmb, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rmbk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rmbkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rmk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rmkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rr, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rrk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZ256rrkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrm, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrmb, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrmbk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrmbkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrmk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrmkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrr, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrrb, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPS2DQZrrbk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrrbkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrrk, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQZrrkz, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQrm, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2DQrr, X86_INS_VCVTPS2DQ: vcvtps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PDYrm, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PDYrr, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PDZ128rm, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ128rmb, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ128rmbk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ128rmbkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ128rmk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ128rmkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ128rr, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ128rrk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ128rrkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rm, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rmb, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rmbk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rmbkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rmk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rmkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rr, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rrk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZ256rrkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrm, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PDZrmb, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrmbk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrmbkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrmk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrmkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrr, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PDZrrb, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrrbk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrrbkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrrk, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDZrrkz, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTPS2PDrm, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PDrr, X86_INS_VCVTPS2PD: vcvtps2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHYmr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPS2PHYrr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPS2PHZ128mr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ128mrk, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ128rr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ128rrk, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ128rrkz, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ256mr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ256mrk, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ256rr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ256rrk, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZ256rrkz, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZmr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPS2PHZmrk, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZrr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPS2PHZrrb, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZrrbk, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZrrbkz, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZrrk, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHZrrkz, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2PHmr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPS2PHrr, X86_INS_VCVTPS2PH: vcvtps2ph */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPS2QQZ128rm, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ128rmb, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ128rmbk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ128rmbkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ128rmk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ128rmkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ128rr, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ128rrk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ128rrkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rm, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rmb, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rmbk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rmbkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rmk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rmkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rr, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rrk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZ256rrkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrm, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrmb, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrmbk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrmbkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrmk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrmkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrr, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrrb, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrrbk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrrbkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrrk, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2QQZrrkz, X86_INS_VCVTPS2QQ: vcvtps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rm, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rmb, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rmbk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rmbkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rmk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rmkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rr, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rrk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ128rrkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rm, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rmb, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rmbk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rmbkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rmk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rmkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rr, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rrk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZ256rrkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrm, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrmb, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrmbk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrmbkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrmk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrmkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrr, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrrb, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTPS2UDQZrrbk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrrbkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrrk, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UDQZrrkz, X86_INS_VCVTPS2UDQ: vcvtps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rm, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rmb, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rmbk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rmbkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rmk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rmkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rr, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rrk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ128rrkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rm, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rmb, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rmbk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rmbkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rmk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rmkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rr, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rrk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZ256rrkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrm, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrmb, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrmbk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrmbkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrmk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrmkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrr, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrrb, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrrbk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrrbkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrrk, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTPS2UQQZrrkz, X86_INS_VCVTPS2UQQ: vcvtps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rm, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rmb, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rmbk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rmbkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rmk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rmkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rr, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rrk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ128rrkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rm, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rmb, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rmbk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rmbkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rmk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rmkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rr, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rrk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZ256rrkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrm, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrmb, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrmbk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrmbkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrmk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrmkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrr, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrrb, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrrbk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrrbkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrrk, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PDZrrkz, X86_INS_VCVTQQ2PD: vcvtqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rm, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rmb, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rmbk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rmbkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rmk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rmkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rr, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rrk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ128rrkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rm, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rmb, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rmbk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rmbkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rmk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rmkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rr, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rrk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZ256rrkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrm, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrmb, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrmbk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrmbkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrmk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrmkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrr, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrrb, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrrbk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrrbkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrrk, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTQQ2PSZrrkz, X86_INS_VCVTQQ2PS: vcvtqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SI64Zrm_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SI64Zrr_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SI64Zrrb_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SI64rm_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SI64rr_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SIZrm_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SIZrr_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SIZrrb_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SIrm_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SIrr_Int, X86_INS_VCVTSD2SI: vcvtsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrm, X86_INS_VCVTSD2SS: vcvtsd2ss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrm_Int, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrm_Intk, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrm_Intkz, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrr, X86_INS_VCVTSD2SS: vcvtsd2ss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrr_Int, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrr_Intk, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrr_Intkz, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrrb_Int, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrrb_Intk, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSZrrb_Intkz, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSrm, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSrm_Int, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSrr, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2SSrr_Int, X86_INS_VCVTSD2SS: vcvtsd2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2USI64Zrm_Int, X86_INS_VCVTSD2USI: vcvtsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2USI64Zrr_Int, X86_INS_VCVTSD2USI: vcvtsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2USI64Zrrb_Int, X86_INS_VCVTSD2USI: vcvtsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2USIZrm_Int, X86_INS_VCVTSD2USI: vcvtsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2USIZrr_Int, X86_INS_VCVTSD2USI: vcvtsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSD2USIZrrb_Int, X86_INS_VCVTSD2USI: vcvtsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDZrm, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDZrm_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDZrr, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDZrr_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDZrrb_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDrm, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDrm_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDrr, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SDrr_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSZrm, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSZrm_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSZrr, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSZrr_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSZrrb_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSrm, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSrm_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSrr, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI2SSrr_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDZrm, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDZrm_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDZrr, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDZrr_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDZrrb_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDrm, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDrm_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDrr, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SDrr_Int, X86_INS_VCVTSI2SD: vcvtsi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSZrm, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSZrm_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSZrr, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSZrr_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSZrrb_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSrm, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSrm_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSrr, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSI642SSrr_Int, X86_INS_VCVTSI2SS: vcvtsi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrm, X86_INS_VCVTSS2SD: vcvtss2sd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrm_Int, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrm_Intk, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrm_Intkz, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrr, X86_INS_VCVTSS2SD: vcvtss2sd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrr_Int, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrr_Intk, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrr_Intkz, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrrb_Int, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrrb_Intk, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDZrrb_Intkz, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDrm, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDrm_Int, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDrr, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SDrr_Int, X86_INS_VCVTSS2SD: vcvtss2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SI64Zrm_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SI64Zrr_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SI64Zrrb_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SI64rm_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SI64rr_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SIZrm_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SIZrr_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SIZrrb_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SIrm_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2SIrr_Int, X86_INS_VCVTSS2SI: vcvtss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2USI64Zrm_Int, X86_INS_VCVTSS2USI: vcvtss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2USI64Zrr_Int, X86_INS_VCVTSS2USI: vcvtss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2USI64Zrrb_Int, X86_INS_VCVTSS2USI: vcvtss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2USIZrm_Int, X86_INS_VCVTSS2USI: vcvtss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2USIZrr_Int, X86_INS_VCVTSS2USI: vcvtss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTSS2USIZrrb_Int, X86_INS_VCVTSS2USI: vcvtss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQYrm, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQYrr, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rm, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rmb, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rmbk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rmbkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rmk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rmkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rr, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rrk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ128rrkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rm, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rmb, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rmbk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rmbkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rmk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rmkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rr, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rrk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZ256rrkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrm, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrmb, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrmbk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrmbkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrmk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrmkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrr, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrrb, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrrbk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrrbkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrrk, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQZrrkz, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQrm, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2DQrr, X86_INS_VCVTTPD2DQ: vcvttpd2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rm, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rmb, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rmbk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rmbkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rmk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rmkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rr, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rrk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ128rrkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rm, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rmb, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rmbk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rmbkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rmk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rmkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rr, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rrk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZ256rrkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrm, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrmb, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrmbk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrmbkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrmk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrmkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrr, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrrb, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrrbk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrrbkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrrk, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2QQZrrkz, X86_INS_VCVTTPD2QQ: vcvttpd2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rm, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rmb, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rmbk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rmbkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rmk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rmkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rr, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rrk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ128rrkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rm, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rmb, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rmbk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rmbkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rmk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rmkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rr, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rrk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZ256rrkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrm, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrmb, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrmbk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrmbkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrmk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrmkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrr, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrrb, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrrbk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrrbkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrrk, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UDQZrrkz, X86_INS_VCVTTPD2UDQ: vcvttpd2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rm, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rmb, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rmbk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rmbkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rmk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rmkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rr, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rrk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ128rrkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rm, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rmb, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rmbk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rmbkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rmk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rmkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rr, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rrk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZ256rrkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrm, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrmb, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrmbk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrmbkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrmk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrmkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrr, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrrb, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrrbk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrrbkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrrk, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPD2UQQZrrkz, X86_INS_VCVTTPD2UQQ: vcvttpd2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQYrm, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQYrr, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rm, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rmb, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rmbk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rmbkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rmk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rmkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rr, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rrk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ128rrkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rm, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rmb, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rmbk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rmbkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rmk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rmkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rr, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rrk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZ256rrkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrm, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrmb, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrmbk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrmbkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrmk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrmkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrr, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrrb, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrrbk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrrbkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrrk, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQZrrkz, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQrm, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2DQrr, X86_INS_VCVTTPS2DQ: vcvttps2dq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rm, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rmb, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rmbk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rmbkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rmk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rmkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rr, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rrk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ128rrkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rm, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rmb, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rmbk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rmbkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rmk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rmkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rr, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rrk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZ256rrkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrm, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrmb, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrmbk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrmbkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrmk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrmkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrr, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrrb, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrrbk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrrbkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrrk, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2QQZrrkz, X86_INS_VCVTTPS2QQ: vcvttps2qq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rm, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rmb, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rmbk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rmbkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rmk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rmkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rr, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rrk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ128rrkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rm, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rmb, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rmbk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rmbkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rmk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rmkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rr, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rrk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZ256rrkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrm, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrmb, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrmbk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrmbkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrmk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrmkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrr, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrrb, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrrbk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrrbkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrrk, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UDQZrrkz, X86_INS_VCVTTPS2UDQ: vcvttps2udq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rm, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rmb, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rmbk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rmbkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rmk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rmkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rr, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rrk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ128rrkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rm, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rmb, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rmbk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rmbkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rmk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rmkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rr, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rrk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZ256rrkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrm, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrmb, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrmbk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrmbkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrmk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrmkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrr, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrrb, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrrbk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrrbkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrrk, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTPS2UQQZrrkz, X86_INS_VCVTTPS2UQQ: vcvttps2uqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64Zrm, X86_INS_VCVTTSD2SI: vcvttsd2si	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64Zrm_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64Zrr, X86_INS_VCVTTSD2SI: vcvttsd2si	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64Zrr_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64Zrrb_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64rm, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64rm_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64rr, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SI64rr_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIZrm, X86_INS_VCVTTSD2SI: vcvttsd2si	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIZrm_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIZrr, X86_INS_VCVTTSD2SI: vcvttsd2si	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIZrr_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIZrrb_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIrm, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIrm_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIrr, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2SIrr_Int, X86_INS_VCVTTSD2SI: vcvttsd2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USI64Zrm, X86_INS_VCVTTSD2USI: vcvttsd2usi	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USI64Zrm_Int, X86_INS_VCVTTSD2USI: vcvttsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USI64Zrr, X86_INS_VCVTTSD2USI: vcvttsd2usi	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USI64Zrr_Int, X86_INS_VCVTTSD2USI: vcvttsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USI64Zrrb_Int, X86_INS_VCVTTSD2USI: vcvttsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USIZrm, X86_INS_VCVTTSD2USI: vcvttsd2usi	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USIZrm_Int, X86_INS_VCVTTSD2USI: vcvttsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USIZrr, X86_INS_VCVTTSD2USI: vcvttsd2usi	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USIZrr_Int, X86_INS_VCVTTSD2USI: vcvttsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSD2USIZrrb_Int, X86_INS_VCVTTSD2USI: vcvttsd2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64Zrm, X86_INS_VCVTTSS2SI: vcvttss2si	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64Zrm_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64Zrr, X86_INS_VCVTTSS2SI: vcvttss2si	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64Zrr_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64Zrrb_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64rm, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64rm_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64rr, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SI64rr_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIZrm, X86_INS_VCVTTSS2SI: vcvttss2si	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIZrm_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIZrr, X86_INS_VCVTTSS2SI: vcvttss2si	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIZrr_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIZrrb_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIrm, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIrm_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIrr, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2SIrr_Int, X86_INS_VCVTTSS2SI: vcvttss2si */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USI64Zrm, X86_INS_VCVTTSS2USI: vcvttss2usi	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USI64Zrm_Int, X86_INS_VCVTTSS2USI: vcvttss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USI64Zrr, X86_INS_VCVTTSS2USI: vcvttss2usi	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USI64Zrr_Int, X86_INS_VCVTTSS2USI: vcvttss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USI64Zrrb_Int, X86_INS_VCVTTSS2USI: vcvttss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USIZrm, X86_INS_VCVTTSS2USI: vcvttss2usi	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USIZrm_Int, X86_INS_VCVTTSS2USI: vcvttss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USIZrr, X86_INS_VCVTTSS2USI: vcvttss2usi	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USIZrr_Int, X86_INS_VCVTTSS2USI: vcvttss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTTSS2USIZrrb_Int, X86_INS_VCVTTSS2USI: vcvttss2usi */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PDZ128rm, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ128rmb, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ128rmbk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ128rmbkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ128rmk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ128rmkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ128rr, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ128rrk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ128rrkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rm, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rmb, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rmbk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rmbkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rmk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rmkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rr, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rrk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZ256rrkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZrm, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PDZrmb, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZrmbk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZrmbkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZrmk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZrmkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZrr, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PDZrrk, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PDZrrkz, X86_INS_VCVTUDQ2PD: vcvtudq2pd */
	0,
	{ 0 }
},

{	/* X86_VCVTUDQ2PSZ128rm, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ128rmb, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ128rmbk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ128rmbkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ128rmk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ128rmkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ128rr, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ128rrk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ128rrkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rm, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rmb, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rmbk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rmbkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rmk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rmkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rr, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rrk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZ256rrkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrm, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrmb, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrmbk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrmbkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrmk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrmkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrr, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrrb, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VCVTUDQ2PSZrrbk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrrbkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrrk, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUDQ2PSZrrkz, X86_INS_VCVTUDQ2PS: vcvtudq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rm, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rmb, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rmbk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rmbkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rmk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rmkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rr, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rrk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ128rrkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rm, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rmb, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rmbk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rmbkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rmk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rmkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rr, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rrk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZ256rrkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrm, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrmb, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrmbk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrmbkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrmk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrmkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrr, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrrb, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrrbk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrrbkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrrk, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PDZrrkz, X86_INS_VCVTUQQ2PD: vcvtuqq2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rm, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rmb, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rmbk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rmbkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rmk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rmkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rr, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rrk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ128rrkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rm, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rmb, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rmbk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rmbkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rmk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rmkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rr, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rrk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZ256rrkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrm, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrmb, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrmbk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrmbkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrmk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrmkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrr, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrrb, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrrbk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrrbkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrrk, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUQQ2PSZrrkz, X86_INS_VCVTUQQ2PS: vcvtuqq2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SDZrm, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SDZrm_Int, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SDZrr, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SDZrr_Int, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SSZrm, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SSZrm_Int, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SSZrr, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SSZrr_Int, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI2SSZrrb_Int, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SDZrm, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SDZrm_Int, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SDZrr, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SDZrr_Int, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SDZrrb_Int, X86_INS_VCVTUSI2SD: vcvtusi2sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SSZrm, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SSZrm_Int, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SSZrr, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SSZrr_Int, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VCVTUSI642SSZrrb_Int, X86_INS_VCVTUSI2SS: vcvtusi2ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDBPSADBWZ128rmi, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ128rmik, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ128rmikz, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ128rri, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ128rrik, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ128rrikz, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ256rmi, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ256rmik, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ256rmikz, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ256rri, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ256rrik, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZ256rrikz, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZrmi, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZrmik, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZrmikz, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZrri, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZrrik, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDBPSADBWZrrikz, X86_INS_VDBPSADBW: vdbpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDIVPDYrm, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDYrr, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rm, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rmb, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rmbk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rmbkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rmk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rmkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rr, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rrk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ128rrkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rm, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rmb, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rmbk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rmbkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rmk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rmkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rr, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rrk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZ256rrkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrm, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrmb, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrmbk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrmbkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrmk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrmkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrr, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrrb, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrrbk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrrbkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrrk, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDZrrkz, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDrm, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPDrr, X86_INS_VDIVPD: vdivpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSYrm, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSYrr, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rm, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rmb, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rmbk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rmbkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rmk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rmkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rr, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rrk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ128rrkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rm, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rmb, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rmbk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rmbkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rmk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rmkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rr, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rrk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZ256rrkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrm, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrmb, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrmbk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrmbkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrmk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrmkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrr, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrrb, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrrbk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrrbkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrrk, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSZrrkz, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSrm, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVPSrr, X86_INS_VDIVPS: vdivps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrm, X86_INS_VDIVSD: vdivsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrm_Int, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrm_Intk, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrm_Intkz, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrr, X86_INS_VDIVSD: vdivsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrr_Int, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrr_Intk, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrr_Intkz, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrrb_Int, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrrb_Intk, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDZrrb_Intkz, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDrm, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDrm_Int, X86_INS_VDIVSD: vdivsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDIVSDrr, X86_INS_VDIVSD: vdivsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSDrr_Int, X86_INS_VDIVSD: vdivsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrm, X86_INS_VDIVSS: vdivss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrm_Int, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrm_Intk, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrm_Intkz, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrr, X86_INS_VDIVSS: vdivss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrr_Int, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrr_Intk, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrr_Intkz, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrrb_Int, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrrb_Intk, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSZrrb_Intkz, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSrm, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSrm_Int, X86_INS_VDIVSS: vdivss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDIVSSrr, X86_INS_VDIVSS: vdivss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDIVSSrr_Int, X86_INS_VDIVSS: vdivss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VDPPDrmi, X86_INS_VDPPD: vdppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDPPDrri, X86_INS_VDPPD: vdppd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDPPSYrmi, X86_INS_VDPPS: vdpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDPPSYrri, X86_INS_VDPPS: vdpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDPPSrmi, X86_INS_VDPPS: vdpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VDPPSrri, X86_INS_VDPPS: vdpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VERRm, X86_INS_VERR: verr */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_READ, 0 }
},

{	/* X86_VERRr, X86_INS_VERR: verr */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_READ, 0 }
},

{	/* X86_VERWm, X86_INS_VERW: verw */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_READ, 0 }
},

{	/* X86_VERWr, X86_INS_VERW: verw */
	X86_EFLAGS_MODIFY_ZF,
	{ CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZm, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZmb, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZmbk, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZmbkz, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZmk, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZmkz, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZr, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZrb, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZrbk, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZrbkz, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZrk, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PDZrkz, X86_INS_VEXP2PD: vexp2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZm, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZmb, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZmbk, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZmbkz, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZmk, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZmkz, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZr, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZrb, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZrbk, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZrbkz, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZrk, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXP2PSZrkz, X86_INS_VEXP2PS: vexp2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ128rm, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ128rmk, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ128rmkz, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ128rr, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ128rrk, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ128rrkz, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ256rm, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ256rmk, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ256rmkz, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ256rr, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ256rrk, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZ256rrkz, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZrm, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZrmk, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZrmkz, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZrr, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZrrk, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPDZrrkz, X86_INS_VEXPANDPD: vexpandpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ128rm, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ128rmk, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ128rmkz, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ128rr, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ128rrk, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ128rrkz, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ256rm, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ256rmk, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ256rmkz, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ256rr, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ256rrk, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZ256rrkz, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZrm, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZrmk, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZrmkz, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZrr, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZrrk, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXPANDPSZrrkz, X86_INS_VEXPANDPS: vexpandps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF128mr, X86_INS_VEXTRACTF128: vextractf128 */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VEXTRACTF128rr, X86_INS_VEXTRACTF128: vextractf128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VEXTRACTF32x4Z256mr, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Z256mrk, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Z256rr, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Z256rrk, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Z256rrkz, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Zmr, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Zmrk, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Zrr, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Zrrk, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x4Zrrkz, X86_INS_VEXTRACTF32X4: vextractf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x8Zmr, X86_INS_VEXTRACTF32X8: vextractf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x8Zmrk, X86_INS_VEXTRACTF32X8: vextractf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x8Zrr, X86_INS_VEXTRACTF32X8: vextractf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x8Zrrk, X86_INS_VEXTRACTF32X8: vextractf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF32x8Zrrkz, X86_INS_VEXTRACTF32X8: vextractf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Z256mr, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Z256mrk, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Z256rr, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Z256rrk, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Z256rrkz, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Zmr, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Zmrk, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Zrr, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Zrrk, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x2Zrrkz, X86_INS_VEXTRACTF64X2: vextractf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x4Zmr, X86_INS_VEXTRACTF64X4: vextractf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x4Zmrk, X86_INS_VEXTRACTF64X4: vextractf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x4Zrr, X86_INS_VEXTRACTF64X4: vextractf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x4Zrrk, X86_INS_VEXTRACTF64X4: vextractf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTF64x4Zrrkz, X86_INS_VEXTRACTF64X4: vextractf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI128mr, X86_INS_VEXTRACTI128: vextracti128 */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VEXTRACTI128rr, X86_INS_VEXTRACTI128: vextracti128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VEXTRACTI32x4Z256mr, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Z256mrk, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Z256rr, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Z256rrk, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Z256rrkz, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Zmr, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Zmrk, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Zrr, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Zrrk, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x4Zrrkz, X86_INS_VEXTRACTI32X4: vextracti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x8Zmr, X86_INS_VEXTRACTI32X8: vextracti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x8Zmrk, X86_INS_VEXTRACTI32X8: vextracti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x8Zrr, X86_INS_VEXTRACTI32X8: vextracti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x8Zrrk, X86_INS_VEXTRACTI32X8: vextracti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI32x8Zrrkz, X86_INS_VEXTRACTI32X8: vextracti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Z256mr, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Z256mrk, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Z256rr, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Z256rrk, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Z256rrkz, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Zmr, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Zmrk, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Zrr, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Zrrk, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x2Zrrkz, X86_INS_VEXTRACTI64X2: vextracti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x4Zmr, X86_INS_VEXTRACTI64X4: vextracti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x4Zmrk, X86_INS_VEXTRACTI64X4: vextracti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x4Zrr, X86_INS_VEXTRACTI64X4: vextracti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x4Zrrk, X86_INS_VEXTRACTI64X4: vextracti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTI64x4Zrrkz, X86_INS_VEXTRACTI64X4: vextracti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTPSZmr, X86_INS_VEXTRACTPS: vextractps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTPSZrr, X86_INS_VEXTRACTPS: vextractps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VEXTRACTPSmr, X86_INS_VEXTRACTPS: vextractps */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VEXTRACTPSrr, X86_INS_VEXTRACTPS: vextractps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rmbi, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rmbik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rmbikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rmi, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rmik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rmikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rri, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rrik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ128rrikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rmbi, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rmbik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rmbikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rmi, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rmik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rmikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rri, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rrik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZ256rrikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrmbi, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrmbik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrmbikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrmi, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrmik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrmikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrri, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrrib, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrribk, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrribkz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrrik, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPDZrrikz, X86_INS_VFIXUPIMMPD: vfixupimmpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rmbi, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rmbik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rmbikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rmi, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rmik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rmikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rri, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rrik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ128rrikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rmbi, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rmbik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rmbikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rmi, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rmik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rmikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rri, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rrik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZ256rrikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrmbi, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrmbik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrmbikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrmi, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrmik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrmikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrri, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrrib, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrribk, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrribkz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrrik, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMPSZrrikz, X86_INS_VFIXUPIMMPS: vfixupimmps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrmi, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrmik, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrmikz, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrri, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrrib, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrribk, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrribkz, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrrik, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSDZrrikz, X86_INS_VFIXUPIMMSD: vfixupimmsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrmi, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrmik, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrmikz, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrri, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrrib, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrribk, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrribkz, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrrik, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFIXUPIMMSSZrrikz, X86_INS_VFIXUPIMMSS: vfixupimmss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFMADD132PDYm, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDYr, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128m, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128mb, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128mbk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128mbkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128mk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128mkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128r, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128rk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ128rkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256m, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256mb, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256mbk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256mbkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256mk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256mkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256r, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256rk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZ256rkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZm, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZmb, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZmbk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZmbkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZmk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZmkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZr, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZrb, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZrbk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZrbkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZrk, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDZrkz, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDm, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PDr, X86_INS_VFMADD132PD: vfmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSYm, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSYr, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128m, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128mb, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128mbk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128mbkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128mk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128mkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128r, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128rk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ128rkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256m, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256mb, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256mbk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256mbkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256mk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256mkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256r, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256rk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZ256rkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZm, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZmb, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZmbk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZmbkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZmk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZmkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZr, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZrb, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZrbk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZrbkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZrk, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSZrkz, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSm, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132PSr, X86_INS_VFMADD132PS: vfmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZm, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZm_Int, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZm_Intk, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZm_Intkz, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZr, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZr_Int, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZr_Intk, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZr_Intkz, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZrb, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZrb_Int, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZrb_Intk, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDZrb_Intkz, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDm, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDm_Int, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDr, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SDr_Int, X86_INS_VFMADD132SD: vfmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZm, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZm_Int, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZm_Intk, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZm_Intkz, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZr, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZr_Int, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZr_Intk, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZr_Intkz, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZrb, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZrb_Int, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZrb_Intk, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSZrb_Intkz, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSm, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSm_Int, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSr, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD132SSr_Int, X86_INS_VFMADD132SS: vfmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDYm, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDYr, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128m, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128mb, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128mbk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128mbkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128mk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128mkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128r, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128rk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ128rkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256m, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256mb, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256mbk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256mbkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256mk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256mkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256r, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256rk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZ256rkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZm, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZmb, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZmbk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZmbkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZmk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZmkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZr, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZrb, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZrbk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZrbkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZrk, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDZrkz, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDm, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PDr, X86_INS_VFMADD213PD: vfmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSYm, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSYr, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128m, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128mb, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128mbk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128mbkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128mk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128mkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128r, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128rk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ128rkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256m, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256mb, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256mbk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256mbkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256mk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256mkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256r, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256rk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZ256rkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZm, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZmb, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZmbk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZmbkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZmk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZmkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZr, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZrb, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZrbk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZrbkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZrk, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSZrkz, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSm, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213PSr, X86_INS_VFMADD213PS: vfmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZm, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZm_Int, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZm_Intk, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZm_Intkz, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZr, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZr_Int, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZr_Intk, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZr_Intkz, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZrb, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZrb_Int, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZrb_Intk, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDZrb_Intkz, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDm, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDm_Int, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDr, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SDr_Int, X86_INS_VFMADD213SD: vfmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZm, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZm_Int, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZm_Intk, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZm_Intkz, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZr, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZr_Int, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZr_Intk, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZr_Intkz, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZrb, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZrb_Int, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZrb_Intk, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSZrb_Intkz, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSm, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSm_Int, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSr, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD213SSr_Int, X86_INS_VFMADD213SS: vfmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDYm, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDYr, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128m, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128mb, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128mbk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128mbkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128mk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128mkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128r, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128rk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ128rkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256m, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256mb, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256mbk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256mbkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256mk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256mkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256r, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256rk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZ256rkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZm, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZmb, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZmbk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZmbkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZmk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZmkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZr, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZrb, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZrbk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZrbkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZrk, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDZrkz, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDm, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PDr, X86_INS_VFMADD231PD: vfmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSYm, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSYr, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128m, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128mb, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128mbk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128mbkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128mk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128mkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128r, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128rk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ128rkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256m, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256mb, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256mbk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256mbkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256mk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256mkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256r, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256rk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZ256rkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZm, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZmb, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZmbk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZmbkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZmk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZmkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZr, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZrb, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZrbk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZrbkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZrk, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSZrkz, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSm, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231PSr, X86_INS_VFMADD231PS: vfmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZm, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZm_Int, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZm_Intk, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZm_Intkz, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZr, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZr_Int, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZr_Intk, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZr_Intkz, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZrb, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZrb_Int, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZrb_Intk, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDZrb_Intkz, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDm, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDm_Int, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDr, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SDr_Int, X86_INS_VFMADD231SD: vfmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZm, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZm_Int, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZm_Intk, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZm_Intkz, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZr, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZr_Int, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZr_Intk, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZr_Intkz, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZrb, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZrb_Int, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZrb_Intk, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSZrb_Intkz, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSm, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSm_Int, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSr, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADD231SSr_Int, X86_INS_VFMADD231SS: vfmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPD4Ymr, X86_INS_VFMADDPD: vfmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPD4Yrm, X86_INS_VFMADDPD: vfmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPD4Yrr, X86_INS_VFMADDPD: vfmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPD4Yrr_REV, X86_INS_VFMADDPD: vfmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPD4mr, X86_INS_VFMADDPD: vfmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPD4rm, X86_INS_VFMADDPD: vfmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPD4rr, X86_INS_VFMADDPD: vfmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPD4rr_REV, X86_INS_VFMADDPD: vfmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPS4Ymr, X86_INS_VFMADDPS: vfmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPS4Yrm, X86_INS_VFMADDPS: vfmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPS4Yrr, X86_INS_VFMADDPS: vfmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPS4Yrr_REV, X86_INS_VFMADDPS: vfmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPS4mr, X86_INS_VFMADDPS: vfmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPS4rm, X86_INS_VFMADDPS: vfmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPS4rr, X86_INS_VFMADDPS: vfmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDPS4rr_REV, X86_INS_VFMADDPS: vfmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSD4mr, X86_INS_VFMADDSD: vfmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSD4mr_Int, X86_INS_VFMADDSD: vfmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSD4rm, X86_INS_VFMADDSD: vfmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSD4rm_Int, X86_INS_VFMADDSD: vfmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFMADDSD4rr, X86_INS_VFMADDSD: vfmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSD4rr_Int, X86_INS_VFMADDSD: vfmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSD4rr_Int_REV, X86_INS_VFMADDSD: vfmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSD4rr_REV, X86_INS_VFMADDSD: vfmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSS4mr, X86_INS_VFMADDSS: vfmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSS4mr_Int, X86_INS_VFMADDSS: vfmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSS4rm, X86_INS_VFMADDSS: vfmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSS4rm_Int, X86_INS_VFMADDSS: vfmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFMADDSS4rr, X86_INS_VFMADDSS: vfmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSS4rr_Int, X86_INS_VFMADDSS: vfmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSS4rr_Int_REV, X86_INS_VFMADDSS: vfmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSS4rr_REV, X86_INS_VFMADDSS: vfmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDYm, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDYr, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128m, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128mb, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128mbk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128mbkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128mk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128mkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128r, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128rk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ128rkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256m, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256mb, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256mbk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256mbkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256mk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256mkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256r, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256rk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZ256rkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZm, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZmb, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZmbk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZmbkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZmk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZmkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZr, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZrb, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZrbk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZrbkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZrk, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDZrkz, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDm, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PDr, X86_INS_VFMADDSUB132PD: vfmaddsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSYm, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSYr, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128m, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128mb, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128mbk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128mbkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128mk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128mkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128r, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128rk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ128rkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256m, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256mb, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256mbk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256mbkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256mk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256mkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256r, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256rk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZ256rkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZm, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZmb, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZmbk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZmbkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZmk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZmkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZr, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZrb, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZrbk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZrbkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZrk, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSZrkz, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSm, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB132PSr, X86_INS_VFMADDSUB132PS: vfmaddsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDYm, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDYr, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128m, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128mb, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128mbk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128mbkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128mk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128mkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128r, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128rk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ128rkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256m, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256mb, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256mbk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256mbkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256mk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256mkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256r, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256rk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZ256rkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZm, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZmb, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZmbk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZmbkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZmk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZmkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZr, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZrb, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZrbk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZrbkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZrk, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDZrkz, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDm, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PDr, X86_INS_VFMADDSUB213PD: vfmaddsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSYm, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSYr, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128m, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128mb, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128mbk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128mbkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128mk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128mkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128r, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128rk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ128rkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256m, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256mb, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256mbk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256mbkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256mk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256mkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256r, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256rk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZ256rkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZm, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZmb, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZmbk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZmbkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZmk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZmkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZr, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZrb, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZrbk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZrbkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZrk, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSZrkz, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSm, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB213PSr, X86_INS_VFMADDSUB213PS: vfmaddsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDYm, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDYr, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128m, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128mb, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128mbk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128mbkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128mk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128mkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128r, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128rk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ128rkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256m, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256mb, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256mbk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256mbkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256mk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256mkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256r, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256rk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZ256rkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZm, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZmb, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZmbk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZmbkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZmk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZmkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZr, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZrb, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZrbk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZrbkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZrk, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDZrkz, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDm, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PDr, X86_INS_VFMADDSUB231PD: vfmaddsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSYm, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSYr, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128m, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128mb, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128mbk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128mbkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128mk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128mkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128r, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128rk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ128rkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256m, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256mb, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256mbk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256mbkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256mk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256mkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256r, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256rk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZ256rkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZm, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZmb, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZmbk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZmbkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZmk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZmkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZr, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZrb, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZrbk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZrbkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZrk, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSZrkz, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSm, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUB231PSr, X86_INS_VFMADDSUB231PS: vfmaddsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPD4Ymr, X86_INS_VFMADDSUBPD: vfmaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPD4Yrm, X86_INS_VFMADDSUBPD: vfmaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPD4Yrr, X86_INS_VFMADDSUBPD: vfmaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPD4Yrr_REV, X86_INS_VFMADDSUBPD: vfmaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPD4mr, X86_INS_VFMADDSUBPD: vfmaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPD4rm, X86_INS_VFMADDSUBPD: vfmaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPD4rr, X86_INS_VFMADDSUBPD: vfmaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPD4rr_REV, X86_INS_VFMADDSUBPD: vfmaddsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPS4Ymr, X86_INS_VFMADDSUBPS: vfmaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPS4Yrm, X86_INS_VFMADDSUBPS: vfmaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPS4Yrr, X86_INS_VFMADDSUBPS: vfmaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPS4Yrr_REV, X86_INS_VFMADDSUBPS: vfmaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPS4mr, X86_INS_VFMADDSUBPS: vfmaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPS4rm, X86_INS_VFMADDSUBPS: vfmaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPS4rr, X86_INS_VFMADDSUBPS: vfmaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMADDSUBPS4rr_REV, X86_INS_VFMADDSUBPS: vfmaddsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDYm, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDYr, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128m, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128mb, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128mbk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128mbkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128mk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128mkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128r, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128rk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ128rkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256m, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256mb, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256mbk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256mbkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256mk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256mkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256r, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256rk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZ256rkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZm, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZmb, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZmbk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZmbkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZmk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZmkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZr, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZrb, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZrbk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZrbkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZrk, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDZrkz, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDm, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PDr, X86_INS_VFMSUB132PD: vfmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSYm, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSYr, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128m, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128mb, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128mbk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128mbkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128mk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128mkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128r, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128rk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ128rkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256m, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256mb, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256mbk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256mbkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256mk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256mkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256r, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256rk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZ256rkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZm, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZmb, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZmbk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZmbkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZmk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZmkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZr, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZrb, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZrbk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZrbkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZrk, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSZrkz, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSm, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132PSr, X86_INS_VFMSUB132PS: vfmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZm, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZm_Int, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZm_Intk, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZm_Intkz, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZr, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZr_Int, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZr_Intk, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZr_Intkz, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZrb, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZrb_Int, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZrb_Intk, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDZrb_Intkz, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDm, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDm_Int, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDr, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SDr_Int, X86_INS_VFMSUB132SD: vfmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZm, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZm_Int, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZm_Intk, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZm_Intkz, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZr, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZr_Int, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZr_Intk, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZr_Intkz, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZrb, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZrb_Int, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZrb_Intk, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSZrb_Intkz, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSm, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSm_Int, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSr, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB132SSr_Int, X86_INS_VFMSUB132SS: vfmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDYm, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDYr, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128m, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128mb, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128mbk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128mbkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128mk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128mkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128r, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128rk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ128rkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256m, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256mb, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256mbk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256mbkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256mk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256mkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256r, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256rk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZ256rkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZm, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZmb, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZmbk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZmbkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZmk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZmkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZr, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZrb, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZrbk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZrbkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZrk, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDZrkz, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDm, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PDr, X86_INS_VFMSUB213PD: vfmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSYm, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSYr, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128m, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128mb, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128mbk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128mbkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128mk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128mkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128r, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128rk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ128rkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256m, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256mb, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256mbk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256mbkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256mk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256mkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256r, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256rk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZ256rkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZm, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZmb, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZmbk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZmbkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZmk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZmkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZr, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZrb, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZrbk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZrbkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZrk, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSZrkz, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSm, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213PSr, X86_INS_VFMSUB213PS: vfmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZm, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZm_Int, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZm_Intk, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZm_Intkz, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZr, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZr_Int, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZr_Intk, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZr_Intkz, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZrb, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZrb_Int, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZrb_Intk, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDZrb_Intkz, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDm, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDm_Int, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDr, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SDr_Int, X86_INS_VFMSUB213SD: vfmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZm, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZm_Int, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZm_Intk, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZm_Intkz, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZr, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZr_Int, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZr_Intk, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZr_Intkz, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZrb, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZrb_Int, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZrb_Intk, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSZrb_Intkz, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSm, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSm_Int, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSr, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB213SSr_Int, X86_INS_VFMSUB213SS: vfmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDYm, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDYr, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128m, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128mb, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128mbk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128mbkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128mk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128mkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128r, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128rk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ128rkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256m, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256mb, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256mbk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256mbkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256mk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256mkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256r, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256rk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZ256rkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZm, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZmb, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZmbk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZmbkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZmk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZmkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZr, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZrb, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZrbk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZrbkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZrk, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDZrkz, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDm, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PDr, X86_INS_VFMSUB231PD: vfmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSYm, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSYr, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128m, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128mb, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128mbk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128mbkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128mk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128mkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128r, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128rk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ128rkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256m, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256mb, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256mbk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256mbkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256mk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256mkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256r, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256rk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZ256rkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZm, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZmb, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZmbk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZmbkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZmk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZmkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZr, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZrb, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZrbk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZrbkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZrk, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSZrkz, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSm, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231PSr, X86_INS_VFMSUB231PS: vfmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZm, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZm_Int, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZm_Intk, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZm_Intkz, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZr, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZr_Int, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZr_Intk, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZr_Intkz, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZrb, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZrb_Int, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZrb_Intk, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDZrb_Intkz, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDm, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDm_Int, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDr, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SDr_Int, X86_INS_VFMSUB231SD: vfmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZm, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZm_Int, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZm_Intk, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZm_Intkz, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZr, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZr_Int, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZr_Intk, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZr_Intkz, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZrb, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZrb_Int, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZrb_Intk, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSZrb_Intkz, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSm, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSm_Int, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSr, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUB231SSr_Int, X86_INS_VFMSUB231SS: vfmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDYm, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDYr, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128m, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128mb, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128mbk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128mbkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128mk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128mkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128r, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128rk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ128rkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256m, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256mb, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256mbk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256mbkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256mk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256mkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256r, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256rk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZ256rkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZm, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZmb, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZmbk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZmbkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZmk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZmkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZr, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZrb, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZrbk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZrbkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZrk, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDZrkz, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDm, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PDr, X86_INS_VFMSUBADD132PD: vfmsubadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSYm, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSYr, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128m, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128mb, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128mbk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128mbkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128mk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128mkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128r, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128rk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ128rkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256m, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256mb, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256mbk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256mbkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256mk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256mkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256r, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256rk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZ256rkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZm, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZmb, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZmbk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZmbkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZmk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZmkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZr, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZrb, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZrbk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZrbkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZrk, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSZrkz, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSm, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD132PSr, X86_INS_VFMSUBADD132PS: vfmsubadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDYm, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDYr, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128m, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128mb, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128mbk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128mbkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128mk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128mkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128r, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128rk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ128rkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256m, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256mb, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256mbk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256mbkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256mk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256mkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256r, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256rk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZ256rkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZm, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZmb, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZmbk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZmbkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZmk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZmkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZr, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZrb, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZrbk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZrbkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZrk, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDZrkz, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDm, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PDr, X86_INS_VFMSUBADD213PD: vfmsubadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSYm, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSYr, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128m, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128mb, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128mbk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128mbkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128mk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128mkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128r, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128rk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ128rkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256m, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256mb, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256mbk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256mbkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256mk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256mkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256r, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256rk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZ256rkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZm, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZmb, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZmbk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZmbkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZmk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZmkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZr, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZrb, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZrbk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZrbkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZrk, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSZrkz, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSm, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD213PSr, X86_INS_VFMSUBADD213PS: vfmsubadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDYm, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDYr, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128m, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128mb, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128mbk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128mbkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128mk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128mkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128r, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128rk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ128rkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256m, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256mb, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256mbk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256mbkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256mk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256mkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256r, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256rk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZ256rkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZm, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZmb, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZmbk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZmbkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZmk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZmkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZr, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZrb, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZrbk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZrbkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZrk, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDZrkz, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDm, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PDr, X86_INS_VFMSUBADD231PD: vfmsubadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSYm, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSYr, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128m, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128mb, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128mbk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128mbkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128mk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128mkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128r, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128rk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ128rkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256m, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256mb, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256mbk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256mbkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256mk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256mkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256r, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256rk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZ256rkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZm, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZmb, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZmbk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZmbkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZmk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZmkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZr, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZrb, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZrbk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZrbkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZrk, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSZrkz, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSm, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADD231PSr, X86_INS_VFMSUBADD231PS: vfmsubadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPD4Ymr, X86_INS_VFMSUBADDPD: vfmsubaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPD4Yrm, X86_INS_VFMSUBADDPD: vfmsubaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPD4Yrr, X86_INS_VFMSUBADDPD: vfmsubaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPD4Yrr_REV, X86_INS_VFMSUBADDPD: vfmsubaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPD4mr, X86_INS_VFMSUBADDPD: vfmsubaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPD4rm, X86_INS_VFMSUBADDPD: vfmsubaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPD4rr, X86_INS_VFMSUBADDPD: vfmsubaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPD4rr_REV, X86_INS_VFMSUBADDPD: vfmsubaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPS4Ymr, X86_INS_VFMSUBADDPS: vfmsubaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPS4Yrm, X86_INS_VFMSUBADDPS: vfmsubaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPS4Yrr, X86_INS_VFMSUBADDPS: vfmsubaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPS4Yrr_REV, X86_INS_VFMSUBADDPS: vfmsubaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPS4mr, X86_INS_VFMSUBADDPS: vfmsubaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPS4rm, X86_INS_VFMSUBADDPS: vfmsubaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPS4rr, X86_INS_VFMSUBADDPS: vfmsubaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBADDPS4rr_REV, X86_INS_VFMSUBADDPS: vfmsubaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPD4Ymr, X86_INS_VFMSUBPD: vfmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPD4Yrm, X86_INS_VFMSUBPD: vfmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPD4Yrr, X86_INS_VFMSUBPD: vfmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPD4Yrr_REV, X86_INS_VFMSUBPD: vfmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPD4mr, X86_INS_VFMSUBPD: vfmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPD4rm, X86_INS_VFMSUBPD: vfmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPD4rr, X86_INS_VFMSUBPD: vfmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPD4rr_REV, X86_INS_VFMSUBPD: vfmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPS4Ymr, X86_INS_VFMSUBPS: vfmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPS4Yrm, X86_INS_VFMSUBPS: vfmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPS4Yrr, X86_INS_VFMSUBPS: vfmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPS4Yrr_REV, X86_INS_VFMSUBPS: vfmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPS4mr, X86_INS_VFMSUBPS: vfmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPS4rm, X86_INS_VFMSUBPS: vfmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPS4rr, X86_INS_VFMSUBPS: vfmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBPS4rr_REV, X86_INS_VFMSUBPS: vfmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSD4mr, X86_INS_VFMSUBSD: vfmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSD4mr_Int, X86_INS_VFMSUBSD: vfmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSD4rm, X86_INS_VFMSUBSD: vfmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSD4rm_Int, X86_INS_VFMSUBSD: vfmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFMSUBSD4rr, X86_INS_VFMSUBSD: vfmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSD4rr_Int, X86_INS_VFMSUBSD: vfmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSD4rr_Int_REV, X86_INS_VFMSUBSD: vfmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSD4rr_REV, X86_INS_VFMSUBSD: vfmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSS4mr, X86_INS_VFMSUBSS: vfmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSS4mr_Int, X86_INS_VFMSUBSS: vfmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSS4rm, X86_INS_VFMSUBSS: vfmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSS4rm_Int, X86_INS_VFMSUBSS: vfmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFMSUBSS4rr, X86_INS_VFMSUBSS: vfmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSS4rr_Int, X86_INS_VFMSUBSS: vfmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSS4rr_Int_REV, X86_INS_VFMSUBSS: vfmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFMSUBSS4rr_REV, X86_INS_VFMSUBSS: vfmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDYm, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDYr, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128m, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128mb, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128mbk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128mbkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128mk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128mkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128r, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128rk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ128rkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256m, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256mb, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256mbk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256mbkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256mk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256mkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256r, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256rk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZ256rkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZm, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZmb, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZmbk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZmbkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZmk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZmkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZr, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZrb, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZrbk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZrbkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZrk, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDZrkz, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDm, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PDr, X86_INS_VFNMADD132PD: vfnmadd132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSYm, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSYr, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128m, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128mb, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128mbk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128mbkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128mk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128mkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128r, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128rk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ128rkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256m, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256mb, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256mbk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256mbkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256mk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256mkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256r, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256rk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZ256rkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZm, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZmb, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZmbk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZmbkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZmk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZmkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZr, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZrb, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZrbk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZrbkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZrk, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSZrkz, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSm, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132PSr, X86_INS_VFNMADD132PS: vfnmadd132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZm, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZm_Int, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZm_Intk, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZm_Intkz, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZr, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZr_Int, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZr_Intk, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZr_Intkz, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZrb, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZrb_Int, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZrb_Intk, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDZrb_Intkz, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDm, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDm_Int, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDr, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SDr_Int, X86_INS_VFNMADD132SD: vfnmadd132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZm, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZm_Int, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZm_Intk, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZm_Intkz, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZr, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZr_Int, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZr_Intk, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZr_Intkz, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZrb, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZrb_Int, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZrb_Intk, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSZrb_Intkz, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSm, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSm_Int, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSr, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD132SSr_Int, X86_INS_VFNMADD132SS: vfnmadd132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDYm, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDYr, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128m, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128mb, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128mbk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128mbkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128mk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128mkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128r, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128rk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ128rkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256m, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256mb, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256mbk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256mbkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256mk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256mkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256r, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256rk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZ256rkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZm, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZmb, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZmbk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZmbkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZmk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZmkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZr, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZrb, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZrbk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZrbkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZrk, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDZrkz, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDm, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PDr, X86_INS_VFNMADD213PD: vfnmadd213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSYm, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSYr, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128m, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128mb, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128mbk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128mbkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128mk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128mkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128r, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128rk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ128rkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256m, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256mb, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256mbk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256mbkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256mk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256mkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256r, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256rk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZ256rkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZm, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZmb, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZmbk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZmbkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZmk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZmkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZr, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZrb, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZrbk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZrbkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZrk, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSZrkz, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSm, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213PSr, X86_INS_VFNMADD213PS: vfnmadd213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZm, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZm_Int, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZm_Intk, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZm_Intkz, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZr, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZr_Int, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZr_Intk, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZr_Intkz, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZrb, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZrb_Int, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZrb_Intk, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDZrb_Intkz, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDm, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDm_Int, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDr, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SDr_Int, X86_INS_VFNMADD213SD: vfnmadd213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZm, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZm_Int, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZm_Intk, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZm_Intkz, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZr, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZr_Int, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZr_Intk, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZr_Intkz, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZrb, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZrb_Int, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZrb_Intk, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSZrb_Intkz, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSm, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSm_Int, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSr, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD213SSr_Int, X86_INS_VFNMADD213SS: vfnmadd213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDYm, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDYr, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128m, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128mb, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128mbk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128mbkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128mk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128mkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128r, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128rk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ128rkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256m, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256mb, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256mbk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256mbkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256mk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256mkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256r, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256rk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZ256rkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZm, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZmb, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZmbk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZmbkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZmk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZmkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZr, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZrb, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZrbk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZrbkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZrk, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDZrkz, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDm, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PDr, X86_INS_VFNMADD231PD: vfnmadd231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSYm, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSYr, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128m, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128mb, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128mbk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128mbkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128mk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128mkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128r, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128rk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ128rkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256m, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256mb, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256mbk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256mbkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256mk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256mkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256r, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256rk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZ256rkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZm, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZmb, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZmbk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZmbkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZmk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZmkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZr, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZrb, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZrbk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZrbkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZrk, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSZrkz, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSm, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231PSr, X86_INS_VFNMADD231PS: vfnmadd231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZm, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZm_Int, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZm_Intk, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZm_Intkz, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZr, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZr_Int, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZr_Intk, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZr_Intkz, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZrb, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZrb_Int, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZrb_Intk, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDZrb_Intkz, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDm, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDm_Int, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDr, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SDr_Int, X86_INS_VFNMADD231SD: vfnmadd231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZm, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZm_Int, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZm_Intk, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZm_Intkz, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZr, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZr_Int, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZr_Intk, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZr_Intkz, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZrb, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZrb_Int, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZrb_Intk, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSZrb_Intkz, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSm, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSm_Int, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSr, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADD231SSr_Int, X86_INS_VFNMADD231SS: vfnmadd231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPD4Ymr, X86_INS_VFNMADDPD: vfnmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPD4Yrm, X86_INS_VFNMADDPD: vfnmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPD4Yrr, X86_INS_VFNMADDPD: vfnmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPD4Yrr_REV, X86_INS_VFNMADDPD: vfnmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPD4mr, X86_INS_VFNMADDPD: vfnmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPD4rm, X86_INS_VFNMADDPD: vfnmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPD4rr, X86_INS_VFNMADDPD: vfnmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPD4rr_REV, X86_INS_VFNMADDPD: vfnmaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPS4Ymr, X86_INS_VFNMADDPS: vfnmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPS4Yrm, X86_INS_VFNMADDPS: vfnmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPS4Yrr, X86_INS_VFNMADDPS: vfnmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPS4Yrr_REV, X86_INS_VFNMADDPS: vfnmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPS4mr, X86_INS_VFNMADDPS: vfnmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPS4rm, X86_INS_VFNMADDPS: vfnmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPS4rr, X86_INS_VFNMADDPS: vfnmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDPS4rr_REV, X86_INS_VFNMADDPS: vfnmaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSD4mr, X86_INS_VFNMADDSD: vfnmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSD4mr_Int, X86_INS_VFNMADDSD: vfnmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSD4rm, X86_INS_VFNMADDSD: vfnmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSD4rm_Int, X86_INS_VFNMADDSD: vfnmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFNMADDSD4rr, X86_INS_VFNMADDSD: vfnmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSD4rr_Int, X86_INS_VFNMADDSD: vfnmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSD4rr_Int_REV, X86_INS_VFNMADDSD: vfnmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSD4rr_REV, X86_INS_VFNMADDSD: vfnmaddsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSS4mr, X86_INS_VFNMADDSS: vfnmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSS4mr_Int, X86_INS_VFNMADDSS: vfnmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSS4rm, X86_INS_VFNMADDSS: vfnmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSS4rm_Int, X86_INS_VFNMADDSS: vfnmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFNMADDSS4rr, X86_INS_VFNMADDSS: vfnmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSS4rr_Int, X86_INS_VFNMADDSS: vfnmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSS4rr_Int_REV, X86_INS_VFNMADDSS: vfnmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMADDSS4rr_REV, X86_INS_VFNMADDSS: vfnmaddss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDYm, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDYr, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128m, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128mb, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128mbk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128mbkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128mk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128mkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128r, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128rk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ128rkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256m, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256mb, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256mbk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256mbkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256mk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256mkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256r, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256rk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZ256rkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZm, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZmb, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZmbk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZmbkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZmk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZmkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZr, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZrb, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZrbk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZrbkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZrk, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDZrkz, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDm, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PDr, X86_INS_VFNMSUB132PD: vfnmsub132pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSYm, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSYr, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128m, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128mb, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128mbk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128mbkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128mk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128mkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128r, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128rk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ128rkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256m, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256mb, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256mbk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256mbkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256mk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256mkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256r, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256rk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZ256rkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZm, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZmb, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZmbk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZmbkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZmk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZmkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZr, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZrb, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZrbk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZrbkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZrk, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSZrkz, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSm, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132PSr, X86_INS_VFNMSUB132PS: vfnmsub132ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZm, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZm_Int, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZm_Intk, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZm_Intkz, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZr, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZr_Int, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZr_Intk, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZr_Intkz, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZrb, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZrb_Int, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZrb_Intk, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDZrb_Intkz, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDm, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDm_Int, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDr, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SDr_Int, X86_INS_VFNMSUB132SD: vfnmsub132sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZm, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZm_Int, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZm_Intk, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZm_Intkz, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZr, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZr_Int, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZr_Intk, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZr_Intkz, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZrb, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZrb_Int, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZrb_Intk, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSZrb_Intkz, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSm, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSm_Int, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSr, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB132SSr_Int, X86_INS_VFNMSUB132SS: vfnmsub132ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDYm, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDYr, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128m, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128mb, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128mbk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128mbkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128mk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128mkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128r, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128rk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ128rkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256m, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256mb, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256mbk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256mbkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256mk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256mkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256r, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256rk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZ256rkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZm, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZmb, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZmbk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZmbkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZmk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZmkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZr, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZrb, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZrbk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZrbkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZrk, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDZrkz, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDm, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PDr, X86_INS_VFNMSUB213PD: vfnmsub213pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSYm, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSYr, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128m, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128mb, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128mbk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128mbkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128mk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128mkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128r, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128rk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ128rkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256m, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256mb, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256mbk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256mbkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256mk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256mkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256r, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256rk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZ256rkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZm, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZmb, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZmbk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZmbkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZmk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZmkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZr, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZrb, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZrbk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZrbkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZrk, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSZrkz, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSm, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213PSr, X86_INS_VFNMSUB213PS: vfnmsub213ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZm, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZm_Int, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZm_Intk, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZm_Intkz, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZr, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZr_Int, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZr_Intk, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZr_Intkz, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZrb, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZrb_Int, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZrb_Intk, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDZrb_Intkz, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDm, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDm_Int, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDr, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SDr_Int, X86_INS_VFNMSUB213SD: vfnmsub213sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZm, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZm_Int, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZm_Intk, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZm_Intkz, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZr, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZr_Int, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZr_Intk, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZr_Intkz, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZrb, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZrb_Int, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZrb_Intk, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSZrb_Intkz, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSm, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSm_Int, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSr, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB213SSr_Int, X86_INS_VFNMSUB213SS: vfnmsub213ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDYm, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDYr, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128m, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128mb, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128mbk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128mbkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128mk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128mkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128r, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128rk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ128rkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256m, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256mb, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256mbk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256mbkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256mk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256mkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256r, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256rk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZ256rkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZm, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZmb, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZmbk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZmbkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZmk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZmkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZr, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZrb, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZrbk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZrbkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZrk, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDZrkz, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDm, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PDr, X86_INS_VFNMSUB231PD: vfnmsub231pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSYm, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSYr, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128m, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128mb, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128mbk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128mbkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128mk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128mkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128r, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128rk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ128rkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256m, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256mb, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256mbk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256mbkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256mk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256mkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256r, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256rk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZ256rkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZm, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZmb, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZmbk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZmbkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZmk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZmkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZr, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZrb, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZrbk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZrbkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZrk, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSZrkz, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSm, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231PSr, X86_INS_VFNMSUB231PS: vfnmsub231ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZm, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZm_Int, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZm_Intk, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZm_Intkz, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZr, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZr_Int, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZr_Intk, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZr_Intkz, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZrb, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZrb_Int, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZrb_Intk, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDZrb_Intkz, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDm, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDm_Int, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDr, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SDr_Int, X86_INS_VFNMSUB231SD: vfnmsub231sd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZm, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZm_Int, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZm_Intk, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZm_Intkz, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZr, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZr_Int, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZr_Intk, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZr_Intkz, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZrb, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZrb_Int, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZrb_Intk, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSZrb_Intkz, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSm, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSm_Int, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSr, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUB231SSr_Int, X86_INS_VFNMSUB231SS: vfnmsub231ss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPD4Ymr, X86_INS_VFNMSUBPD: vfnmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPD4Yrm, X86_INS_VFNMSUBPD: vfnmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPD4Yrr, X86_INS_VFNMSUBPD: vfnmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPD4Yrr_REV, X86_INS_VFNMSUBPD: vfnmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPD4mr, X86_INS_VFNMSUBPD: vfnmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPD4rm, X86_INS_VFNMSUBPD: vfnmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPD4rr, X86_INS_VFNMSUBPD: vfnmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPD4rr_REV, X86_INS_VFNMSUBPD: vfnmsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPS4Ymr, X86_INS_VFNMSUBPS: vfnmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPS4Yrm, X86_INS_VFNMSUBPS: vfnmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPS4Yrr, X86_INS_VFNMSUBPS: vfnmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPS4Yrr_REV, X86_INS_VFNMSUBPS: vfnmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPS4mr, X86_INS_VFNMSUBPS: vfnmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPS4rm, X86_INS_VFNMSUBPS: vfnmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPS4rr, X86_INS_VFNMSUBPS: vfnmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBPS4rr_REV, X86_INS_VFNMSUBPS: vfnmsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSD4mr, X86_INS_VFNMSUBSD: vfnmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSD4mr_Int, X86_INS_VFNMSUBSD: vfnmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSD4rm, X86_INS_VFNMSUBSD: vfnmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSD4rm_Int, X86_INS_VFNMSUBSD: vfnmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFNMSUBSD4rr, X86_INS_VFNMSUBSD: vfnmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSD4rr_Int, X86_INS_VFNMSUBSD: vfnmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSD4rr_Int_REV, X86_INS_VFNMSUBSD: vfnmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSD4rr_REV, X86_INS_VFNMSUBSD: vfnmsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSS4mr, X86_INS_VFNMSUBSS: vfnmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSS4mr_Int, X86_INS_VFNMSUBSS: vfnmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSS4rm, X86_INS_VFNMSUBSS: vfnmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSS4rm_Int, X86_INS_VFNMSUBSS: vfnmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VFNMSUBSS4rr, X86_INS_VFNMSUBSS: vfnmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSS4rr_Int, X86_INS_VFNMSUBSS: vfnmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSS4rr_Int_REV, X86_INS_VFNMSUBSS: vfnmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFNMSUBSS4rr_REV, X86_INS_VFNMSUBSS: vfnmsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ128rm, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ128rmb, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ128rmbk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ128rmk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ128rr, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ128rrk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ256rm, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ256rmb, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ256rmbk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ256rmk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ256rr, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZ256rrk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZrm, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZrmb, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZrmbk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZrmk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZrr, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPDZrrk, X86_INS_VFPCLASSPD: vfpclasspd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ128rm, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ128rmb, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ128rmbk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ128rmk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ128rr, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ128rrk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ256rm, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ256rmb, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ256rmbk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ256rmk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ256rr, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZ256rrk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZrm, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZrmb, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZrmbk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZrmk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZrr, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSPSZrrk, X86_INS_VFPCLASSPS: vfpclassps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSSDZrm, X86_INS_VFPCLASSSD: vfpclasssd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSSDZrmk, X86_INS_VFPCLASSSD: vfpclasssd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSSDZrr, X86_INS_VFPCLASSSD: vfpclasssd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSSDZrrk, X86_INS_VFPCLASSSD: vfpclasssd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSSSZrm, X86_INS_VFPCLASSSS: vfpclassss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSSSZrmk, X86_INS_VFPCLASSSS: vfpclassss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSSSZrr, X86_INS_VFPCLASSSS: vfpclassss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFPCLASSSSZrrk, X86_INS_VFPCLASSSS: vfpclassss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VFRCZPDYrm, X86_INS_VFRCZPD: vfrczpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZPDYrr, X86_INS_VFRCZPD: vfrczpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZPDrm, X86_INS_VFRCZPD: vfrczpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZPDrr, X86_INS_VFRCZPD: vfrczpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZPSYrm, X86_INS_VFRCZPS: vfrczps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZPSYrr, X86_INS_VFRCZPS: vfrczps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZPSrm, X86_INS_VFRCZPS: vfrczps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZPSrr, X86_INS_VFRCZPS: vfrczps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZSDrm, X86_INS_VFRCZSD: vfrczsd */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_VFRCZSDrr, X86_INS_VFRCZSD: vfrczsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VFRCZSSrm, X86_INS_VFRCZSS: vfrczss */
	0,
	{ CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_VFRCZSSrr, X86_INS_VFRCZSS: vfrczss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VGATHERDPDYrm, X86_INS_VGATHERDPD: vgatherdpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGATHERDPDZ128rm, X86_INS_VGATHERDPD: vgatherdpd */
	0,
	{ 0 }
},

{	/* X86_VGATHERDPDZ256rm, X86_INS_VGATHERDPD: vgatherdpd */
	0,
	{ 0 }
},

{	/* X86_VGATHERDPDZrm, X86_INS_VGATHERDPD: vgatherdpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VGATHERDPDrm, X86_INS_VGATHERDPD: vgatherdpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGATHERDPSYrm, X86_INS_VGATHERDPS: vgatherdps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGATHERDPSZ128rm, X86_INS_VGATHERDPS: vgatherdps */
	0,
	{ 0 }
},

{	/* X86_VGATHERDPSZ256rm, X86_INS_VGATHERDPS: vgatherdps */
	0,
	{ 0 }
},

{	/* X86_VGATHERDPSZrm, X86_INS_VGATHERDPS: vgatherdps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VGATHERDPSrm, X86_INS_VGATHERDPS: vgatherdps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGATHERPF0DPDm, X86_INS_VGATHERPF0DPD: vgatherpf0dpd */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VGATHERPF0DPSm, X86_INS_VGATHERPF0DPS: vgatherpf0dps */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VGATHERPF0QPDm, X86_INS_VGATHERPF0QPD: vgatherpf0qpd */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VGATHERPF0QPSm, X86_INS_VGATHERPF0QPS: vgatherpf0qps */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VGATHERPF1DPDm, X86_INS_VGATHERPF1DPD: vgatherpf1dpd */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VGATHERPF1DPSm, X86_INS_VGATHERPF1DPS: vgatherpf1dps */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VGATHERPF1QPDm, X86_INS_VGATHERPF1QPD: vgatherpf1qpd */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VGATHERPF1QPSm, X86_INS_VGATHERPF1QPS: vgatherpf1qps */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VGATHERQPDYrm, X86_INS_VGATHERQPD: vgatherqpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGATHERQPDZ128rm, X86_INS_VGATHERQPD: vgatherqpd */
	0,
	{ 0 }
},

{	/* X86_VGATHERQPDZ256rm, X86_INS_VGATHERQPD: vgatherqpd */
	0,
	{ 0 }
},

{	/* X86_VGATHERQPDZrm, X86_INS_VGATHERQPD: vgatherqpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VGATHERQPDrm, X86_INS_VGATHERQPD: vgatherqpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGATHERQPSYrm, X86_INS_VGATHERQPS: vgatherqps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGATHERQPSZ128rm, X86_INS_VGATHERQPS: vgatherqps */
	0,
	{ 0 }
},

{	/* X86_VGATHERQPSZ256rm, X86_INS_VGATHERQPS: vgatherqps */
	0,
	{ 0 }
},

{	/* X86_VGATHERQPSZrm, X86_INS_VGATHERQPS: vgatherqps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VGATHERQPSrm, X86_INS_VGATHERQPS: vgatherqps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPPDZ128m, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ128mb, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ128mbk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ128mbkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ128mk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ128mkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ128r, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ128rk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ128rkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256m, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256mb, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256mbk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256mbkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256mk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256mkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256r, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256rk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZ256rkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZm, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZmb, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZmbk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZmbkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZmk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZmkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZr, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZrb, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZrbk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZrbkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZrk, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPDZrkz, X86_INS_VGETEXPPD: vgetexppd */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128m, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128mb, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128mbk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128mbkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128mk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128mkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128r, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128rk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ128rkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256m, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256mb, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256mbk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256mbkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256mk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256mkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256r, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256rk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZ256rkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZm, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZmb, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZmbk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZmbkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZmk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZmkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZr, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZrb, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZrbk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZrbkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZrk, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPPSZrkz, X86_INS_VGETEXPPS: vgetexpps */
	0,
	{ 0 }
},

{	/* X86_VGETEXPSDZm, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSDZmk, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSDZmkz, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSDZr, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSDZrb, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSDZrbk, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSDZrbkz, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSDZrk, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSDZrkz, X86_INS_VGETEXPSD: vgetexpsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZm, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZmk, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZmkz, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZr, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZrb, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZrbk, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZrbkz, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZrk, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETEXPSSZrkz, X86_INS_VGETEXPSS: vgetexpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGETMANTPDZ128rmbi, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ128rmbik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ128rmbikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ128rmi, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ128rmik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ128rmikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ128rri, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ128rrik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ128rrikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rmbi, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rmbik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rmbikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rmi, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rmik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rmikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rri, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rrik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZ256rrikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrmbi, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrmbik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrmbikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrmi, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrmik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrmikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrri, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrrib, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrribk, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrribkz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrrik, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPDZrrikz, X86_INS_VGETMANTPD: vgetmantpd */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rmbi, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rmbik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rmbikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rmi, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rmik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rmikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rri, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rrik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ128rrikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rmbi, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rmbik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rmbikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rmi, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rmik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rmikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rri, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rrik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZ256rrikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrmbi, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrmbik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrmbikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrmi, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrmik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrmikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrri, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrrib, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrribk, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrribkz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrrik, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTPSZrrikz, X86_INS_VGETMANTPS: vgetmantps */
	0,
	{ 0 }
},

{	/* X86_VGETMANTSDZrmi, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSDZrmik, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSDZrmikz, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSDZrri, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSDZrrib, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSDZrribk, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSDZrribkz, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSDZrrik, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSDZrrikz, X86_INS_VGETMANTSD: vgetmantsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrmi, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrmik, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrmikz, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrri, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrrib, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrribk, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrribkz, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrrik, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGETMANTSSZrrikz, X86_INS_VGETMANTSS: vgetmantss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBYrmi, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBYrri, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rmbi, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rmbik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rmbikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rmi, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rmik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rmikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rri, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rrik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ128rrikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rmbi, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rmbik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rmbikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rmi, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rmik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rmikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rri, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rrik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZ256rrikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrmbi, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrmbik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrmbikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrmi, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrmik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrmikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrri, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrrik, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBZrrikz, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBrmi, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEINVQBrri, X86_INS_VGF2P8AFFINEINVQB: vgf2p8affineinvqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBYrmi, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBYrri, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rmbi, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rmbik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rmbikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rmi, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rmik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rmikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rri, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rrik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ128rrikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rmbi, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rmbik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rmbikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rmi, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rmik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rmikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rri, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rrik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZ256rrikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrmbi, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrmbik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrmbikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrmi, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrmik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrmikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrri, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrrik, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBZrrikz, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBrmi, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8AFFINEQBrri, X86_INS_VGF2P8AFFINEQB: vgf2p8affineqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VGF2P8MULBYrm, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBYrr, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ128rm, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ128rmk, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ128rmkz, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ128rr, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ128rrk, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ128rrkz, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ256rm, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ256rmk, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ256rmkz, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ256rr, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ256rrk, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZ256rrkz, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZrm, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZrmk, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZrmkz, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZrr, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZrrk, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBZrrkz, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBrm, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VGF2P8MULBrr, X86_INS_VGF2P8MULB: vgf2p8mulb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHADDPDYrm, X86_INS_VHADDPD: vhaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHADDPDYrr, X86_INS_VHADDPD: vhaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHADDPDrm, X86_INS_VHADDPD: vhaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHADDPDrr, X86_INS_VHADDPD: vhaddpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHADDPSYrm, X86_INS_VHADDPS: vhaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHADDPSYrr, X86_INS_VHADDPS: vhaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHADDPSrm, X86_INS_VHADDPS: vhaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHADDPSrr, X86_INS_VHADDPS: vhaddps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHSUBPDYrm, X86_INS_VHSUBPD: vhsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHSUBPDYrr, X86_INS_VHSUBPD: vhsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHSUBPDrm, X86_INS_VHSUBPD: vhsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHSUBPDrr, X86_INS_VHSUBPD: vhsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHSUBPSYrm, X86_INS_VHSUBPS: vhsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHSUBPSYrr, X86_INS_VHSUBPS: vhsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHSUBPSrm, X86_INS_VHSUBPS: vhsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VHSUBPSrr, X86_INS_VHSUBPS: vhsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF128rm, X86_INS_VINSERTF128: vinsertf128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VINSERTF128rr, X86_INS_VINSERTF128: vinsertf128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VINSERTF32x4Z256rm, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Z256rmk, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Z256rmkz, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Z256rr, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Z256rrk, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Z256rrkz, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Zrm, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Zrmk, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Zrmkz, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Zrr, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Zrrk, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x4Zrrkz, X86_INS_VINSERTF32X4: vinsertf32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x8Zrm, X86_INS_VINSERTF32X8: vinsertf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x8Zrmk, X86_INS_VINSERTF32X8: vinsertf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x8Zrmkz, X86_INS_VINSERTF32X8: vinsertf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x8Zrr, X86_INS_VINSERTF32X8: vinsertf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x8Zrrk, X86_INS_VINSERTF32X8: vinsertf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF32x8Zrrkz, X86_INS_VINSERTF32X8: vinsertf32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Z256rm, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Z256rmk, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Z256rmkz, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Z256rr, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Z256rrk, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Z256rrkz, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Zrm, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Zrmk, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Zrmkz, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Zrr, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Zrrk, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x2Zrrkz, X86_INS_VINSERTF64X2: vinsertf64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x4Zrm, X86_INS_VINSERTF64X4: vinsertf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x4Zrmk, X86_INS_VINSERTF64X4: vinsertf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x4Zrmkz, X86_INS_VINSERTF64X4: vinsertf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x4Zrr, X86_INS_VINSERTF64X4: vinsertf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x4Zrrk, X86_INS_VINSERTF64X4: vinsertf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTF64x4Zrrkz, X86_INS_VINSERTF64X4: vinsertf64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI128rm, X86_INS_VINSERTI128: vinserti128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VINSERTI128rr, X86_INS_VINSERTI128: vinserti128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VINSERTI32x4Z256rm, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Z256rmk, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Z256rmkz, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Z256rr, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Z256rrk, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Z256rrkz, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Zrm, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Zrmk, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Zrmkz, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Zrr, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Zrrk, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x4Zrrkz, X86_INS_VINSERTI32X4: vinserti32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x8Zrm, X86_INS_VINSERTI32X8: vinserti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x8Zrmk, X86_INS_VINSERTI32X8: vinserti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x8Zrmkz, X86_INS_VINSERTI32X8: vinserti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x8Zrr, X86_INS_VINSERTI32X8: vinserti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x8Zrrk, X86_INS_VINSERTI32X8: vinserti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI32x8Zrrkz, X86_INS_VINSERTI32X8: vinserti32x8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Z256rm, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Z256rmk, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Z256rmkz, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Z256rr, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Z256rrk, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Z256rrkz, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Zrm, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Zrmk, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Zrmkz, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Zrr, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Zrrk, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x2Zrrkz, X86_INS_VINSERTI64X2: vinserti64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x4Zrm, X86_INS_VINSERTI64X4: vinserti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x4Zrmk, X86_INS_VINSERTI64X4: vinserti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x4Zrmkz, X86_INS_VINSERTI64X4: vinserti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x4Zrr, X86_INS_VINSERTI64X4: vinserti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x4Zrrk, X86_INS_VINSERTI64X4: vinserti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTI64x4Zrrkz, X86_INS_VINSERTI64X4: vinserti64x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTPSZrm, X86_INS_VINSERTPS: vinsertps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTPSZrr, X86_INS_VINSERTPS: vinsertps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VINSERTPSrm, X86_INS_VINSERTPS: vinsertps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VINSERTPSrr, X86_INS_VINSERTPS: vinsertps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VLDDQUYrm, X86_INS_VLDDQU: vlddqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VLDDQUrm, X86_INS_VLDDQU: vlddqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VLDMXCSR, X86_INS_VLDMXCSR: vldmxcsr */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVDQU, X86_INS_VMASKMOVDQU: vmaskmovdqu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVDQU64, X86_INS_VMASKMOVDQU: vmaskmovdqu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVPDYmr, X86_INS_VMASKMOVPD: vmaskmovpd */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVPDYrm, X86_INS_VMASKMOVPD: vmaskmovpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVPDmr, X86_INS_VMASKMOVPD: vmaskmovpd */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVPDrm, X86_INS_VMASKMOVPD: vmaskmovpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVPSYmr, X86_INS_VMASKMOVPS: vmaskmovps */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVPSYrm, X86_INS_VMASKMOVPS: vmaskmovps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVPSmr, X86_INS_VMASKMOVPS: vmaskmovps */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMASKMOVPSrm, X86_INS_VMASKMOVPS: vmaskmovps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDYrm, X86_INS_VMAXPD: vmaxpd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDYrr, X86_INS_VMAXPD: vmaxpd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rm, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rmb, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rmbk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rmbkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rmk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rmkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rr, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rrk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ128rrkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rm, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rmb, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rmbk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rmbkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rmk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rmkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rr, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rrk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZ256rrkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrm, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrmb, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrmbk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrmbkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrmk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrmkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrr, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrrk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDZrrkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDrm, X86_INS_VMAXPD: vmaxpd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPDrr, X86_INS_VMAXPD: vmaxpd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSYrm, X86_INS_VMAXPS: vmaxps	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSYrr, X86_INS_VMAXPS: vmaxps	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rm, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rmb, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rmbk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rmbkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rmk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rmkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rr, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rrk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ128rrkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rm, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rmb, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rmbk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rmbkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rmk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rmkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rr, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rrk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZ256rrkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrm, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrmb, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrmbk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrmbkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrmk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrmkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrr, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrrk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSZrrkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSrm, X86_INS_VMAXPS: vmaxps	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCPSrr, X86_INS_VMAXPS: vmaxps	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCSDZrm, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCSDZrr, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCSDrm, X86_INS_VMAXSD: vmaxsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCSDrr, X86_INS_VMAXSD: vmaxsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCSSZrm, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCSSZrr, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCSSrm, X86_INS_VMAXSS: vmaxss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXCSSrr, X86_INS_VMAXSS: vmaxss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDYrm, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDYrr, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rm, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rmb, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rmbk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rmbkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rmk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rmkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rr, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rrk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ128rrkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rm, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rmb, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rmbk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rmbkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rmk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rmkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rr, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rrk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZ256rrkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrm, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrmb, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrmbk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrmbkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrmk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrmkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrr, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrrb, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrrbk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrrbkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrrk, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDZrrkz, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDrm, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPDrr, X86_INS_VMAXPD: vmaxpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSYrm, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSYrr, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rm, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rmb, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rmbk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rmbkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rmk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rmkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rr, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rrk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ128rrkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rm, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rmb, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rmbk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rmbkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rmk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rmkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rr, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rrk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZ256rrkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrm, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrmb, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrmbk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrmbkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrmk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrmkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrr, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrrb, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrrbk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrrbkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrrk, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSZrrkz, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSrm, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXPSrr, X86_INS_VMAXPS: vmaxps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrm, X86_INS_VMAXSD: vmaxsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrm_Int, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrm_Intk, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrm_Intkz, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrr, X86_INS_VMAXSD: vmaxsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrr_Int, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrr_Intk, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrr_Intkz, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrrb_Int, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrrb_Intk, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDZrrb_Intkz, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDrm, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDrm_Int, X86_INS_VMAXSD: vmaxsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMAXSDrr, X86_INS_VMAXSD: vmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSDrr_Int, X86_INS_VMAXSD: vmaxsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrm, X86_INS_VMAXSS: vmaxss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrm_Int, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrm_Intk, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrm_Intkz, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrr, X86_INS_VMAXSS: vmaxss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrr_Int, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrr_Intk, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrr_Intkz, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrrb_Int, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrrb_Intk, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSZrrb_Intkz, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSrm, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSrm_Int, X86_INS_VMAXSS: vmaxss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMAXSSrr, X86_INS_VMAXSS: vmaxss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMAXSSrr_Int, X86_INS_VMAXSS: vmaxss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMCALL, X86_INS_VMCALL: vmcall */
	0,
	{ 0 }
},

{	/* X86_VMCLEARm, X86_INS_VMCLEAR: vmclear */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMFUNC, X86_INS_VMFUNC: vmfunc */
	0,
	{ 0 }
},

{	/* X86_VMINCPDYrm, X86_INS_VMINPD: vminpd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDYrr, X86_INS_VMINPD: vminpd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rm, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rmb, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rmbk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rmbkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rmk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rmkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rr, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rrk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ128rrkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rm, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rmb, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rmbk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rmbkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rmk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rmkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rr, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rrk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZ256rrkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrm, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrmb, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrmbk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrmbkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrmk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrmkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrr, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrrk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDZrrkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDrm, X86_INS_VMINPD: vminpd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPDrr, X86_INS_VMINPD: vminpd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSYrm, X86_INS_VMINPS: vminps	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSYrr, X86_INS_VMINPS: vminps	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rm, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rmb, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rmbk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rmbkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rmk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rmkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rr, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rrk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ128rrkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rm, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rmb, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rmbk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rmbkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rmk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rmkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rr, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rrk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZ256rrkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrm, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrmb, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrmbk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrmbkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrmk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrmkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrr, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrrk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSZrrkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSrm, X86_INS_VMINPS: vminps	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCPSrr, X86_INS_VMINPS: vminps	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCSDZrm, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCSDZrr, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCSDrm, X86_INS_VMINSD: vminsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCSDrr, X86_INS_VMINSD: vminsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCSSZrm, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCSSZrr, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCSSrm, X86_INS_VMINSS: vminss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINCSSrr, X86_INS_VMINSS: vminss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDYrm, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDYrr, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rm, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rmb, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rmbk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rmbkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rmk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rmkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rr, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rrk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ128rrkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rm, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rmb, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rmbk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rmbkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rmk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rmkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rr, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rrk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZ256rrkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrm, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrmb, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrmbk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrmbkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrmk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrmkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrr, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrrb, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrrbk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrrbkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrrk, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDZrrkz, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDrm, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPDrr, X86_INS_VMINPD: vminpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSYrm, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSYrr, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rm, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rmb, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rmbk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rmbkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rmk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rmkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rr, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rrk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ128rrkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rm, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rmb, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rmbk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rmbkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rmk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rmkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rr, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rrk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZ256rrkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrm, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrmb, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrmbk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrmbkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrmk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrmkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrr, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrrb, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrrbk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrrbkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrrk, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSZrrkz, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSrm, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINPSrr, X86_INS_VMINPS: vminps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrm, X86_INS_VMINSD: vminsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrm_Int, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrm_Intk, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrm_Intkz, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrr, X86_INS_VMINSD: vminsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrr_Int, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrr_Intk, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrr_Intkz, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrrb_Int, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrrb_Intk, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDZrrb_Intkz, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDrm, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDrm_Int, X86_INS_VMINSD: vminsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMINSDrr, X86_INS_VMINSD: vminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSDrr_Int, X86_INS_VMINSD: vminsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrm, X86_INS_VMINSS: vminss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrm_Int, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrm_Intk, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrm_Intkz, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrr, X86_INS_VMINSS: vminss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrr_Int, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrr_Intk, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrr_Intkz, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrrb_Int, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrrb_Intk, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSZrrb_Intkz, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSrm, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSrm_Int, X86_INS_VMINSS: vminss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMINSSrr, X86_INS_VMINSS: vminss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMINSSrr_Int, X86_INS_VMINSS: vminss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMLAUNCH, X86_INS_VMLAUNCH: vmlaunch */
	0,
	{ 0 }
},

{	/* X86_VMLOAD32, X86_INS_VMLOAD: vmload */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMLOAD64, X86_INS_VMLOAD: vmload */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMMCALL, X86_INS_VMMCALL: vmmcall */
	0,
	{ 0 }
},

{	/* X86_VMOV64toPQIZrm, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOV64toPQIZrr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOV64toPQIrm, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOV64toPQIrr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOV64toSDZrm, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOV64toSDZrr, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOV64toSDrm, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOV64toSDrr, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDYmr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDYrm, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDYrr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDYrr_REV, X86_INS_VMOVAPD: vmovapd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128mr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128mrk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128rm, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128rmk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128rmkz, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128rr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128rr_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDZ128rrk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128rrk_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDZ128rrkz, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ128rrkz_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDZ256mr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ256mrk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ256rm, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ256rmk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ256rmkz, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ256rr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ256rr_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDZ256rrk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ256rrk_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDZ256rrkz, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZ256rrkz_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDZmr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZmrk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZrm, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZrmk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZrmkz, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZrr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZrr_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDZrrk, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZrrk_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDZrrkz, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDZrrkz_REV, X86_INS_VMOVAPD: vmovapd */
	0,
	{ 0 }
},

{	/* X86_VMOVAPDmr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDrm, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDrr, X86_INS_VMOVAPD: vmovapd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPDrr_REV, X86_INS_VMOVAPD: vmovapd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSYmr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSYrm, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSYrr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSYrr_REV, X86_INS_VMOVAPS: vmovaps	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128mr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128mrk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128rm, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128rmk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128rmkz, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128rr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128rr_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSZ128rrk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128rrk_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSZ128rrkz, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ128rrkz_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSZ256mr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ256mrk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ256rm, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ256rmk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ256rmkz, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ256rr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ256rr_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSZ256rrk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ256rrk_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSZ256rrkz, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZ256rrkz_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSZmr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZmrk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZrm, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZrmk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZrmkz, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZrr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZrr_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSZrrk, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZrrk_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSZrrkz, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSZrrkz_REV, X86_INS_VMOVAPS: vmovaps */
	0,
	{ 0 }
},

{	/* X86_VMOVAPSmr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSrm, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSrr, X86_INS_VMOVAPS: vmovaps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVAPSrr_REV, X86_INS_VMOVAPS: vmovaps	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPYrm, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPYrr, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ128rm, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ128rmk, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ128rmkz, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ128rr, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ128rrk, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ128rrkz, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ256rm, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ256rmk, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ256rmkz, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ256rr, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ256rrk, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZ256rrkz, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZrm, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZrmk, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZrmkz, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZrr, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZrrk, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPZrrkz, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPrm, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDDUPrr, X86_INS_VMOVDDUP: vmovddup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDI2PDIZrm, X86_INS_VMOVD: vmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDI2PDIZrr, X86_INS_VMOVD: vmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDI2PDIrm, X86_INS_VMOVD: vmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDI2PDIrr, X86_INS_VMOVD: vmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDI2SSZrm, X86_INS_VMOVD: vmovd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDI2SSZrr, X86_INS_VMOVD: vmovd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDI2SSrm, X86_INS_VMOVD: vmovd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDI2SSrr, X86_INS_VMOVD: vmovd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128mr, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128mrk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128rm, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128rmk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128rmkz, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128rr, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128rr_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA32Z128rrk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128rrk_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA32Z128rrkz, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z128rrkz_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA32Z256mr, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z256mrk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z256rm, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z256rmk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z256rmkz, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z256rr, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z256rr_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA32Z256rrk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z256rrk_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA32Z256rrkz, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Z256rrkz_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA32Zmr, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Zmrk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Zrm, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Zrmk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Zrmkz, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Zrr, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Zrr_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA32Zrrk, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Zrrk_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA32Zrrkz, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA32Zrrkz_REV, X86_INS_VMOVDQA32: vmovdqa32 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Z128mr, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z128mrk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z128rm, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z128rmk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z128rmkz, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z128rr, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z128rr_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Z128rrk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z128rrk_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Z128rrkz, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z128rrkz_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Z256mr, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z256mrk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z256rm, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z256rmk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z256rmkz, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z256rr, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z256rr_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Z256rrk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z256rrk_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Z256rrkz, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Z256rrkz_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Zmr, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Zmrk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Zrm, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Zrmk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Zrmkz, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Zrr, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Zrr_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Zrrk, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Zrrk_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQA64Zrrkz, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQA64Zrrkz_REV, X86_INS_VMOVDQA64: vmovdqa64 */
	0,
	{ 0 }
},

{	/* X86_VMOVDQAYmr, X86_INS_VMOVDQA: vmovdqa */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQAYrm, X86_INS_VMOVDQA: vmovdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQAYrr, X86_INS_VMOVDQA: vmovdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQAYrr_REV, X86_INS_VMOVDQA: vmovdqa	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQAmr, X86_INS_VMOVDQA: vmovdqa */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQArm, X86_INS_VMOVDQA: vmovdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQArr, X86_INS_VMOVDQA: vmovdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQArr_REV, X86_INS_VMOVDQA: vmovdqa	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128mr, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128mrk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rm, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rmk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rmkz, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rr, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rr_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rrk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rrk_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rrkz, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z128rrkz_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256mr, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256mrk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rm, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rmk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rmkz, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rr, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rr_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rrk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rrk_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rrkz, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Z256rrkz_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zmr, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zmrk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrm, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrmk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrmkz, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrr, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrr_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrrk, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrrk_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrrkz, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU16Zrrkz_REV, X86_INS_VMOVDQU16: vmovdqu16 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128mr, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128mrk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rm, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rmk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rmkz, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rr, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rr_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rrk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rrk_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rrkz, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z128rrkz_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256mr, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256mrk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rm, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rmk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rmkz, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rr, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rr_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rrk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rrk_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rrkz, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Z256rrkz_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zmr, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zmrk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrm, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrmk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrmkz, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrr, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrr_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrrk, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrrk_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrrkz, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU32Zrrkz_REV, X86_INS_VMOVDQU32: vmovdqu32 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128mr, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128mrk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rm, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rmk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rmkz, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rr, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rr_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rrk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rrk_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rrkz, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z128rrkz_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256mr, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256mrk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rm, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rmk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rmkz, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rr, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rr_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rrk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rrk_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rrkz, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Z256rrkz_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zmr, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zmrk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrm, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrmk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrmkz, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrr, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrr_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrrk, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrrk_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrrkz, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU64Zrrkz_REV, X86_INS_VMOVDQU64: vmovdqu64 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128mr, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128mrk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rm, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rmk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rmkz, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rr, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rr_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rrk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rrk_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rrkz, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z128rrkz_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256mr, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256mrk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rm, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rmk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rmkz, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rr, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rr_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rrk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rrk_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rrkz, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Z256rrkz_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zmr, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zmrk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrm, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrmk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrmkz, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrr, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrr_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrrk, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrrk_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrrkz, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQU8Zrrkz_REV, X86_INS_VMOVDQU8: vmovdqu8 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQUYmr, X86_INS_VMOVDQU: vmovdqu */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQUYrm, X86_INS_VMOVDQU: vmovdqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQUYrr, X86_INS_VMOVDQU: vmovdqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQUYrr_REV, X86_INS_VMOVDQU: vmovdqu	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQUmr, X86_INS_VMOVDQU: vmovdqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQUrm, X86_INS_VMOVDQU: vmovdqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQUrr, X86_INS_VMOVDQU: vmovdqu */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVDQUrr_REV, X86_INS_VMOVDQU: vmovdqu	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVHLPSZrr, X86_INS_VMOVHLPS: vmovhlps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVHLPSrr, X86_INS_VMOVHLPS: vmovhlps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVHPDZ128mr, X86_INS_VMOVHPD: vmovhpd */
	0,
	{ 0 }
},

{	/* X86_VMOVHPDZ128rm, X86_INS_VMOVHPD: vmovhpd */
	0,
	{ 0 }
},

{	/* X86_VMOVHPDmr, X86_INS_VMOVHPD: vmovhpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVHPDrm, X86_INS_VMOVHPD: vmovhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVHPSZ128mr, X86_INS_VMOVHPS: vmovhps */
	0,
	{ 0 }
},

{	/* X86_VMOVHPSZ128rm, X86_INS_VMOVHPS: vmovhps */
	0,
	{ 0 }
},

{	/* X86_VMOVHPSmr, X86_INS_VMOVHPS: vmovhps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVHPSrm, X86_INS_VMOVHPS: vmovhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVLHPSZrr, X86_INS_VMOVLHPS: vmovlhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVLHPSrr, X86_INS_VMOVLHPS: vmovlhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVLPDZ128mr, X86_INS_VMOVLPD: vmovlpd */
	0,
	{ 0 }
},

{	/* X86_VMOVLPDZ128rm, X86_INS_VMOVLPD: vmovlpd */
	0,
	{ 0 }
},

{	/* X86_VMOVLPDmr, X86_INS_VMOVLPD: vmovlpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVLPDrm, X86_INS_VMOVLPD: vmovlpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVLPSZ128mr, X86_INS_VMOVLPS: vmovlps */
	0,
	{ 0 }
},

{	/* X86_VMOVLPSZ128rm, X86_INS_VMOVLPS: vmovlps */
	0,
	{ 0 }
},

{	/* X86_VMOVLPSmr, X86_INS_VMOVLPS: vmovlps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVLPSrm, X86_INS_VMOVLPS: vmovlps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVMSKPDYrr, X86_INS_VMOVMSKPD: vmovmskpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVMSKPDrr, X86_INS_VMOVMSKPD: vmovmskpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVMSKPSYrr, X86_INS_VMOVMSKPS: vmovmskps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVMSKPSrr, X86_INS_VMOVMSKPS: vmovmskps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQAYrm, X86_INS_VMOVNTDQA: vmovntdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQAZ128rm, X86_INS_VMOVNTDQA: vmovntdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQAZ256rm, X86_INS_VMOVNTDQA: vmovntdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQAZrm, X86_INS_VMOVNTDQA: vmovntdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQArm, X86_INS_VMOVNTDQA: vmovntdqa */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQYmr, X86_INS_VMOVNTDQ: vmovntdq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQZ128mr, X86_INS_VMOVNTDQ: vmovntdq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQZ256mr, X86_INS_VMOVNTDQ: vmovntdq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQZmr, X86_INS_VMOVNTDQ: vmovntdq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTDQmr, X86_INS_VMOVNTDQ: vmovntdq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPDYmr, X86_INS_VMOVNTPD: vmovntpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPDZ128mr, X86_INS_VMOVNTPD: vmovntpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPDZ256mr, X86_INS_VMOVNTPD: vmovntpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPDZmr, X86_INS_VMOVNTPD: vmovntpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPDmr, X86_INS_VMOVNTPD: vmovntpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPSYmr, X86_INS_VMOVNTPS: vmovntps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPSZ128mr, X86_INS_VMOVNTPS: vmovntps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPSZ256mr, X86_INS_VMOVNTPS: vmovntps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPSZmr, X86_INS_VMOVNTPS: vmovntps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVNTPSmr, X86_INS_VMOVNTPS: vmovntps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVPDI2DIZmr, X86_INS_VMOVD: vmovd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVPDI2DIZrr, X86_INS_VMOVD: vmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVPDI2DImr, X86_INS_VMOVD: vmovd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVPDI2DIrr, X86_INS_VMOVD: vmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVPQI2QIZmr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVPQI2QIZrr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVPQI2QImr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVPQI2QIrr, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVPQIto64Zmr, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVPQIto64Zrr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVPQIto64mr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVPQIto64rr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVQI2PQIZrm, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVQI2PQIrm, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDZmr, X86_INS_VMOVSD: vmovsd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDZmrk, X86_INS_VMOVSD: vmovsd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDZrm, X86_INS_VMOVSD: vmovsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDZrmk, X86_INS_VMOVSD: vmovsd */
	0,
	{ 0 }
},

{	/* X86_VMOVSDZrmkz, X86_INS_VMOVSD: vmovsd */
	0,
	{ 0 }
},

{	/* X86_VMOVSDZrr, X86_INS_VMOVSD: vmovsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDZrr_REV, X86_INS_VMOVSD: vmovsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDZrrk, X86_INS_VMOVSD: vmovsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDZrrk_REV, X86_INS_VMOVSD: vmovsd */
	0,
	{ 0 }
},

{	/* X86_VMOVSDZrrkz, X86_INS_VMOVSD: vmovsd */
	0,
	{ 0 }
},

{	/* X86_VMOVSDZrrkz_REV, X86_INS_VMOVSD: vmovsd */
	0,
	{ 0 }
},

{	/* X86_VMOVSDmr, X86_INS_VMOVSD: vmovsd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDrm, X86_INS_VMOVSD: vmovsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDrr, X86_INS_VMOVSD: vmovsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDrr_REV, X86_INS_VMOVSD: vmovsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDto64Zmr, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDto64Zrr, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDto64mr, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSDto64rr, X86_INS_VMOVQ: vmovq	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPYrm, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPYrr, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ128rm, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ128rmk, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ128rmkz, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ128rr, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ128rrk, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ128rrkz, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ256rm, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ256rmk, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ256rmkz, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ256rr, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ256rrk, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZ256rrkz, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZrm, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZrmk, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZrmkz, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZrr, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZrrk, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPZrrkz, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPrm, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSHDUPrr, X86_INS_VMOVSHDUP: vmovshdup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPYrm, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPYrr, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ128rm, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ128rmk, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ128rmkz, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ128rr, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ128rrk, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ128rrkz, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ256rm, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ256rmk, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ256rmkz, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ256rr, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ256rrk, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZ256rrkz, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZrm, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZrmk, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZrmkz, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZrr, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZrrk, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPZrrkz, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPrm, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSLDUPrr, X86_INS_VMOVSLDUP: vmovsldup */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSS2DIZmr, X86_INS_VMOVD: vmovd	$dst $src */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSS2DIZrr, X86_INS_VMOVD: vmovd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSS2DImr, X86_INS_VMOVD: vmovd	$dst $src */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSS2DIrr, X86_INS_VMOVD: vmovd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSZmr, X86_INS_VMOVSS: vmovss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSZmrk, X86_INS_VMOVSS: vmovss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSZrm, X86_INS_VMOVSS: vmovss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSZrmk, X86_INS_VMOVSS: vmovss */
	0,
	{ 0 }
},

{	/* X86_VMOVSSZrmkz, X86_INS_VMOVSS: vmovss */
	0,
	{ 0 }
},

{	/* X86_VMOVSSZrr, X86_INS_VMOVSS: vmovss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSZrr_REV, X86_INS_VMOVSS: vmovss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSZrrk, X86_INS_VMOVSS: vmovss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSZrrk_REV, X86_INS_VMOVSS: vmovss */
	0,
	{ 0 }
},

{	/* X86_VMOVSSZrrkz, X86_INS_VMOVSS: vmovss */
	0,
	{ 0 }
},

{	/* X86_VMOVSSZrrkz_REV, X86_INS_VMOVSS: vmovss */
	0,
	{ 0 }
},

{	/* X86_VMOVSSmr, X86_INS_VMOVSS: vmovss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSrm, X86_INS_VMOVSS: vmovss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSrr, X86_INS_VMOVSS: vmovss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVSSrr_REV, X86_INS_VMOVSS: vmovss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDYmr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDYrm, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDYrr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDYrr_REV, X86_INS_VMOVUPD: vmovupd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128mr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128mrk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rm, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rmk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rmkz, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rr_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rrk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rrk_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rrkz, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ128rrkz_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256mr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256mrk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rm, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rmk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rmkz, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rr_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rrk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rrk_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rrkz, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZ256rrkz_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZmr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZmrk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrm, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrmk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrmkz, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrr_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrrk, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrrk_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrrkz, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDZrrkz_REV, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDmr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDrm, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDrr, X86_INS_VMOVUPD: vmovupd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPDrr_REV, X86_INS_VMOVUPD: vmovupd	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSYmr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSYrm, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSYrr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSYrr_REV, X86_INS_VMOVUPS: vmovups	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128mr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128mrk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rm, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rmk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rmkz, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rr_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rrk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rrk_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rrkz, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ128rrkz_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256mr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256mrk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rm, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rmk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rmkz, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rr_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rrk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rrk_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rrkz, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZ256rrkz_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZmr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZmrk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrm, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrmk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrmkz, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrr_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrrk, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrrk_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrrkz, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSZrrkz_REV, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSmr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSrm, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSrr, X86_INS_VMOVUPS: vmovups */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVUPSrr_REV, X86_INS_VMOVUPS: vmovups	$dst $src */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVZPQILo2PQIZrr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMOVZPQILo2PQIrr, X86_INS_VMOVQ: vmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMPSADBWYrmi, X86_INS_VMPSADBW: vmpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMPSADBWYrri, X86_INS_VMPSADBW: vmpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMPSADBWrmi, X86_INS_VMPSADBW: vmpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMPSADBWrri, X86_INS_VMPSADBW: vmpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMPTRLDm, X86_INS_VMPTRLD: vmptrld */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMPTRSTm, X86_INS_VMPTRST: vmptrst */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_VMREAD32mr, X86_INS_VMREAD: vmread */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMREAD32rr, X86_INS_VMREAD: vmread */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMREAD64mr, X86_INS_VMREAD: vmread */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMREAD64rr, X86_INS_VMREAD: vmread */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMRESUME, X86_INS_VMRESUME: vmresume */
	0,
	{ 0 }
},

{	/* X86_VMRUN32, X86_INS_VMRUN: vmrun */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMRUN64, X86_INS_VMRUN: vmrun */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMSAVE32, X86_INS_VMSAVE: vmsave */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMSAVE64, X86_INS_VMSAVE: vmsave */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VMULPDYrm, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDYrr, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rm, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rmb, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rmbk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rmbkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rmk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rmkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rr, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rrk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ128rrkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rm, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rmb, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rmbk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rmbkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rmk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rmkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rr, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rrk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZ256rrkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrm, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrmb, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrmbk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrmbkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrmk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrmkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrr, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrrb, X86_INS_VMULPD: vmulpd */
	0,
	{ 0 }
},

{	/* X86_VMULPDZrrbk, X86_INS_VMULPD: vmulpd */
	0,
	{ 0 }
},

{	/* X86_VMULPDZrrbkz, X86_INS_VMULPD: vmulpd */
	0,
	{ 0 }
},

{	/* X86_VMULPDZrrk, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDZrrkz, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDrm, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPDrr, X86_INS_VMULPD: vmulpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSYrm, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSYrr, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rm, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rmb, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rmbk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rmbkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rmk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rmkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rr, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rrk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ128rrkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rm, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rmb, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rmbk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rmbkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rmk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rmkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rr, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rrk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZ256rrkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrm, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrmb, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrmbk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrmbkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrmk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrmkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrr, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrrb, X86_INS_VMULPS: vmulps */
	0,
	{ 0 }
},

{	/* X86_VMULPSZrrbk, X86_INS_VMULPS: vmulps */
	0,
	{ 0 }
},

{	/* X86_VMULPSZrrbkz, X86_INS_VMULPS: vmulps */
	0,
	{ 0 }
},

{	/* X86_VMULPSZrrk, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSZrrkz, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSrm, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULPSrr, X86_INS_VMULPS: vmulps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrm, X86_INS_VMULSD: vmulsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrm_Int, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrm_Intk, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrm_Intkz, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrr, X86_INS_VMULSD: vmulsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrr_Int, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrr_Intk, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrr_Intkz, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrrb_Int, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrrb_Intk, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDZrrb_Intkz, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDrm, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDrm_Int, X86_INS_VMULSD: vmulsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMULSDrr, X86_INS_VMULSD: vmulsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSDrr_Int, X86_INS_VMULSD: vmulsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrm, X86_INS_VMULSS: vmulss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrm_Int, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrm_Intk, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrm_Intkz, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrr, X86_INS_VMULSS: vmulss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrr_Int, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrr_Intk, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrr_Intkz, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrrb_Int, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrrb_Intk, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSZrrb_Intkz, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSrm, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSrm_Int, X86_INS_VMULSS: vmulss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VMULSSrr, X86_INS_VMULSS: vmulss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMULSSrr_Int, X86_INS_VMULSS: vmulss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VMWRITE32rm, X86_INS_VMWRITE: vmwrite */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMWRITE32rr, X86_INS_VMWRITE: vmwrite */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMWRITE64rm, X86_INS_VMWRITE: vmwrite */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMWRITE64rr, X86_INS_VMWRITE: vmwrite */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VMXOFF, X86_INS_VMXOFF: vmxoff */
	0,
	{ 0 }
},

{	/* X86_VMXON, X86_INS_VMXON: vmxon */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VORPDYrm, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDYrr, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rm, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rmb, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rmbk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rmbkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rmk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rmkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rr, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rrk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ128rrkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rm, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rmb, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rmbk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rmbkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rmk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rmkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rr, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rrk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZ256rrkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrm, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrmb, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrmbk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrmbkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrmk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrmkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrr, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrrk, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDZrrkz, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDrm, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPDrr, X86_INS_VORPD: vorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSYrm, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSYrr, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rm, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rmb, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rmbk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rmbkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rmk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rmkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rr, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rrk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ128rrkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rm, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rmb, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rmbk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rmbkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rmk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rmkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rr, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rrk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZ256rrkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrm, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrmb, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrmbk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrmbkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrmk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrmkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrr, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrrk, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSZrrkz, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSrm, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VORPSrr, X86_INS_VORPS: vorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VP4DPWSSDSrm, X86_INS_VP4DPWSSDS: vp4dpwssds */
	0,
	{ 0 }
},

{	/* X86_VP4DPWSSDSrmk, X86_INS_VP4DPWSSDS: vp4dpwssds */
	0,
	{ 0 }
},

{	/* X86_VP4DPWSSDSrmkz, X86_INS_VP4DPWSSDS: vp4dpwssds */
	0,
	{ 0 }
},

{	/* X86_VP4DPWSSDrm, X86_INS_VP4DPWSSD: vp4dpwssd */
	0,
	{ 0 }
},

{	/* X86_VP4DPWSSDrmk, X86_INS_VP4DPWSSD: vp4dpwssd */
	0,
	{ 0 }
},

{	/* X86_VP4DPWSSDrmkz, X86_INS_VP4DPWSSD: vp4dpwssd */
	0,
	{ 0 }
},

{	/* X86_VPABSBYrm, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBYrr, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ128rm, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ128rmk, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ128rmkz, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ128rr, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ128rrk, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ128rrkz, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ256rm, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ256rmk, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ256rmkz, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ256rr, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ256rrk, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZ256rrkz, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZrm, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZrmk, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZrmkz, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZrr, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZrrk, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBZrrkz, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBrm, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSBrr, X86_INS_VPABSB: vpabsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDYrm, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDYrr, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rm, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rmb, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rmbk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rmbkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rmk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rmkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rr, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rrk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ128rrkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rm, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rmb, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rmbk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rmbkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rmk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rmkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rr, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rrk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZ256rrkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrm, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrmb, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrmbk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrmbkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrmk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrmkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrr, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrrk, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDZrrkz, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDrm, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSDrr, X86_INS_VPABSD: vpabsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rm, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rmb, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rmbk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rmbkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rmk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rmkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rr, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rrk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ128rrkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rm, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rmb, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rmbk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rmbkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rmk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rmkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rr, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rrk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZ256rrkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrm, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrmb, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrmbk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrmbkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrmk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrmkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrr, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrrk, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSQZrrkz, X86_INS_VPABSQ: vpabsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWYrm, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWYrr, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ128rm, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ128rmk, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ128rmkz, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ128rr, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ128rrk, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ128rrkz, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ256rm, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ256rmk, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ256rmkz, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ256rr, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ256rrk, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZ256rrkz, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZrm, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZrmk, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZrmkz, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZrr, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZrrk, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWZrrkz, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWrm, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPABSWrr, X86_INS_VPABSW: vpabsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWYrm, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWYrr, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rm, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rmb, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rmbk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rmbkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rmk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rmkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rr, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rrk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ128rrkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rm, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rmb, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rmbk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rmbkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rmk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rmkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rr, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rrk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZ256rrkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrm, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrmb, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrmbk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrmbkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrmk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrmkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrr, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrrk, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWZrrkz, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWrm, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSDWrr, X86_INS_VPACKSSDW: vpackssdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBYrm, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBYrr, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ128rm, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ128rmk, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ128rmkz, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ128rr, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ128rrk, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ128rrkz, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ256rm, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ256rmk, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ256rmkz, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ256rr, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ256rrk, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZ256rrkz, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZrm, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZrmk, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZrmkz, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZrr, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZrrk, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBZrrkz, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBrm, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKSSWBrr, X86_INS_VPACKSSWB: vpacksswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWYrm, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWYrr, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rm, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rmb, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rmbk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rmbkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rmk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rmkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rr, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rrk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ128rrkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rm, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rmb, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rmbk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rmbkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rmk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rmkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rr, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rrk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZ256rrkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrm, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrmb, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrmbk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrmbkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrmk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrmkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrr, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrrk, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWZrrkz, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWrm, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSDWrr, X86_INS_VPACKUSDW: vpackusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBYrm, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBYrr, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ128rm, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ128rmk, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ128rmkz, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ128rr, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ128rrk, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ128rrkz, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ256rm, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ256rmk, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ256rmkz, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ256rr, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ256rrk, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZ256rrkz, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZrm, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZrmk, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZrmkz, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZrr, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZrrk, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBZrrkz, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBrm, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPACKUSWBrr, X86_INS_VPACKUSWB: vpackuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBYrm, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBYrr, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ128rm, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ128rmk, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ128rmkz, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ128rr, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ128rrk, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ128rrkz, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ256rm, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ256rmk, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ256rmkz, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ256rr, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ256rrk, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZ256rrkz, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZrm, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZrmk, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZrmkz, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZrr, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZrrk, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBZrrkz, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBrm, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDBrr, X86_INS_VPADDB: vpaddb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDYrm, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDYrr, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rm, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rmb, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rmbk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rmbkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rmk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rmkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rr, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rrk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ128rrkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rm, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rmb, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rmbk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rmbkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rmk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rmkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rr, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rrk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZ256rrkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrm, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrmb, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrmbk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrmbkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrmk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrmkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrr, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrrk, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDZrrkz, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDrm, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDDrr, X86_INS_VPADDD: vpaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQYrm, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQYrr, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rm, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rmb, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rmbk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rmbkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rmk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rmkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rr, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rrk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ128rrkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rm, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rmb, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rmbk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rmbkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rmk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rmkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rr, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rrk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZ256rrkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrm, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrmb, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrmbk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrmbkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrmk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrmkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrr, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrrk, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQZrrkz, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQrm, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDQrr, X86_INS_VPADDQ: vpaddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBYrm, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBYrr, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ128rm, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ128rmk, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ128rmkz, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ128rr, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ128rrk, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ128rrkz, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ256rm, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ256rmk, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ256rmkz, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ256rr, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ256rrk, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZ256rrkz, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZrm, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZrmk, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZrmkz, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZrr, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZrrk, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBZrrkz, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBrm, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSBrr, X86_INS_VPADDSB: vpaddsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWYrm, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWYrr, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ128rm, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ128rmk, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ128rmkz, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ128rr, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ128rrk, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ128rrkz, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ256rm, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ256rmk, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ256rmkz, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ256rr, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ256rrk, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZ256rrkz, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZrm, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZrmk, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZrmkz, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZrr, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZrrk, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWZrrkz, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWrm, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDSWrr, X86_INS_VPADDSW: vpaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBYrm, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBYrr, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ128rm, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ128rmk, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ128rmkz, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ128rr, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ128rrk, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ128rrkz, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ256rm, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ256rmk, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ256rmkz, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ256rr, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ256rrk, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZ256rrkz, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZrm, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZrmk, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZrmkz, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZrr, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZrrk, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBZrrkz, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBrm, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSBrr, X86_INS_VPADDUSB: vpaddusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWYrm, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWYrr, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ128rm, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ128rmk, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ128rmkz, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ128rr, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ128rrk, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ128rrkz, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ256rm, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ256rmk, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ256rmkz, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ256rr, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ256rrk, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZ256rrkz, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZrm, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZrmk, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZrmkz, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZrr, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZrrk, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWZrrkz, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWrm, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDUSWrr, X86_INS_VPADDUSW: vpaddusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWYrm, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWYrr, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ128rm, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ128rmk, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ128rmkz, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ128rr, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ128rrk, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ128rrkz, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ256rm, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ256rmk, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ256rmkz, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ256rr, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ256rrk, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZ256rrkz, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZrm, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZrmk, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZrmkz, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZrr, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZrrk, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWZrrkz, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWrm, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPADDWrr, X86_INS_VPADDW: vpaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPALIGNRYrmi, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRYrri, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ128rmi, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ128rmik, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ128rmikz, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ128rri, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ128rrik, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ128rrikz, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ256rmi, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ256rmik, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ256rmikz, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ256rri, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ256rrik, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZ256rrikz, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZrmi, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZrmik, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZrmikz, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZrri, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZrrik, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRZrrikz, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRrmi, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPALIGNRrri, X86_INS_VPALIGNR: vpalignr */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPANDDZ128rm, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ128rmb, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ128rmbk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ128rmbkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ128rmk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ128rmkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ128rr, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ128rrk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ128rrkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rm, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rmb, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rmbk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rmbkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rmk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rmkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rr, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rrk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZ256rrkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrm, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrmb, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrmbk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrmbkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrmk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrmkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrr, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrrk, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDDZrrkz, X86_INS_VPANDD: vpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rm, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rmb, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rmbk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rmbkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rmk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rmkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rr, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rrk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ128rrkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rm, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rmb, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rmbk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rmbkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rmk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rmkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rr, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rrk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZ256rrkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrm, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrmb, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrmbk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrmbkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrmk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrmkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrr, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrrk, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNDZrrkz, X86_INS_VPANDND: vpandnd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rm, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rmb, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rmbk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rmbkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rmk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rmkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rr, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rrk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ128rrkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rm, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rmb, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rmbk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rmbkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rmk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rmkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rr, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rrk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZ256rrkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrm, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrmb, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrmbk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrmbkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrmk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrmkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrr, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrrk, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNQZrrkz, X86_INS_VPANDNQ: vpandnq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNYrm, X86_INS_VPANDN: vpandn */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNYrr, X86_INS_VPANDN: vpandn */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNrm, X86_INS_VPANDN: vpandn */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDNrr, X86_INS_VPANDN: vpandn */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rm, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rmb, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rmbk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rmbkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rmk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rmkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rr, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rrk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ128rrkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rm, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rmb, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rmbk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rmbkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rmk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rmkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rr, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rrk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZ256rrkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrm, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrmb, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrmbk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrmbkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrmk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrmkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrr, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrrk, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDQZrrkz, X86_INS_VPANDQ: vpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDYrm, X86_INS_VPAND: vpand */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDYrr, X86_INS_VPAND: vpand */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDrm, X86_INS_VPAND: vpand */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPANDrr, X86_INS_VPAND: vpand */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBYrm, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBYrr, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ128rm, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ128rmk, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ128rmkz, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ128rr, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ128rrk, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ128rrkz, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ256rm, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ256rmk, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ256rmkz, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ256rr, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ256rrk, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZ256rrkz, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZrm, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZrmk, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZrmkz, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZrr, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZrrk, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBZrrkz, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBrm, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGBrr, X86_INS_VPAVGB: vpavgb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWYrm, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWYrr, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ128rm, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ128rmk, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ128rmkz, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ128rr, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ128rrk, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ128rrkz, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ256rm, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ256rmk, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ256rmkz, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ256rr, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ256rrk, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZ256rrkz, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZrm, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZrmk, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZrmkz, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZrr, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZrrk, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWZrrkz, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWrm, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPAVGWrr, X86_INS_VPAVGW: vpavgw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDDYrmi, X86_INS_VPBLENDD: vpblendd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPBLENDDYrri, X86_INS_VPBLENDD: vpblendd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPBLENDDrmi, X86_INS_VPBLENDD: vpblendd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPBLENDDrri, X86_INS_VPBLENDD: vpblendd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPBLENDMBZ128rm, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ128rmk, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ128rmkz, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ128rr, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ128rrk, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ128rrkz, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ256rm, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ256rmk, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ256rmkz, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ256rr, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ256rrk, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZ256rrkz, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZrm, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZrmk, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZrmkz, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZrr, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZrrk, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMBZrrkz, X86_INS_VPBLENDMB: vpblendmb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ128rm, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ128rmb, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ128rmbk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ128rmbkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ 0 }
},

{	/* X86_VPBLENDMDZ128rmk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ128rmkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ128rr, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ128rrk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ128rrkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ256rm, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ256rmb, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ256rmbk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ256rmbkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ 0 }
},

{	/* X86_VPBLENDMDZ256rmk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ256rmkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ256rr, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ256rrk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZ256rrkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZrm, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZrmb, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZrmbk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZrmbkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ 0 }
},

{	/* X86_VPBLENDMDZrmk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZrmkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZrr, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZrrk, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMDZrrkz, X86_INS_VPBLENDMD: vpblendmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ128rm, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ128rmb, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ128rmbk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ128rmbkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ 0 }
},

{	/* X86_VPBLENDMQZ128rmk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ128rmkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ128rr, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ128rrk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ128rrkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ256rm, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ256rmb, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ256rmbk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ256rmbkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ 0 }
},

{	/* X86_VPBLENDMQZ256rmk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ256rmkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ256rr, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ256rrk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZ256rrkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZrm, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZrmb, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZrmbk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZrmbkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ 0 }
},

{	/* X86_VPBLENDMQZrmk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZrmkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZrr, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZrrk, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMQZrrkz, X86_INS_VPBLENDMQ: vpblendmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ128rm, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ128rmk, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ128rmkz, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ128rr, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ128rrk, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ128rrkz, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ256rm, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ256rmk, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ256rmkz, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ256rr, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ256rrk, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZ256rrkz, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZrm, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZrmk, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZrmkz, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZrr, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZrrk, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDMWZrrkz, X86_INS_VPBLENDMW: vpblendmw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDVBYrm, X86_INS_VPBLENDVB: vpblendvb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDVBYrr, X86_INS_VPBLENDVB: vpblendvb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDVBrm, X86_INS_VPBLENDVB: vpblendvb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDVBrr, X86_INS_VPBLENDVB: vpblendvb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPBLENDWYrmi, X86_INS_VPBLENDW: vpblendw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPBLENDWYrri, X86_INS_VPBLENDW: vpblendw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPBLENDWrmi, X86_INS_VPBLENDW: vpblendw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPBLENDWrri, X86_INS_VPBLENDW: vpblendw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPBROADCASTBYrm, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBYrr, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ128m, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ128mk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ128mkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ128r, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ128rk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ128rkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ256m, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ256mk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ256mkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ256r, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ256rk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZ256rkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZm, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZmk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZmkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZr, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZrk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBZrkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZ128r, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZ128rk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZ128rkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZ256r, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZ256rk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZ256rkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZr, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZrk, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrZrkz, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrm, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTBrr, X86_INS_VPBROADCASTB: vpbroadcastb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDYrm, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDYrr, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDZ128m, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ128mk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ128mkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ128r, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ128rk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ128rkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ256m, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ256mk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ256mkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ256r, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ256rk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZ256rkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZm, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZmk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZmkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZr, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZrk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDZrkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTDrZ128r, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrZ128rk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrZ128rkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrZ256r, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrZ256rk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrZ256rkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrZr, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrZrk, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrZrkz, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrm, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTDrr, X86_INS_VPBROADCASTD: vpbroadcastd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTMB2QZ128rr, X86_INS_VPBROADCASTMB2Q: vpbroadcastmb2q */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTMB2QZ256rr, X86_INS_VPBROADCASTMB2Q: vpbroadcastmb2q */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTMB2QZrr, X86_INS_VPBROADCASTMB2Q: vpbroadcastmb2q */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTMW2DZ128rr, X86_INS_VPBROADCASTMW2D: vpbroadcastmw2d */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTMW2DZ256rr, X86_INS_VPBROADCASTMW2D: vpbroadcastmw2d */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTMW2DZrr, X86_INS_VPBROADCASTMW2D: vpbroadcastmw2d */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQYrm, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQYrr, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQZ128m, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ128mk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ128mkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ128r, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ128rk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ128rkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ256m, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ256mk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ256mkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ256r, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ256rk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZ256rkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZm, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZmk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZmkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZr, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZrk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQZrkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ 0 }
},

{	/* X86_VPBROADCASTQrZ128r, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrZ128rk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrZ128rkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrZ256r, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrZ256rk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrZ256rkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrZr, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrZrk, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrZrkz, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrm, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTQrr, X86_INS_VPBROADCASTQ: vpbroadcastq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWYrm, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWYrr, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ128m, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ128mk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ128mkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ128r, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ128rk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ128rkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ256m, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ256mk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ256mkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ256r, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ256rk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZ256rkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZm, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZmk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZmkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZr, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZrk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWZrkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZ128r, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZ128rk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZ128rkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZ256r, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZ256rk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZ256rkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZr, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZrk, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrZrkz, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrm, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPBROADCASTWrr, X86_INS_VPBROADCASTW: vpbroadcastw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQYrm, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQYrr, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQZ128rm, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQZ128rr, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQZ256rm, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQZ256rr, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQZrm, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQZrr, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCLMULQDQrm, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCLMULQDQrr, X86_INS_VPCLMULQDQ: vpclmulqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMOVYrmr, X86_INS_VPCMOV: vpcmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMOVYrrm, X86_INS_VPCMOV: vpcmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMOVYrrr, X86_INS_VPCMOV: vpcmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMOVYrrr_REV, X86_INS_VPCMOV: vpcmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMOVrmr, X86_INS_VPCMOV: vpcmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMOVrrm, X86_INS_VPCMOV: vpcmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMOVrrr, X86_INS_VPCMOV: vpcmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMOVrrr_REV, X86_INS_VPCMOV: vpcmov */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ128rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ128rmi_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZ128rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ128rmik_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZ128rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ128rri_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZ128rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ128rrik_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZ256rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ256rmi_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZ256rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ256rmik_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZ256rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ256rri_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZ256rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZ256rrik_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZrmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZrmi_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZrmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZrmik_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZrri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZrri_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPBZrrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPBZrrik_alt, X86_INS_VPCMPB: vpcmpb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ128rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ128rmi_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ128rmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ128rmib_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ128rmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ128rmibk_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ128rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ128rmik_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ128rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ128rri_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ128rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ128rrik_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ256rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ256rmi_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ256rmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ256rmib_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ256rmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ256rmibk_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ256rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ256rmik_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ256rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ256rri_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZ256rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZ256rrik_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZrmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZrmi_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZrmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZrmib_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZrmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZrmibk_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZrmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZrmik_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZrri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZrri_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPDZrrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPDZrrik_alt, X86_INS_VPCMPD: vpcmpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPEQBYrm, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBYrr, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZ128rm, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZ128rmk, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZ128rr, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZ128rrk, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZ256rm, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZ256rmk, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZ256rr, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZ256rrk, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZrm, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZrmk, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZrr, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBZrrk, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBrm, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQBrr, X86_INS_VPCMPEQB: vpcmpeqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDYrm, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDYrr, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ128rm, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ128rmb, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ128rmbk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ128rmk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ128rr, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ128rrk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ256rm, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ256rmb, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ256rmbk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ256rmk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ256rr, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZ256rrk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZrm, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZrmb, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZrmbk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZrmk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZrr, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDZrrk, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDrm, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQDrr, X86_INS_VPCMPEQD: vpcmpeqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQYrm, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQYrr, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ128rm, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ128rmb, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ128rmbk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ128rmk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ128rr, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ128rrk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ256rm, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ256rmb, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ256rmbk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ256rmk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ256rr, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZ256rrk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZrm, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZrmb, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZrmbk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZrmk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZrr, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQZrrk, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQrm, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQQrr, X86_INS_VPCMPEQQ: vpcmpeqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWYrm, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWYrr, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZ128rm, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZ128rmk, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZ128rr, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZ128rrk, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZ256rm, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZ256rmk, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZ256rr, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZ256rrk, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZrm, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZrmk, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZrr, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWZrrk, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWrm, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPEQWrr, X86_INS_VPCMPEQW: vpcmpeqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPESTRIrm, X86_INS_VPCMPESTRI: vpcmpestri */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPESTRIrr, X86_INS_VPCMPESTRI: vpcmpestri */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPESTRMrm, X86_INS_VPCMPESTRM: vpcmpestrm */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPESTRMrr, X86_INS_VPCMPESTRM: vpcmpestrm */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBYrm, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBYrr, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZ128rm, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZ128rmk, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZ128rr, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZ128rrk, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZ256rm, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZ256rmk, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZ256rr, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZ256rrk, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZrm, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZrmk, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZrr, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBZrrk, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBrm, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTBrr, X86_INS_VPCMPGTB: vpcmpgtb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDYrm, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDYrr, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ128rm, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ128rmb, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ128rmbk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ128rmk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ128rr, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ128rrk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ256rm, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ256rmb, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ256rmbk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ256rmk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ256rr, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZ256rrk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZrm, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZrmb, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZrmbk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZrmk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZrr, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDZrrk, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDrm, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTDrr, X86_INS_VPCMPGTD: vpcmpgtd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQYrm, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQYrr, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ128rm, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ128rmb, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ128rmbk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ128rmk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ128rr, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ128rrk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ256rm, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ256rmb, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ256rmbk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ256rmk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ256rr, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZ256rrk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZrm, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZrmb, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZrmbk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZrmk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZrr, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQZrrk, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQrm, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTQrr, X86_INS_VPCMPGTQ: vpcmpgtq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWYrm, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWYrr, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZ128rm, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZ128rmk, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZ128rr, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZ128rrk, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZ256rm, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZ256rmk, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZ256rr, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZ256rrk, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZrm, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZrmk, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZrr, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWZrrk, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWrm, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPGTWrr, X86_INS_VPCMPGTW: vpcmpgtw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPISTRIrm, X86_INS_VPCMPISTRI: vpcmpistri */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPISTRIrr, X86_INS_VPCMPISTRI: vpcmpistri */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPISTRMrm, X86_INS_VPCMPISTRM: vpcmpistrm */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPISTRMrr, X86_INS_VPCMPISTRM: vpcmpistrm */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ128rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ128rmi_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ128rmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ128rmib_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ128rmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ128rmibk_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ128rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ128rmik_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ128rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ128rri_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ128rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ128rrik_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ256rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ256rmi_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ256rmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ256rmib_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ256rmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ256rmibk_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ256rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ256rmik_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ256rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ256rri_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZ256rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZ256rrik_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZrmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZrmi_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZrmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZrmib_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZrmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZrmibk_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZrmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZrmik_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZrri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZrri_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPQZrrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPQZrrik_alt, X86_INS_VPCMPQ: vpcmpq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZ128rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZ128rmi_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZ128rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZ128rmik_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZ128rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZ128rri_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZ128rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZ128rrik_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZ256rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZ256rmi_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZ256rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZ256rmik_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZ256rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZ256rri_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZ256rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZ256rrik_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZrmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZrmi_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZrmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZrmik_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZrri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZrri_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUBZrrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUBZrrik_alt, X86_INS_VPCMPUB: vpcmpub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ128rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ128rmi_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ128rmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ128rmib_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ128rmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ128rmibk_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ128rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ128rmik_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ128rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ128rri_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ128rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ128rrik_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ256rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ256rmi_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ256rmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ256rmib_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ256rmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ256rmibk_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ256rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ256rmik_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ256rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ256rri_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZ256rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZ256rrik_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZrmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZrmi_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZrmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZrmib_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZrmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZrmibk_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZrmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZrmik_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZrri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZrri_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUDZrrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUDZrrik_alt, X86_INS_VPCMPUD: vpcmpud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ128rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ128rmi_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ128rmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ128rmib_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ128rmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ128rmibk_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ128rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ128rmik_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ128rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ128rri_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ128rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ128rrik_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ256rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ256rmi_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ256rmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ256rmib_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ256rmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ256rmibk_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ256rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ256rmik_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ256rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ256rri_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZ256rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZ256rrik_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZrmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZrmi_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZrmib, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZrmib_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZrmibk, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZrmibk_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZrmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZrmik_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZrri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZrri_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUQZrrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUQZrrik_alt, X86_INS_VPCMPUQ: vpcmpuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZ128rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZ128rmi_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZ128rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZ128rmik_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZ128rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZ128rri_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZ128rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZ128rrik_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZ256rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZ256rmi_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZ256rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZ256rmik_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZ256rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZ256rri_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZ256rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZ256rrik_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZrmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZrmi_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZrmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZrmik_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZrri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZrri_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPUWZrrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPUWZrrik_alt, X86_INS_VPCMPUW: vpcmpuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZ128rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZ128rmi_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZ128rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZ128rmik_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZ128rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZ128rri_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZ128rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZ128rrik_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZ256rmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZ256rmi_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZ256rmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZ256rmik_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZ256rri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZ256rri_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZ256rrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZ256rrik_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZrmi, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZrmi_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZrmik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZrmik_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZrri, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZrri_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCMPWZrrik, X86_INS_VPCMP: vpcmp */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCMPWZrrik_alt, X86_INS_VPCMPW: vpcmpw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMBmi, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMBmi_alt, X86_INS_VPCOMB: vpcomb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMBri, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMBri_alt, X86_INS_VPCOMB: vpcomb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMDmi, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMDmi_alt, X86_INS_VPCOMD: vpcomd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMDri, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMDri_alt, X86_INS_VPCOMD: vpcomd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMPRESSBZ128mr, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ128mrk, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ128rr, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ128rrk, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ128rrkz, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ256mr, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ256mrk, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ256rr, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ256rrk, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZ256rrkz, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZmr, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZmrk, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZrr, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZrrk, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSBZrrkz, X86_INS_VPCOMPRESSB: vpcompressb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ128mr, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ128mrk, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ128rr, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ128rrk, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ128rrkz, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ256mr, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ256mrk, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ256rr, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ256rrk, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZ256rrkz, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZmr, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZmrk, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZrr, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZrrk, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSDZrrkz, X86_INS_VPCOMPRESSD: vpcompressd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ128mr, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ128mrk, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ128rr, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ128rrk, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ128rrkz, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ256mr, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ256mrk, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ256rr, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ256rrk, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZ256rrkz, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZmr, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZmrk, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZrr, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZrrk, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSQZrrkz, X86_INS_VPCOMPRESSQ: vpcompressq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ128mr, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ128mrk, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ128rr, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ128rrk, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ128rrkz, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ256mr, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ256mrk, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ256rr, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ256rrk, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZ256rrkz, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZmr, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZmrk, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZrr, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZrrk, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMPRESSWZrrkz, X86_INS_VPCOMPRESSW: vpcompressw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCOMQmi, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMQmi_alt, X86_INS_VPCOMQ: vpcomq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMQri, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMQri_alt, X86_INS_VPCOMQ: vpcomq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMUBmi, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMUBmi_alt, X86_INS_VPCOMUB: vpcomub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMUBri, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMUBri_alt, X86_INS_VPCOMUB: vpcomub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMUDmi, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMUDmi_alt, X86_INS_VPCOMUD: vpcomud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMUDri, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMUDri_alt, X86_INS_VPCOMUD: vpcomud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMUQmi, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMUQmi_alt, X86_INS_VPCOMUQ: vpcomuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMUQri, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMUQri_alt, X86_INS_VPCOMUQ: vpcomuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMUWmi, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMUWmi_alt, X86_INS_VPCOMUW: vpcomuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMUWri, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMUWri_alt, X86_INS_VPCOMUW: vpcomuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMWmi, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMWmi_alt, X86_INS_VPCOMW: vpcomw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCOMWri, X86_INS_VPCOM: vpcom */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPCOMWri_alt, X86_INS_VPCOMW: vpcomw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPCONFLICTDZ128rm, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ128rmb, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ128rmbk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ128rmbkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ128rmk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ128rmkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ128rr, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ128rrk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ128rrkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rm, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rmb, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rmbk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rmbkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rmk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rmkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rr, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rrk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZ256rrkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrm, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrmb, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrmbk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrmbkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrmk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrmkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrr, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrrk, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTDZrrkz, X86_INS_VPCONFLICTD: vpconflictd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rm, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rmb, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rmbk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rmbkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rmk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rmkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rr, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rrk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ128rrkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rm, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rmb, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rmbk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rmbkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rmk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rmkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rr, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rrk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZ256rrkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrm, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrmb, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrmbk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrmbkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrmk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrmkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrr, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrrk, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPCONFLICTQZrrkz, X86_INS_VPCONFLICTQ: vpconflictq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128m, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128mb, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128mbk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128mbkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128mk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128mkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128r, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128rk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ128rkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256m, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256mb, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256mbk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256mbkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256mk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256mkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256r, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256rk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZ256rkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZm, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZmb, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZmbk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZmbkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZmk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZmkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZr, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZrk, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDSZrkz, X86_INS_VPDPBUSDS: vpdpbusds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128m, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128mb, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128mbk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128mbkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128mk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128mkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128r, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128rk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ128rkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256m, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256mb, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256mbk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256mbkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256mk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256mkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256r, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256rk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZ256rkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZm, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZmb, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZmbk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZmbkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZmk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZmkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZr, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZrk, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPBUSDZrkz, X86_INS_VPDPBUSD: vpdpbusd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128m, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128mb, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128mbk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128mbkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128mk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128mkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128r, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128rk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ128rkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256m, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256mb, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256mbk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256mbkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256mk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256mkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256r, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256rk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZ256rkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZm, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZmb, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZmbk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZmbkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZmk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZmkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZr, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZrk, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDSZrkz, X86_INS_VPDPWSSDS: vpdpwssds */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128m, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128mb, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128mbk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128mbkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128mk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128mkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128r, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128rk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ128rkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256m, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256mb, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256mbk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256mbkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256mk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256mkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256r, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256rk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZ256rkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZm, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZmb, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZmbk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZmbkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZmk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZmkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZr, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZrk, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPDPWSSDZrkz, X86_INS_VPDPWSSD: vpdpwssd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERM2F128rm, X86_INS_VPERM2F128: vperm2f128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERM2F128rr, X86_INS_VPERM2F128: vperm2f128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERM2I128rm, X86_INS_VPERM2I128: vperm2i128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERM2I128rr, X86_INS_VPERM2I128: vperm2i128 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMBZ128rm, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ128rmk, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ128rmkz, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ128rr, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ128rrk, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ128rrkz, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ256rm, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ256rmk, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ256rmkz, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ256rr, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ256rrk, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZ256rrkz, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZrm, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZrmk, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZrmkz, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZrr, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZrrk, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMBZrrkz, X86_INS_VPERMB: vpermb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMDYrm, X86_INS_VPERMD: vpermd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMDYrr, X86_INS_VPERMD: vpermd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMDZ256rm, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZ256rmb, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZ256rmbk, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZ256rmbkz, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZ256rmk, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZ256rmkz, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZ256rr, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZ256rrk, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZ256rrkz, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZrm, X86_INS_VPERMD: vpermd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMDZrmb, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZrmbk, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZrmbkz, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZrmk, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZrmkz, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZrr, X86_INS_VPERMD: vpermd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMDZrrk, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMDZrrkz, X86_INS_VPERMD: vpermd */
	0,
	{ 0 }
},

{	/* X86_VPERMI2B128rm, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B128rmk, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B128rmkz, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B128rr, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B128rrk, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B128rrkz, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B256rm, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B256rmk, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B256rmkz, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B256rr, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B256rrk, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2B256rrkz, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Brm, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Brmk, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Brmkz, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Brr, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Brrk, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Brrkz, X86_INS_VPERMI2B: vpermi2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rm, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rmb, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rmbk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rmbkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rmk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rmkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rr, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rrk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D128rrkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rm, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rmb, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rmbk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rmbkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rmk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rmkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rr, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rrk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2D256rrkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drm, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drmb, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drmbk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drmbkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drmk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drmkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drr, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drrk, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Drrkz, X86_INS_VPERMI2D: vpermi2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rm, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rmb, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rmbk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rmbkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rmk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rmkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rr, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rrk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD128rrkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rm, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rmb, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rmbk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rmbkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rmk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rmkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rr, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rrk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PD256rrkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrm, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrmb, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrmbk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrmbkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrmk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrmkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrr, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrrk, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PDrrkz, X86_INS_VPERMI2PD: vpermi2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rm, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rmb, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rmbk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rmbkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rmk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rmkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rr, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rrk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS128rrkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rm, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rmb, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rmbk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rmbkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rmk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rmkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rr, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rrk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PS256rrkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrm, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrmb, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrmbk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrmbkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrmk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrmkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrr, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrrk, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2PSrrkz, X86_INS_VPERMI2PS: vpermi2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rm, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rmb, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rmbk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rmbkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rmk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rmkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rr, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rrk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q128rrkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rm, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rmb, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rmbk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rmbkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rmk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rmkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rr, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rrk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Q256rrkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrm, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrmb, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrmbk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrmbkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrmk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrmkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrr, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrrk, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Qrrkz, X86_INS_VPERMI2Q: vpermi2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W128rm, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W128rmk, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W128rmkz, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W128rr, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W128rrk, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W128rrkz, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W256rm, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W256rmk, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W256rmkz, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W256rr, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W256rrk, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2W256rrkz, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Wrm, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Wrmk, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Wrmkz, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Wrr, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Wrrk, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMI2Wrrkz, X86_INS_VPERMI2W: vpermi2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMIL2PDYmr, X86_INS_VPERMIL2PD: vpermil2pd */
	0,
	{ 0 }
},

{	/* X86_VPERMIL2PDYrm, X86_INS_VPERMIL2PD: vpermil2pd */
	0,
	{ 0 }
},

{	/* X86_VPERMIL2PDYrr, X86_INS_VPERMIL2PD: vpermil2pd */
	0,
	{ 0 }
},

{	/* X86_VPERMIL2PDYrr_REV, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMIL2PDmr, X86_INS_VPERMIL2PD: vpermil2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMIL2PDrm, X86_INS_VPERMIL2PD: vpermil2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMIL2PDrr, X86_INS_VPERMIL2PD: vpermil2pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMIL2PDrr_REV, X86_INS_VPERMIL2PD: vpermil2pd */
	0,
	{ 0 }
},

{	/* X86_VPERMIL2PSYmr, X86_INS_VPERMIL2PS: vpermil2ps */
	0,
	{ 0 }
},

{	/* X86_VPERMIL2PSYrm, X86_INS_VPERMIL2PS: vpermil2ps */
	0,
	{ 0 }
},

{	/* X86_VPERMIL2PSYrr, X86_INS_VPERMIL2PS: vpermil2ps */
	0,
	{ 0 }
},

{	/* X86_VPERMIL2PSYrr_REV, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMIL2PSmr, X86_INS_VPERMIL2PS: vpermil2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMIL2PSrm, X86_INS_VPERMIL2PS: vpermil2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMIL2PSrr, X86_INS_VPERMIL2PS: vpermil2ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMIL2PSrr_REV, X86_INS_VPERMIL2PS: vpermil2ps */
	0,
	{ 0 }
},

{	/* X86_VPERMILPDYmi, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDYri, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDYrm, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDYrr, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128mbi, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128mbik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128mbikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128mi, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128mik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128mikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128ri, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128rik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128rikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ128rm, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128rmb, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128rmbk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128rmbkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128rmk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128rmkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128rr, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128rrk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ128rrkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256mbi, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256mbik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256mbikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256mi, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256mik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256mikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256ri, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256rik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256rikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZ256rm, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256rmb, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256rmbk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256rmbkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256rmk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256rmkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256rr, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256rrk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZ256rrkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZmbi, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZmbik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZmbikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZmi, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZmik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZmikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZri, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZrik, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZrikz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDZrm, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZrmb, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZrmbk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZrmbkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZrmk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZrmkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZrr, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZrrk, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDZrrkz, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDmi, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDri, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPDrm, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPDrr, X86_INS_VPERMILPD: vpermilpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSYmi, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSYri, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSYrm, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSYrr, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128mbi, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128mbik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128mbikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128mi, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128mik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128mikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128ri, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128rik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128rikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ128rm, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128rmb, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128rmbk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128rmbkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128rmk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128rmkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128rr, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128rrk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ128rrkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256mbi, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256mbik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256mbikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256mi, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256mik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256mikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256ri, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256rik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256rikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZ256rm, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256rmb, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256rmbk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256rmbkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256rmk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256rmkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256rr, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256rrk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZ256rrkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZmbi, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZmbik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZmbikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZmi, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZmik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZmikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZri, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZrik, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZrikz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSZrm, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZrmb, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZrmbk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZrmbkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZrmk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZrmkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZrr, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZrrk, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSZrrkz, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSmi, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSri, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMILPSrm, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMILPSrr, X86_INS_VPERMILPS: vpermilps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDYmi, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDYri, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256mbi, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256mbik, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256mbikz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256mi, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256mik, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256mikz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256ri, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256rik, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256rikz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZ256rm, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZ256rmb, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZ256rmbk, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZ256rmbkz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZ256rmk, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZ256rmkz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZ256rr, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZ256rrk, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZ256rrkz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZmbi, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZmbik, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZmbikz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZmi, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZmik, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZmikz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZri, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZrik, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZrikz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMPDZrm, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZrmb, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZrmbk, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZrmbkz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZrmk, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZrmkz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZrr, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZrrk, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPDZrrkz, X86_INS_VPERMPD: vpermpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSYrm, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSYrr, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rm, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rmb, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rmbk, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rmbkz, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rmk, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rmkz, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rr, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rrk, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZ256rrkz, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrm, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrmb, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrmbk, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrmbkz, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrmk, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrmkz, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrr, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrrk, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMPSZrrkz, X86_INS_VPERMPS: vpermps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQYmi, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQYri, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256mbi, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256mbik, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256mbikz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256mi, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256mik, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256mikz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256ri, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256rik, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256rikz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZ256rm, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZ256rmb, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZ256rmbk, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZ256rmbkz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZ256rmk, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZ256rmkz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZ256rr, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZ256rrk, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZ256rrkz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZmbi, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZmbik, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZmbikz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZmi, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZmik, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZmikz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZri, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZrik, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZrikz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPERMQZrm, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZrmb, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZrmbk, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZrmbkz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZrmk, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZrmkz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZrr, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZrrk, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMQZrrkz, X86_INS_VPERMQ: vpermq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B128rm, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B128rmk, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B128rmkz, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B128rr, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B128rrk, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B128rrkz, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B256rm, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B256rmk, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B256rmkz, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B256rr, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B256rrk, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2B256rrkz, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Brm, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Brmk, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Brmkz, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Brr, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Brrk, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Brrkz, X86_INS_VPERMT2B: vpermt2b */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rm, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rmb, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rmbk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rmbkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rmk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rmkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rr, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rrk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D128rrkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rm, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rmb, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rmbk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rmbkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rmk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rmkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rr, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rrk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2D256rrkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drm, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drmb, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drmbk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drmbkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drmk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drmkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drr, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drrk, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Drrkz, X86_INS_VPERMT2D: vpermt2d */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rm, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rmb, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rmbk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rmbkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rmk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rmkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rr, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rrk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD128rrkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rm, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rmb, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rmbk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rmbkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rmk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rmkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rr, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rrk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PD256rrkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrm, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrmb, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrmbk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrmbkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrmk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrmkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrr, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrrk, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PDrrkz, X86_INS_VPERMT2PD: vpermt2pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rm, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rmb, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rmbk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rmbkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rmk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rmkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rr, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rrk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS128rrkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rm, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rmb, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rmbk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rmbkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rmk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rmkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rr, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rrk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PS256rrkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrm, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrmb, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrmbk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrmbkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrmk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrmkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrr, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrrk, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2PSrrkz, X86_INS_VPERMT2PS: vpermt2ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rm, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rmb, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rmbk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rmbkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rmk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rmkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rr, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rrk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q128rrkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rm, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rmb, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rmbk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rmbkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rmk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rmkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rr, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rrk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Q256rrkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrm, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrmb, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrmbk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrmbkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrmk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrmkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrr, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrrk, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Qrrkz, X86_INS_VPERMT2Q: vpermt2q */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W128rm, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W128rmk, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W128rmkz, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W128rr, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W128rrk, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W128rrkz, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W256rm, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W256rmk, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W256rmkz, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W256rr, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W256rrk, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2W256rrkz, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Wrm, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Wrmk, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Wrmkz, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Wrr, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Wrrk, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMT2Wrrkz, X86_INS_VPERMT2W: vpermt2w */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ128rm, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ128rmk, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ128rmkz, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ128rr, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ128rrk, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ128rrkz, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ256rm, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ256rmk, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ256rmkz, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ256rr, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ256rrk, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZ256rrkz, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZrm, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZrmk, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZrmkz, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZrr, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZrrk, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPERMWZrrkz, X86_INS_VPERMW: vpermw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ128rm, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ128rmk, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ128rmkz, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ128rr, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ128rrk, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ128rrkz, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ256rm, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ256rmk, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ256rmkz, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ256rr, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ256rrk, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZ256rrkz, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZrm, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZrmk, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZrmkz, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZrr, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZrrk, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDBZrrkz, X86_INS_VPEXPANDB: vpexpandb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ128rm, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ128rmk, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ128rmkz, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ128rr, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ128rrk, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ128rrkz, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ256rm, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ256rmk, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ256rmkz, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ256rr, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ256rrk, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZ256rrkz, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZrm, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZrmk, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZrmkz, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZrr, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZrrk, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDDZrrkz, X86_INS_VPEXPANDD: vpexpandd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ128rm, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ128rmk, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ128rmkz, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ128rr, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ128rrk, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ128rrkz, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ256rm, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ256rmk, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ256rmkz, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ256rr, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ256rrk, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZ256rrkz, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZrm, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZrmk, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZrmkz, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZrr, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZrrk, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDQZrrkz, X86_INS_VPEXPANDQ: vpexpandq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ128rm, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ128rmk, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ128rmkz, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ128rr, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ128rrk, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ128rrkz, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ256rm, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ256rmk, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ256rmkz, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ256rr, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ256rrk, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZ256rrkz, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZrm, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZrmk, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZrmkz, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZrr, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZrrk, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXPANDWZrrkz, X86_INS_VPEXPANDW: vpexpandw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRBZmr, X86_INS_VPEXTRB: vpextrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRBZrr, X86_INS_VPEXTRB: vpextrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRBmr, X86_INS_VPEXTRB: vpextrb */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPEXTRBrr, X86_INS_VPEXTRB: vpextrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPEXTRDZmr, X86_INS_VPEXTRD: vpextrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRDZrr, X86_INS_VPEXTRD: vpextrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRDmr, X86_INS_VPEXTRD: vpextrd */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPEXTRDrr, X86_INS_VPEXTRD: vpextrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPEXTRQZmr, X86_INS_VPEXTRQ: vpextrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRQZrr, X86_INS_VPEXTRQ: vpextrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRQmr, X86_INS_VPEXTRQ: vpextrq */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPEXTRQrr, X86_INS_VPEXTRQ: vpextrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPEXTRWZmr, X86_INS_VPEXTRW: vpextrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRWZrr, X86_INS_VPEXTRW: vpextrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRWZrr_REV, X86_INS_VPEXTRW: vpextrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRWmr, X86_INS_VPEXTRW: vpextrw */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPEXTRWrr, X86_INS_VPEXTRW: vpextrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPEXTRWrr_REV, X86_INS_VPEXTRW: vpextrw	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPGATHERDDYrm, X86_INS_VPGATHERDD: vpgatherdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERDDZ128rm, X86_INS_VPGATHERDD: vpgatherdd */
	0,
	{ 0 }
},

{	/* X86_VPGATHERDDZ256rm, X86_INS_VPGATHERDD: vpgatherdd */
	0,
	{ 0 }
},

{	/* X86_VPGATHERDDZrm, X86_INS_VPGATHERDD: vpgatherdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERDDrm, X86_INS_VPGATHERDD: vpgatherdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERDQYrm, X86_INS_VPGATHERDQ: vpgatherdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERDQZ128rm, X86_INS_VPGATHERDQ: vpgatherdq */
	0,
	{ 0 }
},

{	/* X86_VPGATHERDQZ256rm, X86_INS_VPGATHERDQ: vpgatherdq */
	0,
	{ 0 }
},

{	/* X86_VPGATHERDQZrm, X86_INS_VPGATHERDQ: vpgatherdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERDQrm, X86_INS_VPGATHERDQ: vpgatherdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERQDYrm, X86_INS_VPGATHERQD: vpgatherqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERQDZ128rm, X86_INS_VPGATHERQD: vpgatherqd */
	0,
	{ 0 }
},

{	/* X86_VPGATHERQDZ256rm, X86_INS_VPGATHERQD: vpgatherqd */
	0,
	{ 0 }
},

{	/* X86_VPGATHERQDZrm, X86_INS_VPGATHERQD: vpgatherqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERQDrm, X86_INS_VPGATHERQD: vpgatherqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERQQYrm, X86_INS_VPGATHERQQ: vpgatherqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERQQZ128rm, X86_INS_VPGATHERQQ: vpgatherqq */
	0,
	{ 0 }
},

{	/* X86_VPGATHERQQZ256rm, X86_INS_VPGATHERQQ: vpgatherqq */
	0,
	{ 0 }
},

{	/* X86_VPGATHERQQZrm, X86_INS_VPGATHERQQ: vpgatherqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPGATHERQQrm, X86_INS_VPGATHERQQ: vpgatherqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDBDrm, X86_INS_VPHADDBD: vphaddbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDBDrr, X86_INS_VPHADDBD: vphaddbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDBQrm, X86_INS_VPHADDBQ: vphaddbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDBQrr, X86_INS_VPHADDBQ: vphaddbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDBWrm, X86_INS_VPHADDBW: vphaddbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDBWrr, X86_INS_VPHADDBW: vphaddbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDDQrm, X86_INS_VPHADDDQ: vphadddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDDQrr, X86_INS_VPHADDDQ: vphadddq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDDYrm, X86_INS_VPHADDD: vphaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDDYrr, X86_INS_VPHADDD: vphaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDDrm, X86_INS_VPHADDD: vphaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDDrr, X86_INS_VPHADDD: vphaddd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDSWYrm, X86_INS_VPHADDSW: vphaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDSWYrr, X86_INS_VPHADDSW: vphaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDSWrm, X86_INS_VPHADDSW: vphaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDSWrr, X86_INS_VPHADDSW: vphaddsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUBDrm, X86_INS_VPHADDUBD: vphaddubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUBDrr, X86_INS_VPHADDUBD: vphaddubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUBQrm, X86_INS_VPHADDUBQ: vphaddubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUBQrr, X86_INS_VPHADDUBQ: vphaddubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUBWrm, X86_INS_VPHADDUBW: vphaddubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUBWrr, X86_INS_VPHADDUBW: vphaddubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUDQrm, X86_INS_VPHADDUDQ: vphaddudq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUDQrr, X86_INS_VPHADDUDQ: vphaddudq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUWDrm, X86_INS_VPHADDUWD: vphadduwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUWDrr, X86_INS_VPHADDUWD: vphadduwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUWQrm, X86_INS_VPHADDUWQ: vphadduwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDUWQrr, X86_INS_VPHADDUWQ: vphadduwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDWDrm, X86_INS_VPHADDWD: vphaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDWDrr, X86_INS_VPHADDWD: vphaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDWQrm, X86_INS_VPHADDWQ: vphaddwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDWQrr, X86_INS_VPHADDWQ: vphaddwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHADDWYrm, X86_INS_VPHADDW: vphaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDWYrr, X86_INS_VPHADDW: vphaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDWrm, X86_INS_VPHADDW: vphaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHADDWrr, X86_INS_VPHADDW: vphaddw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHMINPOSUWrm, X86_INS_VPHMINPOSUW: vphminposuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHMINPOSUWrr, X86_INS_VPHMINPOSUW: vphminposuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBBWrm, X86_INS_VPHSUBBW: vphsubbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBBWrr, X86_INS_VPHSUBBW: vphsubbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBDQrm, X86_INS_VPHSUBDQ: vphsubdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBDQrr, X86_INS_VPHSUBDQ: vphsubdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBDYrm, X86_INS_VPHSUBD: vphsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBDYrr, X86_INS_VPHSUBD: vphsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBDrm, X86_INS_VPHSUBD: vphsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBDrr, X86_INS_VPHSUBD: vphsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBSWYrm, X86_INS_VPHSUBSW: vphsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBSWYrr, X86_INS_VPHSUBSW: vphsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBSWrm, X86_INS_VPHSUBSW: vphsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBSWrr, X86_INS_VPHSUBSW: vphsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBWDrm, X86_INS_VPHSUBWD: vphsubwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBWDrr, X86_INS_VPHSUBWD: vphsubwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBWYrm, X86_INS_VPHSUBW: vphsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBWYrr, X86_INS_VPHSUBW: vphsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBWrm, X86_INS_VPHSUBW: vphsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPHSUBWrr, X86_INS_VPHSUBW: vphsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRBZrm, X86_INS_VPINSRB: vpinsrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRBZrr, X86_INS_VPINSRB: vpinsrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRBrm, X86_INS_VPINSRB: vpinsrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPINSRBrr, X86_INS_VPINSRB: vpinsrb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPINSRDZrm, X86_INS_VPINSRD: vpinsrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRDZrr, X86_INS_VPINSRD: vpinsrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRDrm, X86_INS_VPINSRD: vpinsrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPINSRDrr, X86_INS_VPINSRD: vpinsrd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPINSRQZrm, X86_INS_VPINSRQ: vpinsrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRQZrr, X86_INS_VPINSRQ: vpinsrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRQrm, X86_INS_VPINSRQ: vpinsrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPINSRQrr, X86_INS_VPINSRQ: vpinsrq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPINSRWZrm, X86_INS_VPINSRW: vpinsrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRWZrr, X86_INS_VPINSRW: vpinsrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRWrm, X86_INS_VPINSRW: vpinsrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPINSRWrr, X86_INS_VPINSRW: vpinsrw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rm, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rmb, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rmbk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rmbkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rmk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rmkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rr, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rrk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ128rrkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rm, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rmb, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rmbk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rmbkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rmk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rmkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rr, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rrk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZ256rrkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrm, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrmb, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrmbk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrmbkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrmk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrmkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrr, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrrk, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTDZrrkz, X86_INS_VPLZCNTD: vplzcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rm, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rmb, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rmbk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rmbkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rmk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rmkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rr, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rrk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ128rrkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rm, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rmb, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rmbk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rmbkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rmk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rmkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rr, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rrk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZ256rrkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrm, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrmb, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrmbk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrmbkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrmk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrmkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrr, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrrk, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPLZCNTQZrrkz, X86_INS_VPLZCNTQ: vplzcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMACSDDrm, X86_INS_VPMACSDD: vpmacsdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSDDrr, X86_INS_VPMACSDD: vpmacsdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSDQHrm, X86_INS_VPMACSDQH: vpmacsdqh */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSDQHrr, X86_INS_VPMACSDQH: vpmacsdqh */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSDQLrm, X86_INS_VPMACSDQL: vpmacsdql */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSDQLrr, X86_INS_VPMACSDQL: vpmacsdql */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSDDrm, X86_INS_VPMACSSDD: vpmacssdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSDDrr, X86_INS_VPMACSSDD: vpmacssdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSDQHrm, X86_INS_VPMACSSDQH: vpmacssdqh */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSDQHrr, X86_INS_VPMACSSDQH: vpmacssdqh */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSDQLrm, X86_INS_VPMACSSDQL: vpmacssdql */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSDQLrr, X86_INS_VPMACSSDQL: vpmacssdql */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSWDrm, X86_INS_VPMACSSWD: vpmacsswd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSWDrr, X86_INS_VPMACSSWD: vpmacsswd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSWWrm, X86_INS_VPMACSSWW: vpmacssww */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSSWWrr, X86_INS_VPMACSSWW: vpmacssww */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSWDrm, X86_INS_VPMACSWD: vpmacswd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSWDrr, X86_INS_VPMACSWD: vpmacswd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSWWrm, X86_INS_VPMACSWW: vpmacsww */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMACSWWrr, X86_INS_VPMACSWW: vpmacsww */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADCSSWDrm, X86_INS_VPMADCSSWD: vpmadcsswd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADCSSWDrr, X86_INS_VPMADCSSWD: vpmadcsswd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADCSWDrm, X86_INS_VPMADCSWD: vpmadcswd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADCSWDrr, X86_INS_VPMADCSWD: vpmadcswd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128m, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128mb, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128mbk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128mbkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128mk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128mkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128r, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128rk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ128rkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256m, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256mb, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256mbk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256mbkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256mk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256mkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256r, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256rk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZ256rkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZm, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZmb, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZmbk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZmbkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZmk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZmkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZr, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZrk, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52HUQZrkz, X86_INS_VPMADD52HUQ: vpmadd52huq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128m, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128mb, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128mbk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128mbkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128mk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128mkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128r, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128rk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ128rkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256m, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256mb, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256mbk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256mbkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256mk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256mkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256r, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256rk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZ256rkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZm, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZmb, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZmbk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZmbkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZmk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZmkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZr, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZrk, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADD52LUQZrkz, X86_INS_VPMADD52LUQ: vpmadd52luq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWYrm, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWYrr, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ128rm, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ128rmk, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ128rmkz, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ128rr, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ128rrk, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ128rrkz, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ256rm, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ256rmk, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ256rmkz, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ256rr, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ256rrk, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZ256rrkz, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZrm, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZrmk, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZrmkz, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZrr, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZrrk, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWZrrkz, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWrm, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDUBSWrr, X86_INS_VPMADDUBSW: vpmaddubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDYrm, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDYrr, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ128rm, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ128rmk, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ128rmkz, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ128rr, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ128rrk, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ128rrkz, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ256rm, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ256rmk, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ256rmkz, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ256rr, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ256rrk, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZ256rrkz, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZrm, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZrmk, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZrmkz, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZrr, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZrrk, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDZrrkz, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDrm, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMADDWDrr, X86_INS_VPMADDWD: vpmaddwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMASKMOVDYmr, X86_INS_VPMASKMOVD: vpmaskmovd */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMASKMOVDYrm, X86_INS_VPMASKMOVD: vpmaskmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMASKMOVDmr, X86_INS_VPMASKMOVD: vpmaskmovd */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMASKMOVDrm, X86_INS_VPMASKMOVD: vpmaskmovd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMASKMOVQYmr, X86_INS_VPMASKMOVQ: vpmaskmovq */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMASKMOVQYrm, X86_INS_VPMASKMOVQ: vpmaskmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMASKMOVQmr, X86_INS_VPMASKMOVQ: vpmaskmovq */
	0,
	{ CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMASKMOVQrm, X86_INS_VPMASKMOVQ: vpmaskmovq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBYrm, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBYrr, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ128rm, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ128rmk, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ128rmkz, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ128rr, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ128rrk, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ128rrkz, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ256rm, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ256rmk, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ256rmkz, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ256rr, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ256rrk, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZ256rrkz, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZrm, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZrmk, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZrmkz, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZrr, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZrrk, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBZrrkz, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBrm, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSBrr, X86_INS_VPMAXSB: vpmaxsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDYrm, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDYrr, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rm, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rmb, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rmbk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rmbkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rmk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rmkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rr, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rrk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ128rrkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rm, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rmb, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rmbk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rmbkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rmk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rmkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rr, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rrk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZ256rrkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrm, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrmb, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrmbk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrmbkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrmk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrmkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrr, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrrk, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDZrrkz, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDrm, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSDrr, X86_INS_VPMAXSD: vpmaxsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rm, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rmb, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rmbk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rmbkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rmk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rmkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rr, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rrk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ128rrkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rm, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rmb, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rmbk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rmbkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rmk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rmkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rr, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rrk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZ256rrkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrm, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrmb, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrmbk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrmbkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrmk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrmkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrr, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrrk, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSQZrrkz, X86_INS_VPMAXSQ: vpmaxsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWYrm, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWYrr, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ128rm, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ128rmk, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ128rmkz, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ128rr, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ128rrk, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ128rrkz, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ256rm, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ256rmk, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ256rmkz, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ256rr, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ256rrk, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZ256rrkz, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZrm, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZrmk, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZrmkz, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZrr, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZrrk, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWZrrkz, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWrm, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXSWrr, X86_INS_VPMAXSW: vpmaxsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBYrm, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBYrr, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ128rm, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ128rmk, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ128rmkz, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ128rr, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ128rrk, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ128rrkz, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ256rm, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ256rmk, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ256rmkz, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ256rr, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ256rrk, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZ256rrkz, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZrm, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZrmk, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZrmkz, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZrr, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZrrk, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBZrrkz, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBrm, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUBrr, X86_INS_VPMAXUB: vpmaxub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDYrm, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDYrr, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rm, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rmb, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rmbk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rmbkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rmk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rmkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rr, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rrk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ128rrkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rm, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rmb, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rmbk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rmbkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rmk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rmkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rr, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rrk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZ256rrkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrm, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrmb, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrmbk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrmbkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrmk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrmkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrr, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrrk, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDZrrkz, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDrm, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUDrr, X86_INS_VPMAXUD: vpmaxud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rm, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rmb, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rmbk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rmbkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rmk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rmkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rr, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rrk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ128rrkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rm, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rmb, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rmbk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rmbkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rmk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rmkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rr, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rrk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZ256rrkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrm, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrmb, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrmbk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrmbkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrmk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrmkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrr, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrrk, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUQZrrkz, X86_INS_VPMAXUQ: vpmaxuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWYrm, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWYrr, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ128rm, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ128rmk, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ128rmkz, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ128rr, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ128rrk, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ128rrkz, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ256rm, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ256rmk, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ256rmkz, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ256rr, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ256rrk, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZ256rrkz, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZrm, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZrmk, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZrmkz, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZrr, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZrrk, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWZrrkz, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWrm, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMAXUWrr, X86_INS_VPMAXUW: vpmaxuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBYrm, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBYrr, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ128rm, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ128rmk, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ128rmkz, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ128rr, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ128rrk, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ128rrkz, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ256rm, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ256rmk, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ256rmkz, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ256rr, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ256rrk, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZ256rrkz, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZrm, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZrmk, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZrmkz, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZrr, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZrrk, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBZrrkz, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBrm, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSBrr, X86_INS_VPMINSB: vpminsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDYrm, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDYrr, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rm, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rmb, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rmbk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rmbkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rmk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rmkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rr, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rrk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ128rrkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rm, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rmb, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rmbk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rmbkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rmk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rmkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rr, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rrk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZ256rrkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrm, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrmb, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrmbk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrmbkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrmk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrmkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrr, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrrk, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDZrrkz, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDrm, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSDrr, X86_INS_VPMINSD: vpminsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rm, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rmb, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rmbk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rmbkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rmk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rmkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rr, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rrk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ128rrkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rm, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rmb, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rmbk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rmbkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rmk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rmkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rr, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rrk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZ256rrkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrm, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrmb, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrmbk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrmbkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrmk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrmkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrr, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrrk, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSQZrrkz, X86_INS_VPMINSQ: vpminsq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWYrm, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWYrr, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ128rm, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ128rmk, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ128rmkz, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ128rr, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ128rrk, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ128rrkz, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ256rm, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ256rmk, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ256rmkz, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ256rr, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ256rrk, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZ256rrkz, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZrm, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZrmk, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZrmkz, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZrr, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZrrk, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWZrrkz, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWrm, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINSWrr, X86_INS_VPMINSW: vpminsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBYrm, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBYrr, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ128rm, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ128rmk, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ128rmkz, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ128rr, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ128rrk, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ128rrkz, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ256rm, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ256rmk, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ256rmkz, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ256rr, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ256rrk, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZ256rrkz, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZrm, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZrmk, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZrmkz, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZrr, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZrrk, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBZrrkz, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBrm, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUBrr, X86_INS_VPMINUB: vpminub */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDYrm, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDYrr, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rm, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rmb, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rmbk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rmbkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rmk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rmkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rr, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rrk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ128rrkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rm, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rmb, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rmbk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rmbkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rmk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rmkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rr, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rrk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZ256rrkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrm, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrmb, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrmbk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrmbkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrmk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrmkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrr, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrrk, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDZrrkz, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDrm, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUDrr, X86_INS_VPMINUD: vpminud */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rm, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rmb, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rmbk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rmbkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rmk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rmkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rr, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rrk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ128rrkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rm, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rmb, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rmbk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rmbkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rmk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rmkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rr, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rrk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZ256rrkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrm, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrmb, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrmbk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrmbkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrmk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrmkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrr, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrrk, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUQZrrkz, X86_INS_VPMINUQ: vpminuq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWYrm, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWYrr, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ128rm, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ128rmk, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ128rmkz, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ128rr, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ128rrk, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ128rrkz, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ256rm, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ256rmk, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ256rmkz, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ256rr, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ256rrk, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZ256rrkz, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZrm, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZrmk, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZrmkz, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZrr, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZrrk, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWZrrkz, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWrm, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMINUWrr, X86_INS_VPMINUW: vpminuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMOVB2MZ128rr, X86_INS_VPMOVB2M: vpmovb2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVB2MZ256rr, X86_INS_VPMOVB2M: vpmovb2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVB2MZrr, X86_INS_VPMOVB2M: vpmovb2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVD2MZ128rr, X86_INS_VPMOVD2M: vpmovd2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVD2MZ256rr, X86_INS_VPMOVD2M: vpmovd2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVD2MZrr, X86_INS_VPMOVD2M: vpmovd2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ128mr, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ128mrk, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ128rr, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ128rrk, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ128rrkz, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ256mr, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ256mrk, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ256rr, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ256rrk, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZ256rrkz, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZmr, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZmrk, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZrr, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZrrk, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDBZrrkz, X86_INS_VPMOVDB: vpmovdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ128mr, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ128mrk, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ128rr, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ128rrk, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ128rrkz, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ256mr, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ256mrk, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ256rr, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ256rrk, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZ256rrkz, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZmr, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZmrk, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZrr, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZrrk, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVDWZrrkz, X86_INS_VPMOVDW: vpmovdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2BZ128rr, X86_INS_VPMOVM2B: vpmovm2b */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2BZ256rr, X86_INS_VPMOVM2B: vpmovm2b */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2BZrr, X86_INS_VPMOVM2B: vpmovm2b */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2DZ128rr, X86_INS_VPMOVM2D: vpmovm2d */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2DZ256rr, X86_INS_VPMOVM2D: vpmovm2d */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2DZrr, X86_INS_VPMOVM2D: vpmovm2d */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2QZ128rr, X86_INS_VPMOVM2Q: vpmovm2q */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2QZ256rr, X86_INS_VPMOVM2Q: vpmovm2q */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2QZrr, X86_INS_VPMOVM2Q: vpmovm2q */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2WZ128rr, X86_INS_VPMOVM2W: vpmovm2w */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2WZ256rr, X86_INS_VPMOVM2W: vpmovm2w */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVM2WZrr, X86_INS_VPMOVM2W: vpmovm2w */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVMSKBYrr, X86_INS_VPMOVMSKB: vpmovmskb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVMSKBrr, X86_INS_VPMOVMSKB: vpmovmskb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQ2MZ128rr, X86_INS_VPMOVQ2M: vpmovq2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVQ2MZ256rr, X86_INS_VPMOVQ2M: vpmovq2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVQ2MZrr, X86_INS_VPMOVQ2M: vpmovq2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ128mr, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ128mrk, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ128rr, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ128rrk, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ128rrkz, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ256mr, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ256mrk, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ256rr, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ256rrk, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZ256rrkz, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZmr, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZmrk, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZrr, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZrrk, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQBZrrkz, X86_INS_VPMOVQB: vpmovqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ128mr, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ128mrk, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ128rr, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ128rrk, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ128rrkz, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ256mr, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ256mrk, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ256rr, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ256rrk, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZ256rrkz, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZmr, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZmrk, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZrr, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZrrk, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQDZrrkz, X86_INS_VPMOVQD: vpmovqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ128mr, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ128mrk, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ128rr, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ128rrk, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ128rrkz, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ256mr, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ256mrk, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ256rr, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ256rrk, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZ256rrkz, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZmr, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZmrk, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZrr, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZrrk, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVQWZrrkz, X86_INS_VPMOVQW: vpmovqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ128mr, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ128mrk, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ128rr, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ128rrk, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ128rrkz, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ256mr, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ256mrk, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ256rr, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ256rrk, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZ256rrkz, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZmr, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZmrk, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZrr, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZrrk, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDBZrrkz, X86_INS_VPMOVSDB: vpmovsdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ128mr, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ128mrk, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ128rr, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ128rrk, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ128rrkz, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ256mr, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ256mrk, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ256rr, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ256rrk, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZ256rrkz, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZmr, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZmrk, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZrr, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZrrk, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSDWZrrkz, X86_INS_VPMOVSDW: vpmovsdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ128mr, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ128mrk, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ128rr, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ128rrk, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ128rrkz, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ256mr, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ256mrk, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ256rr, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ256rrk, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZ256rrkz, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZmr, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZmrk, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZrr, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZrrk, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQBZrrkz, X86_INS_VPMOVSQB: vpmovsqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ128mr, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ128mrk, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ128rr, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ128rrk, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ128rrkz, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ256mr, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ256mrk, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ256rr, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ256rrk, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZ256rrkz, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZmr, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZmrk, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZrr, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZrrk, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQDZrrkz, X86_INS_VPMOVSQD: vpmovsqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ128mr, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ128mrk, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ128rr, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ128rrk, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ128rrkz, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ256mr, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ256mrk, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ256rr, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ256rrk, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZ256rrkz, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZmr, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZmrk, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZrr, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZrrk, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSQWZrrkz, X86_INS_VPMOVSQW: vpmovsqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ128mr, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ128mrk, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ128rr, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ128rrk, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ128rrkz, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ256mr, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ256mrk, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ256rr, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ256rrk, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZ256rrkz, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZmr, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZmrk, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZrr, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZrrk, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSWBZrrkz, X86_INS_VPMOVSWB: vpmovswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDYrm, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDYrr, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ128rm, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ128rmk, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ128rmkz, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ128rr, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ128rrk, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ128rrkz, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ256rm, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ256rmk, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ256rmkz, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ256rr, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ256rrk, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZ256rrkz, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZrm, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZrmk, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZrmkz, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZrr, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZrrk, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDZrrkz, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDrm, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBDrr, X86_INS_VPMOVSXBD: vpmovsxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQYrm, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQYrr, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ128rm, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ128rmk, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ128rmkz, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ128rr, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ128rrk, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ128rrkz, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ256rm, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ256rmk, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ256rmkz, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ256rr, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ256rrk, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZ256rrkz, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZrm, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZrmk, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZrmkz, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZrr, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZrrk, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQZrrkz, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQrm, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBQrr, X86_INS_VPMOVSXBQ: vpmovsxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWYrm, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWYrr, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ128rm, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ128rmk, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ128rmkz, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ128rr, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ128rrk, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ128rrkz, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ256rm, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ256rmk, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ256rmkz, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ256rr, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ256rrk, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZ256rrkz, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZrm, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZrmk, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZrmkz, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZrr, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZrrk, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWZrrkz, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWrm, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXBWrr, X86_INS_VPMOVSXBW: vpmovsxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQYrm, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQYrr, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ128rm, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ128rmk, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ128rmkz, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ128rr, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ128rrk, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ128rrkz, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ256rm, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ256rmk, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ256rmkz, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ256rr, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ256rrk, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZ256rrkz, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZrm, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZrmk, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZrmkz, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZrr, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZrrk, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQZrrkz, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQrm, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXDQrr, X86_INS_VPMOVSXDQ: vpmovsxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDYrm, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDYrr, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ128rm, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ128rmk, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ128rmkz, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ128rr, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ128rrk, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ128rrkz, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ256rm, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ256rmk, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ256rmkz, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ256rr, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ256rrk, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZ256rrkz, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZrm, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZrmk, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZrmkz, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZrr, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZrrk, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDZrrkz, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDrm, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWDrr, X86_INS_VPMOVSXWD: vpmovsxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQYrm, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQYrr, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ128rm, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ128rmk, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ128rmkz, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ128rr, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ128rrk, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ128rrkz, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ256rm, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ256rmk, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ256rmkz, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ256rr, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ256rrk, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZ256rrkz, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZrm, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZrmk, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZrmkz, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZrr, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZrrk, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQZrrkz, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQrm, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVSXWQrr, X86_INS_VPMOVSXWQ: vpmovsxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ128mr, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ128mrk, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ128rr, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ128rrk, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ128rrkz, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ256mr, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ256mrk, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ256rr, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ256rrk, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZ256rrkz, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZmr, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZmrk, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZrr, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZrrk, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDBZrrkz, X86_INS_VPMOVUSDB: vpmovusdb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ128mr, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ128mrk, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ128rr, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ128rrk, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ128rrkz, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ256mr, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ256mrk, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ256rr, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ256rrk, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZ256rrkz, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZmr, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZmrk, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZrr, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZrrk, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSDWZrrkz, X86_INS_VPMOVUSDW: vpmovusdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ128mr, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ128mrk, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ128rr, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ128rrk, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ128rrkz, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ256mr, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ256mrk, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ256rr, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ256rrk, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZ256rrkz, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZmr, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZmrk, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZrr, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZrrk, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQBZrrkz, X86_INS_VPMOVUSQB: vpmovusqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ128mr, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ128mrk, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ128rr, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ128rrk, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ128rrkz, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ256mr, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ256mrk, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ256rr, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ256rrk, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZ256rrkz, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZmr, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZmrk, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZrr, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZrrk, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQDZrrkz, X86_INS_VPMOVUSQD: vpmovusqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ128mr, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ128mrk, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ128rr, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ128rrk, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ128rrkz, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ256mr, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ256mrk, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ256rr, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ256rrk, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZ256rrkz, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZmr, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZmrk, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZrr, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZrrk, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSQWZrrkz, X86_INS_VPMOVUSQW: vpmovusqw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ128mr, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ128mrk, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ128rr, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ128rrk, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ128rrkz, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ256mr, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ256mrk, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ256rr, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ256rrk, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZ256rrkz, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZmr, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZmrk, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZrr, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZrrk, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVUSWBZrrkz, X86_INS_VPMOVUSWB: vpmovuswb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVW2MZ128rr, X86_INS_VPMOVW2M: vpmovw2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVW2MZ256rr, X86_INS_VPMOVW2M: vpmovw2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVW2MZrr, X86_INS_VPMOVW2M: vpmovw2m */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ128mr, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ128mrk, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ128rr, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ128rrk, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ128rrkz, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ256mr, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ256mrk, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ256rr, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ256rrk, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZ256rrkz, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZmr, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZmrk, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZrr, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZrrk, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVWBZrrkz, X86_INS_VPMOVWB: vpmovwb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDYrm, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDYrr, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ128rm, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ128rmk, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ128rmkz, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ128rr, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ128rrk, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ128rrkz, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ256rm, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ256rmk, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ256rmkz, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ256rr, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ256rrk, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZ256rrkz, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZrm, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZrmk, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZrmkz, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZrr, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZrrk, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDZrrkz, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDrm, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBDrr, X86_INS_VPMOVZXBD: vpmovzxbd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQYrm, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQYrr, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ128rm, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ128rmk, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ128rmkz, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ128rr, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ128rrk, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ128rrkz, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ256rm, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ256rmk, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ256rmkz, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ256rr, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ256rrk, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZ256rrkz, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZrm, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZrmk, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZrmkz, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZrr, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZrrk, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQZrrkz, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQrm, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBQrr, X86_INS_VPMOVZXBQ: vpmovzxbq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWYrm, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWYrr, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ128rm, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ128rmk, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ128rmkz, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ128rr, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ128rrk, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ128rrkz, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ256rm, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ256rmk, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ256rmkz, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ256rr, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ256rrk, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZ256rrkz, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZrm, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZrmk, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZrmkz, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZrr, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZrrk, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWZrrkz, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWrm, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXBWrr, X86_INS_VPMOVZXBW: vpmovzxbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQYrm, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQYrr, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ128rm, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ128rmk, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ128rmkz, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ128rr, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ128rrk, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ128rrkz, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ256rm, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ256rmk, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ256rmkz, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ256rr, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ256rrk, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZ256rrkz, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZrm, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZrmk, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZrmkz, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZrr, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZrrk, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQZrrkz, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQrm, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXDQrr, X86_INS_VPMOVZXDQ: vpmovzxdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDYrm, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDYrr, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ128rm, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ128rmk, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ128rmkz, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ128rr, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ128rrk, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ128rrkz, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ256rm, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ256rmk, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ256rmkz, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ256rr, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ256rrk, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZ256rrkz, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZrm, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZrmk, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZrmkz, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZrr, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZrrk, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDZrrkz, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDrm, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWDrr, X86_INS_VPMOVZXWD: vpmovzxwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQYrm, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQYrr, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ128rm, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ128rmk, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ128rmkz, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ128rr, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ128rrk, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ128rrkz, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ256rm, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ256rmk, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ256rmkz, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ256rr, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ256rrk, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZ256rrkz, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZrm, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZrmk, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZrmkz, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZrr, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZrrk, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQZrrkz, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQrm, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMOVZXWQrr, X86_INS_VPMOVZXWQ: vpmovzxwq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQYrm, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQYrr, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rm, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rmb, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rmbk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rmbkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rmk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rmkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rr, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rrk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ128rrkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rm, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rmb, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rmbk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rmbkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rmk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rmkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rr, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rrk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZ256rrkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrm, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrmb, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrmbk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrmbkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrmk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrmkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrr, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrrk, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQZrrkz, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQrm, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULDQrr, X86_INS_VPMULDQ: vpmuldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWYrm, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWYrr, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ128rm, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ128rmk, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ128rmkz, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ128rr, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ128rrk, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ128rrkz, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ256rm, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ256rmk, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ256rmkz, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ256rr, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ256rrk, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZ256rrkz, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZrm, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZrmk, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZrmkz, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZrr, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZrrk, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWZrrkz, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWrm, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHRSWrr, X86_INS_VPMULHRSW: vpmulhrsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWYrm, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWYrr, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ128rm, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ128rmk, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ128rmkz, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ128rr, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ128rrk, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ128rrkz, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ256rm, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ256rmk, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ256rmkz, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ256rr, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ256rrk, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZ256rrkz, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZrm, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZrmk, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZrmkz, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZrr, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZrrk, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWZrrkz, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWrm, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHUWrr, X86_INS_VPMULHUW: vpmulhuw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWYrm, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWYrr, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ128rm, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ128rmk, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ128rmkz, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ128rr, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ128rrk, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ128rrkz, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ256rm, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ256rmk, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ256rmkz, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ256rr, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ256rrk, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZ256rrkz, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZrm, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZrmk, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZrmkz, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZrr, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZrrk, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWZrrkz, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWrm, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULHWrr, X86_INS_VPMULHW: vpmulhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDYrm, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDYrr, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rm, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rmb, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rmbk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rmbkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rmk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rmkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rr, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rrk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ128rrkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rm, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rmb, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rmbk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rmbkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rmk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rmkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rr, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rrk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZ256rrkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrm, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrmb, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrmbk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrmbkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrmk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrmkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrr, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrrk, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDZrrkz, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDrm, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLDrr, X86_INS_VPMULLD: vpmulld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rm, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rmb, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rmbk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rmbkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rmk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rmkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rr, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rrk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ128rrkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rm, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rmb, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rmbk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rmbkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rmk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rmkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rr, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rrk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZ256rrkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrm, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrmb, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrmbk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrmbkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrmk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrmkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrr, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrrk, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLQZrrkz, X86_INS_VPMULLQ: vpmullq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWYrm, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWYrr, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ128rm, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ128rmk, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ128rmkz, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ128rr, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ128rrk, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ128rrkz, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ256rm, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ256rmk, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ256rmkz, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ256rr, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ256rrk, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZ256rrkz, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZrm, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZrmk, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZrmkz, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZrr, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZrrk, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWZrrkz, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWrm, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULLWrr, X86_INS_VPMULLW: vpmullw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rm, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rmb, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rmbk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rmbkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rmk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rmkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rr, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rrk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ128rrkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rm, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rmb, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rmbk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rmbkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rmk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rmkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rr, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rrk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZ256rrkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrm, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrmb, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrmbk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrmbkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrmk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrmkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrr, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrrk, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULTISHIFTQBZrrkz, X86_INS_VPMULTISHIFTQB: vpmultishiftqb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQYrm, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQYrr, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rm, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rmb, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rmbk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rmbkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rmk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rmkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rr, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rrk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ128rrkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rm, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rmb, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rmbk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rmbkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rmk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rmkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rr, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rrk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZ256rrkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrm, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrmb, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrmbk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrmbkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrmk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrmkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrr, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrrk, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQZrrkz, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQrm, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPMULUDQrr, X86_INS_VPMULUDQ: vpmuludq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ128rm, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ128rmk, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ128rmkz, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ128rr, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ128rrk, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ128rrkz, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ256rm, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ256rmk, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ256rmkz, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ256rr, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ256rrk, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZ256rrkz, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZrm, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZrmk, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZrmkz, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZrr, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZrrk, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTBZrrkz, X86_INS_VPOPCNTB: vpopcntb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rm, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rmb, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rmbk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rmbkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rmk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rmkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rr, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rrk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ128rrkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rm, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rmb, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rmbk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rmbkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rmk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rmkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rr, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rrk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZ256rrkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrm, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrmb, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrmbk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrmbkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrmk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrmkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrr, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrrk, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTDZrrkz, X86_INS_VPOPCNTD: vpopcntd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rm, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rmb, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rmbk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rmbkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rmk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rmkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rr, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rrk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ128rrkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rm, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rmb, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rmbk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rmbkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rmk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rmkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rr, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rrk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZ256rrkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrm, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrmb, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrmbk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrmbkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrmk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrmkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrr, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrrk, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTQZrrkz, X86_INS_VPOPCNTQ: vpopcntq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ128rm, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ128rmk, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ128rmkz, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ128rr, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ128rrk, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ128rrkz, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ256rm, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ256rmk, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ256rmkz, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ256rr, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ256rrk, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZ256rrkz, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZrm, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZrmk, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZrmkz, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZrr, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZrrk, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPOPCNTWZrrkz, X86_INS_VPOPCNTW: vpopcntw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rm, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rmb, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rmbk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rmbkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rmk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rmkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rr, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rrk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ128rrkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rm, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rmb, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rmbk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rmbkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rmk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rmkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rr, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rrk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZ256rrkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrm, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrmb, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrmbk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrmbkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrmk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrmkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrr, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrrk, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORDZrrkz, X86_INS_VPORD: vpord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rm, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rmb, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rmbk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rmbkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rmk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rmkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rr, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rrk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ128rrkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rm, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rmb, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rmbk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rmbkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rmk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rmkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rr, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rrk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZ256rrkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrm, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrmb, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrmbk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrmbkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrmk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrmkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrr, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrrk, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORQZrrkz, X86_INS_VPORQ: vporq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORYrm, X86_INS_VPOR: vpor */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORYrr, X86_INS_VPOR: vpor */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORrm, X86_INS_VPOR: vpor */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPORrr, X86_INS_VPOR: vpor */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPPERMrmr, X86_INS_VPPERM: vpperm */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPPERMrrm, X86_INS_VPPERM: vpperm */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPPERMrrr, X86_INS_VPPERM: vpperm */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPPERMrrr_REV, X86_INS_VPPERM: vpperm */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLDZ128mbi, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ128mbik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ128mbikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ128mi, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ128mik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ128mikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ128ri, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ128rik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ128rikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256mbi, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256mbik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256mbikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256mi, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256mik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256mikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256ri, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256rik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZ256rikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZmbi, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZmbik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZmbikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZmi, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZmik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZmikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZri, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZrik, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLDZrikz, X86_INS_VPROLD: vprold */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128mbi, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128mbik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128mbikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128mi, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128mik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128mikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128ri, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128rik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ128rikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256mbi, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256mbik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256mbikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256mi, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256mik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256mikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256ri, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256rik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZ256rikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZmbi, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZmbik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZmbikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZmi, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZmik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZmikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZri, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZrik, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLQZrikz, X86_INS_VPROLQ: vprolq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROLVDZ128rm, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ128rmb, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ128rmbk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ128rmbkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ128rmk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ128rmkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ128rr, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ128rrk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ128rrkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rm, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rmb, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rmbk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rmbkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rmk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rmkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rr, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rrk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZ256rrkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrm, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrmb, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrmbk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrmbkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrmk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrmkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrr, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrrk, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVDZrrkz, X86_INS_VPROLVD: vprolvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rm, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rmb, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rmbk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rmbkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rmk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rmkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rr, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rrk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ128rrkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rm, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rmb, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rmbk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rmbkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rmk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rmkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rr, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rrk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZ256rrkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrm, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrmb, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrmbk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrmbkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrmk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrmkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrr, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrrk, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROLVQZrrkz, X86_INS_VPROLVQ: vprolvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORDZ128mbi, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ128mbik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ128mbikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ128mi, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ128mik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ128mikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ128ri, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ128rik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ128rikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256mbi, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256mbik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256mbikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256mi, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256mik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256mikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256ri, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256rik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZ256rikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZmbi, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZmbik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZmbikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZmi, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZmik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZmikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZri, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZrik, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORDZrikz, X86_INS_VPRORD: vprord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128mbi, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128mbik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128mbikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128mi, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128mik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128mikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128ri, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128rik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ128rikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256mbi, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256mbik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256mbikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256mi, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256mik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256mikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256ri, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256rik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZ256rikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZmbi, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZmbik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZmbikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZmi, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZmik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZmikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZri, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZrik, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORQZrikz, X86_INS_VPRORQ: vprorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPRORVDZ128rm, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ128rmb, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ128rmbk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ128rmbkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ128rmk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ128rmkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ128rr, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ128rrk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ128rrkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rm, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rmb, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rmbk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rmbkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rmk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rmkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rr, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rrk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZ256rrkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrm, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrmb, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrmbk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrmbkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrmk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrmkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrr, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrrk, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVDZrrkz, X86_INS_VPRORVD: vprorvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rm, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rmb, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rmbk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rmbkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rmk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rmkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rr, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rrk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ128rrkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rm, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rmb, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rmbk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rmbkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rmk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rmkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rr, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rrk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZ256rrkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrm, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrmb, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrmbk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrmbkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrmk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrmkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrr, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrrk, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPRORVQZrrkz, X86_INS_VPRORVQ: vprorvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTBmi, X86_INS_VPROTB: vprotb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROTBmr, X86_INS_VPROTB: vprotb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTBri, X86_INS_VPROTB: vprotb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROTBrm, X86_INS_VPROTB: vprotb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTBrr, X86_INS_VPROTB: vprotb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTBrr_REV, X86_INS_VPROTB: vprotb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTDmi, X86_INS_VPROTD: vprotd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROTDmr, X86_INS_VPROTD: vprotd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTDri, X86_INS_VPROTD: vprotd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROTDrm, X86_INS_VPROTD: vprotd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTDrr, X86_INS_VPROTD: vprotd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTDrr_REV, X86_INS_VPROTD: vprotd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTQmi, X86_INS_VPROTQ: vprotq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROTQmr, X86_INS_VPROTQ: vprotq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTQri, X86_INS_VPROTQ: vprotq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROTQrm, X86_INS_VPROTQ: vprotq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTQrr, X86_INS_VPROTQ: vprotq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTQrr_REV, X86_INS_VPROTQ: vprotq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTWmi, X86_INS_VPROTW: vprotw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROTWmr, X86_INS_VPROTW: vprotw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTWri, X86_INS_VPROTW: vprotw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPROTWrm, X86_INS_VPROTW: vprotw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTWrr, X86_INS_VPROTW: vprotw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPROTWrr_REV, X86_INS_VPROTW: vprotw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWYrm, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWYrr, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWZ128rm, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWZ128rr, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWZ256rm, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWZ256rr, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWZrm, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWZrr, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWrm, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSADBWrr, X86_INS_VPSADBW: vpsadbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERDDZ128mr, X86_INS_VPSCATTERDD: vpscatterdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERDDZ256mr, X86_INS_VPSCATTERDD: vpscatterdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERDDZmr, X86_INS_VPSCATTERDD: vpscatterdd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERDQZ128mr, X86_INS_VPSCATTERDQ: vpscatterdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERDQZ256mr, X86_INS_VPSCATTERDQ: vpscatterdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERDQZmr, X86_INS_VPSCATTERDQ: vpscatterdq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERQDZ128mr, X86_INS_VPSCATTERQD: vpscatterqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERQDZ256mr, X86_INS_VPSCATTERQD: vpscatterqd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERQDZmr, X86_INS_VPSCATTERQD: vpscatterqd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERQQZ128mr, X86_INS_VPSCATTERQQ: vpscatterqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERQQZ256mr, X86_INS_VPSCATTERQQ: vpscatterqq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VPSCATTERQQZmr, X86_INS_VPSCATTERQQ: vpscatterqq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHABmr, X86_INS_VPSHAB: vpshab */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHABrm, X86_INS_VPSHAB: vpshab */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHABrr, X86_INS_VPSHAB: vpshab */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHABrr_REV, X86_INS_VPSHAB: vpshab */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHADmr, X86_INS_VPSHAD: vpshad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHADrm, X86_INS_VPSHAD: vpshad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHADrr, X86_INS_VPSHAD: vpshad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHADrr_REV, X86_INS_VPSHAD: vpshad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHAQmr, X86_INS_VPSHAQ: vpshaq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHAQrm, X86_INS_VPSHAQ: vpshaq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHAQrr, X86_INS_VPSHAQ: vpshaq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHAQrr_REV, X86_INS_VPSHAQ: vpshaq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHAWmr, X86_INS_VPSHAW: vpshaw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHAWrm, X86_INS_VPSHAW: vpshaw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHAWrr, X86_INS_VPSHAW: vpshaw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHAWrr_REV, X86_INS_VPSHAW: vpshaw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLBmr, X86_INS_VPSHLB: vpshlb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLBrm, X86_INS_VPSHLB: vpshlb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLBrr, X86_INS_VPSHLB: vpshlb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLBrr_REV, X86_INS_VPSHLB: vpshlb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDDZ128rmbi, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ128rmbik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ128rmbikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ128rmi, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ128rmik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ128rmikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ128rri, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ128rrik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ128rrikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rmbi, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rmbik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rmbikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rmi, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rmik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rmikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rri, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rrik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZ256rrikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrmbi, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrmbik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrmbikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrmi, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrmik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrmikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrri, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrrik, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDDZrrikz, X86_INS_VPSHLDD: vpshldd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rmbi, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rmbik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rmbikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rmi, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rmik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rmikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rri, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rrik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ128rrikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rmbi, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rmbik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rmbikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rmi, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rmik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rmikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rri, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rrik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZ256rrikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrmbi, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrmbik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrmbikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrmi, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrmik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrmikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrri, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrrik, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDQZrrikz, X86_INS_VPSHLDQ: vpshldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDVDZ128m, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ128mb, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ128mbk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ128mbkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ128mk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ128mkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ128r, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ128rk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ128rkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256m, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256mb, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256mbk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256mbkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256mk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256mkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256r, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256rk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZ256rkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZm, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZmb, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZmbk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZmbkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZmk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZmkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZr, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZrk, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVDZrkz, X86_INS_VPSHLDVD: vpshldvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128m, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128mb, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128mbk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128mbkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128mk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128mkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128r, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128rk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ128rkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256m, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256mb, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256mbk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256mbkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256mk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256mkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256r, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256rk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZ256rkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZm, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZmb, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZmbk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZmbkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZmk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZmkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZr, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZrk, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVQZrkz, X86_INS_VPSHLDVQ: vpshldvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ128m, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ128mk, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ128mkz, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ128r, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ128rk, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ128rkz, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ256m, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ256mk, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ256mkz, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ256r, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ256rk, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZ256rkz, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZm, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZmk, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZmkz, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZr, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZrk, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDVWZrkz, X86_INS_VPSHLDVW: vpshldvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDWZ128rmi, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ128rmik, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ128rmikz, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ128rri, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ128rrik, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ128rrikz, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ256rmi, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ256rmik, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ256rmikz, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ256rri, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ256rrik, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZ256rrikz, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZrmi, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZrmik, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZrmikz, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZrri, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZrrik, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDWZrrikz, X86_INS_VPSHLDW: vpshldw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHLDmr, X86_INS_VPSHLD: vpshld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDrm, X86_INS_VPSHLD: vpshld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDrr, X86_INS_VPSHLD: vpshld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLDrr_REV, X86_INS_VPSHLD: vpshld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLQmr, X86_INS_VPSHLQ: vpshlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLQrm, X86_INS_VPSHLQ: vpshlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLQrr, X86_INS_VPSHLQ: vpshlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLQrr_REV, X86_INS_VPSHLQ: vpshlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLWmr, X86_INS_VPSHLW: vpshlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLWrm, X86_INS_VPSHLW: vpshlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLWrr, X86_INS_VPSHLW: vpshlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHLWrr_REV, X86_INS_VPSHLW: vpshlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDDZ128rmbi, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ128rmbik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ128rmbikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ128rmi, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ128rmik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ128rmikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ128rri, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ128rrik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ128rrikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rmbi, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rmbik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rmbikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rmi, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rmik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rmikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rri, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rrik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZ256rrikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrmbi, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrmbik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrmbikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrmi, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrmik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrmikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrri, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrrik, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDDZrrikz, X86_INS_VPSHRDD: vpshrdd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rmbi, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rmbik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rmbikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rmi, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rmik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rmikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rri, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rrik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ128rrikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rmbi, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rmbik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rmbikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rmi, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rmik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rmikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rri, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rrik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZ256rrikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrmbi, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrmbik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrmbikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrmi, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrmik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrmikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrri, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrrik, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDQZrrikz, X86_INS_VPSHRDQ: vpshrdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDVDZ128m, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ128mb, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ128mbk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ128mbkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ128mk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ128mkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ128r, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ128rk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ128rkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256m, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256mb, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256mbk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256mbkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256mk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256mkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256r, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256rk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZ256rkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZm, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZmb, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZmbk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZmbkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZmk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZmkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZr, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZrk, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVDZrkz, X86_INS_VPSHRDVD: vpshrdvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128m, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128mb, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128mbk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128mbkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128mk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128mkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128r, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128rk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ128rkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256m, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256mb, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256mbk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256mbkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256mk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256mkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256r, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256rk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZ256rkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZm, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZmb, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZmbk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZmbkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZmk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZmkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZr, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZrk, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVQZrkz, X86_INS_VPSHRDVQ: vpshrdvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ128m, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ128mk, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ128mkz, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ128r, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ128rk, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ128rkz, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ256m, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ256mk, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ256mkz, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ256r, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ256rk, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZ256rkz, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZm, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZmk, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZmkz, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZr, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZrk, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDVWZrkz, X86_INS_VPSHRDVW: vpshrdvw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHRDWZ128rmi, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ128rmik, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ128rmikz, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ128rri, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ128rrik, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ128rrikz, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ256rmi, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ256rmik, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ256rmikz, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ256rri, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ256rrik, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZ256rrikz, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZrmi, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZrmik, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZrmikz, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZrri, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZrrik, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHRDWZrrikz, X86_INS_VPSHRDW: vpshrdw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFBITQMBZ128rm, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZ128rmk, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZ128rr, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZ128rrk, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZ256rm, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZ256rmk, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZ256rr, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZ256rrk, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZrm, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZrmk, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZrr, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBITQMBZrrk, X86_INS_VPSHUFBITQMB: vpshufbitqmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBYrm, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBYrr, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ128rm, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ128rmk, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ128rmkz, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ128rr, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ128rrk, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ128rrkz, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ256rm, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ256rmk, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ256rmkz, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ256rr, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ256rrk, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZ256rrkz, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZrm, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZrmk, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZrmkz, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZrr, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZrrk, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBZrrkz, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBrm, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFBrr, X86_INS_VPSHUFB: vpshufb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSHUFDYmi, X86_INS_VPSHUFD: vpshufd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFDYri, X86_INS_VPSHUFD: vpshufd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFDZ128mbi, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ128mbik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ128mbikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ128mi, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ128mik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ128mikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ128ri, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ128rik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ128rikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256mbi, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256mbik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256mbikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256mi, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256mik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256mikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256ri, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256rik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZ256rikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZmbi, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZmbik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZmbikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZmi, X86_INS_VPSHUFD: vpshufd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFDZmik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZmikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZri, X86_INS_VPSHUFD: vpshufd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFDZrik, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDZrikz, X86_INS_VPSHUFD: vpshufd */
	0,
	{ 0 }
},

{	/* X86_VPSHUFDmi, X86_INS_VPSHUFD: vpshufd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFDri, X86_INS_VPSHUFD: vpshufd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWYmi, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWYri, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ128mi, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ128mik, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ128mikz, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ128ri, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ128rik, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ128rikz, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ256mi, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ256mik, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ256mikz, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ256ri, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ256rik, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZ256rikz, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZmi, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZmik, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZmikz, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZri, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZrik, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWZrikz, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWmi, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFHWri, X86_INS_VPSHUFHW: vpshufhw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWYmi, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWYri, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ128mi, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ128mik, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ128mikz, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ128ri, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ128rik, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ128rikz, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ256mi, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ256mik, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ256mikz, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ256ri, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ256rik, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZ256rikz, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZmi, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZmik, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZmikz, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZri, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZrik, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWZrikz, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWmi, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSHUFLWri, X86_INS_VPSHUFLW: vpshuflw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSIGNBYrm, X86_INS_VPSIGNB: vpsignb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNBYrr, X86_INS_VPSIGNB: vpsignb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNBrm, X86_INS_VPSIGNB: vpsignb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNBrr, X86_INS_VPSIGNB: vpsignb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNDYrm, X86_INS_VPSIGND: vpsignd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNDYrr, X86_INS_VPSIGND: vpsignd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNDrm, X86_INS_VPSIGND: vpsignd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNDrr, X86_INS_VPSIGND: vpsignd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNWYrm, X86_INS_VPSIGNW: vpsignw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNWYrr, X86_INS_VPSIGNW: vpsignw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNWrm, X86_INS_VPSIGNW: vpsignw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSIGNWrr, X86_INS_VPSIGNW: vpsignw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDQYri, X86_INS_VPSLLDQ: vpslldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDQZ128rm, X86_INS_VPSLLDQ: vpslldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDQZ128rr, X86_INS_VPSLLDQ: vpslldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDQZ256rm, X86_INS_VPSLLDQ: vpslldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDQZ256rr, X86_INS_VPSLLDQ: vpslldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDQZrm, X86_INS_VPSLLDQ: vpslldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDQZrr, X86_INS_VPSLLDQ: vpslldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDQri, X86_INS_VPSLLDQ: vpslldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDYri, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDYrm, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDYrr, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDZ128mbi, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128mbik, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128mbikz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128mi, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128mik, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128mikz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128ri, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128rik, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128rikz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128rm, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128rmk, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128rmkz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128rr, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128rrk, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ128rrkz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256mbi, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256mbik, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256mbikz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256mi, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256mik, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256mikz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256ri, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256rik, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256rikz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256rm, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256rmk, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256rmkz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256rr, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256rrk, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZ256rrkz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZmbi, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZmbik, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZmbikz, X86_INS_VPSLLD: vpslld */
	0,
	{ 0 }
},

{	/* X86_VPSLLDZmi, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDZmik, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDZmikz, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDZri, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDZrik, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDZrikz, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDZrm, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDZrmk, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDZrmkz, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDZrr, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDZrrk, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDZrrkz, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDri, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLDrm, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLDrr, X86_INS_VPSLLD: vpslld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQYri, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQYrm, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQYrr, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ128mbi, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128mbik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128mbikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128mi, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128mik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128mikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128ri, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128rik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128rikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ128rm, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ128rmk, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ128rmkz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ128rr, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ128rrk, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ128rrkz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ256mbi, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256mbik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256mbikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256mi, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256mik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256mikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256ri, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256rik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256rikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZ256rm, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ256rmk, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ256rmkz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ256rr, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ256rrk, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZ256rrkz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZmbi, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZmbik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZmbikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZmi, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZmik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZmikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZri, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZrik, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZrikz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQZrm, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZrmk, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZrmkz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZrr, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZrrk, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQZrrkz, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQri, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLQrm, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLQrr, X86_INS_VPSLLQ: vpsllq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDYrm, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDYrr, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDZ128rm, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ128rmb, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ128rmbk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ128rmbkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ128rmk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ128rmkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ128rr, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ128rrk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ128rrkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rm, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rmb, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rmbk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rmbkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rmk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rmkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rr, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rrk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZ256rrkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZrm, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDZrmb, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZrmbk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZrmbkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ 0 }
},

{	/* X86_VPSLLVDZrmk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDZrmkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDZrr, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDZrrk, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDZrrkz, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDrm, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVDrr, X86_INS_VPSLLVD: vpsllvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQYrm, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQYrr, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rm, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rmb, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rmbk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rmbkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rmk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rmkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rr, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rrk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ128rrkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rm, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rmb, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rmbk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rmbkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rmk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rmkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rr, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rrk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZ256rrkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrm, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrmb, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrmbk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrmbkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrmk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrmkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrr, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrrk, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQZrrkz, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQrm, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVQrr, X86_INS_VPSLLVQ: vpsllvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ128rm, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ128rmk, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ128rmkz, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ128rr, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ128rrk, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ128rrkz, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ256rm, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ256rmk, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ256rmkz, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ256rr, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ256rrk, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZ256rrkz, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZrm, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZrmk, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZrmkz, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZrr, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZrrk, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLVWZrrkz, X86_INS_VPSLLVW: vpsllvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWYri, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWYrm, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWYrr, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ128mi, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ128mik, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ128mikz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ128ri, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ128rik, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ128rikz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ128rm, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ128rmk, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ128rmkz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ128rr, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ128rrk, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ128rrkz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ256mi, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ256mik, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ256mikz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ256ri, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ256rik, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ256rikz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZ256rm, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ256rmk, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ256rmkz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ256rr, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ256rrk, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZ256rrkz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZmi, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZmik, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZmikz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZri, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZrik, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZrikz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWZrm, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZrmk, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZrmkz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZrr, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZrrk, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWZrrkz, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWri, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSLLWrm, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSLLWrr, X86_INS_VPSLLW: vpsllw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADYri, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRADYrm, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADYrr, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADZ128mbi, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128mbik, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128mbikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128mi, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128mik, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128mikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128ri, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128rik, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128rikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128rm, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128rmk, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128rmkz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128rr, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128rrk, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ128rrkz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256mbi, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256mbik, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256mbikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256mi, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256mik, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256mikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256ri, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256rik, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256rikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256rm, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256rmk, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256rmkz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256rr, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256rrk, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZ256rrkz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZmbi, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZmbik, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZmbikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ 0 }
},

{	/* X86_VPSRADZmi, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRADZmik, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRADZmikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRADZri, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRADZrik, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRADZrikz, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRADZrm, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADZrmk, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADZrmkz, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADZrr, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADZrrk, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADZrrkz, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADri, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRADrm, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRADrr, X86_INS_VPSRAD: vpsrad */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ128mbi, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128mbik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128mbikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128mi, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128mik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128mikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128ri, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128rik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128rikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ128rm, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ128rmk, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ128rmkz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ128rr, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ128rrk, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ128rrkz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ256mbi, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256mbik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256mbikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256mi, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256mik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256mikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256ri, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256rik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256rikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZ256rm, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ256rmk, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ256rmkz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ256rr, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ256rrk, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZ256rrkz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZmbi, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZmbik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZmbikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZmi, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZmik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZmikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZri, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZrik, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZrikz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAQZrm, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZrmk, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZrmkz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZrr, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZrrk, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAQZrrkz, X86_INS_VPSRAQ: vpsraq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDYrm, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDYrr, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDZ128rm, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ128rmb, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ128rmbk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ128rmbkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ128rmk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ128rmkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ128rr, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ128rrk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ128rrkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rm, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rmb, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rmbk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rmbkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rmk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rmkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rr, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rrk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZ256rrkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZrm, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDZrmb, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZrmbk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZrmbkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ 0 }
},

{	/* X86_VPSRAVDZrmk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDZrmkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDZrr, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDZrrk, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDZrrkz, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDrm, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVDrr, X86_INS_VPSRAVD: vpsravd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rm, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rmb, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rmbk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rmbkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rmk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rmkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rr, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rrk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ128rrkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rm, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rmb, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rmbk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rmbkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rmk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rmkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rr, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rrk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZ256rrkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrm, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrmb, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrmbk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrmbkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrmk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrmkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrr, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrrk, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVQZrrkz, X86_INS_VPSRAVQ: vpsravq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ128rm, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ128rmk, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ128rmkz, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ128rr, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ128rrk, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ128rrkz, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ256rm, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ256rmk, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ256rmkz, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ256rr, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ256rrk, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZ256rrkz, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZrm, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZrmk, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZrmkz, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZrr, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZrrk, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAVWZrrkz, X86_INS_VPSRAVW: vpsravw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWYri, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWYrm, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWYrr, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ128mi, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ128mik, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ128mikz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ128ri, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ128rik, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ128rikz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ128rm, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ128rmk, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ128rmkz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ128rr, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ128rrk, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ128rrkz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ256mi, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ256mik, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ256mikz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ256ri, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ256rik, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ256rikz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZ256rm, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ256rmk, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ256rmkz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ256rr, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ256rrk, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZ256rrkz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZmi, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZmik, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZmikz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZri, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZrik, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZrikz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWZrm, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZrmk, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZrmkz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZrr, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZrrk, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWZrrkz, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWri, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRAWrm, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRAWrr, X86_INS_VPSRAW: vpsraw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDQYri, X86_INS_VPSRLDQ: vpsrldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDQZ128rm, X86_INS_VPSRLDQ: vpsrldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDQZ128rr, X86_INS_VPSRLDQ: vpsrldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDQZ256rm, X86_INS_VPSRLDQ: vpsrldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDQZ256rr, X86_INS_VPSRLDQ: vpsrldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDQZrm, X86_INS_VPSRLDQ: vpsrldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDQZrr, X86_INS_VPSRLDQ: vpsrldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDQri, X86_INS_VPSRLDQ: vpsrldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDYri, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDYrm, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDYrr, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDZ128mbi, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128mbik, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128mbikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128mi, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128mik, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128mikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128ri, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128rik, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128rikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128rm, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128rmk, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128rmkz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128rr, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128rrk, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ128rrkz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256mbi, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256mbik, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256mbikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256mi, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256mik, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256mikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256ri, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256rik, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256rikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256rm, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256rmk, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256rmkz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256rr, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256rrk, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZ256rrkz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZmbi, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZmbik, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZmbikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ 0 }
},

{	/* X86_VPSRLDZmi, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDZmik, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDZmikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDZri, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDZrik, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDZrikz, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDZrm, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDZrmk, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDZrmkz, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDZrr, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDZrrk, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDZrrkz, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDri, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLDrm, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLDrr, X86_INS_VPSRLD: vpsrld */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQYri, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQYrm, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQYrr, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ128mbi, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128mbik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128mbikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128mi, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128mik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128mikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128ri, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128rik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128rikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ128rm, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ128rmk, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ128rmkz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ128rr, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ128rrk, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ128rrkz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ256mbi, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256mbik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256mbikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256mi, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256mik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256mikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256ri, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256rik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256rikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZ256rm, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ256rmk, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ256rmkz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ256rr, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ256rrk, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZ256rrkz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZmbi, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZmbik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZmbikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZmi, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZmik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZmikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZri, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZrik, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZrikz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQZrm, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZrmk, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZrmkz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZrr, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZrrk, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQZrrkz, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQri, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLQrm, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLQrr, X86_INS_VPSRLQ: vpsrlq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDYrm, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDYrr, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDZ128rm, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ128rmb, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ128rmbk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ128rmbkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ128rmk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ128rmkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ128rr, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ128rrk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ128rrkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rm, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rmb, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rmbk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rmbkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rmk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rmkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rr, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rrk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZ256rrkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZrm, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDZrmb, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZrmbk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZrmbkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ 0 }
},

{	/* X86_VPSRLVDZrmk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDZrmkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDZrr, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDZrrk, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDZrrkz, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDrm, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVDrr, X86_INS_VPSRLVD: vpsrlvd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQYrm, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQYrr, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rm, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rmb, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rmbk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rmbkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rmk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rmkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rr, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rrk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ128rrkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rm, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rmb, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rmbk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rmbkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rmk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rmkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rr, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rrk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZ256rrkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrm, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrmb, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrmbk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrmbkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrmk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrmkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrr, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrrk, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQZrrkz, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQrm, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVQrr, X86_INS_VPSRLVQ: vpsrlvq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ128rm, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ128rmk, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ128rmkz, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ128rr, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ128rrk, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ128rrkz, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ256rm, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ256rmk, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ256rmkz, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ256rr, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ256rrk, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZ256rrkz, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZrm, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZrmk, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZrmkz, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZrr, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZrrk, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLVWZrrkz, X86_INS_VPSRLVW: vpsrlvw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWYri, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWYrm, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWYrr, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ128mi, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ128mik, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ128mikz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ128ri, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ128rik, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ128rikz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ128rm, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ128rmk, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ128rmkz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ128rr, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ128rrk, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ128rrkz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ256mi, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ256mik, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ256mikz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ256ri, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ256rik, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ256rikz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZ256rm, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ256rmk, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ256rmkz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ256rr, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ256rrk, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZ256rrkz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZmi, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZmik, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZmikz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZri, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZrik, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZrikz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWZrm, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZrmk, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZrmkz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZrr, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZrrk, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWZrrkz, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWri, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPSRLWrm, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSRLWrr, X86_INS_VPSRLW: vpsrlw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBYrm, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBYrr, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ128rm, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ128rmk, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ128rmkz, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ128rr, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ128rrk, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ128rrkz, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ256rm, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ256rmk, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ256rmkz, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ256rr, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ256rrk, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZ256rrkz, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZrm, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZrmk, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZrmkz, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZrr, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZrrk, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBZrrkz, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBrm, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBBrr, X86_INS_VPSUBB: vpsubb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDYrm, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDYrr, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rm, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rmb, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rmbk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rmbkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rmk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rmkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rr, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rrk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ128rrkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rm, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rmb, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rmbk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rmbkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rmk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rmkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rr, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rrk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZ256rrkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrm, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrmb, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrmbk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrmbkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrmk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrmkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrr, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrrk, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDZrrkz, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDrm, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBDrr, X86_INS_VPSUBD: vpsubd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQYrm, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQYrr, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rm, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rmb, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rmbk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rmbkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rmk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rmkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rr, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rrk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ128rrkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rm, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rmb, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rmbk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rmbkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rmk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rmkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rr, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rrk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZ256rrkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrm, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrmb, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrmbk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrmbkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrmk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrmkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrr, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrrk, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQZrrkz, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQrm, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBQrr, X86_INS_VPSUBQ: vpsubq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBYrm, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBYrr, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ128rm, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ128rmk, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ128rmkz, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ128rr, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ128rrk, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ128rrkz, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ256rm, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ256rmk, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ256rmkz, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ256rr, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ256rrk, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZ256rrkz, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZrm, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZrmk, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZrmkz, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZrr, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZrrk, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBZrrkz, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBrm, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSBrr, X86_INS_VPSUBSB: vpsubsb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWYrm, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWYrr, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ128rm, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ128rmk, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ128rmkz, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ128rr, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ128rrk, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ128rrkz, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ256rm, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ256rmk, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ256rmkz, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ256rr, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ256rrk, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZ256rrkz, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZrm, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZrmk, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZrmkz, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZrr, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZrrk, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWZrrkz, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWrm, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBSWrr, X86_INS_VPSUBSW: vpsubsw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBYrm, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBYrr, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ128rm, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ128rmk, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ128rmkz, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ128rr, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ128rrk, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ128rrkz, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ256rm, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ256rmk, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ256rmkz, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ256rr, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ256rrk, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZ256rrkz, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZrm, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZrmk, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZrmkz, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZrr, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZrrk, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBZrrkz, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBrm, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSBrr, X86_INS_VPSUBUSB: vpsubusb */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWYrm, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWYrr, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ128rm, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ128rmk, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ128rmkz, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ128rr, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ128rrk, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ128rrkz, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ256rm, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ256rmk, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ256rmkz, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ256rr, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ256rrk, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZ256rrkz, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZrm, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZrmk, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZrmkz, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZrr, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZrrk, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWZrrkz, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWrm, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBUSWrr, X86_INS_VPSUBUSW: vpsubusw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWYrm, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWYrr, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ128rm, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ128rmk, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ128rmkz, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ128rr, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ128rrk, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ128rrkz, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ256rm, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ256rmk, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ256rmkz, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ256rr, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ256rrk, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZ256rrkz, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZrm, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZrmk, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZrmkz, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZrr, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZrrk, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWZrrkz, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWrm, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPSUBWrr, X86_INS_VPSUBW: vpsubw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTERNLOGDZ128rmbi, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ128rmbik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ128rmbikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ128rmi, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ128rmik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ128rmikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ128rri, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ128rrik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ128rrikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rmbi, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rmbik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rmbikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rmi, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rmik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rmikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rri, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rrik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZ256rrikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrmbi, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrmbik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrmbikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrmi, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrmik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrmikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrri, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrrik, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGDZrrikz, X86_INS_VPTERNLOGD: vpternlogd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rmbi, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rmbik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rmbikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rmi, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rmik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rmikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rri, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rrik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ128rrikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rmbi, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rmbik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rmbikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rmi, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rmik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rmikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rri, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rrik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZ256rrikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrmbi, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrmbik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrmbikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrmi, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrmik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrmikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrri, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrrik, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTERNLOGQZrrikz, X86_INS_VPTERNLOGQ: vpternlogq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VPTESTMBZ128rm, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZ128rmk, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZ128rr, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZ128rrk, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZ256rm, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZ256rmk, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZ256rr, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZ256rrk, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZrm, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZrmk, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZrr, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMBZrrk, X86_INS_VPTESTMB: vptestmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ128rm, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ128rmb, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ128rmbk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ128rmk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ128rr, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ128rrk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ256rm, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ256rmb, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ256rmbk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ256rmk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ256rr, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZ256rrk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZrm, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZrmb, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZrmbk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZrmk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZrr, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMDZrrk, X86_INS_VPTESTMD: vptestmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ128rm, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ128rmb, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ128rmbk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ128rmk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ128rr, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ128rrk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ256rm, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ256rmb, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ256rmbk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ256rmk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ256rr, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZ256rrk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZrm, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZrmb, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZrmbk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZrmk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZrr, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMQZrrk, X86_INS_VPTESTMQ: vptestmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZ128rm, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZ128rmk, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZ128rr, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZ128rrk, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZ256rm, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZ256rmk, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZ256rr, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZ256rrk, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZrm, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZrmk, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZrr, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTMWZrrk, X86_INS_VPTESTMW: vptestmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZ128rm, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZ128rmk, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZ128rr, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZ128rrk, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZ256rm, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZ256rmk, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZ256rr, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZ256rrk, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZrm, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZrmk, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZrr, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMBZrrk, X86_INS_VPTESTNMB: vptestnmb */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ128rm, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ128rmb, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ128rmbk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ128rmk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ128rr, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ128rrk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ256rm, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ256rmb, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ256rmbk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ256rmk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ256rr, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZ256rrk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZrm, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZrmb, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZrmbk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZrmk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZrr, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMDZrrk, X86_INS_VPTESTNMD: vptestnmd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ128rm, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ128rmb, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ128rmbk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ128rmk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ128rr, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ128rrk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ256rm, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ256rmb, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ256rmbk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ256rmk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ256rr, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZ256rrk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZrm, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZrmb, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZrmbk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZrmk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZrr, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMQZrrk, X86_INS_VPTESTNMQ: vptestnmq */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZ128rm, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZ128rmk, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZ128rr, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZ128rrk, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZ256rm, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZ256rmk, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZ256rr, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZ256rrk, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZrm, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZrmk, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZrr, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTNMWZrrk, X86_INS_VPTESTNMW: vptestnmw */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTYrm, X86_INS_VPTEST: vptest */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTYrr, X86_INS_VPTEST: vptest */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTrm, X86_INS_VPTEST: vptest */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPTESTrr, X86_INS_VPTEST: vptest */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWYrm, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWYrr, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ128rm, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ128rmk, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ128rmkz, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ128rr, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ128rrk, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ128rrkz, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ256rm, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ256rmk, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ256rmkz, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ256rr, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ256rrk, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZ256rrkz, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZrm, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZrmk, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZrmkz, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZrr, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZrrk, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWZrrkz, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWrm, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHBWrr, X86_INS_VPUNPCKHBW: vpunpckhbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQYrm, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQYrr, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rm, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rmb, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rmbk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rmbkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rmk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rmkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rr, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rrk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ128rrkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rm, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rmb, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rmbk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rmbkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rmk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rmkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rr, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rrk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZ256rrkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrm, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrmb, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrmbk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrmbkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrmk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrmkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrr, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrrk, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQZrrkz, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQrm, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHDQrr, X86_INS_VPUNPCKHDQ: vpunpckhdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQYrm, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQYrr, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rm, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rmb, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rmbk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rmbkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rmk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rmkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rr, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rrk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ128rrkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rm, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rmb, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rmbk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rmbkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rmk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rmkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rr, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rrk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZ256rrkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrm, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrmb, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrmbk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrmbkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrmk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrmkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrr, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrrk, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQZrrkz, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQrm, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHQDQrr, X86_INS_VPUNPCKHQDQ: vpunpckhqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDYrm, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDYrr, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ128rm, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ128rmk, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ128rmkz, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ128rr, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ128rrk, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ128rrkz, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ256rm, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ256rmk, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ256rmkz, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ256rr, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ256rrk, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZ256rrkz, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZrm, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZrmk, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZrmkz, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZrr, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZrrk, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDZrrkz, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDrm, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKHWDrr, X86_INS_VPUNPCKHWD: vpunpckhwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWYrm, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWYrr, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ128rm, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ128rmk, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ128rmkz, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ128rr, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ128rrk, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ128rrkz, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ256rm, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ256rmk, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ256rmkz, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ256rr, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ256rrk, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZ256rrkz, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZrm, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZrmk, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZrmkz, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZrr, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZrrk, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWZrrkz, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWrm, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLBWrr, X86_INS_VPUNPCKLBW: vpunpcklbw */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQYrm, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQYrr, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rm, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rmb, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rmbk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rmbkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rmk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rmkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rr, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rrk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ128rrkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rm, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rmb, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rmbk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rmbkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rmk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rmkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rr, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rrk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZ256rrkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrm, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrmb, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrmbk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrmbkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrmk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrmkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrr, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrrk, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQZrrkz, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQrm, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLDQrr, X86_INS_VPUNPCKLDQ: vpunpckldq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQYrm, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQYrr, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rm, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rmb, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rmbk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rmbkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rmk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rmkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rr, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rrk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ128rrkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rm, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rmb, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rmbk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rmbkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rmk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rmkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rr, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rrk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZ256rrkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrm, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrmb, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrmbk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrmbkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrmk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrmkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrr, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrrk, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQZrrkz, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQrm, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLQDQrr, X86_INS_VPUNPCKLQDQ: vpunpcklqdq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDYrm, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDYrr, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ128rm, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ128rmk, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ128rmkz, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ128rr, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ128rrk, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ128rrkz, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ256rm, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ256rmk, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ256rmkz, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ256rr, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ256rrk, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZ256rrkz, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZrm, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZrmk, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZrmkz, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZrr, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZrrk, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDZrrkz, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDrm, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPUNPCKLWDrr, X86_INS_VPUNPCKLWD: vpunpcklwd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rm, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rmb, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rmbk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rmbkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rmk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rmkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rr, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rrk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ128rrkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rm, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rmb, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rmbk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rmbkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rmk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rmkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rr, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rrk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZ256rrkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrm, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrmb, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrmbk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrmbkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrmk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrmkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrr, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrrk, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORDZrrkz, X86_INS_VPXORD: vpxord */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rm, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rmb, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rmbk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rmbkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rmk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rmkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rr, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rrk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ128rrkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rm, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rmb, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rmbk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rmbkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rmk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rmkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rr, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rrk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZ256rrkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrm, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrmb, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrmbk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrmbkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrmk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrmkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrr, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrrk, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORQZrrkz, X86_INS_VPXORQ: vpxorq */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORYrm, X86_INS_VPXOR: vpxor */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORYrr, X86_INS_VPXOR: vpxor */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORrm, X86_INS_VPXOR: vpxor */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VPXORrr, X86_INS_VPXOR: vpxor */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRANGEPDZ128rmbi, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ128rmbik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ128rmbikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ128rmi, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ128rmik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ128rmikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ128rri, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ128rrik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ128rrikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rmbi, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rmbik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rmbikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rmi, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rmik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rmikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rri, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rrik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZ256rrikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrmbi, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrmbik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrmbikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrmi, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrmik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrmikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrri, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrrib, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrribk, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrribkz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrrik, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPDZrrikz, X86_INS_VRANGEPD: vrangepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rmbi, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rmbik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rmbikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rmi, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rmik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rmikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rri, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rrik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ128rrikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rmbi, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rmbik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rmbikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rmi, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rmik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rmikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rri, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rrik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZ256rrikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrmbi, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrmbik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrmbikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrmi, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrmik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrmikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrri, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrrib, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrribk, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrribkz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrrik, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGEPSZrrikz, X86_INS_VRANGEPS: vrangeps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrmi, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrmik, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrmikz, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrri, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrrib, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrribk, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrribkz, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrrik, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESDZrrikz, X86_INS_VRANGESD: vrangesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrmi, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrmik, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrmikz, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrri, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrrib, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrribk, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrribkz, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrrik, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRANGESSZrrikz, X86_INS_VRANGESS: vrangess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRCP14PDZ128m, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ128mb, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ128mbk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ128mbkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ128mk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ128mkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ128r, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ128rk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ128rkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256m, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256mb, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256mbk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256mbkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256mk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256mkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256r, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256rk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZ256rkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZm, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZmb, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZmbk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZmbkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZmk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZmkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZr, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZrk, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PDZrkz, X86_INS_VRCP14PD: vrcp14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128m, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128mb, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128mbk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128mbkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128mk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128mkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128r, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128rk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ128rkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256m, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256mb, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256mbk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256mbkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256mk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256mkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256r, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256rk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZ256rkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZm, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZmb, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZmbk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZmbkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZmk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZmkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZr, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZrk, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14PSZrkz, X86_INS_VRCP14PS: vrcp14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SDZrm, X86_INS_VRCP14SD: vrcp14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SDZrmk, X86_INS_VRCP14SD: vrcp14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SDZrmkz, X86_INS_VRCP14SD: vrcp14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SDZrr, X86_INS_VRCP14SD: vrcp14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SDZrrk, X86_INS_VRCP14SD: vrcp14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SDZrrkz, X86_INS_VRCP14SD: vrcp14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SSZrm, X86_INS_VRCP14SS: vrcp14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SSZrmk, X86_INS_VRCP14SS: vrcp14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SSZrmkz, X86_INS_VRCP14SS: vrcp14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SSZrr, X86_INS_VRCP14SS: vrcp14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SSZrrk, X86_INS_VRCP14SS: vrcp14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP14SSZrrkz, X86_INS_VRCP14SS: vrcp14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZm, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZmb, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZmbk, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZmbkz, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZmk, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZmkz, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZr, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZrb, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZrbk, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZrbkz, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZrk, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PDZrkz, X86_INS_VRCP28PD: vrcp28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZm, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZmb, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZmbk, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZmbkz, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZmk, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZmkz, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZr, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZrb, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZrbk, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZrbkz, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZrk, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28PSZrkz, X86_INS_VRCP28PS: vrcp28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZm, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZmk, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZmkz, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZr, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZrb, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZrbk, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZrbkz, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZrk, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SDZrkz, X86_INS_VRCP28SD: vrcp28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZm, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZmk, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZmkz, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZr, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZrb, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZrbk, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZrbkz, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZrk, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCP28SSZrkz, X86_INS_VRCP28SS: vrcp28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCPPSYm, X86_INS_VRCPPS: vrcpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCPPSYr, X86_INS_VRCPPS: vrcpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCPPSm, X86_INS_VRCPPS: vrcpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCPPSr, X86_INS_VRCPPS: vrcpps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRCPSSm, X86_INS_VRCPSS: vrcpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCPSSm_Int, X86_INS_VRCPSS: vrcpss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRCPSSr, X86_INS_VRCPSS: vrcpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRCPSSr_Int, X86_INS_VRCPSS: vrcpss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VREDUCEPDZ128rmbi, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ128rmbik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ128rmbikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ128rmi, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ128rmik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ128rmikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ128rri, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ128rrik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ128rrikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rmbi, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rmbik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rmbikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rmi, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rmik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rmikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rri, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rrik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZ256rrikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrmbi, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrmbik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrmbikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrmi, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrmik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrmikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrri, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrrib, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrribk, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrribkz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrrik, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPDZrrikz, X86_INS_VREDUCEPD: vreducepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rmbi, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rmbik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rmbikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rmi, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rmik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rmikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rri, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rrik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ128rrikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rmbi, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rmbik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rmbikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rmi, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rmik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rmikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rri, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rrik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZ256rrikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrmbi, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrmbik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrmbikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrmi, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrmik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrmikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrri, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrrib, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrribk, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrribkz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrrik, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCEPSZrrikz, X86_INS_VREDUCEPS: vreduceps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrmi, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrmik, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrmikz, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrri, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrrib, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrribk, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrribkz, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrrik, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESDZrrikz, X86_INS_VREDUCESD: vreducesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrmi, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrmik, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrmikz, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrri, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrrib, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrribk, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrribkz, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrrik, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VREDUCESSZrrikz, X86_INS_VREDUCESS: vreducess */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rmbi, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rmbik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rmbikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rmi, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rmik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rmikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rri, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rrik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ128rrikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rmbi, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rmbik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rmbikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rmi, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rmik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rmikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rri, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rrik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZ256rrikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrmbi, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrmbik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrmbikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrmi, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrmik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrmikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrri, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrrib, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrribk, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrribkz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrrik, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPDZrrikz, X86_INS_VRNDSCALEPD: vrndscalepd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rmbi, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rmbik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rmbikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rmi, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rmik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rmikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rri, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rrik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ128rrikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rmbi, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rmbik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rmbikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rmi, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rmik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rmikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rri, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rrik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZ256rrikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrmbi, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrmbik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrmbikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrmi, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrmik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrmikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrri, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrrib, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrribk, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrribkz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrrik, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALEPSZrrikz, X86_INS_VRNDSCALEPS: vrndscaleps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRNDSCALESDZm, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZm_Int, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZm_Intk, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZm_Intkz, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZr, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZr_Int, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZr_Intk, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZr_Intkz, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZrb_Int, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZrb_Intk, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESDZrb_Intkz, X86_INS_VRNDSCALESD: vrndscalesd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZm, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZm_Int, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZm_Intk, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZm_Intkz, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZr, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZr_Int, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZr_Intk, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZr_Intkz, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZrb_Int, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZrb_Intk, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRNDSCALESSZrb_Intkz, X86_INS_VRNDSCALESS: vrndscaless */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VROUNDPDYm, X86_INS_VROUNDPD: vroundpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VROUNDPDYr, X86_INS_VROUNDPD: vroundpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VROUNDPDm, X86_INS_VROUNDPD: vroundpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDPDr, X86_INS_VROUNDPD: vroundpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDPSYm, X86_INS_VROUNDPS: vroundps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VROUNDPSYr, X86_INS_VROUNDPS: vroundps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VROUNDPSm, X86_INS_VROUNDPS: vroundps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDPSr, X86_INS_VROUNDPS: vroundps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDSDm, X86_INS_VROUNDSD: vroundsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDSDm_Int, X86_INS_VROUNDSD: vroundsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VROUNDSDr, X86_INS_VROUNDSD: vroundsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDSDr_Int, X86_INS_VROUNDSD: vroundsd	$dst $src1 $src2 $src3 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDSSm, X86_INS_VROUNDSS: vroundss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDSSm_Int, X86_INS_VROUNDSS: vroundss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VROUNDSSr, X86_INS_VROUNDSS: vroundss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VROUNDSSr_Int, X86_INS_VROUNDSS: vroundss	$dst $src1 $src2 $src3 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRSQRT14PDZ128m, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ128mb, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ128mbk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ128mbkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ128mk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ128mkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ128r, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ128rk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ128rkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256m, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256mb, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256mbk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256mbkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256mk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256mkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256r, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256rk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZ256rkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZm, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZmb, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZmbk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZmbkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZmk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZmkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZr, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZrk, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PDZrkz, X86_INS_VRSQRT14PD: vrsqrt14pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128m, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128mb, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128mbk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128mbkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128mk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128mkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128r, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128rk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ128rkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256m, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256mb, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256mbk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256mbkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256mk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256mkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256r, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256rk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZ256rkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZm, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZmb, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZmbk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZmbkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZmk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZmkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZr, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZrk, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14PSZrkz, X86_INS_VRSQRT14PS: vrsqrt14ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SDZrm, X86_INS_VRSQRT14SD: vrsqrt14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SDZrmk, X86_INS_VRSQRT14SD: vrsqrt14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SDZrmkz, X86_INS_VRSQRT14SD: vrsqrt14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SDZrr, X86_INS_VRSQRT14SD: vrsqrt14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SDZrrk, X86_INS_VRSQRT14SD: vrsqrt14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SDZrrkz, X86_INS_VRSQRT14SD: vrsqrt14sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SSZrm, X86_INS_VRSQRT14SS: vrsqrt14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SSZrmk, X86_INS_VRSQRT14SS: vrsqrt14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SSZrmkz, X86_INS_VRSQRT14SS: vrsqrt14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SSZrr, X86_INS_VRSQRT14SS: vrsqrt14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SSZrrk, X86_INS_VRSQRT14SS: vrsqrt14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT14SSZrrkz, X86_INS_VRSQRT14SS: vrsqrt14ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZm, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZmb, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZmbk, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZmbkz, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZmk, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZmkz, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZr, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZrb, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZrbk, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZrbkz, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZrk, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PDZrkz, X86_INS_VRSQRT28PD: vrsqrt28pd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZm, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZmb, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZmbk, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZmbkz, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZmk, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZmkz, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZr, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZrb, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZrbk, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZrbkz, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZrk, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28PSZrkz, X86_INS_VRSQRT28PS: vrsqrt28ps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZm, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZmk, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZmkz, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZr, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZrb, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZrbk, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZrbkz, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZrk, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SDZrkz, X86_INS_VRSQRT28SD: vrsqrt28sd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZm, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZmk, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZmkz, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZr, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZrb, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZrbk, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZrbkz, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZrk, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRT28SSZrkz, X86_INS_VRSQRT28SS: vrsqrt28ss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRTPSYm, X86_INS_VRSQRTPS: vrsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRTPSYr, X86_INS_VRSQRTPS: vrsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRTPSm, X86_INS_VRSQRTPS: vrsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRTPSr, X86_INS_VRSQRTPS: vrsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VRSQRTSSm, X86_INS_VRSQRTSS: vrsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRTSSm_Int, X86_INS_VRSQRTSS: vrsqrtss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VRSQRTSSr, X86_INS_VRSQRTSS: vrsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VRSQRTSSr_Int, X86_INS_VRSQRTSS: vrsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rm, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rmb, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rmbk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rmbkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rmk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rmkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rr, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rrk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ128rrkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rm, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rmb, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rmbk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rmbkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rmk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rmkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rr, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rrk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZ256rrkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrm, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrmb, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrmbk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrmbkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrmk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrmkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrr, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrrb, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrrbk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrrbkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrrk, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPDZrrkz, X86_INS_VSCALEFPD: vscalefpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rm, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rmb, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rmbk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rmbkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rmk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rmkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rr, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rrk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ128rrkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rm, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rmb, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rmbk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rmbkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rmk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rmkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rr, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rrk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZ256rrkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrm, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrmb, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrmbk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrmbkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrmk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrmkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrr, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrrb, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrrbk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrrbkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrrk, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFPSZrrkz, X86_INS_VSCALEFPS: vscalefps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrm, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrmk, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrmkz, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrr, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrrb_Int, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrrb_Intk, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrrb_Intkz, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrrk, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSDZrrkz, X86_INS_VSCALEFSD: vscalefsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrm, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrmk, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrmkz, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrr, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrrb_Int, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrrb_Intk, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrrb_Intkz, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrrk, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCALEFSSZrrkz, X86_INS_VSCALEFSS: vscalefss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERDPDZ128mr, X86_INS_VSCATTERDPD: vscatterdpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERDPDZ256mr, X86_INS_VSCATTERDPD: vscatterdpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERDPDZmr, X86_INS_VSCATTERDPD: vscatterdpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERDPSZ128mr, X86_INS_VSCATTERDPS: vscatterdps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERDPSZ256mr, X86_INS_VSCATTERDPS: vscatterdps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERDPSZmr, X86_INS_VSCATTERDPS: vscatterdps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERPF0DPDm, X86_INS_VSCATTERPF0DPD: vscatterpf0dpd */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSCATTERPF0DPSm, X86_INS_VSCATTERPF0DPS: vscatterpf0dps */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSCATTERPF0QPDm, X86_INS_VSCATTERPF0QPD: vscatterpf0qpd */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSCATTERPF0QPSm, X86_INS_VSCATTERPF0QPS: vscatterpf0qps */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSCATTERPF1DPDm, X86_INS_VSCATTERPF1DPD: vscatterpf1dpd */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSCATTERPF1DPSm, X86_INS_VSCATTERPF1DPS: vscatterpf1dps */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSCATTERPF1QPDm, X86_INS_VSCATTERPF1QPD: vscatterpf1qpd */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSCATTERPF1QPSm, X86_INS_VSCATTERPF1QPS: vscatterpf1qps */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSCATTERQPDZ128mr, X86_INS_VSCATTERQPD: vscatterqpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERQPDZ256mr, X86_INS_VSCATTERQPD: vscatterqpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERQPDZmr, X86_INS_VSCATTERQPD: vscatterqpd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERQPSZ128mr, X86_INS_VSCATTERQPS: vscatterqps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERQPSZ256mr, X86_INS_VSCATTERQPS: vscatterqps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSCATTERQPSZmr, X86_INS_VSCATTERQPS: vscatterqps */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSHUFF32X4Z256rmbi, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Z256rmbik, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Z256rmbikz, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Z256rmi, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Z256rmik, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Z256rmikz, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Z256rri, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Z256rrik, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Z256rrikz, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrmbi, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrmbik, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrmbikz, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrmi, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrmik, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrmikz, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrri, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrrik, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF32X4Zrrikz, X86_INS_VSHUFF32X4: vshuff32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rmbi, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rmbik, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rmbikz, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rmi, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rmik, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rmikz, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rri, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rrik, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Z256rrikz, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrmbi, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrmbik, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrmbikz, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrmi, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrmik, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrmikz, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrri, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrrik, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFF64X2Zrrikz, X86_INS_VSHUFF64X2: vshuff64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rmbi, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rmbik, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rmbikz, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rmi, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rmik, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rmikz, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rri, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rrik, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Z256rrikz, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrmbi, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrmbik, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrmbikz, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrmi, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrmik, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrmikz, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrri, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrrik, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI32X4Zrrikz, X86_INS_VSHUFI32X4: vshufi32x4 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rmbi, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rmbik, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rmbikz, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rmi, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rmik, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rmikz, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rri, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rrik, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Z256rrikz, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrmbi, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrmbik, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrmbikz, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrmi, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrmik, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrmikz, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrri, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrrik, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFI64X2Zrrikz, X86_INS_VSHUFI64X2: vshufi64x2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDYrmi, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDYrri, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rmbi, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rmbik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rmbikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rmi, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rmik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rmikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rri, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rrik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ128rrikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rmbi, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rmbik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rmbikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rmi, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rmik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rmikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rri, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rrik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZ256rrikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrmbi, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrmbik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrmbikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrmi, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrmik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrmikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrri, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrrik, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDZrrikz, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDrmi, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPDrri, X86_INS_VSHUFPD: vshufpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSYrmi, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSYrri, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rmbi, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rmbik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rmbikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rmi, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rmik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rmikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rri, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rrik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ128rrikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rmbi, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rmbik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rmbikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rmi, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rmik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rmikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rri, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rrik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZ256rrikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrmbi, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrmbik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrmbikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrmi, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrmik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrmikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrri, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrrik, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSZrrikz, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSrmi, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSHUFPSrri, X86_INS_VSHUFPS: vshufps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSQRTPDYm, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDYr, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128m, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128mb, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128mbk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128mbkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128mk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128mkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128r, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128rk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ128rkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256m, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256mb, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256mbk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256mbkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256mk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256mkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256r, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256rk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZ256rkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZm, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZmb, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZmbk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZmbkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZmk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZmkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZr, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZrb, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZrbk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZrbkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZrk, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDZrkz, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDm, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPDr, X86_INS_VSQRTPD: vsqrtpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSYm, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSYr, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128m, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128mb, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128mbk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128mbkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128mk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128mkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128r, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128rk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ128rkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256m, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256mb, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256mbk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256mbkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256mk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256mkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256r, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256rk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZ256rkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZm, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZmb, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZmbk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZmbkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZmk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZmkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZr, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZrb, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZrbk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZrbkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZrk, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSZrkz, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSm, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTPSr, X86_INS_VSQRTPS: vsqrtps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZm, X86_INS_VSQRTSD: vsqrtsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZm_Int, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSQRTSDZm_Intk, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZm_Intkz, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZr, X86_INS_VSQRTSD: vsqrtsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZr_Int, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZr_Intk, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZr_Intkz, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZrb_Int, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZrb_Intk, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDZrb_Intkz, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDm, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDm_Int, X86_INS_VSQRTSD: vsqrtsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSQRTSDr, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSDr_Int, X86_INS_VSQRTSD: vsqrtsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZm, X86_INS_VSQRTSS: vsqrtss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZm_Int, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSQRTSSZm_Intk, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZm_Intkz, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZr, X86_INS_VSQRTSS: vsqrtss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZr_Int, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZr_Intk, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZr_Intkz, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZrb_Int, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZrb_Intk, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSZrb_Intkz, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSm, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSm_Int, X86_INS_VSQRTSS: vsqrtss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSQRTSSr, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSQRTSSr_Int, X86_INS_VSQRTSS: vsqrtss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSTMXCSR, X86_INS_VSTMXCSR: vstmxcsr */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_VSUBPDYrm, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDYrr, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rm, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rmb, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rmbk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rmbkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rmk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rmkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rr, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rrk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ128rrkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rm, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rmb, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rmbk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rmbkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rmk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rmkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rr, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rrk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZ256rrkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrm, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrmb, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrmbk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrmbkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrmk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrmkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrr, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrrb, X86_INS_VSUBPD: vsubpd */
	0,
	{ 0 }
},

{	/* X86_VSUBPDZrrbk, X86_INS_VSUBPD: vsubpd */
	0,
	{ 0 }
},

{	/* X86_VSUBPDZrrbkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ 0 }
},

{	/* X86_VSUBPDZrrk, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDZrrkz, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDrm, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPDrr, X86_INS_VSUBPD: vsubpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSYrm, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSYrr, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rm, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rmb, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rmbk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rmbkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rmk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rmkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rr, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rrk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ128rrkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rm, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rmb, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rmbk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rmbkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rmk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rmkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rr, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rrk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZ256rrkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrm, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrmb, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrmbk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrmbkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrmk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrmkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrr, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrrb, X86_INS_VSUBPS: vsubps */
	0,
	{ 0 }
},

{	/* X86_VSUBPSZrrbk, X86_INS_VSUBPS: vsubps */
	0,
	{ 0 }
},

{	/* X86_VSUBPSZrrbkz, X86_INS_VSUBPS: vsubps */
	0,
	{ 0 }
},

{	/* X86_VSUBPSZrrk, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSZrrkz, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSrm, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBPSrr, X86_INS_VSUBPS: vsubps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrm, X86_INS_VSUBSD: vsubsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrm_Int, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrm_Intk, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrm_Intkz, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrr, X86_INS_VSUBSD: vsubsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrr_Int, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrr_Intk, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrr_Intkz, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrrb_Int, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrrb_Intk, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDZrrb_Intkz, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDrm, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDrm_Int, X86_INS_VSUBSD: vsubsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSUBSDrr, X86_INS_VSUBSD: vsubsd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSDrr_Int, X86_INS_VSUBSD: vsubsd	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrm, X86_INS_VSUBSS: vsubss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrm_Int, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrm_Intk, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrm_Intkz, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrr, X86_INS_VSUBSS: vsubss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrr_Int, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrr_Intk, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrr_Intkz, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrrb_Int, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrrb_Intk, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSZrrb_Intkz, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSrm, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSrm_Int, X86_INS_VSUBSS: vsubss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_IGNORE, 0 }
},

{	/* X86_VSUBSSrr, X86_INS_VSUBSS: vsubss */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VSUBSSrr_Int, X86_INS_VSUBSS: vsubss	$dst $src1 $src2 */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VTESTPDYrm, X86_INS_VTESTPD: vtestpd */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VTESTPDYrr, X86_INS_VTESTPD: vtestpd */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VTESTPDrm, X86_INS_VTESTPD: vtestpd */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VTESTPDrr, X86_INS_VTESTPD: vtestpd */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VTESTPSYrm, X86_INS_VTESTPS: vtestps */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VTESTPSYrr, X86_INS_VTESTPS: vtestps */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VTESTPSrm, X86_INS_VTESTPS: vtestps */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VTESTPSrr, X86_INS_VTESTPS: vtestps */
	X86_EFLAGS_RESET_0F | X86_EFLAGS_RESET_AF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDZrm, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDZrm_Int, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDZrr, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDZrr_Int, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDZrrb, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDrm, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDrm_Int, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDrr, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISDrr_Int, X86_INS_VUCOMISD: vucomisd */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSZrm, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSZrm_Int, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSZrr, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSZrr_Int, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSZrrb, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSrm, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSrm_Int, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSrr, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUCOMISSrr_Int, X86_INS_VUCOMISS: vucomiss */
	0,
	{ CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDYrm, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDYrr, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rm, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rmb, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rmbk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rmbkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rmk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rmkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rr, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rrk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ128rrkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rm, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rmb, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rmbk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rmbkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rmk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rmkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rr, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rrk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZ256rrkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrm, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrmb, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrmbk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrmbkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrmk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrmkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrr, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrrk, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDZrrkz, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDrm, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPDrr, X86_INS_VUNPCKHPD: vunpckhpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSYrm, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSYrr, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rm, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rmb, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rmbk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rmbkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rmk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rmkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rr, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rrk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ128rrkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rm, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rmb, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rmbk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rmbkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rmk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rmkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rr, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rrk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZ256rrkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrm, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrmb, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrmbk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrmbkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrmk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrmkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrr, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrrk, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSZrrkz, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSrm, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKHPSrr, X86_INS_VUNPCKHPS: vunpckhps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDYrm, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDYrr, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rm, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rmb, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rmbk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rmbkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rmk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rmkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rr, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rrk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ128rrkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rm, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rmb, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rmbk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rmbkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rmk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rmkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rr, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rrk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZ256rrkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrm, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrmb, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrmbk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrmbkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrmk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrmkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrr, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrrk, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDZrrkz, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDrm, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPDrr, X86_INS_VUNPCKLPD: vunpcklpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSYrm, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSYrr, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rm, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rmb, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rmbk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rmbkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rmk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rmkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rr, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rrk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ128rrkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rm, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rmb, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rmbk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rmbkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rmk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rmkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rr, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rrk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZ256rrkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrm, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrmb, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrmbk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrmbkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrmk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrmkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrr, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrrk, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSZrrkz, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSrm, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VUNPCKLPSrr, X86_INS_VUNPCKLPS: vunpcklps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDYrm, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDYrr, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rm, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rmb, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rmbk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rmbkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rmk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rmkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rr, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rrk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ128rrkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rm, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rmb, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rmbk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rmbkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rmk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rmkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rr, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rrk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZ256rrkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrm, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrmb, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrmbk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrmbkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrmk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrmkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrr, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrrk, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDZrrkz, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDrm, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPDrr, X86_INS_VXORPD: vxorpd */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSYrm, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSYrr, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rm, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rmb, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rmbk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rmbkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rmk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rmkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rr, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rrk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ128rrkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rm, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rmb, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rmbk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rmbkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rmk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rmkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rr, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rrk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZ256rrkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrm, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrmb, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrmbk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrmbkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrmk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrmkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrr, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrrk, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSZrrkz, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSrm, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VXORPSrr, X86_INS_VXORPS: vxorps */
	0,
	{ CS_AC_WRITE, CS_AC_READ, CS_AC_READ, 0 }
},

{	/* X86_VZEROALL, X86_INS_VZEROALL: vzeroall */
	0,
	{ 0 }
},

{	/* X86_VZEROUPPER, X86_INS_VZEROUPPER: vzeroupper */
	0,
	{ 0 }
},

{	/* X86_WAIT, X86_INS_WAIT: wait */
	X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C1 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ 0 }
},

{	/* X86_WBINVD, X86_INS_WBINVD: wbinvd */
	0,
	{ 0 }
},

{	/* X86_WBNOINVD, X86_INS_WBNOINVD: wbnoinvd */
	0,
	{ 0 }
},

{	/* X86_WRFSBASE, X86_INS_WRFSBASE: wrfsbase */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_WRFSBASE64, X86_INS_WRFSBASE: wrfsbase */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_WRGSBASE, X86_INS_WRGSBASE: wrgsbase */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_WRGSBASE64, X86_INS_WRGSBASE: wrgsbase */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_WRMSR, X86_INS_WRMSR: wrmsr */
	0,
	{ 0 }
},

{	/* X86_WRPKRUr, X86_INS_WRPKRU: wrpkru */
	0,
	{ 0 }
},

{	/* X86_WRSSD, X86_INS_WRSSD: wrssd */
	0,
	{ 0 }
},

{	/* X86_WRSSQ, X86_INS_WRSSQ: wrssq */
	0,
	{ 0 }
},

{	/* X86_WRUSSD, X86_INS_WRUSSD: wrussd */
	0,
	{ 0 }
},

{	/* X86_WRUSSQ, X86_INS_WRUSSQ: wrussq */
	0,
	{ 0 }
},

{	/* X86_XABORT, X86_INS_XABORT: xabort */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_XACQUIRE_PREFIX, X86_INS_XACQUIRE: xacquire */
	0,
	{ 0 }
},

{	/* X86_XADD16rm, X86_INS_XADD: xadd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XADD16rr, X86_INS_XADD: xadd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XADD32rm, X86_INS_XADD: xadd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XADD32rr, X86_INS_XADD: xadd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XADD64rm, X86_INS_XADD: xadd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XADD64rr, X86_INS_XADD: xadd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XADD8rm, X86_INS_XADD: xadd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XADD8rr, X86_INS_XADD: xadd */
	X86_EFLAGS_MODIFY_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_MODIFY_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_MODIFY_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XBEGIN_2, X86_INS_XBEGIN: xbegin */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_XBEGIN_4, X86_INS_XBEGIN: xbegin */
	0,
	{ CS_AC_IGNORE, 0 }
},

{	/* X86_XCHG16ar, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG16rm, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG16rr, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG32ar, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG32rm, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG32rr, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG64ar, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG64rm, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG64rr, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG8rm, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCHG8rr, X86_INS_XCHG: xchg */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, 0 }
},

{	/* X86_XCH_F, X86_INS_FXCH: fxch */
	X86_FPU_FLAGS_RESET_C1 | X86_FPU_FLAGS_UNDEFINED_C0 | X86_FPU_FLAGS_UNDEFINED_C2 | X86_FPU_FLAGS_UNDEFINED_C3,
	{ CS_AC_READ, 0 }
},

{	/* X86_XCRYPTCBC, X86_INS_XCRYPTCBC: xcryptcbc */
	0,
	{ 0 }
},

{	/* X86_XCRYPTCFB, X86_INS_XCRYPTCFB: xcryptcfb */
	0,
	{ 0 }
},

{	/* X86_XCRYPTCTR, X86_INS_XCRYPTCTR: xcryptctr */
	0,
	{ 0 }
},

{	/* X86_XCRYPTECB, X86_INS_XCRYPTECB: xcryptecb */
	0,
	{ 0 }
},

{	/* X86_XCRYPTOFB, X86_INS_XCRYPTOFB: xcryptofb */
	0,
	{ 0 }
},

{	/* X86_XEND, X86_INS_XEND: xend */
	0,
	{ 0 }
},

{	/* X86_XGETBV, X86_INS_XGETBV: xgetbv */
	0,
	{ 0 }
},

{	/* X86_XLAT, X86_INS_XLATB: xlatb */
	0,
	{ 0 }
},

{	/* X86_XOR16i16, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR16mi, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR16mi8, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR16mr, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR16ri, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR16ri8, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR16rm, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR16rr, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR16rr_REV, X86_INS_XOR: xor{w}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR32i32, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR32mi, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR32mi8, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR32mr, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR32ri, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR32ri8, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR32rm, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR32rr, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR32rr_REV, X86_INS_XOR: xor{l}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR64i32, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR64mi32, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR64mi8, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR64mr, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR64ri32, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR64ri8, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR64rm, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR64rr, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR64rr_REV, X86_INS_XOR: xor{q}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR8i8, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR8mi, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR8mi8, X86_INS_XOR: xor{b}	$dst $src */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR8mr, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR8ri, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR8ri8, X86_INS_XOR: xor{b}	$src1 $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_IGNORE, 0 }
},

{	/* X86_XOR8rm, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR8rr, X86_INS_XOR: xor */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XOR8rr_REV, X86_INS_XOR: xor{b}	$dst $src2 */
	X86_EFLAGS_RESET_OF | X86_EFLAGS_MODIFY_SF | X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_UNDEFINED_AF | X86_EFLAGS_MODIFY_PF | X86_EFLAGS_RESET_CF,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XORPDrm, X86_INS_XORPD: xorpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XORPDrr, X86_INS_XORPD: xorpd */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XORPSrm, X86_INS_XORPS: xorps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XORPSrr, X86_INS_XORPS: xorps */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XRELEASE_PREFIX, X86_INS_XRELEASE: xrelease */
	0,
	{ 0 }
},

{	/* X86_XRSTOR, X86_INS_XRSTOR: xrstor */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_XRSTOR64, X86_INS_XRSTOR64: xrstor64 */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_XRSTORS, X86_INS_XRSTORS: xrstors */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_XRSTORS64, X86_INS_XRSTORS64: xrstors64 */
	0,
	{ CS_AC_READ, 0 }
},

{	/* X86_XSAVE, X86_INS_XSAVE: xsave */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_XSAVE64, X86_INS_XSAVE64: xsave64 */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_XSAVEC, X86_INS_XSAVEC: xsavec */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_XSAVEC64, X86_INS_XSAVEC64: xsavec64 */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_XSAVEOPT, X86_INS_XSAVEOPT: xsaveopt */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_XSAVEOPT64, X86_INS_XSAVEOPT64: xsaveopt64 */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_XSAVES, X86_INS_XSAVES: xsaves */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_XSAVES64, X86_INS_XSAVES64: xsaves64 */
	0,
	{ CS_AC_WRITE, 0 }
},

{	/* X86_XSETBV, X86_INS_XSETBV: xsetbv */
	0,
	{ 0 }
},

{	/* X86_XSHA1, X86_INS_XSHA1: xsha1 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XSHA256, X86_INS_XSHA256: xsha256 */
	0,
	{ CS_AC_READ | CS_AC_WRITE, CS_AC_READ | CS_AC_WRITE, CS_AC_WRITE, CS_AC_READ, 0 }
},

{	/* X86_XSTORE, X86_INS_XSTORE: xstore */
	0,
	{ 0 }
},

{	/* X86_XTEST, X86_INS_XTEST: xtest */
	X86_EFLAGS_MODIFY_ZF | X86_EFLAGS_RESET_CF | X86_EFLAGS_RESET_OF | X86_EFLAGS_RESET_SF | X86_EFLAGS_RESET_PF | X86_EFLAGS_RESET_AF,
	{ 0 }
},

