/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2022, */
/*    Rot127 <unisono@quyllur.org> 2022-2023 */
/* Automatically generated file by Capstone's LLVM TableGen Disassembler Backend. */

/* LLVM-commit: <commit> */
/* LLVM-tag: <tag> */

/* Do not edit. */

/* Capstone's LLVM TableGen Backends: */
/* https://github.com/capstone-engine/llvm-capstone */

{
  /* PHINODE */
  TRICORE_PHI /* 0 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_INLINEASM /* 1 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_INLINEASM_BR /* 2 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_CFI_INSTRUCTION /* 3 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_EH_LABEL /* 4 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_GC_LABEL /* 5 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_ANNOTATION_LABEL /* 6 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_KILL /* 7 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_EXTRACT_SUBREG /* 8 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_INSERT_SUBREG /* 9 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_IMPLICIT_DEF /* 10 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_SUBREG_TO_REG /* 11 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_COPY_TO_REGCLASS /* 12 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* DBG_VALUE */
  TRICORE_DBG_VALUE /* 13 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* DBG_VALUE_LIST */
  TRICORE_DBG_VALUE_LIST /* 14 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* DBG_INSTR_REF */
  TRICORE_DBG_INSTR_REF /* 15 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* DBG_PHI */
  TRICORE_DBG_PHI /* 16 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* DBG_LABEL */
  TRICORE_DBG_LABEL /* 17 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_REG_SEQUENCE /* 18 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_COPY /* 19 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* BUNDLE */
  TRICORE_BUNDLE /* 20 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* LIFETIME_START */
  TRICORE_LIFETIME_START /* 21 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* LIFETIME_END */
  TRICORE_LIFETIME_END /* 22 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* PSEUDO_PROBE */
  TRICORE_PSEUDO_PROBE /* 23 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_ARITH_FENCE /* 24 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_STACKMAP /* 25 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* # FEntry call */
  TRICORE_FENTRY_CALL /* 26 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_PATCHPOINT /* 27 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_LOAD_STACK_GUARD /* 28 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_PREALLOCATED_SETUP /* 29 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_PREALLOCATED_ARG /* 30 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_STATEPOINT /* 31 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_LOCAL_ESCAPE /* 32 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_FAULTING_OP /* 33 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_PATCHABLE_OP /* 34 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* # XRay Function Enter. */
  TRICORE_PATCHABLE_FUNCTION_ENTER /* 35 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* # XRay Function Patchable RET. */
  TRICORE_PATCHABLE_RET /* 36 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* # XRay Function Exit. */
  TRICORE_PATCHABLE_FUNCTION_EXIT /* 37 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* # XRay Tail Call Exit. */
  TRICORE_PATCHABLE_TAIL_CALL /* 38 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* # XRay Custom Event Log. */
  TRICORE_PATCHABLE_EVENT_CALL /* 39 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* # XRay Typed Event Log. */
  TRICORE_PATCHABLE_TYPED_EVENT_CALL /* 40 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_ICALL_BRANCH_FUNNEL /* 41 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_MEMBARRIER /* 42 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ASSERT_SEXT /* 43 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ASSERT_ZEXT /* 44 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ASSERT_ALIGN /* 45 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ADD /* 46 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SUB /* 47 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_MUL /* 48 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SDIV /* 49 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UDIV /* 50 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SREM /* 51 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UREM /* 52 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SDIVREM /* 53 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UDIVREM /* 54 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_AND /* 55 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_OR /* 56 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_XOR /* 57 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_IMPLICIT_DEF /* 58 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_PHI /* 59 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FRAME_INDEX /* 60 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_GLOBAL_VALUE /* 61 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_EXTRACT /* 62 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UNMERGE_VALUES /* 63 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INSERT /* 64 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_MERGE_VALUES /* 65 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BUILD_VECTOR /* 66 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BUILD_VECTOR_TRUNC /* 67 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_CONCAT_VECTORS /* 68 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_PTRTOINT /* 69 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INTTOPTR /* 70 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BITCAST /* 71 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FREEZE /* 72 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INTRINSIC_FPTRUNC_ROUND /* 73 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INTRINSIC_TRUNC /* 74 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INTRINSIC_ROUND /* 75 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INTRINSIC_LRINT /* 76 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INTRINSIC_ROUNDEVEN /* 77 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_READCYCLECOUNTER /* 78 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_LOAD /* 79 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SEXTLOAD /* 80 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ZEXTLOAD /* 81 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INDEXED_LOAD /* 82 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INDEXED_SEXTLOAD /* 83 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INDEXED_ZEXTLOAD /* 84 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_STORE /* 85 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INDEXED_STORE /* 86 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMIC_CMPXCHG_WITH_SUCCESS /* 87 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMIC_CMPXCHG /* 88 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_XCHG /* 89 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_ADD /* 90 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_SUB /* 91 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_AND /* 92 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_NAND /* 93 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_OR /* 94 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_XOR /* 95 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_MAX /* 96 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_MIN /* 97 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_UMAX /* 98 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_UMIN /* 99 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_FADD /* 100 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_FSUB /* 101 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_FMAX /* 102 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_FMIN /* 103 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_UINC_WRAP /* 104 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ATOMICRMW_UDEC_WRAP /* 105 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FENCE /* 106 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BRCOND /* 107 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BRINDIRECT /* 108 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INVOKE_REGION_START /* 109 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INTRINSIC /* 110 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INTRINSIC_W_SIDE_EFFECTS /* 111 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ANYEXT /* 112 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_TRUNC /* 113 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_CONSTANT /* 114 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FCONSTANT /* 115 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VASTART /* 116 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VAARG /* 117 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SEXT /* 118 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SEXT_INREG /* 119 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ZEXT /* 120 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SHL /* 121 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_LSHR /* 122 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ASHR /* 123 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FSHL /* 124 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FSHR /* 125 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ROTR /* 126 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ROTL /* 127 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ICMP /* 128 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FCMP /* 129 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SELECT /* 130 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UADDO /* 131 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UADDE /* 132 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_USUBO /* 133 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_USUBE /* 134 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SADDO /* 135 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SADDE /* 136 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SSUBO /* 137 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SSUBE /* 138 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UMULO /* 139 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SMULO /* 140 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UMULH /* 141 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SMULH /* 142 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UADDSAT /* 143 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SADDSAT /* 144 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_USUBSAT /* 145 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SSUBSAT /* 146 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_USHLSAT /* 147 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SSHLSAT /* 148 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SMULFIX /* 149 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UMULFIX /* 150 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SMULFIXSAT /* 151 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UMULFIXSAT /* 152 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SDIVFIX /* 153 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UDIVFIX /* 154 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SDIVFIXSAT /* 155 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UDIVFIXSAT /* 156 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FADD /* 157 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FSUB /* 158 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMUL /* 159 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMA /* 160 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMAD /* 161 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FDIV /* 162 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FREM /* 163 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FPOW /* 164 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FPOWI /* 165 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FEXP /* 166 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FEXP2 /* 167 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FLOG /* 168 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FLOG2 /* 169 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FLOG10 /* 170 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FNEG /* 171 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FPEXT /* 172 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FPTRUNC /* 173 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FPTOSI /* 174 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FPTOUI /* 175 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SITOFP /* 176 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UITOFP /* 177 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FABS /* 178 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FCOPYSIGN /* 179 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_IS_FPCLASS /* 180 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FCANONICALIZE /* 181 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMINNUM /* 182 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMAXNUM /* 183 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMINNUM_IEEE /* 184 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMAXNUM_IEEE /* 185 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMINIMUM /* 186 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FMAXIMUM /* 187 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_PTR_ADD /* 188 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_PTRMASK /* 189 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SMIN /* 190 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SMAX /* 191 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UMIN /* 192 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UMAX /* 193 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ABS /* 194 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_LROUND /* 195 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_LLROUND /* 196 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BR /* 197 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BRJT /* 198 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_INSERT_VECTOR_ELT /* 199 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_EXTRACT_VECTOR_ELT /* 200 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SHUFFLE_VECTOR /* 201 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_CTTZ /* 202 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_CTTZ_ZERO_UNDEF /* 203 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_CTLZ /* 204 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_CTLZ_ZERO_UNDEF /* 205 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_CTPOP /* 206 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BSWAP /* 207 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BITREVERSE /* 208 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FCEIL /* 209 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FCOS /* 210 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FSIN /* 211 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FSQRT /* 212 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FFLOOR /* 213 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FRINT /* 214 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_FNEARBYINT /* 215 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_ADDRSPACE_CAST /* 216 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BLOCK_ADDR /* 217 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_JUMP_TABLE /* 218 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_DYN_STACKALLOC /* 219 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_STRICT_FADD /* 220 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_STRICT_FSUB /* 221 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_STRICT_FMUL /* 222 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_STRICT_FDIV /* 223 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_STRICT_FREM /* 224 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_STRICT_FMA /* 225 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_STRICT_FSQRT /* 226 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_READ_REGISTER /* 227 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_WRITE_REGISTER /* 228 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_MEMCPY /* 229 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_MEMCPY_INLINE /* 230 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_MEMMOVE /* 231 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_MEMSET /* 232 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_BZERO /* 233 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_SEQ_FADD /* 234 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_SEQ_FMUL /* 235 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_FADD /* 236 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_FMUL /* 237 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_FMAX /* 238 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_FMIN /* 239 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_ADD /* 240 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_MUL /* 241 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_AND /* 242 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_OR /* 243 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_XOR /* 244 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_SMAX /* 245 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_SMIN /* 246 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_UMAX /* 247 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_VECREDUCE_UMIN /* 248 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_SBFX /* 249 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* <No AsmString> */
  TRICORE_G_UBFX /* 250 */, TRICORE_INS_INVALID,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* absdifs.b $d, $s1, $s2 */
  TRICORE_ABSDIFS_B_rr_v110 /* 251 */, TRICORE_INS_ABSDIFS_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* absdifs.h $d, $s1, $s2 */
  TRICORE_ABSDIFS_H_rr /* 252 */, TRICORE_INS_ABSDIFS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* absdifs $d, $s1, $s2 */
  TRICORE_ABSDIFS_rc /* 253 */, TRICORE_INS_ABSDIFS,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* absdifs $d, $s1, $s2 */
  TRICORE_ABSDIFS_rr /* 254 */, TRICORE_INS_ABSDIFS,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* absdif.b $d, $s1, $s2 */
  TRICORE_ABSDIF_B_rr /* 255 */, TRICORE_INS_ABSDIF_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* absdif.h $d, $s1, $s2 */
  TRICORE_ABSDIF_H_rr /* 256 */, TRICORE_INS_ABSDIF_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* absdif $d, $s1, $const9 */
  TRICORE_ABSDIF_rc /* 257 */, TRICORE_INS_ABSDIF,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* absdif $d, $s1, $s2 */
  TRICORE_ABSDIF_rr /* 258 */, TRICORE_INS_ABSDIF,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* abss.b $d, $s2 */
  TRICORE_ABSS_B_rr_v110 /* 259 */, TRICORE_INS_ABSS_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* abss.h $d, $s2 */
  TRICORE_ABSS_H_rr /* 260 */, TRICORE_INS_ABSS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* abss $d, $s2 */
  TRICORE_ABSS_rr /* 261 */, TRICORE_INS_ABSS,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* abs.b $d, $s2 */
  TRICORE_ABS_B_rr /* 262 */, TRICORE_INS_ABS_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* abs.h $d, $s2 */
  TRICORE_ABS_H_rr /* 263 */, TRICORE_INS_ABS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* abs $d, $s2 */
  TRICORE_ABS_rr /* 264 */, TRICORE_INS_ABS,
  #ifndef CAPSTONE_DIET
    { 0 }, { TRICORE_REG_PSW, 0 }, { 0 }, 0, 0
  #endif
},
{
  /* addc $d, $s1, $const9 */
  TRICORE_ADDC_rc /* 265 */, TRICORE_INS_ADDC,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* addc $d, $s1, $s2 */
  TRICORE_ADDC_rr /* 266 */, TRICORE_INS_ADDC,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* addih.a $d, $s1, $const16 */
  TRICORE_ADDIH_A_rlc /* 267 */, TRICORE_INS_ADDIH_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* addih $d, $s1, $const16 */
  TRICORE_ADDIH_rlc /* 268 */, TRICORE_INS_ADDIH,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* addi $d, $s1, $const16 */
  TRICORE_ADDI_rlc /* 269 */, TRICORE_INS_ADDI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* addsc.at $d, $s2, $s1 */
  TRICORE_ADDSC_AT_rr /* 270 */, TRICORE_INS_ADDSC_AT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* addsc.at $d, $s1, $s2 */
  TRICORE_ADDSC_AT_rr_v110 /* 271 */, TRICORE_INS_ADDSC_AT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* addsc.a $d, $s2, $s1, $n */
  TRICORE_ADDSC_A_rr /* 272 */, TRICORE_INS_ADDSC_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* addsc.a $d, $s1, $s2, $n */
  TRICORE_ADDSC_A_rr_v110 /* 273 */, TRICORE_INS_ADDSC_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* addsc.a $d, $s2, d15, $n */
  TRICORE_ADDSC_A_srrs /* 274 */, TRICORE_INS_ADDSC_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* addsc.a $d, $s2, $n */
  TRICORE_ADDSC_A_srrs_v110 /* 275 */, TRICORE_INS_ADDSC_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* adds.bu $d, $s1, $s2 */
  TRICORE_ADDS_BU_rr_v110 /* 276 */, TRICORE_INS_ADDS_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* adds.b $d, $s1, $s2 */
  TRICORE_ADDS_B_rr /* 277 */, TRICORE_INS_ADDS_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* adds.h $d, $s1, $s2 */
  TRICORE_ADDS_H /* 278 */, TRICORE_INS_ADDS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* adds.hu $d, $s1, $s2 */
  TRICORE_ADDS_HU /* 279 */, TRICORE_INS_ADDS_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* adds.u $d, $s1, $s2 */
  TRICORE_ADDS_U /* 280 */, TRICORE_INS_ADDS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* adds.u $d, $s1, $const9 */
  TRICORE_ADDS_U_rc /* 281 */, TRICORE_INS_ADDS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* adds $d, $s1, $const9 */
  TRICORE_ADDS_rc /* 282 */, TRICORE_INS_ADDS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* adds $d, $s1, $s2 */
  TRICORE_ADDS_rr /* 283 */, TRICORE_INS_ADDS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* adds $d, $s2 */
  TRICORE_ADDS_srr /* 284 */, TRICORE_INS_ADDS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* addx $d, $s1, $const9 */
  TRICORE_ADDX_rc /* 285 */, TRICORE_INS_ADDX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* addx $d, $s1, $s2 */
  TRICORE_ADDX_rr /* 286 */, TRICORE_INS_ADDX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add.a $d, $s1, $s2 */
  TRICORE_ADD_A_rr /* 287 */, TRICORE_INS_ADD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add.a $d, $const4 */
  TRICORE_ADD_A_src /* 288 */, TRICORE_INS_ADD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* add.a $d, $s2 */
  TRICORE_ADD_A_srr /* 289 */, TRICORE_INS_ADD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* add.b $d, $s1, $s2 */
  TRICORE_ADD_B_rr /* 290 */, TRICORE_INS_ADD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add.f $d, $s3, $s1 */
  TRICORE_ADD_F_rrr /* 291 */, TRICORE_INS_ADD_F,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* add.h $d, $s1, $s2 */
  TRICORE_ADD_H_rr /* 292 */, TRICORE_INS_ADD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add $d, $s1, $const9 */
  TRICORE_ADD_rc /* 293 */, TRICORE_INS_ADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add $d, $s1, $s2 */
  TRICORE_ADD_rr /* 294 */, TRICORE_INS_ADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add $d, $const4 */
  TRICORE_ADD_src /* 295 */, TRICORE_INS_ADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add d15, $d, $const4 */
  TRICORE_ADD_src_15a /* 296 */, TRICORE_INS_ADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add $d, d15, $const4 */
  TRICORE_ADD_src_a15 /* 297 */, TRICORE_INS_ADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* add $d, $s2 */
  TRICORE_ADD_srr /* 298 */, TRICORE_INS_ADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add d15, $d, $s2 */
  TRICORE_ADD_srr_15a /* 299 */, TRICORE_INS_ADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* add $d, d15, $s2 */
  TRICORE_ADD_srr_a15 /* 300 */, TRICORE_INS_ADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* andn.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_ANDN_T /* 301 */, TRICORE_INS_ANDN_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* andn $d, $s1, $const9 */
  TRICORE_ANDN_rc /* 302 */, TRICORE_INS_ANDN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* andn $d, $s1, $s2 */
  TRICORE_ANDN_rr /* 303 */, TRICORE_INS_ANDN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.andn.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_AND_ANDN_T /* 304 */, TRICORE_INS_AND_ANDN_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.and.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_AND_AND_T /* 305 */, TRICORE_INS_AND_AND_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.eq $d, $s1, $const9 */
  TRICORE_AND_EQ_rc /* 306 */, TRICORE_INS_AND_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.eq $d, $s1, $s2 */
  TRICORE_AND_EQ_rr /* 307 */, TRICORE_INS_AND_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.ge.u $d, $s1, $const9 */
  TRICORE_AND_GE_U_rc /* 308 */, TRICORE_INS_AND_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.ge.u $d, $s1, $s2 */
  TRICORE_AND_GE_U_rr /* 309 */, TRICORE_INS_AND_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.ge $d, $s1, $const9 */
  TRICORE_AND_GE_rc /* 310 */, TRICORE_INS_AND_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.ge $d, $s1, $s2 */
  TRICORE_AND_GE_rr /* 311 */, TRICORE_INS_AND_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.lt.u $d, $s1, $const9 */
  TRICORE_AND_LT_U_rc /* 312 */, TRICORE_INS_AND_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.lt.u $d, $s1, $s2 */
  TRICORE_AND_LT_U_rr /* 313 */, TRICORE_INS_AND_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.lt $d, $s1, $const9 */
  TRICORE_AND_LT_rc /* 314 */, TRICORE_INS_AND_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.lt $d, $s1, $s2 */
  TRICORE_AND_LT_rr /* 315 */, TRICORE_INS_AND_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.ne $d, $s1, $const9 */
  TRICORE_AND_NE_rc /* 316 */, TRICORE_INS_AND_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.ne $d, $s1, $s2 */
  TRICORE_AND_NE_rr /* 317 */, TRICORE_INS_AND_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.nor.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_AND_NOR_T /* 318 */, TRICORE_INS_AND_NOR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.or.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_AND_OR_T /* 319 */, TRICORE_INS_AND_OR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_AND_T /* 320 */, TRICORE_INS_AND_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and $d, $s1, $const9 */
  TRICORE_AND_rc /* 321 */, TRICORE_INS_AND,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and $d, $s1, $s2 */
  TRICORE_AND_rr /* 322 */, TRICORE_INS_AND,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* and d15, $const8 */
  TRICORE_AND_sc /* 323 */, TRICORE_INS_AND,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* and d15, $const8 */
  TRICORE_AND_sc_v110 /* 324 */, TRICORE_INS_AND,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* and $d, $s2 */
  TRICORE_AND_srr /* 325 */, TRICORE_INS_AND,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* and $d, $s2 */
  TRICORE_AND_srr_v110 /* 326 */, TRICORE_INS_AND,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* bisr $const9 */
  TRICORE_BISR_rc /* 327 */, TRICORE_INS_BISR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* bisr $const9 */
  TRICORE_BISR_rc_v161 /* 328 */, TRICORE_INS_BISR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161, 0 }, 0, 0
  #endif
},
{
  /* bisr $const8 */
  TRICORE_BISR_sc /* 329 */, TRICORE_INS_BISR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* bisr $const8 */
  TRICORE_BISR_sc_v110 /* 330 */, TRICORE_INS_BISR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* bmerge $d, $s1, $s2 */
  TRICORE_BMERGAE_rr_v110 /* 331 */, TRICORE_INS_BMERGE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* bmerge $d, $s1, $s2 */
  TRICORE_BMERGE_rr /* 332 */, TRICORE_INS_BMERGE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* bsplit $d, $s1 */
  TRICORE_BSPLIT_rr /* 333 */, TRICORE_INS_BSPLIT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* bsplit $d, $s1 */
  TRICORE_BSPLIT_rr_v110 /* 334 */, TRICORE_INS_BSPLIT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* cachea.i [$s2]$off10 */
  TRICORE_CACHEA_I_bo_bso /* 335 */, TRICORE_INS_CACHEA_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.i [${s2}+c]$off10 */
  TRICORE_CACHEA_I_bo_c /* 336 */, TRICORE_INS_CACHEA_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.i [${s2}+]$off10 */
  TRICORE_CACHEA_I_bo_pos /* 337 */, TRICORE_INS_CACHEA_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.i [+${s2}]$off10 */
  TRICORE_CACHEA_I_bo_pre /* 338 */, TRICORE_INS_CACHEA_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.i [${s2}+r] */
  TRICORE_CACHEA_I_bo_r /* 339 */, TRICORE_INS_CACHEA_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.wi [$s2]$off10 */
  TRICORE_CACHEA_WI_bo_bso /* 340 */, TRICORE_INS_CACHEA_WI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.wi [${s2}+c]$off10 */
  TRICORE_CACHEA_WI_bo_c /* 341 */, TRICORE_INS_CACHEA_WI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.wi [${s2}+]$off10 */
  TRICORE_CACHEA_WI_bo_pos /* 342 */, TRICORE_INS_CACHEA_WI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.wi [+${s2}]$off10 */
  TRICORE_CACHEA_WI_bo_pre /* 343 */, TRICORE_INS_CACHEA_WI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.wi [${s2}+r] */
  TRICORE_CACHEA_WI_bo_r /* 344 */, TRICORE_INS_CACHEA_WI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.w [$s2]$off10 */
  TRICORE_CACHEA_W_bo_bso /* 345 */, TRICORE_INS_CACHEA_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.w [${s2}+c]$off10 */
  TRICORE_CACHEA_W_bo_c /* 346 */, TRICORE_INS_CACHEA_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.w [${s2}+]$off10 */
  TRICORE_CACHEA_W_bo_pos /* 347 */, TRICORE_INS_CACHEA_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.w [+${s2}]$off10 */
  TRICORE_CACHEA_W_bo_pre /* 348 */, TRICORE_INS_CACHEA_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachea.w [${s2}+r] */
  TRICORE_CACHEA_W_bo_r /* 349 */, TRICORE_INS_CACHEA_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.i [$s2]$off10 */
  TRICORE_CACHEI_I_bo_bso /* 350 */, TRICORE_INS_CACHEI_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.i [${s2}+]$off10 */
  TRICORE_CACHEI_I_bo_pos /* 351 */, TRICORE_INS_CACHEI_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.i [+${s2}]$off10 */
  TRICORE_CACHEI_I_bo_pre /* 352 */, TRICORE_INS_CACHEI_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.wi [$s2]$off10 */
  TRICORE_CACHEI_WI_bo_bso /* 353 */, TRICORE_INS_CACHEI_WI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.wi [${s2}+]$off10 */
  TRICORE_CACHEI_WI_bo_pos /* 354 */, TRICORE_INS_CACHEI_WI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.wi [+${s2}]$off10 */
  TRICORE_CACHEI_WI_bo_pre /* 355 */, TRICORE_INS_CACHEI_WI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.w [$s2]$off10 */
  TRICORE_CACHEI_W_bo_bso /* 356 */, TRICORE_INS_CACHEI_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.w [${s2}+]$off10 */
  TRICORE_CACHEI_W_bo_pos /* 357 */, TRICORE_INS_CACHEI_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* cachei.w [+${s2}]$off10 */
  TRICORE_CACHEI_W_bo_pre /* 358 */, TRICORE_INS_CACHEI_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* caddn.a $d, $s3, $s1, $const9 */
  TRICORE_CADDN_A_rcr_v110 /* 359 */, TRICORE_INS_CADDN_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* caddn.a $d, $s3, $s1, $s2 */
  TRICORE_CADDN_A_rrr_v110 /* 360 */, TRICORE_INS_CADDN_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* caddn $d, $s3, $s1, $const9 */
  TRICORE_CADDN_rcr /* 361 */, TRICORE_INS_CADDN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* caddn $d, $s3, $s1, $s2 */
  TRICORE_CADDN_rrr /* 362 */, TRICORE_INS_CADDN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* caddn $d, d15, $const4 */
  TRICORE_CADDN_src /* 363 */, TRICORE_INS_CADDN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* caddn $d, d15, $s2 */
  TRICORE_CADDN_srr_v110 /* 364 */, TRICORE_INS_CADDN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* cadd.a $d, $s3, $s1, $const9 */
  TRICORE_CADD_A_rcr_v110 /* 365 */, TRICORE_INS_CADD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* cadd.a $d, $s3, $s1, $s2 */
  TRICORE_CADD_A_rrr_v110 /* 366 */, TRICORE_INS_CADD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* cadd $d, $s3, $s1, $const9 */
  TRICORE_CADD_rcr /* 367 */, TRICORE_INS_CADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cadd $d, $s3, $s1, $s2 */
  TRICORE_CADD_rrr /* 368 */, TRICORE_INS_CADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cadd $d, d15, $const4 */
  TRICORE_CADD_src /* 369 */, TRICORE_INS_CADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cadd $d, d15, $s2 */
  TRICORE_CADD_srr_v110 /* 370 */, TRICORE_INS_CADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* calla $disp24 */
  TRICORE_CALLA_b /* 371 */, TRICORE_INS_CALLA,
  #ifndef CAPSTONE_DIET
    { TRICORE_REG_A10, 0 }, { TRICORE_REG_A11, 0 }, { TRICORE_GRP_CALL, 0 }, 0, 0
  #endif
},
{
  /* calli $s1 */
  TRICORE_CALLI_rr /* 372 */, TRICORE_INS_CALLI,
  #ifndef CAPSTONE_DIET
    { TRICORE_REG_A10, 0 }, { TRICORE_REG_A11, 0 }, { TRICORE_GRP_CALL, TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* calli $s2 */
  TRICORE_CALLI_rr_v110 /* 373 */, TRICORE_INS_CALLI,
  #ifndef CAPSTONE_DIET
    { TRICORE_REG_A10, 0 }, { TRICORE_REG_A11, 0 }, { TRICORE_GRP_CALL, TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* call $disp24 */
  TRICORE_CALL_b /* 374 */, TRICORE_INS_CALL,
  #ifndef CAPSTONE_DIET
    { TRICORE_REG_A10, 0 }, { TRICORE_REG_A11, 0 }, { TRICORE_GRP_CALL, 0 }, 0, 0
  #endif
},
{
  /* call $disp8 */
  TRICORE_CALL_sb /* 375 */, TRICORE_INS_CALL,
  #ifndef CAPSTONE_DIET
    { TRICORE_REG_A10, 0 }, { TRICORE_REG_A11, 0 }, { TRICORE_GRP_CALL, TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* clo.b $d, $s1 */
  TRICORE_CLO_B_rr_v110 /* 376 */, TRICORE_INS_CLO_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* clo.h $d, $s1 */
  TRICORE_CLO_H_rr /* 377 */, TRICORE_INS_CLO_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* clo $d, $s1 */
  TRICORE_CLO_rr /* 378 */, TRICORE_INS_CLO,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cls.b $d, $s1 */
  TRICORE_CLS_B_rr_v110 /* 379 */, TRICORE_INS_CLS_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* cls.h $d, $s1 */
  TRICORE_CLS_H_rr /* 380 */, TRICORE_INS_CLS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cls $d, $s1 */
  TRICORE_CLS_rr /* 381 */, TRICORE_INS_CLS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* clz.b $d, $s1 */
  TRICORE_CLZ_B_rr_v110 /* 382 */, TRICORE_INS_CLZ_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* clz.h $d, $s1 */
  TRICORE_CLZ_H_rr /* 383 */, TRICORE_INS_CLZ_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* clz $d, $s1 */
  TRICORE_CLZ_rr /* 384 */, TRICORE_INS_CLZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cmovn $d, d15, $const4 */
  TRICORE_CMOVN_src /* 385 */, TRICORE_INS_CMOVN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cmovn $d, d15, $s2 */
  TRICORE_CMOVN_srr /* 386 */, TRICORE_INS_CMOVN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cmov $d, d15, $const4 */
  TRICORE_CMOV_src /* 387 */, TRICORE_INS_CMOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cmov $d, d15, $s2 */
  TRICORE_CMOV_srr /* 388 */, TRICORE_INS_CMOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* cmpswap.w [$s2]$off10, $s1 */
  TRICORE_CMPSWAP_W_bo_bso /* 389 */, TRICORE_INS_CMPSWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* cmpswap.w [${s2}+c]$off10, $s1 */
  TRICORE_CMPSWAP_W_bo_c /* 390 */, TRICORE_INS_CMPSWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* cmpswap.w [${s2}+]$off10, $s1 */
  TRICORE_CMPSWAP_W_bo_pos /* 391 */, TRICORE_INS_CMPSWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* cmpswap.w [+$s2]$off10, $s1 */
  TRICORE_CMPSWAP_W_bo_pre /* 392 */, TRICORE_INS_CMPSWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* cmpswap.w [${s2}+r], $s1 */
  TRICORE_CMPSWAP_W_bo_r /* 393 */, TRICORE_INS_CMPSWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* cmp.f $d, $s1, $s2 */
  TRICORE_CMP_F_rr /* 394 */, TRICORE_INS_CMP_F,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* crc32b.w $d, $s2, $s1 */
  TRICORE_CRC32B_W_rr /* 395 */, TRICORE_INS_CRC32B_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162, 0 }, 0, 0
  #endif
},
{
  /* crc32l.w $d, $s2, $s1 */
  TRICORE_CRC32L_W_rr /* 396 */, TRICORE_INS_CRC32L_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162, 0 }, 0, 0
  #endif
},
{
  /* crc32.b $d, $s2, $s1 */
  TRICORE_CRC32_B_rr /* 397 */, TRICORE_INS_CRC32_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162, 0 }, 0, 0
  #endif
},
{
  /* crcn $d, $s3, $s1, $s2 */
  TRICORE_CRCN_rrr /* 398 */, TRICORE_INS_CRCN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162, 0 }, 0, 0
  #endif
},
{
  /* csubn.a $d, $s3, $s1, $s2 */
  TRICORE_CSUBN_A__rrr_v110 /* 399 */, TRICORE_INS_CSUBN_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* csubn $d, $s3, $s1, $s2 */
  TRICORE_CSUBN_rrr /* 400 */, TRICORE_INS_CSUBN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* csub.a $d, $s3, $s1, $s2 */
  TRICORE_CSUB_A__rrr_v110 /* 401 */, TRICORE_INS_CSUB_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* csub $d, $s3, $s1, $s2 */
  TRICORE_CSUB_rrr /* 402 */, TRICORE_INS_CSUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* debug */
  TRICORE_DEBUG_sr /* 403 */, TRICORE_INS_DEBUG,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* debug */
  TRICORE_DEBUG_sys /* 404 */, TRICORE_INS_DEBUG,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* dextr $d, $s1, $s2, $pos */
  TRICORE_DEXTR_rrpw /* 405 */, TRICORE_INS_DEXTR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* dextr $d, $s1, $s2, $s3 */
  TRICORE_DEXTR_rrrr /* 406 */, TRICORE_INS_DEXTR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* difsc.a $d, $s1, $s2, $n */
  TRICORE_DIFSC_A_rr_v110 /* 407 */, TRICORE_INS_DIFSC_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* disable */
  TRICORE_DISABLE_sys /* 408 */, TRICORE_INS_DISABLE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* disable $s1 */
  TRICORE_DISABLE_sys_1 /* 409 */, TRICORE_INS_DISABLE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* div.f $d, $s1, $s2 */
  TRICORE_DIV_F_rr /* 410 */, TRICORE_INS_DIV_F,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* div.u $d, $s1, $s2 */
  TRICORE_DIV_U_rr /* 411 */, TRICORE_INS_DIV_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* div $d, $s1, $s2 */
  TRICORE_DIV_rr /* 412 */, TRICORE_INS_DIV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* dsync */
  TRICORE_DSYNC_sys /* 413 */, TRICORE_INS_DSYNC,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* dvadj $d, $s3, $s2 */
  TRICORE_DVADJ_rrr /* 414 */, TRICORE_INS_DVADJ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvadj $d, $s3, $s2 */
  TRICORE_DVADJ_rrr_v110 /* 415 */, TRICORE_INS_DVADJ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvadj $d, $s2 */
  TRICORE_DVADJ_srr_v110 /* 416 */, TRICORE_INS_DVADJ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvinit.bu $d, $s1, $s2 */
  TRICORE_DVINIT_BU_rr /* 417 */, TRICORE_INS_DVINIT_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvinit.bu $d, $s1, $s2 */
  TRICORE_DVINIT_BU_rr_v110 /* 418 */, TRICORE_INS_DVINIT_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvinit.b $d, $s1, $s2 */
  TRICORE_DVINIT_B_rr /* 419 */, TRICORE_INS_DVINIT_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvinit.b $d, $s1, $s2 */
  TRICORE_DVINIT_B_rr_v110 /* 420 */, TRICORE_INS_DVINIT_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvinit.hu $d, $s1, $s2 */
  TRICORE_DVINIT_HU_rr /* 421 */, TRICORE_INS_DVINIT_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvinit.hu $d, $s1, $s2 */
  TRICORE_DVINIT_HU_rr_v110 /* 422 */, TRICORE_INS_DVINIT_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvinit.h $d, $s1, $s2 */
  TRICORE_DVINIT_H_rr /* 423 */, TRICORE_INS_DVINIT_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvinit.h $d, $s1, $s2 */
  TRICORE_DVINIT_H_rr_v110 /* 424 */, TRICORE_INS_DVINIT_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvinit.u $d, $s1, $s2 */
  TRICORE_DVINIT_U_rr /* 425 */, TRICORE_INS_DVINIT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvinit.u $d, $s1, $s2 */
  TRICORE_DVINIT_U_rr_v110 /* 426 */, TRICORE_INS_DVINIT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvinit $d, $s1, $s2 */
  TRICORE_DVINIT_rr /* 427 */, TRICORE_INS_DVINIT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvinit $d, $s1, $s2 */
  TRICORE_DVINIT_rr_v110 /* 428 */, TRICORE_INS_DVINIT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvstep.u $d, $s3, $s2 */
  TRICORE_DVSTEP_U_rrr /* 429 */, TRICORE_INS_DVSTEP_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvstep.u $d, $s3, $s2 */
  TRICORE_DVSTEP_U_rrrv110 /* 430 */, TRICORE_INS_DVSTEP_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvstep.u $d, $s2 */
  TRICORE_DVSTEP_Uv110 /* 431 */, TRICORE_INS_DVSTEP_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvstep $d, $s3, $s2 */
  TRICORE_DVSTEP_rrr /* 432 */, TRICORE_INS_DVSTEP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* dvstep $d, $s3, $s2 */
  TRICORE_DVSTEP_rrrv110 /* 433 */, TRICORE_INS_DVSTEP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* dvstep $d, $s2 */
  TRICORE_DVSTEPv110 /* 434 */, TRICORE_INS_DVSTEP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* enable */
  TRICORE_ENABLE_sys /* 435 */, TRICORE_INS_ENABLE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eqany.b $d, $s1, $const9 */
  TRICORE_EQANY_B_rc /* 436 */, TRICORE_INS_EQANY_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eqany.b $d, $s1, $s2 */
  TRICORE_EQANY_B_rr /* 437 */, TRICORE_INS_EQANY_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eqany.h $d, $s1, $const9 */
  TRICORE_EQANY_H_rc /* 438 */, TRICORE_INS_EQANY_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eqany.h $d, $s1, $s2 */
  TRICORE_EQANY_H_rr /* 439 */, TRICORE_INS_EQANY_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eqz.a $d, $s1 */
  TRICORE_EQZ_A_rr /* 440 */, TRICORE_INS_EQZ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eq.a $d, $s1, $s2 */
  TRICORE_EQ_A_rr /* 441 */, TRICORE_INS_EQ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eq.b $d, $s1, $s2 */
  TRICORE_EQ_B_rr /* 442 */, TRICORE_INS_EQ_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eq.h $d, $s1, $s2 */
  TRICORE_EQ_H_rr /* 443 */, TRICORE_INS_EQ_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eq.w $d, $s1, $s2 */
  TRICORE_EQ_W_rr /* 444 */, TRICORE_INS_EQ_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eq $d, $s1, $const9 */
  TRICORE_EQ_rc /* 445 */, TRICORE_INS_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eq $d, $s1, $s2 */
  TRICORE_EQ_rr /* 446 */, TRICORE_INS_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eq d15, $d, $const4 */
  TRICORE_EQ_src /* 447 */, TRICORE_INS_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* eq d15, $d, $s2 */
  TRICORE_EQ_srr /* 448 */, TRICORE_INS_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* extr.u $d, $s1, $pos, $width */
  TRICORE_EXTR_U_rrpw /* 449 */, TRICORE_INS_EXTR_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* extr.u $d, $s1, $s3 */
  TRICORE_EXTR_U_rrrr /* 450 */, TRICORE_INS_EXTR_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* extr.u $d, $s1, $s3, $width */
  TRICORE_EXTR_U_rrrw /* 451 */, TRICORE_INS_EXTR_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* extr $d, $s1, $pos, $width */
  TRICORE_EXTR_rrpw /* 452 */, TRICORE_INS_EXTR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* extr $d, $s1, $s3 */
  TRICORE_EXTR_rrrr /* 453 */, TRICORE_INS_EXTR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* extr $d, $s1, $s3, $width */
  TRICORE_EXTR_rrrw /* 454 */, TRICORE_INS_EXTR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* fcalla $disp24 */
  TRICORE_FCALLA_b /* 455 */, TRICORE_INS_FCALLA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* fcalli $s1 */
  TRICORE_FCALLA_i /* 456 */, TRICORE_INS_FCALLI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* fcall $disp24 */
  TRICORE_FCALL_b /* 457 */, TRICORE_INS_FCALL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* fret */
  TRICORE_FRET_sr /* 458 */, TRICORE_INS_FRET,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* fret */
  TRICORE_FRET_sys /* 459 */, TRICORE_INS_FRET,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* ftohp $d, $s1 */
  TRICORE_FTOHP_rr /* 460 */, TRICORE_INS_FTOHP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162_UP, 0 }, 0, 0
  #endif
},
{
  /* ftoiz $d, $s1 */
  TRICORE_FTOIZ_rr /* 461 */, TRICORE_INS_FTOIZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* ftoi $d, $s1 */
  TRICORE_FTOI_rr /* 462 */, TRICORE_INS_FTOI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* ftoq31z $d, $s1, $s2 */
  TRICORE_FTOQ31Z_rr /* 463 */, TRICORE_INS_FTOQ31Z,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* ftoq31 $d, $s1, $s2 */
  TRICORE_FTOQ31_rr /* 464 */, TRICORE_INS_FTOQ31,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* ftouz $d, $s1 */
  TRICORE_FTOUZ_rr /* 465 */, TRICORE_INS_FTOUZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV131_UP, 0 }, 0, 0
  #endif
},
{
  /* ftou $d, $s1 */
  TRICORE_FTOU_rr /* 466 */, TRICORE_INS_FTOU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* ge.a $d, $s1, $s2 */
  TRICORE_GE_A_rr /* 467 */, TRICORE_INS_GE_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ge.u $d, $s1, $const9 */
  TRICORE_GE_U_rc /* 468 */, TRICORE_INS_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ge.u $d, $s1, $s2 */
  TRICORE_GE_U_rr /* 469 */, TRICORE_INS_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ge $d, $s1, $const9 */
  TRICORE_GE_rc /* 470 */, TRICORE_INS_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ge $d, $s1, $s2 */
  TRICORE_GE_rr /* 471 */, TRICORE_INS_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* hptof $d, $s1 */
  TRICORE_HPTOF_rr /* 472 */, TRICORE_INS_HPTOF,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162_UP, 0 }, 0, 0
  #endif
},
{
  /* imask $d, $const4, $pos, $width */
  TRICORE_IMASK_rcpw /* 473 */, TRICORE_INS_IMASK,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* imask $d, $const4, $s3, $width */
  TRICORE_IMASK_rcrw /* 474 */, TRICORE_INS_IMASK,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* imask $d, $s2, $pos, $width */
  TRICORE_IMASK_rrpw /* 475 */, TRICORE_INS_IMASK,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* imask $d, $s2, $s3, $width */
  TRICORE_IMASK_rrrw /* 476 */, TRICORE_INS_IMASK,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* insert $d, $s1, $const4, $pos, $width */
  TRICORE_INSERT_rcpw /* 477 */, TRICORE_INS_INSERT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* insert $d, $s1, $const4, $s3 */
  TRICORE_INSERT_rcrr /* 478 */, TRICORE_INS_INSERT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* insert $d, $s1, $const4, $s3, $width */
  TRICORE_INSERT_rcrw /* 479 */, TRICORE_INS_INSERT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* insert $d, $s1, $s2, $pos, $width */
  TRICORE_INSERT_rrpw /* 480 */, TRICORE_INS_INSERT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* insert $d, $s1, $s2, $s3 */
  TRICORE_INSERT_rrrr /* 481 */, TRICORE_INS_INSERT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* insert $d, $s1, $s2, $s3, $width */
  TRICORE_INSERT_rrrw /* 482 */, TRICORE_INS_INSERT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* insn.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_INSN_T /* 483 */, TRICORE_INS_INSN_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ins.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_INS_T /* 484 */, TRICORE_INS_INS_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* isync */
  TRICORE_ISYNC_sys /* 485 */, TRICORE_INS_ISYNC,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* itof $d, $s1 */
  TRICORE_ITOF_rr /* 486 */, TRICORE_INS_ITOF,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* ixmax.u $d, $s3, $s2 */
  TRICORE_IXMAX_U_rrr /* 487 */, TRICORE_INS_IXMAX_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* ixmax $d, $s3, $s2 */
  TRICORE_IXMAX_rrr /* 488 */, TRICORE_INS_IXMAX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* ixmin.u $d, $s3, $s2 */
  TRICORE_IXMIN_U_rrr /* 489 */, TRICORE_INS_IXMIN_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* ixmin $d, $s3, $s2 */
  TRICORE_IXMIN_rrr /* 490 */, TRICORE_INS_IXMIN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* ja $disp24 */
  TRICORE_JA_b /* 491 */, TRICORE_INS_JA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jeq.a $s1, $s2, $disp15 */
  TRICORE_JEQ_A_brr /* 492 */, TRICORE_INS_JEQ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jeq $s1, $const4, $disp15 */
  TRICORE_JEQ_brc /* 493 */, TRICORE_INS_JEQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jeq $s1, $s2, $disp15 */
  TRICORE_JEQ_brr /* 494 */, TRICORE_INS_JEQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jeq d15, $const4, $disp4 */
  TRICORE_JEQ_sbc1 /* 495 */, TRICORE_INS_JEQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jeq d15, $const4, $disp4 */
  TRICORE_JEQ_sbc2 /* 496 */, TRICORE_INS_JEQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* jeq d15, $const4, $disp4 */
  TRICORE_JEQ_sbc_v110 /* 497 */, TRICORE_INS_JEQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jeq d15, $s2, $disp4 */
  TRICORE_JEQ_sbr1 /* 498 */, TRICORE_INS_JEQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* jeq d15, $s2, $disp4 */
  TRICORE_JEQ_sbr2 /* 499 */, TRICORE_INS_JEQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* jeq d15, $s2, $disp4 */
  TRICORE_JEQ_sbr_v110 /* 500 */, TRICORE_INS_JEQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jgez $s2, $disp4 */
  TRICORE_JGEZ_sbr /* 501 */, TRICORE_INS_JGEZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jgez $s2, $disp4 */
  TRICORE_JGEZ_sbr_v110 /* 502 */, TRICORE_INS_JGEZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jge.u $s1, $const4, $disp15 */
  TRICORE_JGE_U_brc /* 503 */, TRICORE_INS_JGE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jge.u $s1, $s2, $disp15 */
  TRICORE_JGE_U_brr /* 504 */, TRICORE_INS_JGE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jge $s1, $const4, $disp15 */
  TRICORE_JGE_brc /* 505 */, TRICORE_INS_JGE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jge $s1, $s2, $disp15 */
  TRICORE_JGE_brr /* 506 */, TRICORE_INS_JGE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jgtz $s2, $disp4 */
  TRICORE_JGTZ_sbr /* 507 */, TRICORE_INS_JGTZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jgtz $s2, $disp4 */
  TRICORE_JGTZ_sbr_v110 /* 508 */, TRICORE_INS_JGTZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ji $s1 */
  TRICORE_JI_rr /* 509 */, TRICORE_INS_JI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ji $s1 */
  TRICORE_JI_rr_v110 /* 510 */, TRICORE_INS_JI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ji $s2 */
  TRICORE_JI_sbr_v110 /* 511 */, TRICORE_INS_JI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ji $s1 */
  TRICORE_JI_sr /* 512 */, TRICORE_INS_JI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jla $disp24 */
  TRICORE_JLA_b /* 513 */, TRICORE_INS_JLA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jlez $s2, $disp4 */
  TRICORE_JLEZ_sbr /* 514 */, TRICORE_INS_JLEZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jlez $s2, $disp4 */
  TRICORE_JLEZ_sbr_v110 /* 515 */, TRICORE_INS_JLEZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jli $s1 */
  TRICORE_JLI_rr /* 516 */, TRICORE_INS_JLI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jli $s1 */
  TRICORE_JLI_rr_v110 /* 517 */, TRICORE_INS_JLI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jltz $s2, $disp4 */
  TRICORE_JLTZ_sbr /* 518 */, TRICORE_INS_JLTZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jltz $s2, $disp4 */
  TRICORE_JLTZ_sbr_v110 /* 519 */, TRICORE_INS_JLTZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jlt.u $s1, $const4, $disp15 */
  TRICORE_JLT_U_brc /* 520 */, TRICORE_INS_JLT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jlt.u $s1, $s2, $disp15 */
  TRICORE_JLT_U_brr /* 521 */, TRICORE_INS_JLT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jlt $s1, $const4, $disp15 */
  TRICORE_JLT_brc /* 522 */, TRICORE_INS_JLT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jlt $s1, $s2, $disp15 */
  TRICORE_JLT_brr /* 523 */, TRICORE_INS_JLT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jl $disp24 */
  TRICORE_JL_b /* 524 */, TRICORE_INS_JL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jned $s1, $const4, $disp15 */
  TRICORE_JNED_brc /* 525 */, TRICORE_INS_JNED,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jned $s1, $s2, $disp15 */
  TRICORE_JNED_brr /* 526 */, TRICORE_INS_JNED,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jnei $s1, $const4, $disp15 */
  TRICORE_JNEI_brc /* 527 */, TRICORE_INS_JNEI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jnei $s1, $s2, $disp15 */
  TRICORE_JNEI_brr /* 528 */, TRICORE_INS_JNEI,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jne.a $s1, $s2, $disp15 */
  TRICORE_JNE_A_brr /* 529 */, TRICORE_INS_JNE_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jne $s1, $const4, $disp15 */
  TRICORE_JNE_brc /* 530 */, TRICORE_INS_JNE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jne $s1, $s2, $disp15 */
  TRICORE_JNE_brr /* 531 */, TRICORE_INS_JNE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jne d15, $const4, $disp4 */
  TRICORE_JNE_sbc1 /* 532 */, TRICORE_INS_JNE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jne d15, $const4, $disp4 */
  TRICORE_JNE_sbc2 /* 533 */, TRICORE_INS_JNE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* jne d15, $const4, $disp4 */
  TRICORE_JNE_sbc_v110 /* 534 */, TRICORE_INS_JNE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jne d15, $s2, $disp4 */
  TRICORE_JNE_sbr1 /* 535 */, TRICORE_INS_JNE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jne d15, $s2, $disp4 */
  TRICORE_JNE_sbr2 /* 536 */, TRICORE_INS_JNE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* jne d15, $s2, $disp4 */
  TRICORE_JNE_sbr_v110 /* 537 */, TRICORE_INS_JNE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jnz.a $s1, $disp15 */
  TRICORE_JNZ_A_brr /* 538 */, TRICORE_INS_JNZ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jnz.a $s2, $disp4 */
  TRICORE_JNZ_A_sbr /* 539 */, TRICORE_INS_JNZ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jnz.t $s1, $n, $disp15 */
  TRICORE_JNZ_T_brn /* 540 */, TRICORE_INS_JNZ_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jnz.t d15, $n, $disp4 */
  TRICORE_JNZ_T_sbrn /* 541 */, TRICORE_INS_JNZ_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jnz.t d15, $n, $disp4 */
  TRICORE_JNZ_T_sbrn_v110 /* 542 */, TRICORE_INS_JNZ_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jnz d15, $disp8 */
  TRICORE_JNZ_sb /* 543 */, TRICORE_INS_JNZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jnz d15, $disp8 */
  TRICORE_JNZ_sb_v110 /* 544 */, TRICORE_INS_JNZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jnz $s2, $disp4 */
  TRICORE_JNZ_sbr /* 545 */, TRICORE_INS_JNZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jnz $s2, $disp4 */
  TRICORE_JNZ_sbr_v110 /* 546 */, TRICORE_INS_JNZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jz.a $s1, $disp15 */
  TRICORE_JZ_A_brr /* 547 */, TRICORE_INS_JZ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jz.a $s2, $disp4 */
  TRICORE_JZ_A_sbr /* 548 */, TRICORE_INS_JZ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jz.t $s1, $n, $disp15 */
  TRICORE_JZ_T_brn /* 549 */, TRICORE_INS_JZ_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* jz.t d15, $n, $disp4 */
  TRICORE_JZ_T_sbrn /* 550 */, TRICORE_INS_JZ_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jz.t d15, $n, $disp4 */
  TRICORE_JZ_T_sbrn_v110 /* 551 */, TRICORE_INS_JZ_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jz d15, $disp8 */
  TRICORE_JZ_sb /* 552 */, TRICORE_INS_JZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jz d15, $disp8 */
  TRICORE_JZ_sb_v110 /* 553 */, TRICORE_INS_JZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* jz $s2, $disp4 */
  TRICORE_JZ_sbr /* 554 */, TRICORE_INS_JZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* jz $s2, $disp4 */
  TRICORE_JZ_sbr_v110 /* 555 */, TRICORE_INS_JZ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* j $disp24 */
  TRICORE_J_b /* 556 */, TRICORE_INS_J,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* j $disp8 */
  TRICORE_J_sb /* 557 */, TRICORE_INS_J,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* j $disp8 */
  TRICORE_J_sb_v110 /* 558 */, TRICORE_INS_J,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ldlcx $off18 */
  TRICORE_LDLCX_abs /* 559 */, TRICORE_INS_LDLCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ldlcx [$s2]$off10 */
  TRICORE_LDLCX_bo_bso /* 560 */, TRICORE_INS_LDLCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ldmst $off18, $s1 */
  TRICORE_LDMST_abs /* 561 */, TRICORE_INS_LDMST,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ldmst [$s2]$off10, $s1 */
  TRICORE_LDMST_bo_bso /* 562 */, TRICORE_INS_LDMST,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ldmst [${s2}+c]$off10, $s1 */
  TRICORE_LDMST_bo_c /* 563 */, TRICORE_INS_LDMST,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ldmst [${s2}+]$off10, $s1 */
  TRICORE_LDMST_bo_pos /* 564 */, TRICORE_INS_LDMST,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ldmst [+$s2]$off10, $s1 */
  TRICORE_LDMST_bo_pre /* 565 */, TRICORE_INS_LDMST,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ldmst [${s2}+r], $s1 */
  TRICORE_LDMST_bo_r /* 566 */, TRICORE_INS_LDMST,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lducx $off18 */
  TRICORE_LDUCX_abs /* 567 */, TRICORE_INS_LDUCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lducx [$s2]$off10 */
  TRICORE_LDUCX_bo_bso /* 568 */, TRICORE_INS_LDUCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, $off18 */
  TRICORE_LD_A_abs /* 569 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [$s2]$off10 */
  TRICORE_LD_A_bo_bso /* 570 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [${s2}+c]$off10 */
  TRICORE_LD_A_bo_c /* 571 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.a $s1, [${s2}+]$off10 */
  TRICORE_LD_A_bo_pos /* 572 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.a $s1, [+${s2}]$off10 */
  TRICORE_LD_A_bo_pre /* 573 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [${s2}+r] */
  TRICORE_LD_A_bo_r /* 574 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.a $s1, [$s2]$off16 */
  TRICORE_LD_A_bol /* 575 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.a a15, [sp]$const8 */
  TRICORE_LD_A_sc /* 576 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [$s2] */
  TRICORE_LD_A_slr /* 577 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [${s2}+] */
  TRICORE_LD_A_slr_post /* 578 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [${s2}+] */
  TRICORE_LD_A_slr_post_v110 /* 579 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [$s2] */
  TRICORE_LD_A_slr_v110 /* 580 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [a15]$off4 */
  TRICORE_LD_A_slro /* 581 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.a $d, [a15]$off4 */
  TRICORE_LD_A_slro_v110 /* 582 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.a a15, [$s2]$off4 */
  TRICORE_LD_A_sro /* 583 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.a a15, [$s2]$off4 */
  TRICORE_LD_A_sro_v110 /* 584 */, TRICORE_INS_LD_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, $off18 */
  TRICORE_LD_BU_abs /* 585 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [$s2]$off10 */
  TRICORE_LD_BU_bo_bso /* 586 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [${s2}+c]$off10 */
  TRICORE_LD_BU_bo_c /* 587 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.bu $s1, [${s2}+]$off10 */
  TRICORE_LD_BU_bo_pos /* 588 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.bu $s1, [+${s2}]$off10 */
  TRICORE_LD_BU_bo_pre /* 589 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [${s2}+r] */
  TRICORE_LD_BU_bo_r /* 590 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.bu $s1, [$s2]$off16 */
  TRICORE_LD_BU_bol /* 591 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [$s2] */
  TRICORE_LD_BU_slr /* 592 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [${s2}+] */
  TRICORE_LD_BU_slr_post /* 593 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [${s2}+] */
  TRICORE_LD_BU_slr_post_v110 /* 594 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [$s2] */
  TRICORE_LD_BU_slr_v110 /* 595 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [a15]$off4 */
  TRICORE_LD_BU_slro /* 596 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.bu $d, [a15]$off4 */
  TRICORE_LD_BU_slro_v110 /* 597 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.bu d15, [$s2]$off4 */
  TRICORE_LD_BU_sro /* 598 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.bu d15, [$s2]$off4 */
  TRICORE_LD_BU_sro_v110 /* 599 */, TRICORE_INS_LD_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.b $d, $off18 */
  TRICORE_LD_B_abs /* 600 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.b $d, [$s2]$off10 */
  TRICORE_LD_B_bo_bso /* 601 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.b $d, [${s2}+c]$off10 */
  TRICORE_LD_B_bo_c /* 602 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.b $s1, [${s2}+]$off10 */
  TRICORE_LD_B_bo_pos /* 603 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.b $s1, [+${s2}]$off10 */
  TRICORE_LD_B_bo_pre /* 604 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.b $d, [${s2}+r] */
  TRICORE_LD_B_bo_r /* 605 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.b $s1, [$s2]$off16 */
  TRICORE_LD_B_bol /* 606 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.b $d, [${s2}+] */
  TRICORE_LD_B_slr_post_v110 /* 607 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.b $d, [$s2] */
  TRICORE_LD_B_slr_v110 /* 608 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.b $d, [a15]$off4 */
  TRICORE_LD_B_slro_v110 /* 609 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.b d15, [$s2]$off4 */
  TRICORE_LD_B_sro_v110 /* 610 */, TRICORE_INS_LD_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.da $d, $off18 */
  TRICORE_LD_DA_abs /* 611 */, TRICORE_INS_LD_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.da $d, [$s2]$off10 */
  TRICORE_LD_DA_bo_bso /* 612 */, TRICORE_INS_LD_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.da $d, [${s2}+c]$off10 */
  TRICORE_LD_DA_bo_c /* 613 */, TRICORE_INS_LD_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.da $s1, [${s2}+]$off10 */
  TRICORE_LD_DA_bo_pos /* 614 */, TRICORE_INS_LD_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.da $s1, [+${s2}]$off10 */
  TRICORE_LD_DA_bo_pre /* 615 */, TRICORE_INS_LD_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.da $d, [${s2}+r] */
  TRICORE_LD_DA_bo_r /* 616 */, TRICORE_INS_LD_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.d $d, $off18 */
  TRICORE_LD_D_abs /* 617 */, TRICORE_INS_LD_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.d $d, [$s2]$off10 */
  TRICORE_LD_D_bo_bso /* 618 */, TRICORE_INS_LD_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.d $d, [${s2}+c]$off10 */
  TRICORE_LD_D_bo_c /* 619 */, TRICORE_INS_LD_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.d $s1, [${s2}+]$off10 */
  TRICORE_LD_D_bo_pos /* 620 */, TRICORE_INS_LD_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.d $s1, [+${s2}]$off10 */
  TRICORE_LD_D_bo_pre /* 621 */, TRICORE_INS_LD_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.d $d, [${s2}+r] */
  TRICORE_LD_D_bo_r /* 622 */, TRICORE_INS_LD_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.hu $d, $off18 */
  TRICORE_LD_HU_abs /* 623 */, TRICORE_INS_LD_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.hu $d, [$s2]$off10 */
  TRICORE_LD_HU_bo_bso /* 624 */, TRICORE_INS_LD_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.hu $d, [${s2}+c]$off10 */
  TRICORE_LD_HU_bo_c /* 625 */, TRICORE_INS_LD_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.hu $s1, [${s2}+]$off10 */
  TRICORE_LD_HU_bo_pos /* 626 */, TRICORE_INS_LD_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.hu $s1, [+${s2}]$off10 */
  TRICORE_LD_HU_bo_pre /* 627 */, TRICORE_INS_LD_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.hu $d, [${s2}+r] */
  TRICORE_LD_HU_bo_r /* 628 */, TRICORE_INS_LD_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.hu $s1, [$s2]$off16 */
  TRICORE_LD_HU_bol /* 629 */, TRICORE_INS_LD_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, $off18 */
  TRICORE_LD_H_abs /* 630 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [$s2]$off10 */
  TRICORE_LD_H_bo_bso /* 631 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [${s2}+c]$off10 */
  TRICORE_LD_H_bo_c /* 632 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.h $s1, [${s2}+]$off10 */
  TRICORE_LD_H_bo_pos /* 633 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.h $s1, [+${s2}]$off10 */
  TRICORE_LD_H_bo_pre /* 634 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [${s2}+r] */
  TRICORE_LD_H_bo_r /* 635 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.h $s1, [$s2]$off16 */
  TRICORE_LD_H_bol /* 636 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [$s2] */
  TRICORE_LD_H_slr /* 637 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [${s2}+] */
  TRICORE_LD_H_slr_post /* 638 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [${s2}+] */
  TRICORE_LD_H_slr_post_v110 /* 639 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [$s2] */
  TRICORE_LD_H_slr_v110 /* 640 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [a15]$off4 */
  TRICORE_LD_H_slro /* 641 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.h $d, [a15]$off4 */
  TRICORE_LD_H_slro_v110 /* 642 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.h d15, [$s2]$off4 */
  TRICORE_LD_H_sro /* 643 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.h d15, [$s2]$off4 */
  TRICORE_LD_H_sro_v110 /* 644 */, TRICORE_INS_LD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.q $d, $off18 */
  TRICORE_LD_Q_abs /* 645 */, TRICORE_INS_LD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.q $d, [$s2]$off10 */
  TRICORE_LD_Q_bo_bso /* 646 */, TRICORE_INS_LD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.q $d, [${s2}+c]$off10 */
  TRICORE_LD_Q_bo_c /* 647 */, TRICORE_INS_LD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.q $s1, [${s2}+]$off10 */
  TRICORE_LD_Q_bo_pos /* 648 */, TRICORE_INS_LD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.q $s1, [+${s2}]$off10 */
  TRICORE_LD_Q_bo_pre /* 649 */, TRICORE_INS_LD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.q $d, [${s2}+r] */
  TRICORE_LD_Q_bo_r /* 650 */, TRICORE_INS_LD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, $off18 */
  TRICORE_LD_W_abs /* 651 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [$s2]$off10 */
  TRICORE_LD_W_bo_bso /* 652 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [${s2}+c]$off10 */
  TRICORE_LD_W_bo_c /* 653 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.w $s1, [${s2}+]$off10 */
  TRICORE_LD_W_bo_pos /* 654 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.w $s1, [+${s2}]$off10 */
  TRICORE_LD_W_bo_pre /* 655 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [${s2}+r] */
  TRICORE_LD_W_bo_r /* 656 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.w $s1, [$s2]$off16 */
  TRICORE_LD_W_bol /* 657 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ld.w d15, [sp]$const8 */
  TRICORE_LD_W_sc /* 658 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [$s2] */
  TRICORE_LD_W_slr /* 659 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [${s2}+] */
  TRICORE_LD_W_slr_post /* 660 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [${s2}+] */
  TRICORE_LD_W_slr_post_v110 /* 661 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [$s2] */
  TRICORE_LD_W_slr_v110 /* 662 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [a15]$off4 */
  TRICORE_LD_W_slro /* 663 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.w $d, [a15]$off4 */
  TRICORE_LD_W_slro_v110 /* 664 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* ld.w d15, [$s2]$off4 */
  TRICORE_LD_W_sro /* 665 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ld.w d15, [$s2]$off4 */
  TRICORE_LD_W_sro_v110 /* 666 */, TRICORE_INS_LD_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* lea $d, $off18 */
  TRICORE_LEA_abs /* 667 */, TRICORE_INS_LEA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lea $d, [$s2]$off10 */
  TRICORE_LEA_bo_bso /* 668 */, TRICORE_INS_LEA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lea $s1, [$s2]$off16 */
  TRICORE_LEA_bol /* 669 */, TRICORE_INS_LEA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lha $d, $off18 */
  TRICORE_LHA_abs /* 670 */, TRICORE_INS_LHA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162_UP, 0 }, 0, 0
  #endif
},
{
  /* loopu $disp15 */
  TRICORE_LOOPU_brr /* 671 */, TRICORE_INS_LOOPU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* loop $s1, $disp15 */
  TRICORE_LOOP_brr /* 672 */, TRICORE_INS_LOOP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* loop $s2, $disp4 */
  TRICORE_LOOP_sbr /* 673 */, TRICORE_INS_LOOP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.a $d, $s1, $s2 */
  TRICORE_LT_A_rr /* 674 */, TRICORE_INS_LT_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.b $d, $s1, $s2 */
  TRICORE_LT_B /* 675 */, TRICORE_INS_LT_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.bu $d, $s1, $s2 */
  TRICORE_LT_BU /* 676 */, TRICORE_INS_LT_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.h $d, $s1, $s2 */
  TRICORE_LT_H /* 677 */, TRICORE_INS_LT_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.hu $d, $s1, $s2 */
  TRICORE_LT_HU /* 678 */, TRICORE_INS_LT_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.u $d, $s1, $const9 */
  TRICORE_LT_U_rc /* 679 */, TRICORE_INS_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.u $d, $s1, $s2 */
  TRICORE_LT_U_rr /* 680 */, TRICORE_INS_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.u d15, $d, $const4 */
  TRICORE_LT_U_srcv110 /* 681 */, TRICORE_INS_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* lt.u d15, $d, $s2 */
  TRICORE_LT_U_srrv110 /* 682 */, TRICORE_INS_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* lt.w $d, $s1, $s2 */
  TRICORE_LT_W /* 683 */, TRICORE_INS_LT_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt.wu $d, $s1, $s2 */
  TRICORE_LT_WU /* 684 */, TRICORE_INS_LT_WU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt $d, $s1, $const9 */
  TRICORE_LT_rc /* 685 */, TRICORE_INS_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt $d, $s1, $s2 */
  TRICORE_LT_rr /* 686 */, TRICORE_INS_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt d15, $d, $const4 */
  TRICORE_LT_src /* 687 */, TRICORE_INS_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* lt d15, $d, $s2 */
  TRICORE_LT_srr /* 688 */, TRICORE_INS_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* maddms.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDMS_H_rrr1_LL /* 689 */, TRICORE_INS_MADDMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddms.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDMS_H_rrr1_LU /* 690 */, TRICORE_INS_MADDMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddms.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDMS_H_rrr1_UL /* 691 */, TRICORE_INS_MADDMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddms.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDMS_H_rrr1_UU /* 692 */, TRICORE_INS_MADDMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddms.u $d, $s3, $s1, $const9 */
  TRICORE_MADDMS_U_rcr_v110 /* 693 */, TRICORE_INS_MADDMS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddms.u $d, $s3, $s1, $s2 */
  TRICORE_MADDMS_U_rrr2_v110 /* 694 */, TRICORE_INS_MADDMS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddms $d, $s3, $s1, $const9 */
  TRICORE_MADDMS_rcr_v110 /* 695 */, TRICORE_INS_MADDMS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddms $d, $s3, $s1, $s2 */
  TRICORE_MADDMS_rrr2_v110 /* 696 */, TRICORE_INS_MADDMS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddm.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDM_H_rrr1_LL /* 697 */, TRICORE_INS_MADDM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddm.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDM_H_rrr1_LU /* 698 */, TRICORE_INS_MADDM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddm.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDM_H_rrr1_UL /* 699 */, TRICORE_INS_MADDM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddm.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDM_H_rrr1_UU /* 700 */, TRICORE_INS_MADDM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddm.h $d, $s3, $s1, $s2 */
  TRICORE_MADDM_H_rrr1_v110 /* 701 */, TRICORE_INS_MADDM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddm.q $d, $s3, $s1, $s2 */
  TRICORE_MADDM_Q_rrr1_v110 /* 702 */, TRICORE_INS_MADDM_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddm.u $d, $s3, $s1, $const9 */
  TRICORE_MADDM_U_rcr_v110 /* 703 */, TRICORE_INS_MADDM_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddm.u $d, $s3, $s1, $s2 */
  TRICORE_MADDM_U_rrr2_v110 /* 704 */, TRICORE_INS_MADDM_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddm $d, $s3, $s1, $const9 */
  TRICORE_MADDM_rcr_v110 /* 705 */, TRICORE_INS_MADDM,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddm $d, $s3, $s1, $s2 */
  TRICORE_MADDM_rrr2_v110 /* 706 */, TRICORE_INS_MADDM,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddrs.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDRS_H_rrr1_LL /* 707 */, TRICORE_INS_MADDRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddrs.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDRS_H_rrr1_LU /* 708 */, TRICORE_INS_MADDRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddrs.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDRS_H_rrr1_UL /* 709 */, TRICORE_INS_MADDRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddrs.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDRS_H_rrr1_UL_2 /* 710 */, TRICORE_INS_MADDRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddrs.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDRS_H_rrr1_UU /* 711 */, TRICORE_INS_MADDRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddrs.h $d, $s3, $s1, $s2, $n */
  TRICORE_MADDRS_H_rrr1_v110 /* 712 */, TRICORE_INS_MADDRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddrs.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MADDRS_Q_rrr1_L_L /* 713 */, TRICORE_INS_MADDRS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddrs.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MADDRS_Q_rrr1_U_U /* 714 */, TRICORE_INS_MADDRS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddrs.q $d, $s3, $s1, $s2, $n */
  TRICORE_MADDRS_Q_rrr1_v110 /* 715 */, TRICORE_INS_MADDRS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddr.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDR_H_rrr1_LL /* 716 */, TRICORE_INS_MADDR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddr.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDR_H_rrr1_LU /* 717 */, TRICORE_INS_MADDR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddr.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDR_H_rrr1_UL /* 718 */, TRICORE_INS_MADDR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddr.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDR_H_rrr1_UL_2 /* 719 */, TRICORE_INS_MADDR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddr.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDR_H_rrr1_UU /* 720 */, TRICORE_INS_MADDR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddr.h $d, $s3, $s1, $s2, $n */
  TRICORE_MADDR_H_rrr1_v110 /* 721 */, TRICORE_INS_MADDR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddr.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MADDR_Q_rrr1_L_L /* 722 */, TRICORE_INS_MADDR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddr.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MADDR_Q_rrr1_U_U /* 723 */, TRICORE_INS_MADDR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddr.q $d, $s3, $s1, $s2, $n */
  TRICORE_MADDR_Q_rrr1_v110 /* 724 */, TRICORE_INS_MADDR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* maddsums.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDSUMS_H_rrr1_LL /* 725 */, TRICORE_INS_MADDSUMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsums.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDSUMS_H_rrr1_LU /* 726 */, TRICORE_INS_MADDSUMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsums.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDSUMS_H_rrr1_UL /* 727 */, TRICORE_INS_MADDSUMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsums.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDSUMS_H_rrr1_UU /* 728 */, TRICORE_INS_MADDSUMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsum.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDSUM_H_rrr1_LL /* 729 */, TRICORE_INS_MADDSUM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsum.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDSUM_H_rrr1_LU /* 730 */, TRICORE_INS_MADDSUM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsum.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDSUM_H_rrr1_UL /* 731 */, TRICORE_INS_MADDSUM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsum.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDSUM_H_rrr1_UU /* 732 */, TRICORE_INS_MADDSUM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsurs.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDSURS_H_rrr1_LL /* 733 */, TRICORE_INS_MADDSURS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsurs.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDSURS_H_rrr1_LU /* 734 */, TRICORE_INS_MADDSURS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsurs.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDSURS_H_rrr1_UL /* 735 */, TRICORE_INS_MADDSURS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsurs.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDSURS_H_rrr1_UU /* 736 */, TRICORE_INS_MADDSURS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsur.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDSUR_H_rrr1_LL /* 737 */, TRICORE_INS_MADDSUR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsur.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDSUR_H_rrr1_LU /* 738 */, TRICORE_INS_MADDSUR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsur.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDSUR_H_rrr1_UL /* 739 */, TRICORE_INS_MADDSUR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsur.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDSUR_H_rrr1_UU /* 740 */, TRICORE_INS_MADDSUR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsus.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDSUS_H_rrr1_LL /* 741 */, TRICORE_INS_MADDSUS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsus.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDSUS_H_rrr1_LU /* 742 */, TRICORE_INS_MADDSUS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsus.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDSUS_H_rrr1_UL /* 743 */, TRICORE_INS_MADDSUS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsus.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDSUS_H_rrr1_UU /* 744 */, TRICORE_INS_MADDSUS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsu.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDSU_H_rrr1_LL /* 745 */, TRICORE_INS_MADDSU_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsu.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDSU_H_rrr1_LU /* 746 */, TRICORE_INS_MADDSU_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsu.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDSU_H_rrr1_UL /* 747 */, TRICORE_INS_MADDSU_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* maddsu.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDSU_H_rrr1_UU /* 748 */, TRICORE_INS_MADDSU_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADDS_H_rrr1_LL /* 749 */, TRICORE_INS_MADDS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADDS_H_rrr1_LU /* 750 */, TRICORE_INS_MADDS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADDS_H_rrr1_UL /* 751 */, TRICORE_INS_MADDS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADDS_H_rrr1_UU /* 752 */, TRICORE_INS_MADDS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.h $d, $s3, $s1, $s2, $n */
  TRICORE_MADDS_H_rrr1_v110 /* 753 */, TRICORE_INS_MADDS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, $s1, $s2, $n */
  TRICORE_MADDS_Q_rrr1 /* 754 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, $s1, ${s2}l, $n */
  TRICORE_MADDS_Q_rrr1_L /* 755 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MADDS_Q_rrr1_L_L /* 756 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, $s1, ${s2}u, $n */
  TRICORE_MADDS_Q_rrr1_U /* 757 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, $s1, $s2, $n */
  TRICORE_MADDS_Q_rrr1_UU2_v110 /* 758 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MADDS_Q_rrr1_U_U /* 759 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, $s1, $s2, $n */
  TRICORE_MADDS_Q_rrr1_e /* 760 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, $s1, ${s2}l, $n */
  TRICORE_MADDS_Q_rrr1_e_L /* 761 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MADDS_Q_rrr1_e_L_L /* 762 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, $s1, ${s2}u, $n */
  TRICORE_MADDS_Q_rrr1_e_U /* 763 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MADDS_Q_rrr1_e_U_U /* 764 */, TRICORE_INS_MADDS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.u $d, $s3, $s1, $const9 */
  TRICORE_MADDS_U_rcr /* 765 */, TRICORE_INS_MADDS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* madds.u $d, $s3, $s1, $const9 */
  TRICORE_MADDS_U_rcr_e /* 766 */, TRICORE_INS_MADDS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds.u $d, $s3, $s1, $s2 */
  TRICORE_MADDS_U_rrr2 /* 767 */, TRICORE_INS_MADDS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* madds.u $d, $s3, $s1, $s2 */
  TRICORE_MADDS_U_rrr2_e /* 768 */, TRICORE_INS_MADDS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds $d, $s3, $s1, $const9 */
  TRICORE_MADDS_rcr /* 769 */, TRICORE_INS_MADDS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* madds $d, $s3, $s1, $const9 */
  TRICORE_MADDS_rcr_e /* 770 */, TRICORE_INS_MADDS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madds $d, $s3, $s1, $s2 */
  TRICORE_MADDS_rrr2 /* 771 */, TRICORE_INS_MADDS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* madds $d, $s3, $s1, $s2 */
  TRICORE_MADDS_rrr2_e /* 772 */, TRICORE_INS_MADDS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.f $d, $s3, $s1, $s2 */
  TRICORE_MADD_F_rrr /* 773 */, TRICORE_INS_MADD_F,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MADD_H_rrr1_LL /* 774 */, TRICORE_INS_MADD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MADD_H_rrr1_LU /* 775 */, TRICORE_INS_MADD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MADD_H_rrr1_UL /* 776 */, TRICORE_INS_MADD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MADD_H_rrr1_UU /* 777 */, TRICORE_INS_MADD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.h $d, $s3, $s1, $s2, $n */
  TRICORE_MADD_H_rrr1_v110 /* 778 */, TRICORE_INS_MADD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, $s1, $s2, $n */
  TRICORE_MADD_Q_rrr1 /* 779 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, $s1, ${s2}l, $n */
  TRICORE_MADD_Q_rrr1_L /* 780 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MADD_Q_rrr1_L_L /* 781 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, $s1, ${s2}u, $n */
  TRICORE_MADD_Q_rrr1_U /* 782 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, $s1, $s2, $n */
  TRICORE_MADD_Q_rrr1_UU2_v110 /* 783 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MADD_Q_rrr1_U_U /* 784 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, $s1, $s2, $n */
  TRICORE_MADD_Q_rrr1_e /* 785 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, $s1, ${s2}l, $n */
  TRICORE_MADD_Q_rrr1_e_L /* 786 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MADD_Q_rrr1_e_L_L /* 787 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, $s1, ${s2}u, $n */
  TRICORE_MADD_Q_rrr1_e_U /* 788 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MADD_Q_rrr1_e_U_U /* 789 */, TRICORE_INS_MADD_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.u $d, $s3, $s1, $const9 */
  TRICORE_MADD_U_rcr /* 790 */, TRICORE_INS_MADD_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd.u $d, $s3, $s1, $s2 */
  TRICORE_MADD_U_rrr2 /* 791 */, TRICORE_INS_MADD_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd $d, $s3, $s1, $const9 */
  TRICORE_MADD_rcr /* 792 */, TRICORE_INS_MADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* madd $d, $s3, $s1, $const9 */
  TRICORE_MADD_rcr_e /* 793 */, TRICORE_INS_MADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* madd $d, $s3, $s1, $s2 */
  TRICORE_MADD_rrr2 /* 794 */, TRICORE_INS_MADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* madd $d, $s3, $s1, $s2 */
  TRICORE_MADD_rrr2_e /* 795 */, TRICORE_INS_MADD,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* max.b $d, $s1, $s2 */
  TRICORE_MAX_B /* 796 */, TRICORE_INS_MAX_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* max.bu $d, $s1, $s2 */
  TRICORE_MAX_BU /* 797 */, TRICORE_INS_MAX_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* max.h $d, $s1, $s2 */
  TRICORE_MAX_H /* 798 */, TRICORE_INS_MAX_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* max.hu $d, $s1, $s2 */
  TRICORE_MAX_HU /* 799 */, TRICORE_INS_MAX_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* max.u $d, $s1, $const9 */
  TRICORE_MAX_U_rc /* 800 */, TRICORE_INS_MAX_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* max.u $d, $s1, $s2 */
  TRICORE_MAX_U_rr /* 801 */, TRICORE_INS_MAX_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* max $d, $s1, $const9 */
  TRICORE_MAX_rc /* 802 */, TRICORE_INS_MAX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* max $d, $s1, $s2 */
  TRICORE_MAX_rr /* 803 */, TRICORE_INS_MAX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mfcr $d, $const16 */
  TRICORE_MFCR_rlc /* 804 */, TRICORE_INS_MFCR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* min.b $d, $s1, $s2 */
  TRICORE_MIN_B /* 805 */, TRICORE_INS_MIN_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* min.bu $d, $s1, $s2 */
  TRICORE_MIN_BU /* 806 */, TRICORE_INS_MIN_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* min.h $d, $s1, $s2 */
  TRICORE_MIN_H /* 807 */, TRICORE_INS_MIN_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* min.hu $d, $s1, $s2 */
  TRICORE_MIN_HU /* 808 */, TRICORE_INS_MIN_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* min.u $d, $s1, $const9 */
  TRICORE_MIN_U_rc /* 809 */, TRICORE_INS_MIN_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* min.u $d, $s1, $s2 */
  TRICORE_MIN_U_rr /* 810 */, TRICORE_INS_MIN_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* min $d, $s1, $const9 */
  TRICORE_MIN_rc /* 811 */, TRICORE_INS_MIN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* min $d, $s1, $s2 */
  TRICORE_MIN_rr /* 812 */, TRICORE_INS_MIN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* movh.a $d, $const16 */
  TRICORE_MOVH_A_rlc /* 813 */, TRICORE_INS_MOVH_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* movh $d, $const16 */
  TRICORE_MOVH_rlc /* 814 */, TRICORE_INS_MOVH,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* movz.a $s1 */
  TRICORE_MOVZ_A_sr /* 815 */, TRICORE_INS_MOVZ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mov.aa $d, $s2 */
  TRICORE_MOV_AA_rr /* 816 */, TRICORE_INS_MOV_AA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mov.aa $d, $s2 */
  TRICORE_MOV_AA_srr_srr /* 817 */, TRICORE_INS_MOV_AA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mov.aa $d, $s2 */
  TRICORE_MOV_AA_srr_srr_v110 /* 818 */, TRICORE_INS_MOV_AA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mov.a $d, $s2 */
  TRICORE_MOV_A_rr /* 819 */, TRICORE_INS_MOV_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mov.a $d, $const4 */
  TRICORE_MOV_A_src /* 820 */, TRICORE_INS_MOV_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mov.a $d, $s2 */
  TRICORE_MOV_A_srr /* 821 */, TRICORE_INS_MOV_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mov.a $d, $s2 */
  TRICORE_MOV_A_srr_v110 /* 822 */, TRICORE_INS_MOV_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mov.d $d, $s2 */
  TRICORE_MOV_D_rr /* 823 */, TRICORE_INS_MOV_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mov.d $d, $s2 */
  TRICORE_MOV_D_srr_srr /* 824 */, TRICORE_INS_MOV_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mov.d $d, $s2 */
  TRICORE_MOV_D_srr_srr_v110 /* 825 */, TRICORE_INS_MOV_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mov.u $d, $const16 */
  TRICORE_MOV_U_rlc /* 826 */, TRICORE_INS_MOV_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mov $d, $const16 */
  TRICORE_MOV_rlc /* 827 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mov $d, $const16 */
  TRICORE_MOV_rlc_e /* 828 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* mov $d, $s2 */
  TRICORE_MOV_rr /* 829 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mov $d, $s2 */
  TRICORE_MOV_rr_e /* 830 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* mov $d, $s1, $s2 */
  TRICORE_MOV_rr_eab /* 831 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* mov d15, $const8 */
  TRICORE_MOV_sc /* 832 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mov d15, $const8 */
  TRICORE_MOV_sc_v110 /* 833 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mov $d, $const4 */
  TRICORE_MOV_src /* 834 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mov $d, $const4 */
  TRICORE_MOV_src_e /* 835 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* mov $d, $s2 */
  TRICORE_MOV_srr /* 836 */, TRICORE_INS_MOV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* msubadms.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBADMS_H_rrr1_LL /* 837 */, TRICORE_INS_MSUBADMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadms.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBADMS_H_rrr1_LU /* 838 */, TRICORE_INS_MSUBADMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadms.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBADMS_H_rrr1_UL /* 839 */, TRICORE_INS_MSUBADMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadms.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBADMS_H_rrr1_UU /* 840 */, TRICORE_INS_MSUBADMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadm.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBADM_H_rrr1_LL /* 841 */, TRICORE_INS_MSUBADM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadm.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBADM_H_rrr1_LU /* 842 */, TRICORE_INS_MSUBADM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadm.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBADM_H_rrr1_UL /* 843 */, TRICORE_INS_MSUBADM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadm.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBADM_H_rrr1_UU /* 844 */, TRICORE_INS_MSUBADM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadrs.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBADRS_H_rrr1_LL /* 845 */, TRICORE_INS_MSUBADRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadrs.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBADRS_H_rrr1_LU /* 846 */, TRICORE_INS_MSUBADRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadrs.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBADRS_H_rrr1_UL /* 847 */, TRICORE_INS_MSUBADRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadrs.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBADRS_H_rrr1_UU /* 848 */, TRICORE_INS_MSUBADRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadrs.h $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBADRS_H_rrr1_v110 /* 849 */, TRICORE_INS_MSUBADRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubadr.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBADR_H_rrr1_LL /* 850 */, TRICORE_INS_MSUBADR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadr.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBADR_H_rrr1_LU /* 851 */, TRICORE_INS_MSUBADR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadr.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBADR_H_rrr1_UL /* 852 */, TRICORE_INS_MSUBADR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadr.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBADR_H_rrr1_UU /* 853 */, TRICORE_INS_MSUBADR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubadr.h $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBADR_H_rrr1_v110 /* 854 */, TRICORE_INS_MSUBADR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubads.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBADS_H_rrr1_LL /* 855 */, TRICORE_INS_MSUBADS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubads.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBADS_H_rrr1_LU /* 856 */, TRICORE_INS_MSUBADS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubads.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBADS_H_rrr1_UL /* 857 */, TRICORE_INS_MSUBADS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubads.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBADS_H_rrr1_UU /* 858 */, TRICORE_INS_MSUBADS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubad.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBAD_H_rrr1_LL /* 859 */, TRICORE_INS_MSUBAD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubad.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBAD_H_rrr1_LU /* 860 */, TRICORE_INS_MSUBAD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubad.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBAD_H_rrr1_UL /* 861 */, TRICORE_INS_MSUBAD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubad.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBAD_H_rrr1_UU /* 862 */, TRICORE_INS_MSUBAD_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubms.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBMS_H_rrr1_LL /* 863 */, TRICORE_INS_MSUBMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubms.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBMS_H_rrr1_LU /* 864 */, TRICORE_INS_MSUBMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubms.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBMS_H_rrr1_UL /* 865 */, TRICORE_INS_MSUBMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubms.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBMS_H_rrr1_UU /* 866 */, TRICORE_INS_MSUBMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubms.u $d, $s3, $s1, $const9 */
  TRICORE_MSUBMS_U_rcrv110 /* 867 */, TRICORE_INS_MSUBMS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubms.u $d, $s3, $s1, $s2 */
  TRICORE_MSUBMS_U_rrr2v110 /* 868 */, TRICORE_INS_MSUBMS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubms $d, $s3, $s1, $const9 */
  TRICORE_MSUBMS_rcrv110 /* 869 */, TRICORE_INS_MSUBMS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubms $d, $s3, $s1, $s2 */
  TRICORE_MSUBMS_rrr2v110 /* 870 */, TRICORE_INS_MSUBMS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubm.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBM_H_rrr1_LL /* 871 */, TRICORE_INS_MSUBM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubm.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBM_H_rrr1_LU /* 872 */, TRICORE_INS_MSUBM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubm.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBM_H_rrr1_UL /* 873 */, TRICORE_INS_MSUBM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubm.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBM_H_rrr1_UU /* 874 */, TRICORE_INS_MSUBM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubm.h $d, $s3, $s1, $s2 */
  TRICORE_MSUBM_H_rrr1_v110 /* 875 */, TRICORE_INS_MSUBM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubm.q $d, $s3, $s1, $s2 */
  TRICORE_MSUBM_Q_rrr1_v110 /* 876 */, TRICORE_INS_MSUBM_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubm.u $d, $s3, $s1, $const9 */
  TRICORE_MSUBM_U_rcrv110 /* 877 */, TRICORE_INS_MSUBM_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubm.u $d, $s3, $s1, $s2 */
  TRICORE_MSUBM_U_rrr2v110 /* 878 */, TRICORE_INS_MSUBM_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubm $d, $s3, $s1, $const9 */
  TRICORE_MSUBM_rcrv110 /* 879 */, TRICORE_INS_MSUBM,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubm $d, $s3, $s1, $s2 */
  TRICORE_MSUBM_rrr2v110 /* 880 */, TRICORE_INS_MSUBM,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubrs.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBRS_H_rrr1_LL /* 881 */, TRICORE_INS_MSUBRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubrs.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBRS_H_rrr1_LU /* 882 */, TRICORE_INS_MSUBRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubrs.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBRS_H_rrr1_UL /* 883 */, TRICORE_INS_MSUBRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubrs.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBRS_H_rrr1_UL_2 /* 884 */, TRICORE_INS_MSUBRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubrs.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBRS_H_rrr1_UU /* 885 */, TRICORE_INS_MSUBRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubrs.h $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBRS_H_rrr1_v110 /* 886 */, TRICORE_INS_MSUBRS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubrs.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MSUBRS_Q_rrr1_L_L /* 887 */, TRICORE_INS_MSUBRS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubrs.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MSUBRS_Q_rrr1_U_U /* 888 */, TRICORE_INS_MSUBRS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubrs.q $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBRS_Q_rrr1_v110 /* 889 */, TRICORE_INS_MSUBRS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubr.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBR_H_rrr1_LL /* 890 */, TRICORE_INS_MSUBR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubr.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBR_H_rrr1_LU /* 891 */, TRICORE_INS_MSUBR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubr.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBR_H_rrr1_UL /* 892 */, TRICORE_INS_MSUBR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubr.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBR_H_rrr1_UL_2 /* 893 */, TRICORE_INS_MSUBR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubr.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBR_H_rrr1_UU /* 894 */, TRICORE_INS_MSUBR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubr.h $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBR_H_rrr1_v110 /* 895 */, TRICORE_INS_MSUBR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubr.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MSUBR_Q_rrr1_L_L /* 896 */, TRICORE_INS_MSUBR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubr.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MSUBR_Q_rrr1_U_U /* 897 */, TRICORE_INS_MSUBR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubr.q $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBR_Q_rrr1_v110 /* 898 */, TRICORE_INS_MSUBR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubs.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUBS_H_rrr1_LL /* 899 */, TRICORE_INS_MSUBS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUBS_H_rrr1_LU /* 900 */, TRICORE_INS_MSUBS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUBS_H_rrr1_UL /* 901 */, TRICORE_INS_MSUBS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUBS_H_rrr1_UU /* 902 */, TRICORE_INS_MSUBS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.h $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBS_H_rrr1_v110 /* 903 */, TRICORE_INS_MSUBS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBS_Q_rrr1 /* 904 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, $s1, ${s2}l, $n */
  TRICORE_MSUBS_Q_rrr1_L /* 905 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MSUBS_Q_rrr1_L_L /* 906 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, $s1, ${s2}u, $n */
  TRICORE_MSUBS_Q_rrr1_U /* 907 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBS_Q_rrr1_UU2_v110 /* 908 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MSUBS_Q_rrr1_U_U /* 909 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, $s1, $s2, $n */
  TRICORE_MSUBS_Q_rrr1_e /* 910 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, $s1, ${s2}l, $n */
  TRICORE_MSUBS_Q_rrr1_e_L /* 911 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MSUBS_Q_rrr1_e_L_L /* 912 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, $s1, ${s2}u, $n */
  TRICORE_MSUBS_Q_rrr1_e_U /* 913 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MSUBS_Q_rrr1_e_U_U /* 914 */, TRICORE_INS_MSUBS_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.u $d, $s3, $s1, $const9 */
  TRICORE_MSUBS_U_rcr /* 915 */, TRICORE_INS_MSUBS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* msubs.u $d, $s3, $s1, $const9 */
  TRICORE_MSUBS_U_rcr_e /* 916 */, TRICORE_INS_MSUBS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs.u $d, $s3, $s1, $s2 */
  TRICORE_MSUBS_U_rrr2 /* 917 */, TRICORE_INS_MSUBS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* msubs.u $d, $s3, $s1, $s2 */
  TRICORE_MSUBS_U_rrr2_e /* 918 */, TRICORE_INS_MSUBS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs $d, $s3, $s1, $const9 */
  TRICORE_MSUBS_rcr /* 919 */, TRICORE_INS_MSUBS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* msubs $d, $s3, $s1, $const9 */
  TRICORE_MSUBS_rcr_e /* 920 */, TRICORE_INS_MSUBS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msubs $d, $s3, $s1, $s2 */
  TRICORE_MSUBS_rrr2 /* 921 */, TRICORE_INS_MSUBS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* msubs $d, $s3, $s1, $s2 */
  TRICORE_MSUBS_rrr2_e /* 922 */, TRICORE_INS_MSUBS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.f $d, $s3, $s1, $s2 */
  TRICORE_MSUB_F_rrr /* 923 */, TRICORE_INS_MSUB_F,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.h $d, $s3, $s1, ${s2}ll, $n */
  TRICORE_MSUB_H_rrr1_LL /* 924 */, TRICORE_INS_MSUB_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.h $d, $s3, $s1, ${s2}lu, $n */
  TRICORE_MSUB_H_rrr1_LU /* 925 */, TRICORE_INS_MSUB_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.h $d, $s3, $s1, ${s2}ul, $n */
  TRICORE_MSUB_H_rrr1_UL /* 926 */, TRICORE_INS_MSUB_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.h $d, $s3, $s1, ${s2}uu, $n */
  TRICORE_MSUB_H_rrr1_UU /* 927 */, TRICORE_INS_MSUB_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.h $d, $s3, $s1, $s2, $n */
  TRICORE_MSUB_H_rrr1_v110 /* 928 */, TRICORE_INS_MSUB_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, $s1, $s2, $n */
  TRICORE_MSUB_Q_rrr1 /* 929 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, $s1, ${s2}l, $n */
  TRICORE_MSUB_Q_rrr1_L /* 930 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MSUB_Q_rrr1_L_L /* 931 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, $s1, ${s2}u, $n */
  TRICORE_MSUB_Q_rrr1_U /* 932 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, $s1, $s2, $n */
  TRICORE_MSUB_Q_rrr1_UU2_v110 /* 933 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MSUB_Q_rrr1_U_U /* 934 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, $s1, $s2, $n */
  TRICORE_MSUB_Q_rrr1_e /* 935 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, $s1, ${s2}l, $n */
  TRICORE_MSUB_Q_rrr1_e_L /* 936 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, ${s1}l, ${s2}l, $n */
  TRICORE_MSUB_Q_rrr1_e_L_L /* 937 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, $s1, ${s2}u, $n */
  TRICORE_MSUB_Q_rrr1_e_U /* 938 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.q $d, $s3, ${s1}u, ${s2}u, $n */
  TRICORE_MSUB_Q_rrr1_e_U_U /* 939 */, TRICORE_INS_MSUB_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.u $d, $s3, $s1, $const9 */
  TRICORE_MSUB_U_rcr /* 940 */, TRICORE_INS_MSUB_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub.u $d, $s3, $s1, $s2 */
  TRICORE_MSUB_U_rrr2 /* 941 */, TRICORE_INS_MSUB_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub $d, $s3, $s1, $const9 */
  TRICORE_MSUB_rcr /* 942 */, TRICORE_INS_MSUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* msub $d, $s3, $s1, $const9 */
  TRICORE_MSUB_rcr_e /* 943 */, TRICORE_INS_MSUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* msub $d, $s3, $s1, $s2 */
  TRICORE_MSUB_rrr2 /* 944 */, TRICORE_INS_MSUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* msub $d, $s3, $s1, $s2 */
  TRICORE_MSUB_rrr2_e /* 945 */, TRICORE_INS_MSUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mtcr $const16, $d */
  TRICORE_MTCR_rlc /* 946 */, TRICORE_INS_MTCR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mulms.h $d, ${s1}, ${s2}ll, $n */
  TRICORE_MULMS_H_rr1_LL2e /* 947 */, TRICORE_INS_MULMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulms.h $d, ${s1}, ${s2}lu, $n */
  TRICORE_MULMS_H_rr1_LU2e /* 948 */, TRICORE_INS_MULMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulms.h $d, ${s1}, ${s2}ul, $n */
  TRICORE_MULMS_H_rr1_UL2e /* 949 */, TRICORE_INS_MULMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulms.h $d, ${s1}, ${s2}uu, $n */
  TRICORE_MULMS_H_rr1_UU2e /* 950 */, TRICORE_INS_MULMS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulm.h $d, ${s1}, ${s2}ll, $n */
  TRICORE_MULM_H_rr1_LL2e /* 951 */, TRICORE_INS_MULM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulm.h $d, ${s1}, ${s2}lu, $n */
  TRICORE_MULM_H_rr1_LU2e /* 952 */, TRICORE_INS_MULM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulm.h $d, ${s1}, ${s2}ul, $n */
  TRICORE_MULM_H_rr1_UL2e /* 953 */, TRICORE_INS_MULM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulm.h $d, ${s1}, ${s2}uu, $n */
  TRICORE_MULM_H_rr1_UU2e /* 954 */, TRICORE_INS_MULM_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulm.u $d, $s1, $const9 */
  TRICORE_MULM_U_rc /* 955 */, TRICORE_INS_MULM_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mulm.u $d, $s1, $s2 */
  TRICORE_MULM_U_rr /* 956 */, TRICORE_INS_MULM_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mulm $d, $s1, $const9 */
  TRICORE_MULM_rc /* 957 */, TRICORE_INS_MULM,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mulm $d, $s1, $s2 */
  TRICORE_MULM_rr /* 958 */, TRICORE_INS_MULM,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mulr.h $d, ${s1}, ${s2}ll, $n */
  TRICORE_MULR_H_rr1_LL2e /* 959 */, TRICORE_INS_MULR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulr.h $d, ${s1}, ${s2}lu, $n */
  TRICORE_MULR_H_rr1_LU2e /* 960 */, TRICORE_INS_MULR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulr.h $d, ${s1}, ${s2}ul, $n */
  TRICORE_MULR_H_rr1_UL2e /* 961 */, TRICORE_INS_MULR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulr.h $d, ${s1}, ${s2}uu, $n */
  TRICORE_MULR_H_rr1_UU2e /* 962 */, TRICORE_INS_MULR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulr.h $d, $s1, $s2, $n */
  TRICORE_MULR_H_rr_v110 /* 963 */, TRICORE_INS_MULR_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mulr.q $d, ${s1}l, ${s2}l, $n */
  TRICORE_MULR_Q_rr1_2LL /* 964 */, TRICORE_INS_MULR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulr.q $d, ${s1}u, ${s2}u, $n */
  TRICORE_MULR_Q_rr1_2UU /* 965 */, TRICORE_INS_MULR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mulr.q $d, $s1, $s2, $n */
  TRICORE_MULR_Q_rr_v110 /* 966 */, TRICORE_INS_MULR_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* muls.u $d, $s1, $const9 */
  TRICORE_MULS_U_rc /* 967 */, TRICORE_INS_MULS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* muls.u $d, $s1, $s2 */
  TRICORE_MULS_U_rr2 /* 968 */, TRICORE_INS_MULS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* muls.u $d, $s1, $s2 */
  TRICORE_MULS_U_rr_v110 /* 969 */, TRICORE_INS_MULS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* muls $d, $s1, $const9 */
  TRICORE_MULS_rc /* 970 */, TRICORE_INS_MULS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* muls $d, $s1, $s2 */
  TRICORE_MULS_rr2 /* 971 */, TRICORE_INS_MULS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* muls $d, $s1, $s2 */
  TRICORE_MULS_rr_v110 /* 972 */, TRICORE_INS_MULS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mul.f $d, $s1, $s2 */
  TRICORE_MUL_F_rrr /* 973 */, TRICORE_INS_MUL_F,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.h $d, ${s1}, ${s2}ll, $n */
  TRICORE_MUL_H_rr1_LL2e /* 974 */, TRICORE_INS_MUL_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.h $d, ${s1}, ${s2}lu, $n */
  TRICORE_MUL_H_rr1_LU2e /* 975 */, TRICORE_INS_MUL_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.h $d, ${s1}, ${s2}ul, $n */
  TRICORE_MUL_H_rr1_UL2e /* 976 */, TRICORE_INS_MUL_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.h $d, ${s1}, ${s2}uu, $n */
  TRICORE_MUL_H_rr1_UU2e /* 977 */, TRICORE_INS_MUL_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.h $d, $s1, $s2, $n */
  TRICORE_MUL_H_rr_v110 /* 978 */, TRICORE_INS_MUL_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, ${s1}, ${s2}, $n */
  TRICORE_MUL_Q_rr1_2 /* 979 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, ${s1}l, ${s2}l, $n */
  TRICORE_MUL_Q_rr1_2LL /* 980 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, ${s1}u, ${s2}u, $n */
  TRICORE_MUL_Q_rr1_2UU /* 981 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, ${s1}, ${s2}l, $n */
  TRICORE_MUL_Q_rr1_2_L /* 982 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, ${s1}, ${s2}l, $n */
  TRICORE_MUL_Q_rr1_2_Le /* 983 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, ${s1}, ${s2}u, $n */
  TRICORE_MUL_Q_rr1_2_U /* 984 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, ${s1}, ${s2}u, $n */
  TRICORE_MUL_Q_rr1_2_Ue /* 985 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, ${s1}, ${s2}, $n */
  TRICORE_MUL_Q_rr1_2__e /* 986 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.q $d, $s1, $s2, $n */
  TRICORE_MUL_Q_rr_v110 /* 987 */, TRICORE_INS_MUL_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mul.u $d, $s1, $const9 */
  TRICORE_MUL_U_rc /* 988 */, TRICORE_INS_MUL_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul.u $d, $s1, $s2 */
  TRICORE_MUL_U_rr2 /* 989 */, TRICORE_INS_MUL_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul $d, $s1, $const9 */
  TRICORE_MUL_rc /* 990 */, TRICORE_INS_MUL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* mul $d, $s1, $const9 */
  TRICORE_MUL_rc_e /* 991 */, TRICORE_INS_MUL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul $d, $s1, $s2 */
  TRICORE_MUL_rr2 /* 992 */, TRICORE_INS_MUL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul $d, $s1, $s2 */
  TRICORE_MUL_rr2_e /* 993 */, TRICORE_INS_MUL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* mul $d, $s1, $s2 */
  TRICORE_MUL_rr_v110 /* 994 */, TRICORE_INS_MUL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* mul $d, $s2 */
  TRICORE_MUL_srr /* 995 */, TRICORE_INS_MUL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nand.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_NAND_T /* 996 */, TRICORE_INS_NAND_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nand $d, $s1, $const9 */
  TRICORE_NAND_rc /* 997 */, TRICORE_INS_NAND,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nand $d, $s1, $s2 */
  TRICORE_NAND_rr /* 998 */, TRICORE_INS_NAND,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nez.a $d, $s1 */
  TRICORE_NEZ_A /* 999 */, TRICORE_INS_NEZ_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ne.a $d, $s1, $s2 */
  TRICORE_NE_A /* 1000 */, TRICORE_INS_NE_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ne $d, $s1, $const9 */
  TRICORE_NE_rc /* 1001 */, TRICORE_INS_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ne $d, $s1, $s2 */
  TRICORE_NE_rr /* 1002 */, TRICORE_INS_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nop */
  TRICORE_NOP_sr /* 1003 */, TRICORE_INS_NOP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nop */
  TRICORE_NOP_sys /* 1004 */, TRICORE_INS_NOP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nor.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_NOR_T /* 1005 */, TRICORE_INS_NOR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nor $d, $s1, $const9 */
  TRICORE_NOR_rc /* 1006 */, TRICORE_INS_NOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nor $d, $s1, $s2 */
  TRICORE_NOR_rr /* 1007 */, TRICORE_INS_NOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* nor $s1 */
  TRICORE_NOR_sr /* 1008 */, TRICORE_INS_NOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* nor $s1 */
  TRICORE_NOR_sr_v110 /* 1009 */, TRICORE_INS_NOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* not $s1 */
  TRICORE_NOT_sr_v162 /* 1010 */, TRICORE_INS_NOT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162, 0 }, 0, 0
  #endif
},
{
  /* orn.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_ORN_T /* 1011 */, TRICORE_INS_ORN_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* orn $d, $s1, $const9 */
  TRICORE_ORN_rc /* 1012 */, TRICORE_INS_ORN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* orn $d, $s1, $s2 */
  TRICORE_ORN_rr /* 1013 */, TRICORE_INS_ORN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.andn.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_OR_ANDN_T /* 1014 */, TRICORE_INS_OR_ANDN_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.and.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_OR_AND_T /* 1015 */, TRICORE_INS_OR_AND_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.eq $d, $s1, $const9 */
  TRICORE_OR_EQ_rc /* 1016 */, TRICORE_INS_OR_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.eq $d, $s1, $s2 */
  TRICORE_OR_EQ_rr /* 1017 */, TRICORE_INS_OR_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.ge.u $d, $s1, $const9 */
  TRICORE_OR_GE_U_rc /* 1018 */, TRICORE_INS_OR_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.ge.u $d, $s1, $s2 */
  TRICORE_OR_GE_U_rr /* 1019 */, TRICORE_INS_OR_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.ge $d, $s1, $const9 */
  TRICORE_OR_GE_rc /* 1020 */, TRICORE_INS_OR_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.ge $d, $s1, $s2 */
  TRICORE_OR_GE_rr /* 1021 */, TRICORE_INS_OR_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.lt.u $d, $s1, $const9 */
  TRICORE_OR_LT_U_rc /* 1022 */, TRICORE_INS_OR_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.lt.u $d, $s1, $s2 */
  TRICORE_OR_LT_U_rr /* 1023 */, TRICORE_INS_OR_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.lt $d, $s1, $const9 */
  TRICORE_OR_LT_rc /* 1024 */, TRICORE_INS_OR_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.lt $d, $s1, $s2 */
  TRICORE_OR_LT_rr /* 1025 */, TRICORE_INS_OR_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.ne $d, $s1, $const9 */
  TRICORE_OR_NE_rc /* 1026 */, TRICORE_INS_OR_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.ne $d, $s1, $s2 */
  TRICORE_OR_NE_rr /* 1027 */, TRICORE_INS_OR_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.nor.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_OR_NOR_T /* 1028 */, TRICORE_INS_OR_NOR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.or.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_OR_OR_T /* 1029 */, TRICORE_INS_OR_OR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_OR_T /* 1030 */, TRICORE_INS_OR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or $d, $s1, $const9 */
  TRICORE_OR_rc /* 1031 */, TRICORE_INS_OR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or $d, $s1, $s2 */
  TRICORE_OR_rr /* 1032 */, TRICORE_INS_OR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* or d15, $const8 */
  TRICORE_OR_sc /* 1033 */, TRICORE_INS_OR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* or d15, $const8 */
  TRICORE_OR_sc_v110 /* 1034 */, TRICORE_INS_OR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* or $d, $s2 */
  TRICORE_OR_srr /* 1035 */, TRICORE_INS_OR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* or $d, $s2 */
  TRICORE_OR_srr_v110 /* 1036 */, TRICORE_INS_OR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* pack $d, $s3, $s1 */
  TRICORE_PACK_rrr /* 1037 */, TRICORE_INS_PACK,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* parity $d, $s1 */
  TRICORE_PARITY_rr /* 1038 */, TRICORE_INS_PARITY,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* parity $d, $s1 */
  TRICORE_PARITY_rr_v110 /* 1039 */, TRICORE_INS_PARITY,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* popcnt.w $d, $s1 */
  TRICORE_POPCNT_W_rr /* 1040 */, TRICORE_INS_POPCNT_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162, 0 }, 0, 0
  #endif
},
{
  /* q31tof $d, $s1, $s2 */
  TRICORE_Q31TOF_rr /* 1041 */, TRICORE_INS_Q31TOF,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* qseed.f $d, $s1 */
  TRICORE_QSEED_F_rr /* 1042 */, TRICORE_INS_QSEED_F,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* restore $s1 */
  TRICORE_RESTORE_sys /* 1043 */, TRICORE_INS_RESTORE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* ret */
  TRICORE_RET_sr /* 1044 */, TRICORE_INS_RET,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* ret */
  TRICORE_RET_sys /* 1045 */, TRICORE_INS_RET,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* ret */
  TRICORE_RET_sys_v110 /* 1046 */, TRICORE_INS_RET,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* rfe */
  TRICORE_RFE_sr /* 1047 */, TRICORE_INS_RFE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* rfe */
  TRICORE_RFE_sys_sys /* 1048 */, TRICORE_INS_RFE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* rfe */
  TRICORE_RFE_sys_sys_v110 /* 1049 */, TRICORE_INS_RFE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* rfm */
  TRICORE_RFM_sys /* 1050 */, TRICORE_INS_RFM,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* rslcx */
  TRICORE_RSLCX_sys /* 1051 */, TRICORE_INS_RSLCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* rstv */
  TRICORE_RSTV_sys /* 1052 */, TRICORE_INS_RSTV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* rsubs.u $d, $s1, $const9 */
  TRICORE_RSUBS_U_rc /* 1053 */, TRICORE_INS_RSUBS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* rsubs $d, $s1, $const9 */
  TRICORE_RSUBS_rc /* 1054 */, TRICORE_INS_RSUBS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* rsub $d, $s1, $const9 */
  TRICORE_RSUB_rc /* 1055 */, TRICORE_INS_RSUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* rsub $s1 */
  TRICORE_RSUB_sr_sr /* 1056 */, TRICORE_INS_RSUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* rsub $s1 */
  TRICORE_RSUB_sr_sr_v110 /* 1057 */, TRICORE_INS_RSUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sat.bu $d, $s1 */
  TRICORE_SAT_BU_rr /* 1058 */, TRICORE_INS_SAT_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sat.bu $s1 */
  TRICORE_SAT_BU_sr /* 1059 */, TRICORE_INS_SAT_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* sat.bu $s1 */
  TRICORE_SAT_BU_sr_v110 /* 1060 */, TRICORE_INS_SAT_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sat.b $d, $s1 */
  TRICORE_SAT_B_rr /* 1061 */, TRICORE_INS_SAT_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sat.b $s1 */
  TRICORE_SAT_B_sr /* 1062 */, TRICORE_INS_SAT_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* sat.b $s1 */
  TRICORE_SAT_B_sr_v110 /* 1063 */, TRICORE_INS_SAT_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sat.hu $d, $s1 */
  TRICORE_SAT_HU_rr /* 1064 */, TRICORE_INS_SAT_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sat.hu $s1 */
  TRICORE_SAT_HU_sr /* 1065 */, TRICORE_INS_SAT_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* sat.hu $s1 */
  TRICORE_SAT_HU_sr_v110 /* 1066 */, TRICORE_INS_SAT_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sat.h $d, $s1 */
  TRICORE_SAT_H_rr /* 1067 */, TRICORE_INS_SAT_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sat.h $s1 */
  TRICORE_SAT_H_sr /* 1068 */, TRICORE_INS_SAT_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* sat.h $s1 */
  TRICORE_SAT_H_sr_v110 /* 1069 */, TRICORE_INS_SAT_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* seln.a $d, $s3, $s1, $const9 */
  TRICORE_SELN_A_rcr_v110 /* 1070 */, TRICORE_INS_SELN_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* seln.a $d, $s3, $s1, $s2 */
  TRICORE_SELN_A_rrr_v110 /* 1071 */, TRICORE_INS_SELN_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* seln $d, $s3, $s1, $const9 */
  TRICORE_SELN_rcr /* 1072 */, TRICORE_INS_SELN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* seln $d, $s3, $s1, $s2 */
  TRICORE_SELN_rrr /* 1073 */, TRICORE_INS_SELN,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sel.a $d, $s3, $s1, $const9 */
  TRICORE_SEL_A_rcr_v110 /* 1074 */, TRICORE_INS_SEL_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sel.a $d, $s3, $s1, $s2 */
  TRICORE_SEL_A_rrr_v110 /* 1075 */, TRICORE_INS_SEL_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sel $d, $s3, $s1, $const9 */
  TRICORE_SEL_rcr /* 1076 */, TRICORE_INS_SEL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sel $d, $s3, $s1, $s2 */
  TRICORE_SEL_rrr /* 1077 */, TRICORE_INS_SEL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* shas $d, $s1, $const9 */
  TRICORE_SHAS_rc /* 1078 */, TRICORE_INS_SHAS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* shas $d, $s1, $s2 */
  TRICORE_SHAS_rr /* 1079 */, TRICORE_INS_SHAS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sha.b $d, $s1, $const9 */
  TRICORE_SHA_B_rc /* 1080 */, TRICORE_INS_SHA_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sha.b $d, $s1, $s2 */
  TRICORE_SHA_B_rr /* 1081 */, TRICORE_INS_SHA_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sha.h $d, $s1, $const9 */
  TRICORE_SHA_H_rc /* 1082 */, TRICORE_INS_SHA_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sha.h $d, $s1, $s2 */
  TRICORE_SHA_H_rr /* 1083 */, TRICORE_INS_SHA_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sha $d, $s1, $const9 */
  TRICORE_SHA_rc /* 1084 */, TRICORE_INS_SHA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sha $d, $s1, $s2 */
  TRICORE_SHA_rr /* 1085 */, TRICORE_INS_SHA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sha $d, $const4 */
  TRICORE_SHA_src /* 1086 */, TRICORE_INS_SHA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* sha $d, $const4 */
  TRICORE_SHA_src_v110 /* 1087 */, TRICORE_INS_SHA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* shuffle $d, $s1, $const9 */
  TRICORE_SHUFFLE_rc /* 1088 */, TRICORE_INS_SHUFFLE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV162, 0 }, 0, 0
  #endif
},
{
  /* sh.andn.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_SH_ANDN_T /* 1089 */, TRICORE_INS_SH_ANDN_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.and.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_SH_AND_T /* 1090 */, TRICORE_INS_SH_AND_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.b $d, $s1, $const9 */
  TRICORE_SH_B_rc /* 1091 */, TRICORE_INS_SH_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sh.b $d, $s1, $s2 */
  TRICORE_SH_B_rr /* 1092 */, TRICORE_INS_SH_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sh.eq $d, $s1, $const9 */
  TRICORE_SH_EQ_rc /* 1093 */, TRICORE_INS_SH_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.eq $d, $s1, $s2 */
  TRICORE_SH_EQ_rr /* 1094 */, TRICORE_INS_SH_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.ge.u $d, $s1, $const9 */
  TRICORE_SH_GE_U_rc /* 1095 */, TRICORE_INS_SH_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.ge.u $d, $s1, $s2 */
  TRICORE_SH_GE_U_rr /* 1096 */, TRICORE_INS_SH_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.ge $d, $s1, $const9 */
  TRICORE_SH_GE_rc /* 1097 */, TRICORE_INS_SH_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.ge $d, $s1, $s2 */
  TRICORE_SH_GE_rr /* 1098 */, TRICORE_INS_SH_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.h $d, $s1, $const9 */
  TRICORE_SH_H_rc /* 1099 */, TRICORE_INS_SH_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.h $d, $s1, $s2 */
  TRICORE_SH_H_rr /* 1100 */, TRICORE_INS_SH_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.lt.u $d, $s1, $const9 */
  TRICORE_SH_LT_U_rc /* 1101 */, TRICORE_INS_SH_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.lt.u $d, $s1, $s2 */
  TRICORE_SH_LT_U_rr /* 1102 */, TRICORE_INS_SH_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.lt $d, $s1, $const9 */
  TRICORE_SH_LT_rc /* 1103 */, TRICORE_INS_SH_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.lt $d, $s1, $s2 */
  TRICORE_SH_LT_rr /* 1104 */, TRICORE_INS_SH_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.nand.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_SH_NAND_T /* 1105 */, TRICORE_INS_SH_NAND_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.ne $d, $s1, $const9 */
  TRICORE_SH_NE_rc /* 1106 */, TRICORE_INS_SH_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.ne $d, $s1, $s2 */
  TRICORE_SH_NE_rr /* 1107 */, TRICORE_INS_SH_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.nor.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_SH_NOR_T /* 1108 */, TRICORE_INS_SH_NOR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.orn.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_SH_ORN_T /* 1109 */, TRICORE_INS_SH_ORN_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.or.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_SH_OR_T /* 1110 */, TRICORE_INS_SH_OR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.xnor.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_SH_XNOR_T /* 1111 */, TRICORE_INS_SH_XNOR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh.xor.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_SH_XOR_T /* 1112 */, TRICORE_INS_SH_XOR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh $d, $s1, $const9 */
  TRICORE_SH_rc /* 1113 */, TRICORE_INS_SH,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh $d, $s1, $s2 */
  TRICORE_SH_rr /* 1114 */, TRICORE_INS_SH,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sh $d, $const4 */
  TRICORE_SH_src /* 1115 */, TRICORE_INS_SH,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* sh $d, $const4 */
  TRICORE_SH_src_v110 /* 1116 */, TRICORE_INS_SH,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* stlcx $off18 */
  TRICORE_STLCX_abs /* 1117 */, TRICORE_INS_STLCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* stlcx [$s2]$off10 */
  TRICORE_STLCX_bo_bso /* 1118 */, TRICORE_INS_STLCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* stucx $off18 */
  TRICORE_STUCX_abs /* 1119 */, TRICORE_INS_STUCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* stucx [$s2]$off10 */
  TRICORE_STUCX_bo_bso /* 1120 */, TRICORE_INS_STUCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.a $off18, $s1 */
  TRICORE_ST_A_abs /* 1121 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.a [$s1]$off10, $d */
  TRICORE_ST_A_bo_bso /* 1122 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.a [${d}+c]$off10, $s1 */
  TRICORE_ST_A_bo_c /* 1123 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.a [${s2}+]$off10, $s1 */
  TRICORE_ST_A_bo_pos /* 1124 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.a [+${s2}]$off10, $s1 */
  TRICORE_ST_A_bo_pre /* 1125 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.a [${d}+r], $s1 */
  TRICORE_ST_A_bo_r /* 1126 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.a [$s2]$off16, $s1 */
  TRICORE_ST_A_bol /* 1127 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* st.a [sp]$const8, a15 */
  TRICORE_ST_A_sc /* 1128 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.a [$s2]$off4, a15 */
  TRICORE_ST_A_sro /* 1129 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.a [$s2]$off4, a15 */
  TRICORE_ST_A_sro_v110 /* 1130 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.a [$d], $s1 */
  TRICORE_ST_A_ssr /* 1131 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.a [${d}+], $s1 */
  TRICORE_ST_A_ssr_pos /* 1132 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.a [${d}+], $s1 */
  TRICORE_ST_A_ssr_pos_v110 /* 1133 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.a [$d], $s1 */
  TRICORE_ST_A_ssr_v110 /* 1134 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.a [a15]$off4, $s1 */
  TRICORE_ST_A_ssro /* 1135 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.a [a15]$off4, $s1 */
  TRICORE_ST_A_ssro_v110 /* 1136 */, TRICORE_INS_ST_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.b $off18, $s1 */
  TRICORE_ST_B_abs /* 1137 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.b [$s1]$off10, $d */
  TRICORE_ST_B_bo_bso /* 1138 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.b [${d}+c]$off10, $s1 */
  TRICORE_ST_B_bo_c /* 1139 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.b [${s2}+]$off10, $s1 */
  TRICORE_ST_B_bo_pos /* 1140 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.b [+${s2}]$off10, $s1 */
  TRICORE_ST_B_bo_pre /* 1141 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.b [${d}+r], $s1 */
  TRICORE_ST_B_bo_r /* 1142 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.b [$s2]$off16, $s1 */
  TRICORE_ST_B_bol /* 1143 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* st.b [$s2]$off4, d15 */
  TRICORE_ST_B_sro /* 1144 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.b [$s2]$off4, d15 */
  TRICORE_ST_B_sro_v110 /* 1145 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.b [$d], $s1 */
  TRICORE_ST_B_ssr /* 1146 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.b [${d}+], $s1 */
  TRICORE_ST_B_ssr_pos /* 1147 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.b [${d}+], $s1 */
  TRICORE_ST_B_ssr_pos_v110 /* 1148 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.b [$d], $s1 */
  TRICORE_ST_B_ssr_v110 /* 1149 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.b [a15]$off4, $s1 */
  TRICORE_ST_B_ssro /* 1150 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.b [a15]$off4, $s1 */
  TRICORE_ST_B_ssro_v110 /* 1151 */, TRICORE_INS_ST_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.da $off18, $s1 */
  TRICORE_ST_DA_abs /* 1152 */, TRICORE_INS_ST_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.da [$s1]$off10, $d */
  TRICORE_ST_DA_bo_bso /* 1153 */, TRICORE_INS_ST_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.da [${d}+c]$off10, $s1 */
  TRICORE_ST_DA_bo_c /* 1154 */, TRICORE_INS_ST_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.da [${s2}+]$off10, $s1 */
  TRICORE_ST_DA_bo_pos /* 1155 */, TRICORE_INS_ST_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.da [+${s2}]$off10, $s1 */
  TRICORE_ST_DA_bo_pre /* 1156 */, TRICORE_INS_ST_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.da [${d}+r], $s1 */
  TRICORE_ST_DA_bo_r /* 1157 */, TRICORE_INS_ST_DA,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.d $off18, $s1 */
  TRICORE_ST_D_abs /* 1158 */, TRICORE_INS_ST_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.d [$s1]$off10, $d */
  TRICORE_ST_D_bo_bso /* 1159 */, TRICORE_INS_ST_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.d [${d}+c]$off10, $s1 */
  TRICORE_ST_D_bo_c /* 1160 */, TRICORE_INS_ST_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.d [${s2}+]$off10, $s1 */
  TRICORE_ST_D_bo_pos /* 1161 */, TRICORE_INS_ST_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.d [+${s2}]$off10, $s1 */
  TRICORE_ST_D_bo_pre /* 1162 */, TRICORE_INS_ST_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.d [${d}+r], $s1 */
  TRICORE_ST_D_bo_r /* 1163 */, TRICORE_INS_ST_D,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.h $off18, $s1 */
  TRICORE_ST_H_abs /* 1164 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.h [$s1]$off10, $d */
  TRICORE_ST_H_bo_bso /* 1165 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.h [${d}+c]$off10, $s1 */
  TRICORE_ST_H_bo_c /* 1166 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.h [${s2}+]$off10, $s1 */
  TRICORE_ST_H_bo_pos /* 1167 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.h [+${s2}]$off10, $s1 */
  TRICORE_ST_H_bo_pre /* 1168 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.h [${d}+r], $s1 */
  TRICORE_ST_H_bo_r /* 1169 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.h [$s2]$off16, $s1 */
  TRICORE_ST_H_bol /* 1170 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* st.h [$s2]$off4, d15 */
  TRICORE_ST_H_sro /* 1171 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.h [$s2]$off4, d15 */
  TRICORE_ST_H_sro_v110 /* 1172 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.h [$d], $s1 */
  TRICORE_ST_H_ssr /* 1173 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.h [${d}+], $s1 */
  TRICORE_ST_H_ssr_pos /* 1174 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.h [${d}+], $s1 */
  TRICORE_ST_H_ssr_pos_v110 /* 1175 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.h [$d], $s1 */
  TRICORE_ST_H_ssr_v110 /* 1176 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.h [a15]$off4, $s1 */
  TRICORE_ST_H_ssro /* 1177 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.h [a15]$off4, $s1 */
  TRICORE_ST_H_ssro_v110 /* 1178 */, TRICORE_INS_ST_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.q $off18, $s1 */
  TRICORE_ST_Q_abs /* 1179 */, TRICORE_INS_ST_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.q [$s1]$off10, $d */
  TRICORE_ST_Q_bo_bso /* 1180 */, TRICORE_INS_ST_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.q [${d}+c]$off10, $s1 */
  TRICORE_ST_Q_bo_c /* 1181 */, TRICORE_INS_ST_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.q [${s2}+]$off10, $s1 */
  TRICORE_ST_Q_bo_pos /* 1182 */, TRICORE_INS_ST_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.q [+${s2}]$off10, $s1 */
  TRICORE_ST_Q_bo_pre /* 1183 */, TRICORE_INS_ST_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.q [${d}+r], $s1 */
  TRICORE_ST_Q_bo_r /* 1184 */, TRICORE_INS_ST_Q,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.t $off18, $bpos3, $b */
  TRICORE_ST_T /* 1185 */, TRICORE_INS_ST_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.w $off18, $s1 */
  TRICORE_ST_W_abs /* 1186 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.w [$s1]$off10, $d */
  TRICORE_ST_W_bo_bso /* 1187 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.w [${d}+c]$off10, $s1 */
  TRICORE_ST_W_bo_c /* 1188 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.w [${s2}+]$off10, $s1 */
  TRICORE_ST_W_bo_pos /* 1189 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.w [+${s2}]$off10, $s1 */
  TRICORE_ST_W_bo_pre /* 1190 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.w [${d}+r], $s1 */
  TRICORE_ST_W_bo_r /* 1191 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.w [$s2]$off16, $s1 */
  TRICORE_ST_W_bol /* 1192 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* st.w [sp]$const8, d15 */
  TRICORE_ST_W_sc /* 1193 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.w [$s2]$off4, d15 */
  TRICORE_ST_W_sro /* 1194 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.w [$s2]$off4, d15 */
  TRICORE_ST_W_sro_v110 /* 1195 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.w [$d], $s1 */
  TRICORE_ST_W_ssr /* 1196 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.w [${d}+], $s1 */
  TRICORE_ST_W_ssr_pos /* 1197 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.w [${d}+], $s1 */
  TRICORE_ST_W_ssr_pos_v110 /* 1198 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.w [$d], $s1 */
  TRICORE_ST_W_ssr_v110 /* 1199 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* st.w [a15]$off4, $s1 */
  TRICORE_ST_W_ssro /* 1200 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* st.w [a15]$off4, $s1 */
  TRICORE_ST_W_ssro_v110 /* 1201 */, TRICORE_INS_ST_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* subc $d, $s1, $s2 */
  TRICORE_SUBC_rr /* 1202 */, TRICORE_INS_SUBC,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* subsc.a $d, $s1, $s2, $n */
  TRICORE_SUBSC_A_rr /* 1203 */, TRICORE_INS_SUBSC_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* subs.bu $d, $s1, $s2 */
  TRICORE_SUBS_BU_rr /* 1204 */, TRICORE_INS_SUBS_BU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* subs.b $d, $s1, $s2 */
  TRICORE_SUBS_B_rr /* 1205 */, TRICORE_INS_SUBS_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* subs.hu $d, $s1, $s2 */
  TRICORE_SUBS_HU_rr /* 1206 */, TRICORE_INS_SUBS_HU,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* subs.h $d, $s1, $s2 */
  TRICORE_SUBS_H_rr /* 1207 */, TRICORE_INS_SUBS_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* subs.u $d, $s1, $s2 */
  TRICORE_SUBS_U_rr /* 1208 */, TRICORE_INS_SUBS_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* subs $d, $s1, $s2 */
  TRICORE_SUBS_rr /* 1209 */, TRICORE_INS_SUBS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* subs $d, $s2 */
  TRICORE_SUBS_srr /* 1210 */, TRICORE_INS_SUBS,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* subx $d, $s1, $s2 */
  TRICORE_SUBX_rr /* 1211 */, TRICORE_INS_SUBX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sub.a $d, $s1, $s2 */
  TRICORE_SUB_A_rr /* 1212 */, TRICORE_INS_SUB_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sub.a sp, $const8 */
  TRICORE_SUB_A_sc /* 1213 */, TRICORE_INS_SUB_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* sub.a sp, $const8 */
  TRICORE_SUB_A_sc_v110 /* 1214 */, TRICORE_INS_SUB_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* sub.b $d, $s1, $s2 */
  TRICORE_SUB_B_rr /* 1215 */, TRICORE_INS_SUB_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sub.f $d, $s3, $s1 */
  TRICORE_SUB_F_rrr /* 1216 */, TRICORE_INS_SUB_F,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* sub.h $d, $s1, $s2 */
  TRICORE_SUB_H_rr /* 1217 */, TRICORE_INS_SUB_H,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sub $d, $s1, $s2 */
  TRICORE_SUB_rr /* 1218 */, TRICORE_INS_SUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sub $d, $s2 */
  TRICORE_SUB_srr /* 1219 */, TRICORE_INS_SUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sub d15, $d, $s2 */
  TRICORE_SUB_srr_15a /* 1220 */, TRICORE_INS_SUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* sub $d, d15, $s2 */
  TRICORE_SUB_srr_a15 /* 1221 */, TRICORE_INS_SUB,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* svlcx */
  TRICORE_SVLCX_sys /* 1222 */, TRICORE_INS_SVLCX,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* swapmsk.w [$s1]$off10, $d */
  TRICORE_SWAPMSK_W_bo_bso /* 1223 */, TRICORE_INS_SWAPMSK_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* swapmsk.w [${d}+c]$off10, $s1 */
  TRICORE_SWAPMSK_W_bo_c /* 1224 */, TRICORE_INS_SWAPMSK_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* swapmsk.w [${s1}+i], $d */
  TRICORE_SWAPMSK_W_bo_i /* 1225 */, TRICORE_INS_SWAPMSK_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* swapmsk.w [${s2}+]$off10, $s1 */
  TRICORE_SWAPMSK_W_bo_pos /* 1226 */, TRICORE_INS_SWAPMSK_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* swapmsk.w [+${s2}]$off10, $s1 */
  TRICORE_SWAPMSK_W_bo_pre /* 1227 */, TRICORE_INS_SWAPMSK_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* swapmsk.w [${d}+r], $s1 */
  TRICORE_SWAPMSK_W_bo_r /* 1228 */, TRICORE_INS_SWAPMSK_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* swap.a $off18, $s1 */
  TRICORE_SWAP_A_abs /* 1229 */, TRICORE_INS_SWAP_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* swap.a [$s1]$off10, $d */
  TRICORE_SWAP_A_bo_bso /* 1230 */, TRICORE_INS_SWAP_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* swap.a [${d}+c]$off10, $s1 */
  TRICORE_SWAP_A_bo_c /* 1231 */, TRICORE_INS_SWAP_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* swap.a [${s2}+]$off10, $s1 */
  TRICORE_SWAP_A_bo_pos /* 1232 */, TRICORE_INS_SWAP_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* swap.a [+${s2}]$off10, $s1 */
  TRICORE_SWAP_A_bo_pre /* 1233 */, TRICORE_INS_SWAP_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* swap.a [${d}+r], $s1 */
  TRICORE_SWAP_A_bo_r /* 1234 */, TRICORE_INS_SWAP_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* swap.w $off18, $s1 */
  TRICORE_SWAP_W_abs /* 1235 */, TRICORE_INS_SWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* swap.w [$s1]$off10, $d */
  TRICORE_SWAP_W_bo_bso /* 1236 */, TRICORE_INS_SWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* swap.w [${d}+c]$off10, $s1 */
  TRICORE_SWAP_W_bo_c /* 1237 */, TRICORE_INS_SWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* swap.w [${s1}+i], $d */
  TRICORE_SWAP_W_bo_i /* 1238 */, TRICORE_INS_SWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV160_UP, 0 }, 0, 0
  #endif
},
{
  /* swap.w [${s2}+]$off10, $s1 */
  TRICORE_SWAP_W_bo_pos /* 1239 */, TRICORE_INS_SWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* swap.w [+${s2}]$off10, $s1 */
  TRICORE_SWAP_W_bo_pre /* 1240 */, TRICORE_INS_SWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* swap.w [${d}+r], $s1 */
  TRICORE_SWAP_W_bo_r /* 1241 */, TRICORE_INS_SWAP_W,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* syscall $const9 */
  TRICORE_SYSCALL_rc /* 1242 */, TRICORE_INS_SYSCALL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* tlbdemap $s1 */
  TRICORE_TLBDEMAP_rr /* 1243 */, TRICORE_INS_TLBDEMAP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* tlbflush.a */
  TRICORE_TLBFLUSH_A_rr /* 1244 */, TRICORE_INS_TLBFLUSH_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* tlbflush.b */
  TRICORE_TLBFLUSH_B_rr /* 1245 */, TRICORE_INS_TLBFLUSH_B,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* tlbmap $s1 */
  TRICORE_TLBMAP_rr /* 1246 */, TRICORE_INS_TLBMAP,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* tlbprobe.a $s1 */
  TRICORE_TLBPROBE_A_rr /* 1247 */, TRICORE_INS_TLBPROBE_A,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* tlbprobe.i $s1 */
  TRICORE_TLBPROBE_I_rr /* 1248 */, TRICORE_INS_TLBPROBE_I,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* trapsv */
  TRICORE_TRAPSV_sys /* 1249 */, TRICORE_INS_TRAPSV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* trapv */
  TRICORE_TRAPV_sys /* 1250 */, TRICORE_INS_TRAPV,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* unpack $d, $s1 */
  TRICORE_UNPACK_rr_rr /* 1251 */, TRICORE_INS_UNPACK,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
{
  /* unpack $d, $s1 */
  TRICORE_UNPACK_rr_rr_v110 /* 1252 */, TRICORE_INS_UNPACK,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV110, 0 }, 0, 0
  #endif
},
{
  /* updfl $s1 */
  TRICORE_UPDFL_rr /* 1253 */, TRICORE_INS_UPDFL,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* utof $d, $s1 */
  TRICORE_UTOF_rr /* 1254 */, TRICORE_INS_UTOF,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV130_UP, 0 }, 0, 0
  #endif
},
{
  /* wait */
  TRICORE_WAIT_sys /* 1255 */, TRICORE_INS_WAIT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV161_UP, 0 }, 0, 0
  #endif
},
{
  /* xnor.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_XNOR_T /* 1256 */, TRICORE_INS_XNOR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xnor $d, $s1, $const9 */
  TRICORE_XNOR_rc /* 1257 */, TRICORE_INS_XNOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xnor $d, $s1, $s2 */
  TRICORE_XNOR_rr /* 1258 */, TRICORE_INS_XNOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.eq $d, $s1, $const9 */
  TRICORE_XOR_EQ_rc /* 1259 */, TRICORE_INS_XOR_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.eq $d, $s1, $s2 */
  TRICORE_XOR_EQ_rr /* 1260 */, TRICORE_INS_XOR_EQ,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.ge.u $d, $s1, $const9 */
  TRICORE_XOR_GE_U_rc /* 1261 */, TRICORE_INS_XOR_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.ge.u $d, $s1, $s2 */
  TRICORE_XOR_GE_U_rr /* 1262 */, TRICORE_INS_XOR_GE_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.ge $d, $s1, $const9 */
  TRICORE_XOR_GE_rc /* 1263 */, TRICORE_INS_XOR_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.ge $d, $s1, $s2 */
  TRICORE_XOR_GE_rr /* 1264 */, TRICORE_INS_XOR_GE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.lt.u $d, $s1, $const9 */
  TRICORE_XOR_LT_U_rc /* 1265 */, TRICORE_INS_XOR_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.lt.u $d, $s1, $s2 */
  TRICORE_XOR_LT_U_rr /* 1266 */, TRICORE_INS_XOR_LT_U,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.lt $d, $s1, $const9 */
  TRICORE_XOR_LT_rc /* 1267 */, TRICORE_INS_XOR_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.lt $d, $s1, $s2 */
  TRICORE_XOR_LT_rr /* 1268 */, TRICORE_INS_XOR_LT,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.ne $d, $s1, $const9 */
  TRICORE_XOR_NE_rc /* 1269 */, TRICORE_INS_XOR_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.ne $d, $s1, $s2 */
  TRICORE_XOR_NE_rr /* 1270 */, TRICORE_INS_XOR_NE,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor.t $d, $s1, $pos1, $s2, $pos_r */
  TRICORE_XOR_T /* 1271 */, TRICORE_INS_XOR_T,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor $d, $s1, $const9 */
  TRICORE_XOR_rc /* 1272 */, TRICORE_INS_XOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor $d, $s1, $s2 */
  TRICORE_XOR_rr /* 1273 */, TRICORE_INS_XOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { 0 }, 0, 0
  #endif
},
{
  /* xor $d, $s2 */
  TRICORE_XOR_srr /* 1274 */, TRICORE_INS_XOR,
  #ifndef CAPSTONE_DIET
    { 0 }, { 0 }, { TRICORE_FEATURE_HasV120_UP, 0 }, 0, 0
  #endif
},
