/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Assembly Writer Source Fragment                                            *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

/// printInstruction - This method is automatically generated by tablegen
/// from the instruction set description.
static void printInstruction(MCInst *MI, SStream *O)
{
#ifndef CAPSTONE_DIET
  static const char AsmStrs[] = {
  /* 0 */ 'p', 'r', 'e', 'f', 'e', 't', 'c', 'h', 't', '0', 9, 0,
  /* 12 */ 's', 'h', 'a', '1', 'm', 's', 'g', '1', 9, 0,
  /* 22 */ 's', 'h', 'a', '2', '5', '6', 'm', 's', 'g', '1', 9, 0,
  /* 34 */ 'p', 'r', 'e', 'f', 'e', 't', 'c', 'h', 't', '1', 9, 0,
  /* 46 */ 'p', 'f', 'r', 'c', 'p', 'i', 't', '1', 9, 0,
  /* 56 */ 'p', 'f', 'r', 's', 'q', 'i', 't', '1', 9, 0,
  /* 66 */ 'p', 'r', 'e', 'f', 'e', 't', 'c', 'h', 'w', 't', '1', 9, 0,
  /* 79 */ 'v', 'm', 'o', 'v', 'd', 'q', 'a', '3', '2', 9, 0,
  /* 90 */ 'v', 'm', 'o', 'v', 'd', 'q', 'u', '3', '2', 9, 0,
  /* 101 */ 's', 'h', 'a', '1', 'm', 's', 'g', '2', 9, 0,
  /* 111 */ 's', 'h', 'a', '2', '5', '6', 'm', 's', 'g', '2', 9, 0,
  /* 123 */ 'p', 'r', 'e', 'f', 'e', 't', 'c', 'h', 't', '2', 9, 0,
  /* 135 */ 'p', 'f', 'r', 'c', 'p', 'i', 't', '2', 9, 0,
  /* 145 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'f', '3', '2', 'x', '2', 9, 0,
  /* 162 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'i', '3', '2', 'x', '2', 9, 0,
  /* 179 */ 'v', 's', 'h', 'u', 'f', 'f', '6', '4', 'x', '2', 9, 0,
  /* 191 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'f', '6', '4', 'x', '2', 9, 0,
  /* 206 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'f', '6', '4', 'x', '2', 9, 0,
  /* 220 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'f', '6', '4', 'x', '2', 9, 0,
  /* 237 */ 'v', 's', 'h', 'u', 'f', 'i', '6', '4', 'x', '2', 9, 0,
  /* 249 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'i', '6', '4', 'x', '2', 9, 0,
  /* 264 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'i', '6', '4', 'x', '2', 9, 0,
  /* 278 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'i', '6', '4', 'x', '2', 9, 0,
  /* 295 */ 'v', 'm', 'o', 'v', 'd', 'q', 'a', '6', '4', 9, 0,
  /* 306 */ 'x', 's', 'a', 'v', 'e', 'c', '6', '4', 9, 0,
  /* 316 */ 'f', 'x', 's', 'a', 'v', 'e', '6', '4', 9, 0,
  /* 326 */ 'f', 'x', 'r', 's', 't', 'o', 'r', '6', '4', 9, 0,
  /* 337 */ 'x', 's', 'a', 'v', 'e', 's', '6', '4', 9, 0,
  /* 347 */ 'x', 'r', 's', 't', 'o', 'r', 's', '6', '4', 9, 0,
  /* 358 */ 'x', 's', 'a', 'v', 'e', 'o', 'p', 't', '6', '4', 9, 0,
  /* 370 */ 'v', 'm', 'o', 'v', 'd', 'q', 'u', '6', '4', 9, 0,
  /* 381 */ 's', 'h', 'a', '1', 'r', 'n', 'd', 's', '4', 9, 0,
  /* 392 */ 'v', 's', 'h', 'u', 'f', 'f', '3', '2', 'x', '4', 9, 0,
  /* 404 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'f', '3', '2', 'x', '4', 9, 0,
  /* 419 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'f', '3', '2', 'x', '4', 9, 0,
  /* 433 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'f', '3', '2', 'x', '4', 9, 0,
  /* 450 */ 'v', 's', 'h', 'u', 'f', 'i', '3', '2', 'x', '4', 9, 0,
  /* 462 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'i', '3', '2', 'x', '4', 9, 0,
  /* 477 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'i', '3', '2', 'x', '4', 9, 0,
  /* 491 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'i', '3', '2', 'x', '4', 9, 0,
  /* 508 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'f', '6', '4', 'x', '4', 9, 0,
  /* 523 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'f', '6', '4', 'x', '4', 9, 0,
  /* 537 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'f', '6', '4', 'x', '4', 9, 0,
  /* 554 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'i', '6', '4', 'x', '4', 9, 0,
  /* 569 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'i', '6', '4', 'x', '4', 9, 0,
  /* 583 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'i', '6', '4', 'x', '4', 9, 0,
  /* 600 */ 'v', 'm', 'o', 'v', 'd', 'q', 'u', '1', '6', 9, 0,
  /* 611 */ 'v', 'p', 'e', 'r', 'm', '2', 'f', '1', '2', '8', 9, 0,
  /* 623 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'f', '1', '2', '8', 9, 0,
  /* 637 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'f', '1', '2', '8', 9, 0,
  /* 650 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'f', '1', '2', '8', 9, 0,
  /* 666 */ 'v', 'p', 'e', 'r', 'm', '2', 'i', '1', '2', '8', 9, 0,
  /* 678 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'i', '1', '2', '8', 9, 0,
  /* 692 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'i', '1', '2', '8', 9, 0,
  /* 705 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'i', '1', '2', '8', 9, 0,
  /* 721 */ 'v', 'm', 'o', 'v', 'd', 'q', 'u', '8', 9, 0,
  /* 731 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'f', '3', '2', 'x', '8', 9, 0,
  /* 746 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'f', '3', '2', 'x', '8', 9, 0,
  /* 760 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'f', '3', '2', 'x', '8', 9, 0,
  /* 777 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'i', '3', '2', 'x', '8', 9, 0,
  /* 792 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'i', '3', '2', 'x', '8', 9, 0,
  /* 806 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'i', '3', '2', 'x', '8', 9, 0,
  /* 823 */ 'j', 'a', 9, 0,
  /* 827 */ 'v', 'm', 'o', 'v', 'n', 't', 'd', 'q', 'a', 9, 0,
  /* 838 */ 'v', 'm', 'o', 'v', 'd', 'q', 'a', 9, 0,
  /* 847 */ 's', 'e', 't', 'a', 9, 0,
  /* 853 */ 'p', 'r', 'e', 'f', 'e', 't', 'c', 'h', 'n', 't', 'a', 9, 0,
  /* 866 */ 'c', 'r', 'c', '3', '2', 'b', 9, 0,
  /* 874 */ 'v', 'p', 'e', 'r', 'm', 'i', '2', 'b', 9, 0,
  /* 884 */ 'v', 'p', 'm', 'o', 'v', 'm', '2', 'b', 9, 0,
  /* 894 */ 'v', 'p', 'e', 'r', 'm', 't', '2', 'b', 9, 0,
  /* 904 */ 'm', 'o', 'v', 'd', 'i', 'r', '6', '4', 'b', 9, 0,
  /* 915 */ 'c', 'm', 'p', 'x', 'c', 'h', 'g', '1', '6', 'b', 9, 0,
  /* 927 */ 'c', 'm', 'p', 'x', 'c', 'h', 'g', '8', 'b', 9, 0,
  /* 938 */ 'v', 'p', 's', 'h', 'a', 'b', 9, 0,
  /* 946 */ 's', 'b', 'b', 'b', 9, 0,
  /* 952 */ 'v', 'p', 's', 'u', 'b', 'b', 9, 0,
  /* 960 */ 'a', 'd', 'c', 'b', 9, 0,
  /* 966 */ 'd', 'e', 'c', 'b', 9, 0,
  /* 972 */ 'i', 'n', 'c', 'b', 9, 0,
  /* 978 */ 'l', 'l', 'w', 'p', 'c', 'b', 9, 0,
  /* 986 */ 's', 'l', 'w', 'p', 'c', 'b', 9, 0,
  /* 994 */ 'k', 'a', 'd', 'd', 'b', 9, 0,
  /* 1001 */ 'v', 'p', 'a', 'd', 'd', 'b', 9, 0,
  /* 1009 */ 'x', 'a', 'd', 'd', 'b', 9, 0,
  /* 1016 */ 'k', 'a', 'n', 'd', 'b', 9, 0,
  /* 1023 */ 'v', 'p', 'e', 'x', 'p', 'a', 'n', 'd', 'b', 9, 0,
  /* 1034 */ 'v', 'p', 'm', 'o', 'v', 'u', 's', 'd', 'b', 9, 0,
  /* 1045 */ 'v', 'p', 'm', 'o', 'v', 's', 'd', 'b', 9, 0,
  /* 1055 */ 'v', 'p', 'm', 'o', 'v', 'd', 'b', 9, 0,
  /* 1064 */ 'v', 'p', 's', 'h', 'u', 'f', 'b', 9, 0,
  /* 1073 */ 'n', 'e', 'g', 'b', 9, 0,
  /* 1079 */ 'c', 'm', 'p', 'x', 'c', 'h', 'g', 'b', 9, 0,
  /* 1089 */ 'v', 'p', 'a', 'v', 'g', 'b', 9, 0,
  /* 1097 */ 'j', 'b', 9, 0,
  /* 1101 */ 'v', 'p', 'm', 'o', 'v', 'm', 's', 'k', 'b', 9, 0,
  /* 1112 */ 's', 'a', 'l', 'b', 9, 0,
  /* 1118 */ 'r', 'c', 'l', 'b', 9, 0,
  /* 1124 */ 'v', 'p', 's', 'h', 'l', 'b', 9, 0,
  /* 1132 */ 'r', 'o', 'l', 'b', 9, 0,
  /* 1138 */ 'k', 's', 'h', 'i', 'f', 't', 'l', 'b', 9, 0,
  /* 1148 */ 'v', 'g', 'f', '2', 'p', '8', 'm', 'u', 'l', 'b', 9, 0,
  /* 1160 */ 'i', 'm', 'u', 'l', 'b', 9, 0,
  /* 1167 */ 'v', 'p', 'b', 'l', 'e', 'n', 'd', 'm', 'b', 9, 0,
  /* 1178 */ 'v', 'p', 't', 'e', 's', 't', 'n', 'm', 'b', 9, 0,
  /* 1189 */ 'v', 'p', 'c', 'o', 'm', 'b', 9, 0,
  /* 1197 */ 'v', 'p', 's', 'h', 'u', 'f', 'b', 'i', 't', 'q', 'm', 'b', 9, 0,
  /* 1211 */ 'v', 'p', 'e', 'r', 'm', 'b', 9, 0,
  /* 1219 */ 'v', 'p', 't', 'e', 's', 't', 'm', 'b', 9, 0,
  /* 1229 */ 'k', 'a', 'n', 'd', 'n', 'b', 9, 0,
  /* 1237 */ 'v', 'p', 's', 'i', 'g', 'n', 'b', 9, 0,
  /* 1246 */ 'i', 'n', 'b', 9, 0,
  /* 1251 */ 'f', 'c', 'm', 'o', 'v', 'n', 'b', 9, 0,
  /* 1260 */ 'v', 'p', 'c', 'm', 'p', 'b', 9, 0,
  /* 1268 */ 'v', 'g', 'f', '2', 'p', '8', 'a', 'f', 'f', 'i', 'n', 'e', 'q', 'b', 9, 0,
  /* 1284 */ 'v', 'p', 'c', 'm', 'p', 'e', 'q', 'b', 9, 0,
  /* 1294 */ 'v', 'p', 'm', 'o', 'v', 'u', 's', 'q', 'b', 9, 0,
  /* 1305 */ 'v', 'p', 'm', 'o', 'v', 's', 'q', 'b', 9, 0,
  /* 1315 */ 'v', 'p', 'm', 'u', 'l', 't', 'i', 's', 'h', 'i', 'f', 't', 'q', 'b', 9, 0,
  /* 1331 */ 'v', 'g', 'f', '2', 'p', '8', 'a', 'f', 'f', 'i', 'n', 'e', 'i', 'n', 'v', 'q', 'b', 9, 0,
  /* 1350 */ 'v', 'p', 'm', 'o', 'v', 'q', 'b', 9, 0,
  /* 1359 */ 's', 'a', 'r', 'b', 9, 0,
  /* 1365 */ 'r', 'c', 'r', 'b', 9, 0,
  /* 1371 */ 's', 'h', 'r', 'b', 9, 0,
  /* 1377 */ 'k', 'o', 'r', 'b', 9, 0,
  /* 1383 */ 'k', 'x', 'n', 'o', 'r', 'b', 9, 0,
  /* 1391 */ 'r', 'o', 'r', 'b', 9, 0,
  /* 1397 */ 'k', 'x', 'o', 'r', 'b', 9, 0,
  /* 1404 */ 'v', 'p', 'i', 'n', 's', 'r', 'b', 9, 0,
  /* 1413 */ 'k', 's', 'h', 'i', 'f', 't', 'r', 'b', 9, 0,
  /* 1423 */ 'v', 'p', 'e', 'x', 't', 'r', 'b', 9, 0,
  /* 1432 */ 's', 'c', 'a', 's', 'b', 9, 0,
  /* 1439 */ 'v', 'p', 'a', 'b', 's', 'b', 9, 0,
  /* 1447 */ 'm', 'o', 'v', 'a', 'b', 's', 'b', 9, 0,
  /* 1456 */ 'v', 'p', 's', 'u', 'b', 's', 'b', 9, 0,
  /* 1465 */ 'v', 'p', 'a', 'd', 'd', 's', 'b', 9, 0,
  /* 1474 */ 'l', 'o', 'd', 's', 'b', 9, 0,
  /* 1481 */ 'v', 'p', 'm', 'i', 'n', 's', 'b', 9, 0,
  /* 1490 */ 'c', 'm', 'p', 's', 'b', 9, 0,
  /* 1497 */ 'v', 'p', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'b', 9, 0,
  /* 1510 */ 'o', 'u', 't', 's', 'b', 9, 0,
  /* 1517 */ 'v', 'p', 's', 'u', 'b', 'u', 's', 'b', 9, 0,
  /* 1527 */ 'v', 'p', 'a', 'd', 'd', 'u', 's', 'b', 9, 0,
  /* 1537 */ 'p', 'a', 'v', 'g', 'u', 's', 'b', 9, 0,
  /* 1546 */ 'm', 'o', 'v', 's', 'b', 9, 0,
  /* 1553 */ 'v', 'p', 'm', 'a', 'x', 's', 'b', 9, 0,
  /* 1562 */ 's', 'e', 't', 'b', 9, 0,
  /* 1568 */ 'v', 'p', 'c', 'm', 'p', 'g', 't', 'b', 9, 0,
  /* 1578 */ 'v', 'p', 'o', 'p', 'c', 'n', 't', 'b', 9, 0,
  /* 1588 */ 'k', 'n', 'o', 't', 'b', 9, 0,
  /* 1595 */ 'v', 'p', 'r', 'o', 't', 'b', 9, 0,
  /* 1603 */ 'v', 'p', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'b', 9, 0,
  /* 1617 */ 'k', 't', 'e', 's', 't', 'b', 9, 0,
  /* 1625 */ 'k', 'o', 'r', 't', 'e', 's', 't', 'b', 9, 0,
  /* 1635 */ 'v', 'p', 'c', 'o', 'm', 'u', 'b', 9, 0,
  /* 1644 */ 'v', 'p', 'm', 'i', 'n', 'u', 'b', 9, 0,
  /* 1653 */ 'v', 'p', 'c', 'm', 'p', 'u', 'b', 9, 0,
  /* 1662 */ 'p', 'f', 's', 'u', 'b', 9, 0,
  /* 1669 */ 'v', 'p', 'm', 'a', 'x', 'u', 'b', 9, 0,
  /* 1678 */ 'v', 'p', 'b', 'l', 'e', 'n', 'd', 'v', 'b', 9, 0,
  /* 1689 */ 'i', 'd', 'i', 'v', 'b', 9, 0,
  /* 1696 */ 'f', 'c', 'm', 'o', 'v', 'b', 9, 0,
  /* 1704 */ 'k', 'm', 'o', 'v', 'b', 9, 0,
  /* 1711 */ 'c', 'l', 'w', 'b', 9, 0,
  /* 1717 */ 'v', 'p', 'a', 'c', 'k', 's', 's', 'w', 'b', 9, 0,
  /* 1728 */ 'v', 'p', 'a', 'c', 'k', 'u', 's', 'w', 'b', 9, 0,
  /* 1739 */ 'v', 'p', 'm', 'o', 'v', 'u', 's', 'w', 'b', 9, 0,
  /* 1750 */ 'v', 'p', 'm', 'o', 'v', 's', 'w', 'b', 9, 0,
  /* 1760 */ 'v', 'p', 'm', 'o', 'v', 'w', 'b', 9, 0,
  /* 1769 */ 'p', 'f', 'a', 'c', 'c', 9, 0,
  /* 1776 */ 'p', 'f', 'n', 'a', 'c', 'c', 9, 0,
  /* 1784 */ 'p', 'f', 'p', 'n', 'a', 'c', 'c', 9, 0,
  /* 1793 */ 'v', 'a', 'e', 's', 'd', 'e', 'c', 9, 0,
  /* 1802 */ 'x', 's', 'a', 'v', 'e', 'c', 9, 0,
  /* 1810 */ 'v', 'a', 'e', 's', 'i', 'm', 'c', 9, 0,
  /* 1819 */ 'v', 'a', 'e', 's', 'e', 'n', 'c', 9, 0,
  /* 1828 */ 'v', 'p', 'e', 'r', 'm', 'i', '2', 'd', 9, 0,
  /* 1838 */ 'v', 'p', 'm', 'o', 'v', 'm', '2', 'd', 9, 0,
  /* 1848 */ 'v', 'p', 'e', 'r', 'm', 't', '2', 'd', 9, 0,
  /* 1858 */ 'v', 'p', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'm', 'w', '2', 'd', 9, 0,
  /* 1875 */ 'a', 'a', 'd', 9, 0,
  /* 1880 */ 'v', 'p', 's', 'h', 'a', 'd', 9, 0,
  /* 1888 */ 'v', 'p', 's', 'r', 'a', 'd', 9, 0,
  /* 1896 */ 'v', 'p', 'h', 'a', 'd', 'd', 'b', 'd', 9, 0,
  /* 1906 */ 'v', 'p', 'h', 'a', 'd', 'd', 'u', 'b', 'd', 9, 0,
  /* 1917 */ 'v', 'p', 'h', 's', 'u', 'b', 'd', 9, 0,
  /* 1926 */ 'v', 'p', 's', 'u', 'b', 'd', 9, 0,
  /* 1934 */ 'v', 'p', 'm', 'o', 'v', 's', 'x', 'b', 'd', 9, 0,
  /* 1945 */ 'v', 'p', 'm', 'o', 'v', 'z', 'x', 'b', 'd', 9, 0,
  /* 1956 */ 'p', 'f', 'a', 'd', 'd', 9, 0,
  /* 1963 */ 'v', 'p', 'h', 'a', 'd', 'd', 'd', 9, 0,
  /* 1972 */ 'k', 'a', 'd', 'd', 'd', 9, 0,
  /* 1979 */ 'v', 'p', 'a', 'd', 'd', 'd', 9, 0,
  /* 1987 */ 'v', 'p', 's', 'h', 'l', 'd', 'd', 9, 0,
  /* 1996 */ 'k', 'a', 'n', 'd', 'd', 9, 0,
  /* 2003 */ 'v', 'p', 'a', 'n', 'd', 'd', 9, 0,
  /* 2011 */ 'v', 'p', 'e', 'x', 'p', 'a', 'n', 'd', 'd', 9, 0,
  /* 2022 */ 'v', 'p', 'b', 'l', 'e', 'n', 'd', 'd', 9, 0,
  /* 2032 */ 'v', 'p', 'g', 'a', 't', 'h', 'e', 'r', 'd', 'd', 9, 0,
  /* 2044 */ 'v', 'p', 's', 'c', 'a', 't', 't', 'e', 'r', 'd', 'd', 9, 0,
  /* 2057 */ 'v', 'p', 's', 'h', 'r', 'd', 'd', 9, 0,
  /* 2066 */ 'v', 'p', 'm', 'a', 'c', 's', 'd', 'd', 9, 0,
  /* 2076 */ 'v', 'p', 'm', 'a', 'c', 's', 's', 'd', 'd', 9, 0,
  /* 2087 */ 'p', 'i', '2', 'f', 'd', 9, 0,
  /* 2094 */ 'v', 'p', 's', 'h', 'u', 'f', 'd', 9, 0,
  /* 2103 */ 'v', 'p', 't', 'e', 'r', 'n', 'l', 'o', 'g', 'd', 9, 0,
  /* 2115 */ 'p', 'f', '2', 'i', 'd', 9, 0,
  /* 2122 */ 'i', 'n', 'v', 'p', 'c', 'i', 'd', 9, 0,
  /* 2131 */ 'r', 'd', 'p', 'i', 'd', 9, 0,
  /* 2138 */ 'i', 'n', 'v', 'v', 'p', 'i', 'd', 9, 0,
  /* 2147 */ 'f', 'l', 'd', 9, 0,
  /* 2152 */ 'v', 'p', 's', 'h', 'l', 'd', 9, 0,
  /* 2160 */ 'v', 'p', 's', 'l', 'l', 'd', 9, 0,
  /* 2168 */ 'v', 'p', 'm', 'u', 'l', 'l', 'd', 9, 0,
  /* 2177 */ 'v', 'p', 'r', 'o', 'l', 'd', 9, 0,
  /* 2185 */ 'v', 'p', 's', 'r', 'l', 'd', 9, 0,
  /* 2193 */ 'v', 'm', 'p', 't', 'r', 'l', 'd', 9, 0,
  /* 2202 */ 'k', 's', 'h', 'i', 'f', 't', 'l', 'd', 9, 0,
  /* 2212 */ 'v', 'p', 'b', 'l', 'e', 'n', 'd', 'm', 'd', 9, 0,
  /* 2223 */ 'v', 'p', 't', 'e', 's', 't', 'n', 'm', 'd', 9, 0,
  /* 2234 */ 'v', 'p', 'c', 'o', 'm', 'd', 9, 0,
  /* 2242 */ 'v', 'p', 'e', 'r', 'm', 'd', 9, 0,
  /* 2250 */ 'v', 'p', 't', 'e', 's', 't', 'm', 'd', 9, 0,
  /* 2260 */ 'v', 'p', 'a', 'n', 'd', 9, 0,
  /* 2267 */ 'k', 'a', 'n', 'd', 'n', 'd', 9, 0,
  /* 2275 */ 'v', 'p', 'a', 'n', 'd', 'n', 'd', 9, 0,
  /* 2284 */ 'v', 'a', 'l', 'i', 'g', 'n', 'd', 9, 0,
  /* 2293 */ 'v', 'p', 's', 'i', 'g', 'n', 'd', 9, 0,
  /* 2302 */ 'b', 'o', 'u', 'n', 'd', 9, 0,
  /* 2309 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'u', 'b', '2', '3', '1', 'p', 'd', 9, 0,
  /* 2325 */ 'v', 'f', 'm', 's', 'u', 'b', '2', '3', '1', 'p', 'd', 9, 0,
  /* 2338 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '2', '3', '1', 'p', 'd', 9, 0,
  /* 2352 */ 'v', 'f', 'm', 's', 'u', 'b', 'a', 'd', 'd', '2', '3', '1', 'p', 'd', 9, 0,
  /* 2368 */ 'v', 'f', 'm', 'a', 'd', 'd', '2', '3', '1', 'p', 'd', 9, 0,
  /* 2381 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '2', '3', '1', 'p', 'd', 9, 0,
  /* 2395 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'u', 'b', '1', '3', '2', 'p', 'd', 9, 0,
  /* 2411 */ 'v', 'f', 'm', 's', 'u', 'b', '1', '3', '2', 'p', 'd', 9, 0,
  /* 2424 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '1', '3', '2', 'p', 'd', 9, 0,
  /* 2438 */ 'v', 'f', 'm', 's', 'u', 'b', 'a', 'd', 'd', '1', '3', '2', 'p', 'd', 9, 0,
  /* 2454 */ 'v', 'f', 'm', 'a', 'd', 'd', '1', '3', '2', 'p', 'd', 9, 0,
  /* 2467 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '1', '3', '2', 'p', 'd', 9, 0,
  /* 2481 */ 'v', 'p', 'e', 'r', 'm', 'i', '2', 'p', 'd', 9, 0,
  /* 2492 */ 'c', 'v', 't', 'p', 'i', '2', 'p', 'd', 9, 0,
  /* 2502 */ 'v', 'p', 'e', 'r', 'm', 'i', 'l', '2', 'p', 'd', 9, 0,
  /* 2514 */ 'v', 'e', 'x', 'p', '2', 'p', 'd', 9, 0,
  /* 2523 */ 'v', 'c', 'v', 't', 'd', 'q', '2', 'p', 'd', 9, 0,
  /* 2534 */ 'v', 'c', 'v', 't', 'u', 'd', 'q', '2', 'p', 'd', 9, 0,
  /* 2546 */ 'v', 'c', 'v', 't', 'q', 'q', '2', 'p', 'd', 9, 0,
  /* 2557 */ 'v', 'c', 'v', 't', 'u', 'q', 'q', '2', 'p', 'd', 9, 0,
  /* 2569 */ 'v', 'c', 'v', 't', 'p', 's', '2', 'p', 'd', 9, 0,
  /* 2580 */ 'v', 'p', 'e', 'r', 'm', 't', '2', 'p', 'd', 9, 0,
  /* 2591 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'u', 'b', '2', '1', '3', 'p', 'd', 9, 0,
  /* 2607 */ 'v', 'f', 'm', 's', 'u', 'b', '2', '1', '3', 'p', 'd', 9, 0,
  /* 2620 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '2', '1', '3', 'p', 'd', 9, 0,
  /* 2634 */ 'v', 'f', 'm', 's', 'u', 'b', 'a', 'd', 'd', '2', '1', '3', 'p', 'd', 9, 0,
  /* 2650 */ 'v', 'f', 'm', 'a', 'd', 'd', '2', '1', '3', 'p', 'd', 9, 0,
  /* 2663 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '2', '1', '3', 'p', 'd', 9, 0,
  /* 2677 */ 'v', 'r', 'c', 'p', '1', '4', 'p', 'd', 9, 0,
  /* 2687 */ 'v', 'r', 's', 'q', 'r', 't', '1', '4', 'p', 'd', 9, 0,
  /* 2699 */ 'v', 'r', 'c', 'p', '2', '8', 'p', 'd', 9, 0,
  /* 2709 */ 'v', 'r', 's', 'q', 'r', 't', '2', '8', 'p', 'd', 9, 0,
  /* 2721 */ 'v', 'm', 'o', 'v', 'a', 'p', 'd', 9, 0,
  /* 2730 */ 'p', 's', 'w', 'a', 'p', 'd', 9, 0,
  /* 2738 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'u', 'b', 'p', 'd', 9, 0,
  /* 2751 */ 'v', 'a', 'd', 'd', 's', 'u', 'b', 'p', 'd', 9, 0,
  /* 2762 */ 'v', 'h', 's', 'u', 'b', 'p', 'd', 9, 0,
  /* 2771 */ 'v', 'f', 'm', 's', 'u', 'b', 'p', 'd', 9, 0,
  /* 2781 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', 'p', 'd', 9, 0,
  /* 2792 */ 'v', 's', 'u', 'b', 'p', 'd', 9, 0,
  /* 2800 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'p', 'f', '0', 'd', 'p', 'd', 9, 0,
  /* 2815 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'p', 'f', '0', 'd', 'p', 'd', 9, 0,
  /* 2831 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'p', 'f', '1', 'd', 'p', 'd', 9, 0,
  /* 2846 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'p', 'f', '1', 'd', 'p', 'd', 9, 0,
  /* 2862 */ 'v', 'f', 'm', 's', 'u', 'b', 'a', 'd', 'd', 'p', 'd', 9, 0,
  /* 2875 */ 'v', 'h', 'a', 'd', 'd', 'p', 'd', 9, 0,
  /* 2884 */ 'v', 'f', 'm', 'a', 'd', 'd', 'p', 'd', 9, 0,
  /* 2894 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', 'p', 'd', 9, 0,
  /* 2905 */ 'v', 'a', 'd', 'd', 'p', 'd', 9, 0,
  /* 2913 */ 'v', 'e', 'x', 'p', 'a', 'n', 'd', 'p', 'd', 9, 0,
  /* 2924 */ 'v', 'a', 'n', 'd', 'p', 'd', 9, 0,
  /* 2932 */ 'v', 'b', 'l', 'e', 'n', 'd', 'p', 'd', 9, 0,
  /* 2942 */ 'v', 'r', 'o', 'u', 'n', 'd', 'p', 'd', 9, 0,
  /* 2952 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'd', 'p', 'd', 9, 0,
  /* 2964 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'd', 'p', 'd', 9, 0,
  /* 2977 */ 'v', 'r', 'e', 'd', 'u', 'c', 'e', 'p', 'd', 9, 0,
  /* 2988 */ 'v', 'r', 'a', 'n', 'g', 'e', 'p', 'd', 9, 0,
  /* 2998 */ 'v', 'r', 'n', 'd', 's', 'c', 'a', 'l', 'e', 'p', 'd', 9, 0,
  /* 3011 */ 'v', 's', 'c', 'a', 'l', 'e', 'f', 'p', 'd', 9, 0,
  /* 3022 */ 'v', 's', 'h', 'u', 'f', 'p', 'd', 9, 0,
  /* 3031 */ 'v', 'u', 'n', 'p', 'c', 'k', 'h', 'p', 'd', 9, 0,
  /* 3042 */ 'v', 'm', 'o', 'v', 'h', 'p', 'd', 9, 0,
  /* 3051 */ 'v', 'm', 'o', 'v', 'm', 's', 'k', 'p', 'd', 9, 0,
  /* 3062 */ 'v', 'p', 'e', 'r', 'm', 'i', 'l', 'p', 'd', 9, 0,
  /* 3073 */ 'v', 'u', 'n', 'p', 'c', 'k', 'l', 'p', 'd', 9, 0,
  /* 3084 */ 'v', 'm', 'u', 'l', 'p', 'd', 9, 0,
  /* 3092 */ 'v', 'm', 'o', 'v', 'l', 'p', 'd', 9, 0,
  /* 3101 */ 'v', 'p', 'c', 'm', 'p', 'd', 9, 0,
  /* 3109 */ 'v', 'b', 'l', 'e', 'n', 'd', 'm', 'p', 'd', 9, 0,
  /* 3120 */ 'v', 'f', 'i', 'x', 'u', 'p', 'i', 'm', 'm', 'p', 'd', 9, 0,
  /* 3133 */ 'v', 'p', 'e', 'r', 'm', 'p', 'd', 9, 0,
  /* 3142 */ 'v', 'a', 'n', 'd', 'n', 'p', 'd', 9, 0,
  /* 3151 */ 'v', 'm', 'i', 'n', 'p', 'd', 9, 0,
  /* 3159 */ 'v', 'd', 'p', 'p', 'd', 9, 0,
  /* 3166 */ 'v', 'c', 'm', 'p', 'p', 'd', 9, 0,
  /* 3174 */ 'v', 'g', 'e', 't', 'e', 'x', 'p', 'p', 'd', 9, 0,
  /* 3185 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'p', 'f', '0', 'q', 'p', 'd', 9, 0,
  /* 3200 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'p', 'f', '0', 'q', 'p', 'd', 9, 0,
  /* 3216 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'p', 'f', '1', 'q', 'p', 'd', 9, 0,
  /* 3231 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'p', 'f', '1', 'q', 'p', 'd', 9, 0,
  /* 3247 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'q', 'p', 'd', 9, 0,
  /* 3259 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'q', 'p', 'd', 9, 0,
  /* 3272 */ 'v', 'o', 'r', 'p', 'd', 9, 0,
  /* 3279 */ 'v', 'x', 'o', 'r', 'p', 'd', 9, 0,
  /* 3287 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 'd', 9, 0,
  /* 3299 */ 'i', 'n', 'c', 's', 's', 'p', 'd', 9, 0,
  /* 3308 */ 'r', 'd', 's', 's', 'p', 'd', 9, 0,
  /* 3316 */ 'v', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'p', 'd', 9, 0,
  /* 3329 */ 'v', 'g', 'e', 't', 'm', 'a', 'n', 't', 'p', 'd', 9, 0,
  /* 3341 */ 'v', 'm', 'o', 'v', 'n', 't', 'p', 'd', 9, 0,
  /* 3351 */ 'v', 's', 'q', 'r', 't', 'p', 'd', 9, 0,
  /* 3360 */ 'v', 't', 'e', 's', 't', 'p', 'd', 9, 0,
  /* 3369 */ 'v', 'm', 'o', 'v', 'u', 'p', 'd', 9, 0,
  /* 3378 */ 'v', 'b', 'l', 'e', 'n', 'd', 'v', 'p', 'd', 9, 0,
  /* 3389 */ 'v', 'd', 'i', 'v', 'p', 'd', 9, 0,
  /* 3397 */ 'v', 'm', 'a', 's', 'k', 'm', 'o', 'v', 'p', 'd', 9, 0,
  /* 3409 */ 'v', 'm', 'a', 'x', 'p', 'd', 9, 0,
  /* 3417 */ 'v', 'f', 'r', 'c', 'z', 'p', 'd', 9, 0,
  /* 3426 */ 'v', 'p', 'c', 'm', 'p', 'e', 'q', 'd', 9, 0,
  /* 3436 */ 'v', 'p', 'g', 'a', 't', 'h', 'e', 'r', 'q', 'd', 9, 0,
  /* 3448 */ 'v', 'p', 's', 'c', 'a', 't', 't', 'e', 'r', 'q', 'd', 9, 0,
  /* 3461 */ 'v', 'p', 'm', 'o', 'v', 'u', 's', 'q', 'd', 9, 0,
  /* 3472 */ 'v', 'p', 'm', 'o', 'v', 's', 'q', 'd', 9, 0,
  /* 3482 */ 'v', 'p', 'm', 'o', 'v', 'q', 'd', 9, 0,
  /* 3491 */ 'k', 'o', 'r', 'd', 9, 0,
  /* 3497 */ 'k', 'x', 'n', 'o', 'r', 'd', 9, 0,
  /* 3505 */ 'v', 'p', 'o', 'r', 'd', 9, 0,
  /* 3512 */ 'v', 'p', 'r', 'o', 'r', 'd', 9, 0,
  /* 3520 */ 'k', 'x', 'o', 'r', 'd', 9, 0,
  /* 3527 */ 'v', 'p', 'x', 'o', 'r', 'd', 9, 0,
  /* 3535 */ 'v', 'p', 'i', 'n', 's', 'r', 'd', 9, 0,
  /* 3544 */ 'k', 's', 'h', 'i', 'f', 't', 'r', 'd', 9, 0,
  /* 3554 */ 'v', 'p', 'e', 'x', 't', 'r', 'd', 9, 0,
  /* 3563 */ 'v', 'f', 'm', 's', 'u', 'b', '2', '3', '1', 's', 'd', 9, 0,
  /* 3576 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '2', '3', '1', 's', 'd', 9, 0,
  /* 3590 */ 'v', 'f', 'm', 'a', 'd', 'd', '2', '3', '1', 's', 'd', 9, 0,
  /* 3603 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '2', '3', '1', 's', 'd', 9, 0,
  /* 3617 */ 'v', 'f', 'm', 's', 'u', 'b', '1', '3', '2', 's', 'd', 9, 0,
  /* 3630 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '1', '3', '2', 's', 'd', 9, 0,
  /* 3644 */ 'v', 'f', 'm', 'a', 'd', 'd', '1', '3', '2', 's', 'd', 9, 0,
  /* 3657 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '1', '3', '2', 's', 'd', 9, 0,
  /* 3671 */ 'v', 'c', 'v', 't', 's', 's', '2', 's', 'd', 9, 0,
  /* 3682 */ 'v', 'f', 'm', 's', 'u', 'b', '2', '1', '3', 's', 'd', 9, 0,
  /* 3695 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '2', '1', '3', 's', 'd', 9, 0,
  /* 3709 */ 'v', 'f', 'm', 'a', 'd', 'd', '2', '1', '3', 's', 'd', 9, 0,
  /* 3722 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '2', '1', '3', 's', 'd', 9, 0,
  /* 3736 */ 'v', 'r', 'c', 'p', '1', '4', 's', 'd', 9, 0,
  /* 3746 */ 'v', 'r', 's', 'q', 'r', 't', '1', '4', 's', 'd', 9, 0,
  /* 3758 */ 'v', 'r', 'c', 'p', '2', '8', 's', 'd', 9, 0,
  /* 3768 */ 'v', 'r', 's', 'q', 'r', 't', '2', '8', 's', 'd', 9, 0,
  /* 3780 */ 'v', 'p', 'a', 'b', 's', 'd', 9, 0,
  /* 3788 */ 'v', 'f', 'm', 's', 'u', 'b', 's', 'd', 9, 0,
  /* 3798 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', 's', 'd', 9, 0,
  /* 3809 */ 'v', 's', 'u', 'b', 's', 'd', 9, 0,
  /* 3817 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'd', 9, 0,
  /* 3827 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', 's', 'd', 9, 0,
  /* 3838 */ 'v', 'a', 'd', 'd', 's', 'd', 9, 0,
  /* 3846 */ 'v', 'r', 'o', 'u', 'n', 'd', 's', 'd', 9, 0,
  /* 3856 */ 'v', 'r', 'e', 'd', 'u', 'c', 'e', 's', 'd', 9, 0,
  /* 3867 */ 'v', 'r', 'a', 'n', 'g', 'e', 's', 'd', 9, 0,
  /* 3877 */ 'v', 'r', 'n', 'd', 's', 'c', 'a', 'l', 'e', 's', 'd', 9, 0,
  /* 3890 */ 'v', 's', 'c', 'a', 'l', 'e', 'f', 's', 'd', 9, 0,
  /* 3901 */ 'v', 'u', 'c', 'o', 'm', 'i', 's', 'd', 9, 0,
  /* 3911 */ 'v', 'c', 'o', 'm', 'i', 's', 'd', 9, 0,
  /* 3920 */ 'v', 'm', 'u', 'l', 's', 'd', 9, 0,
  /* 3928 */ 'v', 'f', 'i', 'x', 'u', 'p', 'i', 'm', 'm', 's', 'd', 9, 0,
  /* 3941 */ 'v', 'p', 'm', 'i', 'n', 's', 'd', 9, 0,
  /* 3950 */ 'v', 'm', 'i', 'n', 's', 'd', 9, 0,
  /* 3958 */ 'v', 'c', 'm', 'p', 's', 'd', 9, 0,
  /* 3966 */ 'v', 'g', 'e', 't', 'e', 'x', 'p', 's', 'd', 9, 0,
  /* 3977 */ 'v', 'p', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'd', 9, 0,
  /* 3990 */ 'w', 'r', 's', 's', 'd', 9, 0,
  /* 3997 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 's', 'd', 9, 0,
  /* 4009 */ 'w', 'r', 'u', 's', 's', 'd', 9, 0,
  /* 4017 */ 'v', 'p', '4', 'd', 'p', 'w', 's', 's', 'd', 9, 0,
  /* 4028 */ 'v', 'p', 'd', 'p', 'w', 's', 's', 'd', 9, 0,
  /* 4038 */ 'v', 'g', 'e', 't', 'm', 'a', 'n', 't', 's', 'd', 9, 0,
  /* 4050 */ 'm', 'o', 'v', 'n', 't', 's', 'd', 9, 0,
  /* 4059 */ 'v', 's', 'q', 'r', 't', 's', 'd', 9, 0,
  /* 4068 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 's', 'd', 9, 0,
  /* 4082 */ 'v', 'p', 'd', 'p', 'b', 'u', 's', 'd', 9, 0,
  /* 4092 */ 'v', 'd', 'i', 'v', 's', 'd', 9, 0,
  /* 4100 */ 'v', 'm', 'o', 'v', 's', 'd', 9, 0,
  /* 4108 */ 'v', 'p', 'm', 'a', 'x', 's', 'd', 9, 0,
  /* 4117 */ 'v', 'm', 'a', 'x', 's', 'd', 9, 0,
  /* 4125 */ 'v', 'f', 'r', 'c', 'z', 's', 'd', 9, 0,
  /* 4134 */ 'v', 'p', 'c', 'o', 'n', 'f', 'l', 'i', 'c', 't', 'd', 9, 0,
  /* 4147 */ 'v', 'p', 'c', 'm', 'p', 'g', 't', 'd', 9, 0,
  /* 4157 */ 'v', 'p', 'o', 'p', 'c', 'n', 't', 'd', 9, 0,
  /* 4167 */ 'v', 'p', 'l', 'z', 'c', 'n', 't', 'd', 9, 0,
  /* 4177 */ 'k', 'n', 'o', 't', 'd', 9, 0,
  /* 4184 */ 'v', 'p', 'r', 'o', 't', 'd', 9, 0,
  /* 4192 */ 'v', 'p', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'd', 9, 0,
  /* 4206 */ 'k', 't', 'e', 's', 't', 'd', 9, 0,
  /* 4214 */ 'k', 'o', 'r', 't', 'e', 's', 't', 'd', 9, 0,
  /* 4224 */ 'v', 'p', 'c', 'o', 'm', 'u', 'd', 9, 0,
  /* 4233 */ 'v', 'p', 'm', 'i', 'n', 'u', 'd', 9, 0,
  /* 4242 */ 'v', 'p', 'c', 'm', 'p', 'u', 'd', 9, 0,
  /* 4251 */ 'v', 'p', 'm', 'a', 'x', 'u', 'd', 9, 0,
  /* 4260 */ 'v', 'p', 's', 'r', 'a', 'v', 'd', 9, 0,
  /* 4269 */ 'v', 'p', 's', 'h', 'l', 'd', 'v', 'd', 9, 0,
  /* 4279 */ 'v', 'p', 's', 'h', 'r', 'd', 'v', 'd', 9, 0,
  /* 4289 */ 'v', 'p', 's', 'l', 'l', 'v', 'd', 9, 0,
  /* 4298 */ 'v', 'p', 'r', 'o', 'l', 'v', 'd', 9, 0,
  /* 4307 */ 'v', 'p', 's', 'r', 'l', 'v', 'd', 9, 0,
  /* 4316 */ 'v', 'p', 'm', 'a', 's', 'k', 'm', 'o', 'v', 'd', 9, 0,
  /* 4328 */ 'v', 'm', 'o', 'v', 'd', 9, 0,
  /* 4335 */ 'v', 'p', 'r', 'o', 'r', 'v', 'd', 9, 0,
  /* 4344 */ 'v', 'p', 'h', 's', 'u', 'b', 'w', 'd', 9, 0,
  /* 4354 */ 'v', 'p', 'h', 'a', 'd', 'd', 'w', 'd', 9, 0,
  /* 4364 */ 'v', 'p', 'm', 'a', 'd', 'd', 'w', 'd', 9, 0,
  /* 4374 */ 'v', 'p', 'u', 'n', 'p', 'c', 'k', 'h', 'w', 'd', 9, 0,
  /* 4386 */ 'k', 'u', 'n', 'p', 'c', 'k', 'w', 'd', 9, 0,
  /* 4396 */ 'v', 'p', 'u', 'n', 'p', 'c', 'k', 'l', 'w', 'd', 9, 0,
  /* 4408 */ 'v', 'p', 'm', 'a', 'c', 's', 'w', 'd', 9, 0,
  /* 4418 */ 'v', 'p', 'm', 'a', 'd', 'c', 's', 'w', 'd', 9, 0,
  /* 4429 */ 'v', 'p', 'm', 'a', 'c', 's', 's', 'w', 'd', 9, 0,
  /* 4440 */ 'v', 'p', 'm', 'a', 'd', 'c', 's', 's', 'w', 'd', 9, 0,
  /* 4452 */ 'v', 'p', 'h', 'a', 'd', 'd', 'u', 'w', 'd', 9, 0,
  /* 4463 */ 'v', 'p', 'm', 'o', 'v', 's', 'x', 'w', 'd', 9, 0,
  /* 4474 */ 'v', 'p', 'm', 'o', 'v', 'z', 'x', 'w', 'd', 9, 0,
  /* 4485 */ 'j', 'a', 'e', 9, 0,
  /* 4490 */ 's', 'e', 't', 'a', 'e', 9, 0,
  /* 4497 */ 'j', 'b', 'e', 9, 0,
  /* 4502 */ 'f', 'c', 'm', 'o', 'v', 'n', 'b', 'e', 9, 0,
  /* 4512 */ 's', 'e', 't', 'b', 'e', 9, 0,
  /* 4519 */ 'f', 'c', 'm', 'o', 'v', 'b', 'e', 9, 0,
  /* 4528 */ 'f', 'f', 'r', 'e', 'e', 9, 0,
  /* 4535 */ 'j', 'g', 'e', 9, 0,
  /* 4540 */ 'p', 'f', 'c', 'm', 'p', 'g', 'e', 9, 0,
  /* 4549 */ 's', 'e', 't', 'g', 'e', 9, 0,
  /* 4556 */ 'j', 'e', 9, 0,
  /* 4560 */ 'j', 'l', 'e', 9, 0,
  /* 4565 */ 's', 'e', 't', 'l', 'e', 9, 0,
  /* 4572 */ 'j', 'n', 'e', 9, 0,
  /* 4577 */ 'l', 'o', 'o', 'p', 'n', 'e', 9, 0,
  /* 4585 */ 's', 'e', 't', 'n', 'e', 9, 0,
  /* 4592 */ 'f', 'c', 'm', 'o', 'v', 'n', 'e', 9, 0,
  /* 4601 */ 'l', 'o', 'o', 'p', 'e', 9, 0,
  /* 4608 */ 't', 'p', 'a', 'u', 's', 'e', 9, 0,
  /* 4616 */ 's', 'e', 't', 'e', 9, 0,
  /* 4622 */ 'c', 'l', 'd', 'e', 'm', 'o', 't', 'e', 9, 0,
  /* 4632 */ 's', 'h', 'a', '1', 'n', 'e', 'x', 't', 'e', 9, 0,
  /* 4643 */ 'f', 'n', 's', 'a', 'v', 'e', 9, 0,
  /* 4651 */ 'f', 'x', 's', 'a', 'v', 'e', 9, 0,
  /* 4659 */ 'f', 'c', 'm', 'o', 'v', 'e', 9, 0,
  /* 4667 */ 'j', 'g', 9, 0,
  /* 4671 */ 'i', 'n', 'v', 'l', 'p', 'g', 9, 0,
  /* 4679 */ 's', 'e', 't', 'g', 9, 0,
  /* 4685 */ 'p', 'r', 'e', 'f', 'e', 't', 'c', 'h', 9, 0,
  /* 4695 */ 'f', 'x', 'c', 'h', 9, 0,
  /* 4701 */ 'v', 'c', 'v', 't', 'p', 's', '2', 'p', 'h', 9, 0,
  /* 4712 */ 'v', 'p', 'm', 'a', 'c', 's', 'd', 'q', 'h', 9, 0,
  /* 4723 */ 'v', 'p', 'm', 'a', 'c', 's', 's', 'd', 'q', 'h', 9, 0,
  /* 4735 */ 'c', 'l', 'f', 'l', 'u', 's', 'h', 9, 0,
  /* 4744 */ 'f', 'c', 'o', 'm', 'i', 9, 0,
  /* 4751 */ 'f', 'u', 'c', 'o', 'm', 'i', 9, 0,
  /* 4759 */ 'c', 'v', 't', 't', 'p', 'd', '2', 'p', 'i', 9, 0,
  /* 4770 */ 'c', 'v', 't', 'p', 'd', '2', 'p', 'i', 9, 0,
  /* 4780 */ 'c', 'v', 't', 't', 'p', 's', '2', 'p', 'i', 9, 0,
  /* 4791 */ 'c', 'v', 't', 'p', 's', '2', 'p', 'i', 9, 0,
  /* 4801 */ 'f', 'c', 'o', 'm', 'p', 'i', 9, 0,
  /* 4809 */ 'f', 'u', 'c', 'o', 'm', 'p', 'i', 9, 0,
  /* 4818 */ 'm', 'o', 'v', 'd', 'i', 'r', 'i', 9, 0,
  /* 4827 */ 'v', 'p', 'c', 'm', 'p', 'e', 's', 't', 'r', 'i', 9, 0,
  /* 4839 */ 'v', 'p', 'c', 'm', 'p', 'i', 's', 't', 'r', 'i', 9, 0,
  /* 4851 */ 'v', 'c', 'v', 't', 't', 's', 'd', '2', 's', 'i', 9, 0,
  /* 4863 */ 'v', 'c', 'v', 't', 's', 'd', '2', 's', 'i', 9, 0,
  /* 4874 */ 'v', 'c', 'v', 't', 't', 's', 's', '2', 's', 'i', 9, 0,
  /* 4886 */ 'v', 'c', 'v', 't', 's', 's', '2', 's', 'i', 9, 0,
  /* 4897 */ 'v', 'c', 'v', 't', 't', 's', 'd', '2', 'u', 's', 'i', 9, 0,
  /* 4910 */ 'v', 'c', 'v', 't', 's', 'd', '2', 'u', 's', 'i', 9, 0,
  /* 4922 */ 'v', 'c', 'v', 't', 't', 's', 's', '2', 'u', 's', 'i', 9, 0,
  /* 4935 */ 'v', 'c', 'v', 't', 's', 's', '2', 'u', 's', 'i', 9, 0,
  /* 4947 */ 'b', 'n', 'd', 'm', 'k', 9, 0,
  /* 4954 */ 'c', 'r', 'c', '3', '2', 'l', 9, 0,
  /* 4962 */ 'l', 'e', 'a', 'l', 9, 0,
  /* 4968 */ 'c', 'm', 'o', 'v', 'a', 'l', 9, 0,
  /* 4976 */ 'l', 'w', 'p', 'v', 'a', 'l', 9, 0,
  /* 4984 */ 's', 'b', 'b', 'l', 9, 0,
  /* 4990 */ 'm', 'o', 'v', 's', 'b', 'l', 9, 0,
  /* 4998 */ 'f', 's', 'u', 'b', 'l', 9, 0,
  /* 5005 */ 'f', 'i', 's', 'u', 'b', 'l', 9, 0,
  /* 5013 */ 'c', 'm', 'o', 'v', 'b', 'l', 9, 0,
  /* 5021 */ 'm', 'o', 'v', 'z', 'b', 'l', 9, 0,
  /* 5029 */ 'a', 'd', 'c', 'l', 9, 0,
  /* 5035 */ 'b', 'n', 'd', 'c', 'l', 9, 0,
  /* 5042 */ 'd', 'e', 'c', 'l', 9, 0,
  /* 5048 */ 'b', 'l', 'c', 'i', 'c', 'l', 9, 0,
  /* 5056 */ 'b', 'l', 's', 'i', 'c', 'l', 9, 0,
  /* 5064 */ 't', '1', 'm', 's', 'k', 'c', 'l', 9, 0,
  /* 5073 */ 'i', 'n', 'c', 'l', 9, 0,
  /* 5079 */ 'b', 't', 'c', 'l', 9, 0,
  /* 5085 */ 'v', 'm', 'r', 'e', 'a', 'd', 'l', 9, 0,
  /* 5094 */ 'f', 'a', 'd', 'd', 'l', 9, 0,
  /* 5101 */ 'f', 'i', 'a', 'd', 'd', 'l', 9, 0,
  /* 5109 */ 'x', 'a', 'd', 'd', 'l', 9, 0,
  /* 5116 */ 'r', 'd', 's', 'e', 'e', 'd', 'l', 9, 0,
  /* 5125 */ 'f', 'l', 'd', 'l', 9, 0,
  /* 5131 */ 's', 'h', 'l', 'd', 'l', 9, 0,
  /* 5138 */ 'f', 'i', 'l', 'd', 'l', 9, 0,
  /* 5145 */ 'r', 'd', 'r', 'a', 'n', 'd', 'l', 9, 0,
  /* 5154 */ 's', 'h', 'r', 'd', 'l', 9, 0,
  /* 5161 */ 'v', 'c', 'v', 't', 's', 'i', '2', 's', 'd', 'l', 9, 0,
  /* 5173 */ 'v', 'c', 'v', 't', 'u', 's', 'i', '2', 's', 'd', 'l', 9, 0,
  /* 5186 */ 'c', 'm', 'o', 'v', 'a', 'e', 'l', 9, 0,
  /* 5195 */ 'c', 'm', 'o', 'v', 'b', 'e', 'l', 9, 0,
  /* 5204 */ 'c', 'm', 'o', 'v', 'g', 'e', 'l', 9, 0,
  /* 5213 */ 'c', 'm', 'o', 'v', 'l', 'e', 'l', 9, 0,
  /* 5222 */ 'c', 'm', 'o', 'v', 'n', 'e', 'l', 9, 0,
  /* 5231 */ 'r', 'd', 'f', 's', 'b', 'a', 's', 'e', 'l', 9, 0,
  /* 5242 */ 'w', 'r', 'f', 's', 'b', 'a', 's', 'e', 'l', 9, 0,
  /* 5253 */ 'r', 'd', 'g', 's', 'b', 'a', 's', 'e', 'l', 9, 0,
  /* 5264 */ 'w', 'r', 'g', 's', 'b', 'a', 's', 'e', 'l', 9, 0,
  /* 5275 */ 'v', 'm', 'w', 'r', 'i', 't', 'e', 'l', 9, 0,
  /* 5285 */ 'p', 't', 'w', 'r', 'i', 't', 'e', 'l', 9, 0,
  /* 5295 */ 'c', 'm', 'o', 'v', 'e', 'l', 9, 0,
  /* 5303 */ 'b', 's', 'f', 'l', 9, 0,
  /* 5309 */ 'n', 'e', 'g', 'l', 9, 0,
  /* 5315 */ 'c', 'm', 'p', 'x', 'c', 'h', 'g', 'l', 9, 0,
  /* 5325 */ 'c', 'm', 'o', 'v', 'g', 'l', 9, 0,
  /* 5333 */ 'p', 'u', 's', 'h', 'l', 9, 0,
  /* 5340 */ 'b', 'l', 'c', 'i', 'l', 9, 0,
  /* 5347 */ 'b', 'z', 'h', 'i', 'l', 9, 0,
  /* 5354 */ 'b', 'l', 's', 'i', 'l', 9, 0,
  /* 5361 */ 'm', 'o', 'v', 'n', 't', 'i', 'l', 9, 0,
  /* 5370 */ 'j', 'l', 9, 0,
  /* 5374 */ 'b', 'l', 'c', 'm', 's', 'k', 'l', 9, 0,
  /* 5383 */ 'b', 'l', 's', 'm', 's', 'k', 'l', 9, 0,
  /* 5392 */ 't', 'z', 'm', 's', 'k', 'l', 9, 0,
  /* 5400 */ 's', 'a', 'l', 'l', 9, 0,
  /* 5406 */ 'r', 'c', 'l', 'l', 9, 0,
  /* 5412 */ 'f', 'i', 'l', 'd', 'l', 'l', 9, 0,
  /* 5420 */ 's', 'h', 'l', 'l', 9, 0,
  /* 5426 */ 'l', 'c', 'a', 'l', 'l', 'l', 9, 0,
  /* 5434 */ 'b', 'l', 'c', 'f', 'i', 'l', 'l', 'l', 9, 0,
  /* 5444 */ 'b', 'l', 's', 'f', 'i', 'l', 'l', 'l', 9, 0,
  /* 5454 */ 'r', 'o', 'l', 'l', 9, 0,
  /* 5460 */ 'f', 'i', 's', 't', 'p', 'l', 'l', 9, 0,
  /* 5469 */ 'f', 'i', 's', 't', 't', 'p', 'l', 'l', 9, 0,
  /* 5479 */ 'l', 's', 'l', 'l', 9, 0,
  /* 5485 */ 'f', 'm', 'u', 'l', 'l', 9, 0,
  /* 5492 */ 'f', 'i', 'm', 'u', 'l', 'l', 9, 0,
  /* 5500 */ 'c', 'm', 'o', 'v', 'l', 'l', 9, 0,
  /* 5508 */ 'f', 'c', 'o', 'm', 'l', 9, 0,
  /* 5515 */ 'f', 'i', 'c', 'o', 'm', 'l', 9, 0,
  /* 5523 */ 'a', 'n', 'd', 'n', 'l', 9, 0,
  /* 5530 */ 'i', 'n', 'l', 9, 0,
  /* 5535 */ 'c', 'm', 'o', 'v', 'n', 'o', 'l', 9, 0,
  /* 5544 */ 'c', 'm', 'o', 'v', 'o', 'l', 9, 0,
  /* 5552 */ 'b', 's', 'w', 'a', 'p', 'l', 9, 0,
  /* 5560 */ 'p', 'd', 'e', 'p', 'l', 9, 0,
  /* 5567 */ 'c', 'm', 'p', 'l', 9, 0,
  /* 5573 */ 'l', 'j', 'm', 'p', 'l', 9, 0,
  /* 5580 */ 'f', 'c', 'o', 'm', 'p', 'l', 9, 0,
  /* 5588 */ 'f', 'i', 'c', 'o', 'm', 'p', 'l', 9, 0,
  /* 5597 */ 'c', 'm', 'o', 'v', 'n', 'p', 'l', 9, 0,
  /* 5606 */ 'n', 'o', 'p', 'l', 9, 0,
  /* 5612 */ 'p', 'o', 'p', 'l', 9, 0,
  /* 5618 */ 'a', 'r', 'p', 'l', 9, 0,
  /* 5624 */ 'f', 's', 't', 'p', 'l', 9, 0,
  /* 5631 */ 'f', 'i', 's', 't', 'p', 'l', 9, 0,
  /* 5639 */ 'f', 'i', 's', 't', 't', 'p', 'l', 9, 0,
  /* 5648 */ 'c', 'm', 'o', 'v', 'p', 'l', 9, 0,
  /* 5656 */ 'v', 'p', 'm', 'a', 'c', 's', 'd', 'q', 'l', 9, 0,
  /* 5667 */ 'v', 'p', 'm', 'a', 'c', 's', 's', 'd', 'q', 'l', 9, 0,
  /* 5679 */ 'l', 'a', 'r', 'l', 9, 0,
  /* 5685 */ 's', 'a', 'r', 'l', 9, 0,
  /* 5691 */ 'f', 's', 'u', 'b', 'r', 'l', 9, 0,
  /* 5699 */ 'f', 'i', 's', 'u', 'b', 'r', 'l', 9, 0,
  /* 5708 */ 'r', 'c', 'r', 'l', 9, 0,
  /* 5714 */ 's', 'h', 'r', 'l', 9, 0,
  /* 5720 */ 'r', 'o', 'r', 'l', 9, 0,
  /* 5726 */ 'x', 'o', 'r', 'l', 9, 0,
  /* 5732 */ 'b', 's', 'r', 'l', 9, 0,
  /* 5738 */ 'b', 'l', 's', 'r', 'l', 9, 0,
  /* 5745 */ 'b', 't', 'r', 'l', 9, 0,
  /* 5751 */ 's', 't', 'r', 'l', 9, 0,
  /* 5757 */ 'b', 'e', 'x', 't', 'r', 'l', 9, 0,
  /* 5765 */ 'f', 'd', 'i', 'v', 'r', 'l', 9, 0,
  /* 5773 */ 'f', 'i', 'd', 'i', 'v', 'r', 'l', 9, 0,
  /* 5782 */ 's', 'c', 'a', 's', 'l', 9, 0,
  /* 5789 */ 'm', 'o', 'v', 'a', 'b', 's', 'l', 9, 0,
  /* 5798 */ 'b', 'l', 'c', 's', 'l', 9, 0,
  /* 5805 */ 'l', 'd', 's', 'l', 9, 0,
  /* 5811 */ 'l', 'o', 'd', 's', 'l', 9, 0,
  /* 5818 */ 'l', 'e', 's', 'l', 9, 0,
  /* 5824 */ 'l', 'f', 's', 'l', 9, 0,
  /* 5830 */ 'l', 'g', 's', 'l', 9, 0,
  /* 5836 */ 'c', 'm', 'o', 'v', 'n', 's', 'l', 9, 0,
  /* 5845 */ 'c', 'm', 'p', 's', 'l', 9, 0,
  /* 5852 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 's', 'l', 9, 0,
  /* 5865 */ 'v', 'c', 'v', 't', 's', 'i', '2', 's', 's', 'l', 9, 0,
  /* 5877 */ 'v', 'c', 'v', 't', 'u', 's', 'i', '2', 's', 's', 'l', 9, 0,
  /* 5890 */ 'l', 's', 's', 'l', 9, 0,
  /* 5896 */ 'b', 't', 's', 'l', 9, 0,
  /* 5902 */ 'o', 'u', 't', 's', 'l', 9, 0,
  /* 5909 */ 'c', 'm', 'o', 'v', 's', 'l', 9, 0,
  /* 5917 */ 'b', 't', 'l', 9, 0,
  /* 5922 */ 'l', 'g', 'd', 't', 'l', 9, 0,
  /* 5929 */ 's', 'g', 'd', 't', 'l', 9, 0,
  /* 5936 */ 'l', 'i', 'd', 't', 'l', 9, 0,
  /* 5943 */ 's', 'i', 'd', 't', 'l', 9, 0,
  /* 5950 */ 's', 'l', 'd', 't', 'l', 9, 0,
  /* 5957 */ 'l', 'r', 'e', 't', 'l', 9, 0,
  /* 5964 */ 's', 'e', 't', 'l', 9, 0,
  /* 5970 */ 'p', 'o', 'p', 'c', 'n', 't', 'l', 9, 0,
  /* 5979 */ 'l', 'z', 'c', 'n', 't', 'l', 9, 0,
  /* 5987 */ 't', 'z', 'c', 'n', 't', 'l', 9, 0,
  /* 5995 */ 'n', 'o', 't', 'l', 9, 0,
  /* 6001 */ 't', 'e', 's', 't', 'l', 9, 0,
  /* 6008 */ 'f', 's', 't', 'l', 9, 0,
  /* 6014 */ 'f', 'i', 's', 't', 'l', 9, 0,
  /* 6021 */ 'p', 'e', 'x', 't', 'l', 9, 0,
  /* 6028 */ 'p', 'f', 'm', 'u', 'l', 9, 0,
  /* 6035 */ 'f', 'd', 'i', 'v', 'l', 9, 0,
  /* 6042 */ 'f', 'i', 'd', 'i', 'v', 'l', 9, 0,
  /* 6050 */ 'm', 'o', 'v', 'l', 9, 0,
  /* 6056 */ 's', 'm', 's', 'w', 'l', 9, 0,
  /* 6063 */ 'm', 'o', 'v', 's', 'w', 'l', 9, 0,
  /* 6071 */ 'm', 'o', 'v', 'z', 'w', 'l', 9, 0,
  /* 6079 */ 'a', 'd', 'c', 'x', 'l', 9, 0,
  /* 6086 */ 's', 'h', 'l', 'x', 'l', 9, 0,
  /* 6093 */ 'm', 'u', 'l', 'x', 'l', 9, 0,
  /* 6100 */ 'a', 'd', 'o', 'x', 'l', 9, 0,
  /* 6107 */ 's', 'a', 'r', 'x', 'l', 9, 0,
  /* 6114 */ 's', 'h', 'r', 'x', 'l', 9, 0,
  /* 6121 */ 'r', 'o', 'r', 'x', 'l', 9, 0,
  /* 6128 */ 'v', 'p', 'm', 'o', 'v', 'b', '2', 'm', 9, 0,
  /* 6138 */ 'v', 'p', 'm', 'o', 'v', 'd', '2', 'm', 9, 0,
  /* 6148 */ 'v', 'p', 'm', 'o', 'v', 'q', '2', 'm', 9, 0,
  /* 6158 */ 'v', 'p', 'm', 'o', 'v', 'w', '2', 'm', 9, 0,
  /* 6168 */ 'a', 'a', 'm', 9, 0,
  /* 6173 */ 'f', 'c', 'o', 'm', 9, 0,
  /* 6179 */ 'f', 'u', 'c', 'o', 'm', 9, 0,
  /* 6186 */ 'v', 'p', 'p', 'e', 'r', 'm', 9, 0,
  /* 6194 */ 'v', 'p', 'c', 'm', 'p', 'e', 's', 't', 'r', 'm', 9, 0,
  /* 6206 */ 'v', 'p', 'c', 'm', 'p', 'i', 's', 't', 'r', 'm', 9, 0,
  /* 6218 */ 'b', 'n', 'd', 'c', 'n', 9, 0,
  /* 6225 */ 'v', 'p', 'a', 'n', 'd', 'n', 9, 0,
  /* 6233 */ 'x', 'b', 'e', 'g', 'i', 'n', 9, 0,
  /* 6241 */ 'p', 'f', 'm', 'i', 'n', 9, 0,
  /* 6248 */ 'v', 'm', 'x', 'o', 'n', 9, 0,
  /* 6255 */ 'j', 'o', 9, 0,
  /* 6259 */ 'j', 'n', 'o', 9, 0,
  /* 6264 */ 's', 'e', 't', 'n', 'o', 9, 0,
  /* 6271 */ 's', 'e', 't', 'o', 9, 0,
  /* 6277 */ 'f', 's', 'u', 'b', 'p', 9, 0,
  /* 6284 */ 'p', 'f', 'r', 'c', 'p', 9, 0,
  /* 6291 */ 'f', 'a', 'd', 'd', 'p', 9, 0,
  /* 6298 */ 'f', 'f', 'r', 'e', 'e', 'p', 9, 0,
  /* 6306 */ 'j', 'p', 9, 0,
  /* 6310 */ 'f', 'm', 'u', 'l', 'p', 9, 0,
  /* 6317 */ 'j', 'm', 'p', 9, 0,
  /* 6322 */ 'f', 'c', 'o', 'm', 'p', 9, 0,
  /* 6329 */ 'f', 'u', 'c', 'o', 'm', 'p', 9, 0,
  /* 6337 */ 'j', 'n', 'p', 9, 0,
  /* 6342 */ 's', 'e', 't', 'n', 'p', 9, 0,
  /* 6349 */ 'n', 'o', 'p', 9, 0,
  /* 6354 */ 'l', 'o', 'o', 'p', 9, 0,
  /* 6360 */ 'f', 's', 'u', 'b', 'r', 'p', 9, 0,
  /* 6368 */ 'f', 'd', 'i', 'v', 'r', 'p', 9, 0,
  /* 6376 */ 'r', 's', 't', 'o', 'r', 's', 's', 'p', 9, 0,
  /* 6386 */ 's', 'e', 't', 'p', 9, 0,
  /* 6392 */ 'f', 's', 't', 'p', 9, 0,
  /* 6398 */ 'v', 'm', 'o', 'v', 'd', 'd', 'u', 'p', 9, 0,
  /* 6408 */ 'v', 'm', 'o', 'v', 's', 'h', 'd', 'u', 'p', 9, 0,
  /* 6419 */ 'v', 'm', 'o', 'v', 's', 'l', 'd', 'u', 'p', 9, 0,
  /* 6430 */ 'f', 'd', 'i', 'v', 'p', 9, 0,
  /* 6437 */ 'c', 'r', 'c', '3', '2', 'q', 9, 0,
  /* 6445 */ 'v', 'p', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'm', 'b', '2', 'q', 9, 0,
  /* 6462 */ 'v', 'p', 'e', 'r', 'm', 'i', '2', 'q', 9, 0,
  /* 6472 */ 'v', 'p', 'm', 'o', 'v', 'm', '2', 'q', 9, 0,
  /* 6482 */ 'm', 'o', 'v', 'd', 'q', '2', 'q', 9, 0,
  /* 6491 */ 'v', 'p', 'e', 'r', 'm', 't', '2', 'q', 9, 0,
  /* 6501 */ 'l', 'e', 'a', 'q', 9, 0,
  /* 6507 */ 'v', 'p', 's', 'h', 'a', 'q', 9, 0,
  /* 6515 */ 'v', 'p', 's', 'r', 'a', 'q', 9, 0,
  /* 6523 */ 'c', 'm', 'o', 'v', 'a', 'q', 9, 0,
  /* 6531 */ 's', 'b', 'b', 'q', 9, 0,
  /* 6537 */ 'v', 'p', 'h', 'a', 'd', 'd', 'b', 'q', 9, 0,
  /* 6547 */ 'm', 'o', 'v', 's', 'b', 'q', 9, 0,
  /* 6555 */ 'v', 'p', 'h', 'a', 'd', 'd', 'u', 'b', 'q', 9, 0,
  /* 6566 */ 'v', 'p', 's', 'u', 'b', 'q', 9, 0,
  /* 6574 */ 'c', 'm', 'o', 'v', 'b', 'q', 9, 0,
  /* 6582 */ 'v', 'p', 'm', 'o', 'v', 's', 'x', 'b', 'q', 9, 0,
  /* 6593 */ 'v', 'p', 'm', 'o', 'v', 'z', 'x', 'b', 'q', 9, 0,
  /* 6604 */ 'm', 'o', 'v', 'z', 'b', 'q', 9, 0,
  /* 6612 */ 'a', 'd', 'c', 'q', 9, 0,
  /* 6618 */ 'd', 'e', 'c', 'q', 9, 0,
  /* 6624 */ 'b', 'l', 'c', 'i', 'c', 'q', 9, 0,
  /* 6632 */ 'b', 'l', 's', 'i', 'c', 'q', 9, 0,
  /* 6640 */ 't', '1', 'm', 's', 'k', 'c', 'q', 9, 0,
  /* 6649 */ 'i', 'n', 'c', 'q', 9, 0,
  /* 6655 */ 'b', 't', 'c', 'q', 9, 0,
  /* 6661 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'd', 'q', 9, 0,
  /* 6673 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'd', 'q', 9, 0,
  /* 6684 */ 'm', 'o', 'v', 'q', '2', 'd', 'q', 9, 0,
  /* 6693 */ 'v', 'c', 'v', 't', 't', 'p', 's', '2', 'd', 'q', 9, 0,
  /* 6705 */ 'v', 'c', 'v', 't', 'p', 's', '2', 'd', 'q', 9, 0,
  /* 6716 */ 'v', 'm', 'r', 'e', 'a', 'd', 'q', 9, 0,
  /* 6725 */ 'v', 'p', 'h', 's', 'u', 'b', 'd', 'q', 9, 0,
  /* 6735 */ 'k', 'a', 'd', 'd', 'q', 9, 0,
  /* 6742 */ 'v', 'p', 'a', 'd', 'd', 'q', 9, 0,
  /* 6750 */ 'x', 'a', 'd', 'd', 'q', 9, 0,
  /* 6757 */ 'v', 'p', 'h', 'a', 'd', 'd', 'd', 'q', 9, 0,
  /* 6767 */ 'r', 'd', 's', 'e', 'e', 'd', 'q', 9, 0,
  /* 6776 */ 'v', 'p', 'u', 'n', 'p', 'c', 'k', 'h', 'd', 'q', 9, 0,
  /* 6788 */ 'k', 'u', 'n', 'p', 'c', 'k', 'd', 'q', 9, 0,
  /* 6798 */ 'v', 'p', 's', 'h', 'l', 'd', 'q', 9, 0,
  /* 6807 */ 'v', 'p', 'u', 'n', 'p', 'c', 'k', 'l', 'd', 'q', 9, 0,
  /* 6819 */ 'v', 'p', 's', 'l', 'l', 'd', 'q', 9, 0,
  /* 6828 */ 'v', 'p', 's', 'r', 'l', 'd', 'q', 9, 0,
  /* 6837 */ 'v', 'p', 'm', 'u', 'l', 'd', 'q', 9, 0,
  /* 6846 */ 'k', 'a', 'n', 'd', 'q', 9, 0,
  /* 6853 */ 'v', 'p', 'a', 'n', 'd', 'q', 9, 0,
  /* 6861 */ 'v', 'p', 'e', 'x', 'p', 'a', 'n', 'd', 'q', 9, 0,
  /* 6872 */ 'r', 'd', 'r', 'a', 'n', 'd', 'q', 9, 0,
  /* 6881 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 'd', 'q', 9, 0,
  /* 6894 */ 'v', 'p', 'u', 'n', 'p', 'c', 'k', 'h', 'q', 'd', 'q', 9, 0,
  /* 6907 */ 'v', 'p', 'u', 'n', 'p', 'c', 'k', 'l', 'q', 'd', 'q', 9, 0,
  /* 6920 */ 'v', 'p', 'c', 'l', 'm', 'u', 'l', 'q', 'd', 'q', 9, 0,
  /* 6932 */ 'v', 'p', 'g', 'a', 't', 'h', 'e', 'r', 'd', 'q', 9, 0,
  /* 6944 */ 'v', 'p', 's', 'c', 'a', 't', 't', 'e', 'r', 'd', 'q', 9, 0,
  /* 6957 */ 'v', 'p', 's', 'h', 'r', 'd', 'q', 9, 0,
  /* 6966 */ 'v', 'c', 'v', 't', 's', 'i', '2', 's', 'd', 'q', 9, 0,
  /* 6978 */ 'v', 'c', 'v', 't', 'u', 's', 'i', '2', 's', 'd', 'q', 9, 0,
  /* 6991 */ 'v', 'm', 'o', 'v', 'n', 't', 'd', 'q', 9, 0,
  /* 7001 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'u', 'd', 'q', 9, 0,
  /* 7014 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'u', 'd', 'q', 9, 0,
  /* 7026 */ 'v', 'c', 'v', 't', 't', 'p', 's', '2', 'u', 'd', 'q', 9, 0,
  /* 7039 */ 'v', 'c', 'v', 't', 'p', 's', '2', 'u', 'd', 'q', 9, 0,
  /* 7051 */ 'v', 'p', 'h', 'a', 'd', 'd', 'u', 'd', 'q', 9, 0,
  /* 7062 */ 'v', 'p', 'm', 'u', 'l', 'u', 'd', 'q', 9, 0,
  /* 7072 */ 'v', 'p', 'm', 'o', 'v', 's', 'x', 'd', 'q', 9, 0,
  /* 7083 */ 'v', 'p', 'm', 'o', 'v', 'z', 'x', 'd', 'q', 9, 0,
  /* 7094 */ 'c', 'm', 'o', 'v', 'a', 'e', 'q', 9, 0,
  /* 7103 */ 'c', 'm', 'o', 'v', 'b', 'e', 'q', 9, 0,
  /* 7112 */ 'c', 'm', 'o', 'v', 'g', 'e', 'q', 9, 0,
  /* 7121 */ 'c', 'm', 'o', 'v', 'l', 'e', 'q', 9, 0,
  /* 7130 */ 'c', 'm', 'o', 'v', 'n', 'e', 'q', 9, 0,
  /* 7139 */ 'p', 'f', 'c', 'm', 'p', 'e', 'q', 9, 0,
  /* 7148 */ 'r', 'd', 'f', 's', 'b', 'a', 's', 'e', 'q', 9, 0,
  /* 7159 */ 'w', 'r', 'f', 's', 'b', 'a', 's', 'e', 'q', 9, 0,
  /* 7170 */ 'r', 'd', 'g', 's', 'b', 'a', 's', 'e', 'q', 9, 0,
  /* 7181 */ 'w', 'r', 'g', 's', 'b', 'a', 's', 'e', 'q', 9, 0,
  /* 7192 */ 'v', 'm', 'w', 'r', 'i', 't', 'e', 'q', 9, 0,
  /* 7202 */ 'p', 't', 'w', 'r', 'i', 't', 'e', 'q', 9, 0,
  /* 7212 */ 'c', 'm', 'o', 'v', 'e', 'q', 9, 0,
  /* 7220 */ 'b', 's', 'f', 'q', 9, 0,
  /* 7226 */ 'n', 'e', 'g', 'q', 9, 0,
  /* 7232 */ 'c', 'm', 'p', 'x', 'c', 'h', 'g', 'q', 9, 0,
  /* 7242 */ 'v', 'p', 't', 'e', 'r', 'n', 'l', 'o', 'g', 'q', 9, 0,
  /* 7254 */ 'c', 'm', 'o', 'v', 'g', 'q', 9, 0,
  /* 7262 */ 'p', 'u', 's', 'h', 'q', 9, 0,
  /* 7269 */ 'b', 'l', 'c', 'i', 'q', 9, 0,
  /* 7276 */ 'b', 'z', 'h', 'i', 'q', 9, 0,
  /* 7283 */ 'b', 'l', 's', 'i', 'q', 9, 0,
  /* 7290 */ 'm', 'o', 'v', 'n', 't', 'i', 'q', 9, 0,
  /* 7299 */ 'b', 'l', 'c', 'm', 's', 'k', 'q', 9, 0,
  /* 7308 */ 'b', 'l', 's', 'm', 's', 'k', 'q', 9, 0,
  /* 7317 */ 't', 'z', 'm', 's', 'k', 'q', 9, 0,
  /* 7325 */ 's', 'a', 'l', 'q', 9, 0,
  /* 7331 */ 'r', 'c', 'l', 'q', 9, 0,
  /* 7337 */ 'v', 'p', 's', 'h', 'l', 'q', 9, 0,
  /* 7345 */ 'c', 'a', 'l', 'l', 'q', 9, 0,
  /* 7352 */ 'b', 'l', 'c', 'f', 'i', 'l', 'l', 'q', 9, 0,
  /* 7362 */ 'b', 'l', 's', 'f', 'i', 'l', 'l', 'q', 9, 0,
  /* 7372 */ 'v', 'p', 's', 'l', 'l', 'q', 9, 0,
  /* 7380 */ 'v', 'p', 'm', 'u', 'l', 'l', 'q', 9, 0,
  /* 7389 */ 'v', 'p', 'r', 'o', 'l', 'q', 9, 0,
  /* 7397 */ 'v', 'p', 's', 'r', 'l', 'q', 9, 0,
  /* 7405 */ 'l', 's', 'l', 'q', 9, 0,
  /* 7411 */ 'm', 'o', 'v', 's', 'l', 'q', 9, 0,
  /* 7419 */ 'k', 's', 'h', 'i', 'f', 't', 'l', 'q', 9, 0,
  /* 7429 */ 'i', 'm', 'u', 'l', 'q', 9, 0,
  /* 7436 */ 'c', 'm', 'o', 'v', 'l', 'q', 9, 0,
  /* 7444 */ 'v', 'p', 'b', 'l', 'e', 'n', 'd', 'm', 'q', 9, 0,
  /* 7455 */ 'v', 'p', 't', 'e', 's', 't', 'n', 'm', 'q', 9, 0,
  /* 7466 */ 'v', 'p', 'c', 'o', 'm', 'q', 9, 0,
  /* 7474 */ 'v', 'p', 'e', 'r', 'm', 'q', 9, 0,
  /* 7482 */ 'v', 'p', 't', 'e', 's', 't', 'm', 'q', 9, 0,
  /* 7492 */ 'k', 'a', 'n', 'd', 'n', 'q', 9, 0,
  /* 7500 */ 'v', 'p', 'a', 'n', 'd', 'n', 'q', 9, 0,
  /* 7509 */ 'v', 'a', 'l', 'i', 'g', 'n', 'q', 9, 0,
  /* 7518 */ 'c', 'm', 'o', 'v', 'n', 'o', 'q', 9, 0,
  /* 7527 */ 'c', 'm', 'o', 'v', 'o', 'q', 9, 0,
  /* 7535 */ 'b', 's', 'w', 'a', 'p', 'q', 9, 0,
  /* 7543 */ 'p', 'd', 'e', 'p', 'q', 9, 0,
  /* 7550 */ 'v', 'p', 'c', 'm', 'p', 'q', 9, 0,
  /* 7558 */ 'c', 'm', 'o', 'v', 'n', 'p', 'q', 9, 0,
  /* 7567 */ 'n', 'o', 'p', 'q', 9, 0,
  /* 7573 */ 'p', 'o', 'p', 'q', 9, 0,
  /* 7579 */ 'i', 'n', 'c', 's', 's', 'p', 'q', 9, 0,
  /* 7588 */ 'r', 'd', 's', 's', 'p', 'q', 9, 0,
  /* 7596 */ 'c', 'm', 'o', 'v', 'p', 'q', 9, 0,
  /* 7604 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'q', 'q', 9, 0,
  /* 7616 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'q', 'q', 9, 0,
  /* 7627 */ 'v', 'c', 'v', 't', 't', 'p', 's', '2', 'q', 'q', 9, 0,
  /* 7639 */ 'v', 'c', 'v', 't', 'p', 's', '2', 'q', 'q', 9, 0,
  /* 7650 */ 'v', 'p', 'c', 'm', 'p', 'e', 'q', 'q', 9, 0,
  /* 7660 */ 'v', 'p', 'g', 'a', 't', 'h', 'e', 'r', 'q', 'q', 9, 0,
  /* 7672 */ 'v', 'p', 's', 'c', 'a', 't', 't', 'e', 'r', 'q', 'q', 9, 0,
  /* 7685 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'u', 'q', 'q', 9, 0,
  /* 7698 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'u', 'q', 'q', 9, 0,
  /* 7710 */ 'v', 'c', 'v', 't', 't', 'p', 's', '2', 'u', 'q', 'q', 9, 0,
  /* 7723 */ 'v', 'c', 'v', 't', 'p', 's', '2', 'u', 'q', 'q', 9, 0,
  /* 7735 */ 'l', 'a', 'r', 'q', 9, 0,
  /* 7741 */ 's', 'a', 'r', 'q', 9, 0,
  /* 7747 */ 'r', 'c', 'r', 'q', 9, 0,
  /* 7753 */ 's', 'h', 'r', 'q', 9, 0,
  /* 7759 */ 'k', 'o', 'r', 'q', 9, 0,
  /* 7765 */ 'k', 'x', 'n', 'o', 'r', 'q', 9, 0,
  /* 7773 */ 'v', 'p', 'o', 'r', 'q', 9, 0,
  /* 7780 */ 'v', 'p', 'r', 'o', 'r', 'q', 9, 0,
  /* 7788 */ 'k', 'x', 'o', 'r', 'q', 9, 0,
  /* 7795 */ 'v', 'p', 'x', 'o', 'r', 'q', 9, 0,
  /* 7803 */ 'b', 's', 'r', 'q', 9, 0,
  /* 7809 */ 'b', 'l', 's', 'r', 'q', 9, 0,
  /* 7816 */ 'v', 'p', 'i', 'n', 's', 'r', 'q', 9, 0,
  /* 7825 */ 'b', 't', 'r', 'q', 9, 0,
  /* 7831 */ 'k', 's', 'h', 'i', 'f', 't', 'r', 'q', 9, 0,
  /* 7841 */ 's', 't', 'r', 'q', 9, 0,
  /* 7847 */ 'b', 'e', 'x', 't', 'r', 'q', 9, 0,
  /* 7855 */ 'v', 'p', 'e', 'x', 't', 'r', 'q', 9, 0,
  /* 7864 */ 's', 'c', 'a', 's', 'q', 9, 0,
  /* 7871 */ 'v', 'p', 'a', 'b', 's', 'q', 9, 0,
  /* 7879 */ 'm', 'o', 'v', 'a', 'b', 's', 'q', 9, 0,
  /* 7888 */ 'b', 'l', 'c', 's', 'q', 9, 0,
  /* 7895 */ 'l', 'o', 'd', 's', 'q', 9, 0,
  /* 7902 */ 'l', 'f', 's', 'q', 9, 0,
  /* 7908 */ 'v', 'p', 'm', 'i', 'n', 's', 'q', 9, 0,
  /* 7917 */ 'c', 'm', 'o', 'v', 'n', 's', 'q', 9, 0,
  /* 7926 */ 'c', 'm', 'p', 's', 'q', 9, 0,
  /* 7933 */ 'v', 'c', 'v', 't', 's', 'i', '2', 's', 's', 'q', 9, 0,
  /* 7945 */ 'v', 'c', 'v', 't', 'u', 's', 'i', '2', 's', 's', 'q', 9, 0,
  /* 7958 */ 'v', 'p', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'q', 9, 0,
  /* 7971 */ 'l', 's', 's', 'q', 9, 0,
  /* 7977 */ 'w', 'r', 's', 's', 'q', 9, 0,
  /* 7984 */ 'w', 'r', 'u', 's', 's', 'q', 9, 0,
  /* 7992 */ 'b', 't', 's', 'q', 9, 0,
  /* 7998 */ 'c', 'm', 'o', 'v', 's', 'q', 9, 0,
  /* 8006 */ 'v', 'p', 'm', 'a', 'x', 's', 'q', 9, 0,
  /* 8015 */ 'b', 't', 'q', 9, 0,
  /* 8020 */ 'v', 'p', 'c', 'o', 'n', 'f', 'l', 'i', 'c', 't', 'q', 9, 0,
  /* 8033 */ 'l', 'g', 'd', 't', 'q', 9, 0,
  /* 8040 */ 's', 'g', 'd', 't', 'q', 9, 0,
  /* 8047 */ 'l', 'i', 'd', 't', 'q', 9, 0,
  /* 8054 */ 's', 'i', 'd', 't', 'q', 9, 0,
  /* 8061 */ 's', 'l', 'd', 't', 'q', 9, 0,
  /* 8068 */ 'l', 'r', 'e', 't', 'q', 9, 0,
  /* 8075 */ 'v', 'p', 'c', 'm', 'p', 'g', 't', 'q', 9, 0,
  /* 8085 */ 'v', 'p', 'o', 'p', 'c', 'n', 't', 'q', 9, 0,
  /* 8095 */ 'v', 'p', 'l', 'z', 'c', 'n', 't', 'q', 9, 0,
  /* 8105 */ 't', 'z', 'c', 'n', 't', 'q', 9, 0,
  /* 8113 */ 'm', 'o', 'v', 'n', 't', 'q', 9, 0,
  /* 8121 */ 'k', 'n', 'o', 't', 'q', 9, 0,
  /* 8128 */ 'v', 'p', 'r', 'o', 't', 'q', 9, 0,
  /* 8136 */ 'i', 'n', 's', 'e', 'r', 't', 'q', 9, 0,
  /* 8145 */ 'v', 'p', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'q', 9, 0,
  /* 8159 */ 'k', 't', 'e', 's', 't', 'q', 9, 0,
  /* 8167 */ 'k', 'o', 'r', 't', 'e', 's', 't', 'q', 9, 0,
  /* 8177 */ 'p', 'e', 'x', 't', 'q', 9, 0,
  /* 8184 */ 'v', 'p', 'm', 'a', 'd', 'd', '5', '2', 'h', 'u', 'q', 9, 0,
  /* 8197 */ 'v', 'p', 'm', 'a', 'd', 'd', '5', '2', 'l', 'u', 'q', 9, 0,
  /* 8210 */ 'v', 'p', 'c', 'o', 'm', 'u', 'q', 9, 0,
  /* 8219 */ 'v', 'p', 'm', 'i', 'n', 'u', 'q', 9, 0,
  /* 8228 */ 'v', 'p', 'c', 'm', 'p', 'u', 'q', 9, 0,
  /* 8237 */ 'v', 'p', 'm', 'a', 'x', 'u', 'q', 9, 0,
  /* 8246 */ 'v', 'p', 's', 'r', 'a', 'v', 'q', 9, 0,
  /* 8255 */ 'v', 'p', 's', 'h', 'l', 'd', 'v', 'q', 9, 0,
  /* 8265 */ 'v', 'p', 's', 'h', 'r', 'd', 'v', 'q', 9, 0,
  /* 8275 */ 'i', 'd', 'i', 'v', 'q', 9, 0,
  /* 8282 */ 'v', 'p', 's', 'l', 'l', 'v', 'q', 9, 0,
  /* 8291 */ 'v', 'p', 'r', 'o', 'l', 'v', 'q', 9, 0,
  /* 8300 */ 'v', 'p', 's', 'r', 'l', 'v', 'q', 9, 0,
  /* 8309 */ 'v', 'p', 'm', 'a', 's', 'k', 'm', 'o', 'v', 'q', 9, 0,
  /* 8321 */ 'v', 'm', 'o', 'v', 'q', 9, 0,
  /* 8328 */ 'v', 'p', 'r', 'o', 'r', 'v', 'q', 9, 0,
  /* 8337 */ 'v', 'p', 'h', 'a', 'd', 'd', 'w', 'q', 9, 0,
  /* 8347 */ 's', 'm', 's', 'w', 'q', 9, 0,
  /* 8354 */ 'm', 'o', 'v', 's', 'w', 'q', 9, 0,
  /* 8362 */ 'v', 'p', 'h', 'a', 'd', 'd', 'u', 'w', 'q', 9, 0,
  /* 8373 */ 'v', 'p', 'm', 'o', 'v', 's', 'x', 'w', 'q', 9, 0,
  /* 8384 */ 'v', 'p', 'm', 'o', 'v', 'z', 'x', 'w', 'q', 9, 0,
  /* 8395 */ 'm', 'o', 'v', 'z', 'w', 'q', 9, 0,
  /* 8403 */ 'a', 'd', 'c', 'x', 'q', 9, 0,
  /* 8410 */ 's', 'h', 'l', 'x', 'q', 9, 0,
  /* 8417 */ 'm', 'u', 'l', 'x', 'q', 9, 0,
  /* 8424 */ 'a', 'd', 'o', 'x', 'q', 9, 0,
  /* 8431 */ 's', 'a', 'r', 'x', 'q', 9, 0,
  /* 8438 */ 's', 'h', 'r', 'x', 'q', 9, 0,
  /* 8445 */ 'r', 'o', 'r', 'x', 'q', 9, 0,
  /* 8452 */ 'v', 'm', 'c', 'l', 'e', 'a', 'r', 9, 0,
  /* 8461 */ 'p', 'f', 's', 'u', 'b', 'r', 9, 0,
  /* 8469 */ 'e', 'n', 't', 'e', 'r', 9, 0,
  /* 8476 */ 'v', 'p', 'a', 'l', 'i', 'g', 'n', 'r', 9, 0,
  /* 8486 */ 'v', 'p', 'o', 'r', 9, 0,
  /* 8492 */ 'u', 'm', 'o', 'n', 'i', 't', 'o', 'r', 9, 0,
  /* 8502 */ 'f', 'r', 's', 't', 'o', 'r', 9, 0,
  /* 8510 */ 'f', 'x', 'r', 's', 't', 'o', 'r', 9, 0,
  /* 8519 */ 'v', 'p', 'x', 'o', 'r', 9, 0,
  /* 8526 */ 'v', 'e', 'r', 'r', 9, 0,
  /* 8532 */ 'v', 'l', 'd', 'm', 'x', 'c', 's', 'r', 9, 0,
  /* 8542 */ 'v', 's', 't', 'm', 'x', 'c', 's', 'r', 9, 0,
  /* 8552 */ 'f', 'd', 'i', 'v', 'r', 9, 0,
  /* 8559 */ 'f', 's', 'u', 'b', 's', 9, 0,
  /* 8566 */ 'f', 'i', 's', 'u', 'b', 's', 9, 0,
  /* 8574 */ 'f', 'a', 'd', 'd', 's', 9, 0,
  /* 8581 */ 'f', 'i', 'a', 'd', 'd', 's', 9, 0,
  /* 8589 */ 'f', 'l', 'd', 's', 9, 0,
  /* 8595 */ 'f', 'i', 'l', 'd', 's', 9, 0,
  /* 8602 */ 'v', 'p', '4', 'd', 'p', 'w', 's', 's', 'd', 's', 9, 0,
  /* 8614 */ 'v', 'p', 'd', 'p', 'w', 's', 's', 'd', 's', 9, 0,
  /* 8625 */ 'v', 'p', 'd', 'p', 'b', 'u', 's', 'd', 's', 9, 0,
  /* 8636 */ 'x', 's', 'a', 'v', 'e', 's', 9, 0,
  /* 8644 */ 'l', 'g', 's', 9, 0,
  /* 8649 */ 'j', 's', 9, 0,
  /* 8653 */ 'f', 'm', 'u', 'l', 's', 9, 0,
  /* 8660 */ 'f', 'i', 'm', 'u', 'l', 's', 9, 0,
  /* 8668 */ 'f', 'c', 'o', 'm', 's', 9, 0,
  /* 8675 */ 'f', 'i', 'c', 'o', 'm', 's', 9, 0,
  /* 8683 */ 'l', 'w', 'p', 'i', 'n', 's', 9, 0,
  /* 8691 */ 'j', 'n', 's', 9, 0,
  /* 8696 */ 's', 'e', 't', 'n', 's', 9, 0,
  /* 8703 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'u', 'b', '2', '3', '1', 'p', 's', 9, 0,
  /* 8719 */ 'v', 'f', 'm', 's', 'u', 'b', '2', '3', '1', 'p', 's', 9, 0,
  /* 8732 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '2', '3', '1', 'p', 's', 9, 0,
  /* 8746 */ 'v', 'f', 'm', 's', 'u', 'b', 'a', 'd', 'd', '2', '3', '1', 'p', 's', 9, 0,
  /* 8762 */ 'v', 'f', 'm', 'a', 'd', 'd', '2', '3', '1', 'p', 's', 9, 0,
  /* 8775 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '2', '3', '1', 'p', 's', 9, 0,
  /* 8789 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'u', 'b', '1', '3', '2', 'p', 's', 9, 0,
  /* 8805 */ 'v', 'f', 'm', 's', 'u', 'b', '1', '3', '2', 'p', 's', 9, 0,
  /* 8818 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '1', '3', '2', 'p', 's', 9, 0,
  /* 8832 */ 'v', 'f', 'm', 's', 'u', 'b', 'a', 'd', 'd', '1', '3', '2', 'p', 's', 9, 0,
  /* 8848 */ 'v', 'f', 'm', 'a', 'd', 'd', '1', '3', '2', 'p', 's', 9, 0,
  /* 8861 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '1', '3', '2', 'p', 's', 9, 0,
  /* 8875 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'p', 's', 9, 0,
  /* 8886 */ 'v', 'c', 'v', 't', 'p', 'h', '2', 'p', 's', 9, 0,
  /* 8897 */ 'v', 'p', 'e', 'r', 'm', 'i', '2', 'p', 's', 9, 0,
  /* 8908 */ 'c', 'v', 't', 'p', 'i', '2', 'p', 's', 9, 0,
  /* 8918 */ 'v', 'p', 'e', 'r', 'm', 'i', 'l', '2', 'p', 's', 9, 0,
  /* 8930 */ 'v', 'e', 'x', 'p', '2', 'p', 's', 9, 0,
  /* 8939 */ 'v', 'c', 'v', 't', 'd', 'q', '2', 'p', 's', 9, 0,
  /* 8950 */ 'v', 'c', 'v', 't', 'u', 'd', 'q', '2', 'p', 's', 9, 0,
  /* 8962 */ 'v', 'c', 'v', 't', 'q', 'q', '2', 'p', 's', 9, 0,
  /* 8973 */ 'v', 'c', 'v', 't', 'u', 'q', 'q', '2', 'p', 's', 9, 0,
  /* 8985 */ 'v', 'p', 'e', 'r', 'm', 't', '2', 'p', 's', 9, 0,
  /* 8996 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'u', 'b', '2', '1', '3', 'p', 's', 9, 0,
  /* 9012 */ 'v', 'f', 'm', 's', 'u', 'b', '2', '1', '3', 'p', 's', 9, 0,
  /* 9025 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '2', '1', '3', 'p', 's', 9, 0,
  /* 9039 */ 'v', 'f', 'm', 's', 'u', 'b', 'a', 'd', 'd', '2', '1', '3', 'p', 's', 9, 0,
  /* 9055 */ 'v', 'f', 'm', 'a', 'd', 'd', '2', '1', '3', 'p', 's', 9, 0,
  /* 9068 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '2', '1', '3', 'p', 's', 9, 0,
  /* 9082 */ 'v', 'r', 'c', 'p', '1', '4', 'p', 's', 9, 0,
  /* 9092 */ 'v', 'r', 's', 'q', 'r', 't', '1', '4', 'p', 's', 9, 0,
  /* 9104 */ 'v', 'r', 'c', 'p', '2', '8', 'p', 's', 9, 0,
  /* 9114 */ 'v', 'r', 's', 'q', 'r', 't', '2', '8', 'p', 's', 9, 0,
  /* 9126 */ 'v', 'm', 'o', 'v', 'a', 'p', 's', 9, 0,
  /* 9135 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 'u', 'b', 'p', 's', 9, 0,
  /* 9148 */ 'v', 'a', 'd', 'd', 's', 'u', 'b', 'p', 's', 9, 0,
  /* 9159 */ 'v', 'h', 's', 'u', 'b', 'p', 's', 9, 0,
  /* 9168 */ 'v', 'f', 'm', 's', 'u', 'b', 'p', 's', 9, 0,
  /* 9178 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', 'p', 's', 9, 0,
  /* 9189 */ 'v', 's', 'u', 'b', 'p', 's', 9, 0,
  /* 9197 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'p', 'f', '0', 'd', 'p', 's', 9, 0,
  /* 9212 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'p', 'f', '0', 'd', 'p', 's', 9, 0,
  /* 9228 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'p', 'f', '1', 'd', 'p', 's', 9, 0,
  /* 9243 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'p', 'f', '1', 'd', 'p', 's', 9, 0,
  /* 9259 */ 'v', 'f', 'm', 's', 'u', 'b', 'a', 'd', 'd', 'p', 's', 9, 0,
  /* 9272 */ 'v', 'h', 'a', 'd', 'd', 'p', 's', 9, 0,
  /* 9281 */ 'v', '4', 'f', 'm', 'a', 'd', 'd', 'p', 's', 9, 0,
  /* 9292 */ 'v', 'f', 'm', 'a', 'd', 'd', 'p', 's', 9, 0,
  /* 9302 */ 'v', '4', 'f', 'n', 'm', 'a', 'd', 'd', 'p', 's', 9, 0,
  /* 9314 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', 'p', 's', 9, 0,
  /* 9325 */ 'v', 'a', 'd', 'd', 'p', 's', 9, 0,
  /* 9333 */ 'v', 'e', 'x', 'p', 'a', 'n', 'd', 'p', 's', 9, 0,
  /* 9344 */ 'v', 'a', 'n', 'd', 'p', 's', 9, 0,
  /* 9352 */ 'v', 'b', 'l', 'e', 'n', 'd', 'p', 's', 9, 0,
  /* 9362 */ 'v', 'r', 'o', 'u', 'n', 'd', 'p', 's', 9, 0,
  /* 9372 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'd', 'p', 's', 9, 0,
  /* 9384 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'd', 'p', 's', 9, 0,
  /* 9397 */ 'v', 'r', 'e', 'd', 'u', 'c', 'e', 'p', 's', 9, 0,
  /* 9408 */ 'v', 'r', 'a', 'n', 'g', 'e', 'p', 's', 9, 0,
  /* 9418 */ 'v', 'r', 'n', 'd', 's', 'c', 'a', 'l', 'e', 'p', 's', 9, 0,
  /* 9431 */ 'v', 's', 'c', 'a', 'l', 'e', 'f', 'p', 's', 9, 0,
  /* 9442 */ 'v', 's', 'h', 'u', 'f', 'p', 's', 9, 0,
  /* 9451 */ 'v', 'u', 'n', 'p', 'c', 'k', 'h', 'p', 's', 9, 0,
  /* 9462 */ 'v', 'm', 'o', 'v', 'l', 'h', 'p', 's', 9, 0,
  /* 9472 */ 'v', 'm', 'o', 'v', 'h', 'p', 's', 9, 0,
  /* 9481 */ 'v', 'm', 'o', 'v', 'm', 's', 'k', 'p', 's', 9, 0,
  /* 9492 */ 'v', 'm', 'o', 'v', 'h', 'l', 'p', 's', 9, 0,
  /* 9502 */ 'v', 'p', 'e', 'r', 'm', 'i', 'l', 'p', 's', 9, 0,
  /* 9513 */ 'v', 'u', 'n', 'p', 'c', 'k', 'l', 'p', 's', 9, 0,
  /* 9524 */ 'v', 'm', 'u', 'l', 'p', 's', 9, 0,
  /* 9532 */ 'v', 'm', 'o', 'v', 'l', 'p', 's', 9, 0,
  /* 9541 */ 'v', 'b', 'l', 'e', 'n', 'd', 'm', 'p', 's', 9, 0,
  /* 9552 */ 'v', 'f', 'i', 'x', 'u', 'p', 'i', 'm', 'm', 'p', 's', 9, 0,
  /* 9565 */ 'f', 'c', 'o', 'm', 'p', 's', 9, 0,
  /* 9573 */ 'f', 'i', 'c', 'o', 'm', 'p', 's', 9, 0,
  /* 9582 */ 'v', 'p', 'e', 'r', 'm', 'p', 's', 9, 0,
  /* 9591 */ 'v', 'a', 'n', 'd', 'n', 'p', 's', 9, 0,
  /* 9600 */ 'v', 'm', 'i', 'n', 'p', 's', 9, 0,
  /* 9608 */ 'v', 'r', 'c', 'p', 'p', 's', 9, 0,
  /* 9616 */ 'v', 'd', 'p', 'p', 's', 9, 0,
  /* 9623 */ 'v', 'c', 'm', 'p', 'p', 's', 9, 0,
  /* 9631 */ 'v', 'g', 'e', 't', 'e', 'x', 'p', 'p', 's', 9, 0,
  /* 9642 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'p', 'f', '0', 'q', 'p', 's', 9, 0,
  /* 9657 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'p', 'f', '0', 'q', 'p', 's', 9, 0,
  /* 9673 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'p', 'f', '1', 'q', 'p', 's', 9, 0,
  /* 9688 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'p', 'f', '1', 'q', 'p', 's', 9, 0,
  /* 9704 */ 'v', 'g', 'a', 't', 'h', 'e', 'r', 'q', 'p', 's', 9, 0,
  /* 9716 */ 'v', 's', 'c', 'a', 't', 't', 'e', 'r', 'q', 'p', 's', 9, 0,
  /* 9729 */ 'v', 'o', 'r', 'p', 's', 9, 0,
  /* 9736 */ 'v', 'x', 'o', 'r', 'p', 's', 9, 0,
  /* 9744 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 's', 9, 0,
  /* 9756 */ 'v', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'p', 's', 9, 0,
  /* 9769 */ 'v', 'e', 'x', 't', 'r', 'a', 'c', 't', 'p', 's', 9, 0,
  /* 9781 */ 'v', 'g', 'e', 't', 'm', 'a', 'n', 't', 'p', 's', 9, 0,
  /* 9793 */ 'v', 'm', 'o', 'v', 'n', 't', 'p', 's', 9, 0,
  /* 9803 */ 'v', 'i', 'n', 's', 'e', 'r', 't', 'p', 's', 9, 0,
  /* 9814 */ 'v', 'r', 's', 'q', 'r', 't', 'p', 's', 9, 0,
  /* 9824 */ 'v', 's', 'q', 'r', 't', 'p', 's', 9, 0,
  /* 9833 */ 'v', 't', 'e', 's', 't', 'p', 's', 9, 0,
  /* 9842 */ 'f', 's', 't', 'p', 's', 9, 0,
  /* 9849 */ 'f', 'i', 's', 't', 'p', 's', 9, 0,
  /* 9857 */ 'f', 'i', 's', 't', 't', 'p', 's', 9, 0,
  /* 9866 */ 'v', 'm', 'o', 'v', 'u', 'p', 's', 9, 0,
  /* 9875 */ 'v', 'b', 'l', 'e', 'n', 'd', 'v', 'p', 's', 9, 0,
  /* 9886 */ 'v', 'd', 'i', 'v', 'p', 's', 9, 0,
  /* 9894 */ 'v', 'm', 'a', 's', 'k', 'm', 'o', 'v', 'p', 's', 9, 0,
  /* 9906 */ 'v', 'm', 'a', 'x', 'p', 's', 9, 0,
  /* 9914 */ 'v', 'f', 'r', 'c', 'z', 'p', 's', 9, 0,
  /* 9923 */ 'f', 's', 'u', 'b', 'r', 's', 9, 0,
  /* 9931 */ 'f', 'i', 's', 'u', 'b', 'r', 's', 9, 0,
  /* 9940 */ 'x', 'r', 's', 't', 'o', 'r', 's', 9, 0,
  /* 9949 */ 'f', 'd', 'i', 'v', 'r', 's', 9, 0,
  /* 9957 */ 'f', 'i', 'd', 'i', 'v', 'r', 's', 9, 0,
  /* 9966 */ 'v', 'f', 'm', 's', 'u', 'b', '2', '3', '1', 's', 's', 9, 0,
  /* 9979 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '2', '3', '1', 's', 's', 9, 0,
  /* 9993 */ 'v', 'f', 'm', 'a', 'd', 'd', '2', '3', '1', 's', 's', 9, 0,
  /* 10006 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '2', '3', '1', 's', 's', 9, 0,
  /* 10020 */ 'v', 'f', 'm', 's', 'u', 'b', '1', '3', '2', 's', 's', 9, 0,
  /* 10033 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '1', '3', '2', 's', 's', 9, 0,
  /* 10047 */ 'v', 'f', 'm', 'a', 'd', 'd', '1', '3', '2', 's', 's', 9, 0,
  /* 10060 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '1', '3', '2', 's', 's', 9, 0,
  /* 10074 */ 'v', 'c', 'v', 't', 's', 'd', '2', 's', 's', 9, 0,
  /* 10085 */ 'v', 'f', 'm', 's', 'u', 'b', '2', '1', '3', 's', 's', 9, 0,
  /* 10098 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', '2', '1', '3', 's', 's', 9, 0,
  /* 10112 */ 'v', 'f', 'm', 'a', 'd', 'd', '2', '1', '3', 's', 's', 9, 0,
  /* 10125 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', '2', '1', '3', 's', 's', 9, 0,
  /* 10139 */ 'v', 'r', 'c', 'p', '1', '4', 's', 's', 9, 0,
  /* 10149 */ 'v', 'r', 's', 'q', 'r', 't', '1', '4', 's', 's', 9, 0,
  /* 10161 */ 'v', 'r', 'c', 'p', '2', '8', 's', 's', 9, 0,
  /* 10171 */ 'v', 'r', 's', 'q', 'r', 't', '2', '8', 's', 's', 9, 0,
  /* 10183 */ 'v', 'f', 'm', 's', 'u', 'b', 's', 's', 9, 0,
  /* 10193 */ 'v', 'f', 'n', 'm', 's', 'u', 'b', 's', 's', 9, 0,
  /* 10204 */ 'v', 's', 'u', 'b', 's', 's', 9, 0,
  /* 10212 */ 'v', '4', 'f', 'm', 'a', 'd', 'd', 's', 's', 9, 0,
  /* 10223 */ 'v', 'f', 'm', 'a', 'd', 'd', 's', 's', 9, 0,
  /* 10233 */ 'v', '4', 'f', 'n', 'm', 'a', 'd', 'd', 's', 's', 9, 0,
  /* 10245 */ 'v', 'f', 'n', 'm', 'a', 'd', 'd', 's', 's', 9, 0,
  /* 10256 */ 'v', 'a', 'd', 'd', 's', 's', 9, 0,
  /* 10264 */ 'v', 'r', 'o', 'u', 'n', 'd', 's', 's', 9, 0,
  /* 10274 */ 'v', 'r', 'e', 'd', 'u', 'c', 'e', 's', 's', 9, 0,
  /* 10285 */ 'v', 'r', 'a', 'n', 'g', 'e', 's', 's', 9, 0,
  /* 10295 */ 'v', 'r', 'n', 'd', 's', 'c', 'a', 'l', 'e', 's', 's', 9, 0,
  /* 10308 */ 'v', 's', 'c', 'a', 'l', 'e', 'f', 's', 's', 9, 0,
  /* 10319 */ 'v', 'u', 'c', 'o', 'm', 'i', 's', 's', 9, 0,
  /* 10329 */ 'v', 'c', 'o', 'm', 'i', 's', 's', 9, 0,
  /* 10338 */ 'v', 'm', 'u', 'l', 's', 's', 9, 0,
  /* 10346 */ 'v', 'f', 'i', 'x', 'u', 'p', 'i', 'm', 'm', 's', 's', 9, 0,
  /* 10359 */ 'v', 'm', 'i', 'n', 's', 's', 9, 0,
  /* 10367 */ 'v', 'r', 'c', 'p', 's', 's', 9, 0,
  /* 10375 */ 'v', 'c', 'm', 'p', 's', 's', 9, 0,
  /* 10383 */ 'v', 'g', 'e', 't', 'e', 'x', 'p', 's', 's', 9, 0,
  /* 10394 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 's', 's', 9, 0,
  /* 10406 */ 'v', 'g', 'e', 't', 'm', 'a', 'n', 't', 's', 's', 9, 0,
  /* 10418 */ 'm', 'o', 'v', 'n', 't', 's', 's', 9, 0,
  /* 10427 */ 'v', 'r', 's', 'q', 'r', 't', 's', 's', 9, 0,
  /* 10437 */ 'v', 's', 'q', 'r', 't', 's', 's', 9, 0,
  /* 10446 */ 'v', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 's', 's', 9, 0,
  /* 10460 */ 'v', 'd', 'i', 'v', 's', 's', 9, 0,
  /* 10468 */ 'v', 'm', 'o', 'v', 's', 's', 9, 0,
  /* 10476 */ 'v', 'm', 'a', 'x', 's', 's', 9, 0,
  /* 10484 */ 'v', 'f', 'r', 'c', 'z', 's', 's', 9, 0,
  /* 10493 */ 's', 'e', 't', 's', 9, 0,
  /* 10499 */ 'f', 's', 't', 's', 9, 0,
  /* 10505 */ 'f', 'i', 's', 't', 's', 9, 0,
  /* 10512 */ 'f', 'd', 'i', 'v', 's', 9, 0,
  /* 10519 */ 'f', 'i', 'd', 'i', 'v', 's', 9, 0,
  /* 10527 */ 'f', 'l', 'd', 't', 9, 0,
  /* 10533 */ 'p', 'f', 'c', 'm', 'p', 'g', 't', 9, 0,
  /* 10542 */ 'u', 'm', 'w', 'a', 'i', 't', 9, 0,
  /* 10550 */ 'i', 'n', 't', 9, 0,
  /* 10555 */ 'i', 'n', 'v', 'e', 'p', 't', 9, 0,
  /* 10563 */ 'x', 's', 'a', 'v', 'e', 'o', 'p', 't', 9, 0,
  /* 10573 */ 'c', 'l', 'f', 'l', 'u', 's', 'h', 'o', 'p', 't', 9, 0,
  /* 10585 */ 'f', 's', 't', 'p', 't', 9, 0,
  /* 10592 */ 'x', 'a', 'b', 'o', 'r', 't', 9, 0,
  /* 10600 */ 'p', 'f', 'r', 's', 'q', 'r', 't', 9, 0,
  /* 10609 */ 'v', 'a', 'e', 's', 'd', 'e', 'c', 'l', 'a', 's', 't', 9, 0,
  /* 10622 */ 'v', 'a', 'e', 's', 'e', 'n', 'c', 'l', 'a', 's', 't', 9, 0,
  /* 10635 */ 'v', 'p', 't', 'e', 's', 't', 9, 0,
  /* 10643 */ 'f', 's', 't', 9, 0,
  /* 10648 */ 'v', 'a', 'e', 's', 'k', 'e', 'y', 'g', 'e', 'n', 'a', 's', 's', 'i', 's', 't', 9, 0,
  /* 10666 */ 'v', 'm', 'p', 't', 'r', 's', 't', 9, 0,
  /* 10675 */ 'b', 'n', 'd', 'c', 'u', 9, 0,
  /* 10682 */ 'f', 'c', 'm', 'o', 'v', 'n', 'u', 9, 0,
  /* 10691 */ 'v', 'l', 'd', 'd', 'q', 'u', 9, 0,
  /* 10699 */ 'v', 'm', 'a', 's', 'k', 'm', 'o', 'v', 'd', 'q', 'u', 9, 0,
  /* 10712 */ 'v', 'm', 'o', 'v', 'd', 'q', 'u', 9, 0,
  /* 10721 */ 'f', 'c', 'm', 'o', 'v', 'u', 9, 0,
  /* 10729 */ 'f', 'd', 'i', 'v', 9, 0,
  /* 10735 */ 'f', 'l', 'd', 'e', 'n', 'v', 9, 0,
  /* 10743 */ 'f', 'n', 's', 't', 'e', 'n', 'v', 9, 0,
  /* 10752 */ 'v', 'p', 'c', 'm', 'o', 'v', 9, 0,
  /* 10760 */ 'b', 'n', 'd', 'm', 'o', 'v', 9, 0,
  /* 10768 */ 'c', 'r', 'c', '3', '2', 'w', 9, 0,
  /* 10776 */ 'v', 'p', 'e', 'r', 'm', 'i', '2', 'w', 9, 0,
  /* 10786 */ 'v', 'p', 'm', 'o', 'v', 'm', '2', 'w', 9, 0,
  /* 10796 */ 'v', 'p', 'e', 'r', 'm', 't', '2', 'w', 9, 0,
  /* 10806 */ 'l', 'e', 'a', 'w', 9, 0,
  /* 10812 */ 'v', 'p', 's', 'h', 'a', 'w', 9, 0,
  /* 10820 */ 'v', 'p', 's', 'r', 'a', 'w', 9, 0,
  /* 10828 */ 'c', 'm', 'o', 'v', 'a', 'w', 9, 0,
  /* 10836 */ 's', 'b', 'b', 'w', 9, 0,
  /* 10842 */ 'v', 'p', 'h', 's', 'u', 'b', 'b', 'w', 9, 0,
  /* 10852 */ 'v', 'd', 'b', 'p', 's', 'a', 'd', 'b', 'w', 9, 0,
  /* 10863 */ 'v', 'm', 'p', 's', 'a', 'd', 'b', 'w', 9, 0,
  /* 10873 */ 'v', 'p', 's', 'a', 'd', 'b', 'w', 9, 0,
  /* 10882 */ 'v', 'p', 'h', 'a', 'd', 'd', 'b', 'w', 9, 0,
  /* 10892 */ 'v', 'p', 'u', 'n', 'p', 'c', 'k', 'h', 'b', 'w', 9, 0,
  /* 10904 */ 'k', 'u', 'n', 'p', 'c', 'k', 'b', 'w', 9, 0,
  /* 10914 */ 'v', 'p', 'u', 'n', 'p', 'c', 'k', 'l', 'b', 'w', 9, 0,
  /* 10926 */ 'm', 'o', 'v', 's', 'b', 'w', 9, 0,
  /* 10934 */ 'v', 'p', 'h', 'a', 'd', 'd', 'u', 'b', 'w', 9, 0,
  /* 10945 */ 'v', 'p', 'h', 's', 'u', 'b', 'w', 9, 0,
  /* 10954 */ 'v', 'p', 's', 'u', 'b', 'w', 9, 0,
  /* 10962 */ 'c', 'm', 'o', 'v', 'b', 'w', 9, 0,
  /* 10970 */ 'v', 'p', 'm', 'o', 'v', 's', 'x', 'b', 'w', 9, 0,
  /* 10981 */ 'v', 'p', 'm', 'o', 'v', 'z', 'x', 'b', 'w', 9, 0,
  /* 10992 */ 'm', 'o', 'v', 'z', 'b', 'w', 9, 0,
  /* 11000 */ 'a', 'd', 'c', 'w', 9, 0,
  /* 11006 */ 'f', 'l', 'd', 'c', 'w', 9, 0,
  /* 11013 */ 'd', 'e', 'c', 'w', 9, 0,
  /* 11019 */ 'i', 'n', 'c', 'w', 9, 0,
  /* 11025 */ 'b', 't', 'c', 'w', 9, 0,
  /* 11031 */ 'f', 'n', 's', 't', 'c', 'w', 9, 0,
  /* 11039 */ 'v', 'p', 'h', 'a', 'd', 'd', 'w', 9, 0,
  /* 11048 */ 'k', 'a', 'd', 'd', 'w', 9, 0,
  /* 11055 */ 'v', 'p', 'a', 'd', 'd', 'w', 9, 0,
  /* 11063 */ 'x', 'a', 'd', 'd', 'w', 9, 0,
  /* 11070 */ 'r', 'd', 's', 'e', 'e', 'd', 'w', 9, 0,
  /* 11079 */ 'v', 'p', 's', 'h', 'l', 'd', 'w', 9, 0,
  /* 11088 */ 'k', 'a', 'n', 'd', 'w', 9, 0,
  /* 11095 */ 'v', 'p', 'e', 'x', 'p', 'a', 'n', 'd', 'w', 9, 0,
  /* 11106 */ 'r', 'd', 'r', 'a', 'n', 'd', 'w', 9, 0,
  /* 11115 */ 'v', 'p', 'b', 'l', 'e', 'n', 'd', 'w', 9, 0,
  /* 11125 */ 'v', 'p', 's', 'h', 'r', 'd', 'w', 9, 0,
  /* 11134 */ 'v', 'p', 'a', 'c', 'k', 's', 's', 'd', 'w', 9, 0,
  /* 11145 */ 'v', 'p', 'a', 'c', 'k', 'u', 's', 'd', 'w', 9, 0,
  /* 11156 */ 'v', 'p', 'm', 'o', 'v', 'u', 's', 'd', 'w', 9, 0,
  /* 11167 */ 'v', 'p', 'm', 'o', 'v', 's', 'd', 'w', 9, 0,
  /* 11177 */ 'v', 'p', 'm', 'o', 'v', 'd', 'w', 9, 0,
  /* 11186 */ 'c', 'm', 'o', 'v', 'a', 'e', 'w', 9, 0,
  /* 11195 */ 'c', 'm', 'o', 'v', 'b', 'e', 'w', 9, 0,
  /* 11204 */ 'c', 'm', 'o', 'v', 'g', 'e', 'w', 9, 0,
  /* 11213 */ 'c', 'm', 'o', 'v', 'l', 'e', 'w', 9, 0,
  /* 11222 */ 'c', 'm', 'o', 'v', 'n', 'e', 'w', 9, 0,
  /* 11231 */ 'c', 'm', 'o', 'v', 'e', 'w', 9, 0,
  /* 11239 */ 'p', 'i', '2', 'f', 'w', 9, 0,
  /* 11246 */ 'b', 's', 'f', 'w', 9, 0,
  /* 11252 */ 'p', 's', 'h', 'u', 'f', 'w', 9, 0,
  /* 11260 */ 'n', 'e', 'g', 'w', 9, 0,
  /* 11266 */ 'c', 'm', 'p', 'x', 'c', 'h', 'g', 'w', 9, 0,
  /* 11276 */ 'v', 'p', 'a', 'v', 'g', 'w', 9, 0,
  /* 11284 */ 'c', 'm', 'o', 'v', 'g', 'w', 9, 0,
  /* 11292 */ 'p', 'r', 'e', 'f', 'e', 't', 'c', 'h', 'w', 9, 0,
  /* 11303 */ 'v', 'p', 's', 'h', 'u', 'f', 'h', 'w', 9, 0,
  /* 11313 */ 'v', 'p', 'm', 'u', 'l', 'h', 'w', 9, 0,
  /* 11322 */ 'p', 'u', 's', 'h', 'w', 9, 0,
  /* 11329 */ 'p', 'f', '2', 'i', 'w', 9, 0,
  /* 11336 */ 's', 'a', 'l', 'w', 9, 0,
  /* 11342 */ 'r', 'c', 'l', 'w', 9, 0,
  /* 11348 */ 'v', 'p', 's', 'h', 'u', 'f', 'l', 'w', 9, 0,
  /* 11358 */ 'v', 'p', 's', 'h', 'l', 'w', 9, 0,
  /* 11366 */ 'l', 'c', 'a', 'l', 'l', 'w', 9, 0,
  /* 11374 */ 'v', 'p', 's', 'l', 'l', 'w', 9, 0,
  /* 11382 */ 'v', 'p', 'm', 'u', 'l', 'l', 'w', 9, 0,
  /* 11391 */ 'r', 'o', 'l', 'w', 9, 0,
  /* 11397 */ 'v', 'p', 's', 'r', 'l', 'w', 9, 0,
  /* 11405 */ 'l', 's', 'l', 'w', 9, 0,
  /* 11411 */ 'k', 's', 'h', 'i', 'f', 't', 'l', 'w', 9, 0,
  /* 11421 */ 'i', 'm', 'u', 'l', 'w', 9, 0,
  /* 11428 */ 'c', 'm', 'o', 'v', 'l', 'w', 9, 0,
  /* 11436 */ 'v', 'p', 'b', 'l', 'e', 'n', 'd', 'm', 'w', 9, 0,
  /* 11447 */ 'v', 'p', 't', 'e', 's', 't', 'n', 'm', 'w', 9, 0,
  /* 11458 */ 'v', 'p', 'c', 'o', 'm', 'w', 9, 0,
  /* 11466 */ 'v', 'p', 'e', 'r', 'm', 'w', 9, 0,
  /* 11474 */ 'v', 'p', 't', 'e', 's', 't', 'm', 'w', 9, 0,
  /* 11484 */ 'k', 'a', 'n', 'd', 'n', 'w', 9, 0,
  /* 11492 */ 'v', 'p', 's', 'i', 'g', 'n', 'w', 9, 0,
  /* 11501 */ 'i', 'n', 'w', 9, 0,
  /* 11506 */ 'c', 'm', 'o', 'v', 'n', 'o', 'w', 9, 0,
  /* 11515 */ 'c', 'm', 'o', 'v', 'o', 'w', 9, 0,
  /* 11523 */ 'b', 's', 'w', 'a', 'p', 'w', 9, 0,
  /* 11531 */ 'v', 'p', 'c', 'm', 'p', 'w', 9, 0,
  /* 11539 */ 'l', 'j', 'm', 'p', 'w', 9, 0,
  /* 11546 */ 'c', 'm', 'o', 'v', 'n', 'p', 'w', 9, 0,
  /* 11555 */ 'n', 'o', 'p', 'w', 9, 0,
  /* 11561 */ 'p', 'o', 'p', 'w', 9, 0,
  /* 11567 */ 'c', 'm', 'o', 'v', 'p', 'w', 9, 0,
  /* 11575 */ 'v', 'p', 'c', 'm', 'p', 'e', 'q', 'w', 9, 0,
  /* 11585 */ 'v', 'p', 'm', 'o', 'v', 'u', 's', 'q', 'w', 9, 0,
  /* 11596 */ 'v', 'p', 'm', 'o', 'v', 's', 'q', 'w', 9, 0,
  /* 11606 */ 'v', 'p', 'm', 'o', 'v', 'q', 'w', 9, 0,
  /* 11615 */ 'l', 'a', 'r', 'w', 9, 0,
  /* 11621 */ 's', 'a', 'r', 'w', 9, 0,
  /* 11627 */ 'r', 'c', 'r', 'w', 9, 0,
  /* 11633 */ 'v', 'e', 'r', 'w', 9, 0,
  /* 11639 */ 'p', 'm', 'u', 'l', 'h', 'r', 'w', 9, 0,
  /* 11648 */ 's', 'h', 'r', 'w', 9, 0,
  /* 11654 */ 'k', 'o', 'r', 'w', 9, 0,
  /* 11660 */ 'k', 'x', 'n', 'o', 'r', 'w', 9, 0,
  /* 11668 */ 'r', 'o', 'r', 'w', 9, 0,
  /* 11674 */ 'k', 'x', 'o', 'r', 'w', 9, 0,
  /* 11681 */ 'b', 's', 'r', 'w', 9, 0,
  /* 11687 */ 'v', 'p', 'i', 'n', 's', 'r', 'w', 9, 0,
  /* 11696 */ 'b', 't', 'r', 'w', 9, 0,
  /* 11702 */ 'k', 's', 'h', 'i', 'f', 't', 'r', 'w', 9, 0,
  /* 11712 */ 'l', 't', 'r', 'w', 9, 0,
  /* 11718 */ 's', 't', 'r', 'w', 9, 0,
  /* 11724 */ 'v', 'p', 'e', 'x', 't', 'r', 'w', 9, 0,
  /* 11733 */ 's', 'c', 'a', 's', 'w', 9, 0,
  /* 11740 */ 'v', 'p', 'a', 'b', 's', 'w', 9, 0,
  /* 11748 */ 'm', 'o', 'v', 'a', 'b', 's', 'w', 9, 0,
  /* 11757 */ 'v', 'p', 'm', 'a', 'd', 'd', 'u', 'b', 's', 'w', 9, 0,
  /* 11769 */ 'v', 'p', 'h', 's', 'u', 'b', 's', 'w', 9, 0,
  /* 11779 */ 'v', 'p', 's', 'u', 'b', 's', 'w', 9, 0,
  /* 11788 */ 'v', 'p', 'h', 'a', 'd', 'd', 's', 'w', 9, 0,
  /* 11798 */ 'v', 'p', 'a', 'd', 'd', 's', 'w', 9, 0,
  /* 11807 */ 'l', 'd', 's', 'w', 9, 0,
  /* 11813 */ 'l', 'o', 'd', 's', 'w', 9, 0,
  /* 11820 */ 'l', 'e', 's', 'w', 9, 0,
  /* 11826 */ 'l', 'f', 's', 'w', 9, 0,
  /* 11832 */ 'l', 'g', 's', 'w', 9, 0,
  /* 11838 */ 'v', 'p', 'm', 'i', 'n', 's', 'w', 9, 0,
  /* 11847 */ 'c', 'm', 'o', 'v', 'n', 's', 'w', 9, 0,
  /* 11856 */ 'c', 'm', 'p', 's', 'w', 9, 0,
  /* 11863 */ 'v', 'p', 'm', 'u', 'l', 'h', 'r', 's', 'w', 9, 0,
  /* 11874 */ 'v', 'p', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'w', 9, 0,
  /* 11887 */ 'l', 's', 's', 'w', 9, 0,
  /* 11893 */ 'b', 't', 's', 'w', 9, 0,
  /* 11899 */ 'f', 'n', 's', 't', 's', 'w', 9, 0,
  /* 11907 */ 'o', 'u', 't', 's', 'w', 9, 0,
  /* 11914 */ 'v', 'p', 's', 'u', 'b', 'u', 's', 'w', 9, 0,
  /* 11924 */ 'v', 'p', 'a', 'd', 'd', 'u', 's', 'w', 9, 0,
  /* 11934 */ 'c', 'm', 'o', 'v', 's', 'w', 9, 0,
  /* 11942 */ 'v', 'p', 'm', 'a', 'x', 's', 'w', 9, 0,
  /* 11951 */ 'b', 't', 'w', 9, 0,
  /* 11956 */ 'l', 'g', 'd', 't', 'w', 9, 0,
  /* 11963 */ 's', 'g', 'd', 't', 'w', 9, 0,
  /* 11970 */ 'l', 'i', 'd', 't', 'w', 9, 0,
  /* 11977 */ 's', 'i', 'd', 't', 'w', 9, 0,
  /* 11984 */ 'l', 'l', 'd', 't', 'w', 9, 0,
  /* 11991 */ 's', 'l', 'd', 't', 'w', 9, 0,
  /* 11998 */ 'l', 'r', 'e', 't', 'w', 9, 0,
  /* 12005 */ 'v', 'p', 'c', 'm', 'p', 'g', 't', 'w', 9, 0,
  /* 12015 */ 'v', 'p', 'o', 'p', 'c', 'n', 't', 'w', 9, 0,
  /* 12025 */ 'l', 'z', 'c', 'n', 't', 'w', 9, 0,
  /* 12033 */ 't', 'z', 'c', 'n', 't', 'w', 9, 0,
  /* 12041 */ 'k', 'n', 'o', 't', 'w', 9, 0,
  /* 12048 */ 'v', 'p', 'r', 'o', 't', 'w', 9, 0,
  /* 12056 */ 'v', 'p', 'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'w', 9, 0,
  /* 12070 */ 'k', 't', 'e', 's', 't', 'w', 9, 0,
  /* 12078 */ 'k', 'o', 'r', 't', 'e', 's', 't', 'w', 9, 0,
  /* 12088 */ 'v', 'p', 'm', 'u', 'l', 'h', 'u', 'w', 9, 0,
  /* 12098 */ 'v', 'p', 'c', 'o', 'm', 'u', 'w', 9, 0,
  /* 12107 */ 'v', 'p', 'm', 'i', 'n', 'u', 'w', 9, 0,
  /* 12116 */ 'v', 'p', 'c', 'm', 'p', 'u', 'w', 9, 0,
  /* 12125 */ 'v', 'p', 'h', 'm', 'i', 'n', 'p', 'o', 's', 'u', 'w', 9, 0,
  /* 12138 */ 'v', 'p', 'm', 'a', 'x', 'u', 'w', 9, 0,
  /* 12147 */ 'v', 'p', 's', 'r', 'a', 'v', 'w', 9, 0,
  /* 12156 */ 'v', 'p', 's', 'h', 'l', 'd', 'v', 'w', 9, 0,
  /* 12166 */ 'v', 'p', 's', 'h', 'r', 'd', 'v', 'w', 9, 0,
  /* 12176 */ 'i', 'd', 'i', 'v', 'w', 9, 0,
  /* 12183 */ 'v', 'p', 's', 'l', 'l', 'v', 'w', 9, 0,
  /* 12192 */ 'v', 'p', 's', 'r', 'l', 'v', 'w', 9, 0,
  /* 12201 */ 'k', 'm', 'o', 'v', 'w', 9, 0,
  /* 12208 */ 'v', 'p', 'm', 'a', 'c', 's', 'w', 'w', 9, 0,
  /* 12218 */ 'l', 'm', 's', 'w', 'w', 9, 0,
  /* 12225 */ 's', 'm', 's', 'w', 'w', 9, 0,
  /* 12232 */ 'v', 'p', 'm', 'a', 'c', 's', 's', 'w', 'w', 9, 0,
  /* 12243 */ 'm', 'o', 'v', 's', 'w', 'w', 9, 0,
  /* 12251 */ 'm', 'o', 'v', 'z', 'w', 'w', 9, 0,
  /* 12259 */ 'p', 'f', 'm', 'a', 'x', 9, 0,
  /* 12266 */ 'b', 'n', 'd', 'l', 'd', 'x', 9, 0,
  /* 12274 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 'd', 'x', 9, 0,
  /* 12287 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'd', 'q', 'x', 9, 0,
  /* 12300 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'd', 'q', 'x', 9, 0,
  /* 12312 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'u', 'd', 'q', 'x', 9, 0,
  /* 12326 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'u', 'd', 'q', 'x', 9, 0,
  /* 12339 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'p', 's', 'x', 9, 0,
  /* 12351 */ 'v', 'c', 'v', 't', 'q', 'q', '2', 'p', 's', 'x', 9, 0,
  /* 12363 */ 'v', 'c', 'v', 't', 'u', 'q', 'q', '2', 'p', 's', 'x', 9, 0,
  /* 12376 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 's', 'x', 9, 0,
  /* 12389 */ 'b', 'n', 'd', 's', 't', 'x', 9, 0,
  /* 12397 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 'd', 'y', 9, 0,
  /* 12410 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'd', 'q', 'y', 9, 0,
  /* 12423 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'd', 'q', 'y', 9, 0,
  /* 12435 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'u', 'd', 'q', 'y', 9, 0,
  /* 12449 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'u', 'd', 'q', 'y', 9, 0,
  /* 12462 */ 'c', 'l', 'r', 's', 's', 'b', 's', 'y', 9, 0,
  /* 12472 */ 'v', 'c', 'v', 't', 'p', 'd', '2', 'p', 's', 'y', 9, 0,
  /* 12484 */ 'v', 'c', 'v', 't', 'q', 'q', '2', 'p', 's', 'y', 9, 0,
  /* 12496 */ 'v', 'c', 'v', 't', 'u', 'q', 'q', '2', 'p', 's', 'y', 9, 0,
  /* 12509 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 's', 'y', 9, 0,
  /* 12522 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 'd', 'z', 9, 0,
  /* 12535 */ 'v', 'f', 'p', 'c', 'l', 'a', 's', 's', 'p', 's', 'z', 9, 0,
  /* 12548 */ 'j', 'e', 'c', 'x', 'z', 9, 0,
  /* 12555 */ 'j', 'c', 'x', 'z', 9, 0,
  /* 12561 */ 'j', 'r', 'c', 'x', 'z', 9, 0,
  /* 12568 */ 'f', 's', 'u', 'b', 9, '%', 's', 't', '(', '0', ')', ',', 32, 0,
  /* 12582 */ 'f', 'a', 'd', 'd', 9, '%', 's', 't', '(', '0', ')', ',', 32, 0,
  /* 12596 */ 'f', 's', 't', 'p', 'n', 'c', 'e', 9, '%', 's', 't', '(', '0', ')', ',', 32, 0,
  /* 12613 */ 'f', 'm', 'u', 'l', 9, '%', 's', 't', '(', '0', ')', ',', 32, 0,
  /* 12627 */ 'f', 's', 'u', 'b', 'r', 9, '%', 's', 't', '(', '0', ')', ',', 32, 0,
  /* 12642 */ 'f', 'd', 'i', 'v', 'r', 9, '%', 's', 't', '(', '0', ')', ',', 32, 0,
  /* 12657 */ 'f', 'd', 'i', 'v', 9, '%', 's', 't', '(', '0', ')', ',', 32, 0,
  /* 12671 */ 's', 'h', 'a', '2', '5', '6', 'r', 'n', 'd', 's', '2', 9, '%', 'x', 'm', 'm', '0', ',', 32, 0,
  /* 12691 */ 'p', 'b', 'l', 'e', 'n', 'd', 'v', 'b', 9, '%', 'x', 'm', 'm', '0', ',', 32, 0,
  /* 12708 */ 'b', 'l', 'e', 'n', 'd', 'v', 'p', 'd', 9, '%', 'x', 'm', 'm', '0', ',', 32, 0,
  /* 12725 */ 'b', 'l', 'e', 'n', 'd', 'v', 'p', 's', 9, '%', 'x', 'm', 'm', '0', ',', 32, 0,
  /* 12742 */ 's', 'a', 'l', 'b', 9, '$', '1', ',', 32, 0,
  /* 12752 */ 'r', 'c', 'l', 'b', 9, '$', '1', ',', 32, 0,
  /* 12762 */ 's', 'h', 'l', 'b', 9, '$', '1', ',', 32, 0,
  /* 12772 */ 'r', 'o', 'l', 'b', 9, '$', '1', ',', 32, 0,
  /* 12782 */ 's', 'a', 'r', 'b', 9, '$', '1', ',', 32, 0,
  /* 12792 */ 'r', 'c', 'r', 'b', 9, '$', '1', ',', 32, 0,
  /* 12802 */ 's', 'h', 'r', 'b', 9, '$', '1', ',', 32, 0,
  /* 12812 */ 'r', 'o', 'r', 'b', 9, '$', '1', ',', 32, 0,
  /* 12822 */ 's', 'a', 'l', 'l', 9, '$', '1', ',', 32, 0,
  /* 12832 */ 'r', 'c', 'l', 'l', 9, '$', '1', ',', 32, 0,
  /* 12842 */ 's', 'h', 'l', 'l', 9, '$', '1', ',', 32, 0,
  /* 12852 */ 'r', 'o', 'l', 'l', 9, '$', '1', ',', 32, 0,
  /* 12862 */ 's', 'a', 'r', 'l', 9, '$', '1', ',', 32, 0,
  /* 12872 */ 'r', 'c', 'r', 'l', 9, '$', '1', ',', 32, 0,
  /* 12882 */ 's', 'h', 'r', 'l', 9, '$', '1', ',', 32, 0,
  /* 12892 */ 'r', 'o', 'r', 'l', 9, '$', '1', ',', 32, 0,
  /* 12902 */ 's', 'a', 'l', 'q', 9, '$', '1', ',', 32, 0,
  /* 12912 */ 'r', 'c', 'l', 'q', 9, '$', '1', ',', 32, 0,
  /* 12922 */ 's', 'h', 'l', 'q', 9, '$', '1', ',', 32, 0,
  /* 12932 */ 'r', 'o', 'l', 'q', 9, '$', '1', ',', 32, 0,
  /* 12942 */ 's', 'a', 'r', 'q', 9, '$', '1', ',', 32, 0,
  /* 12952 */ 'r', 'c', 'r', 'q', 9, '$', '1', ',', 32, 0,
  /* 12962 */ 's', 'h', 'r', 'q', 9, '$', '1', ',', 32, 0,
  /* 12972 */ 'r', 'o', 'r', 'q', 9, '$', '1', ',', 32, 0,
  /* 12982 */ 's', 'a', 'l', 'w', 9, '$', '1', ',', 32, 0,
  /* 12992 */ 'r', 'c', 'l', 'w', 9, '$', '1', ',', 32, 0,
  /* 13002 */ 's', 'h', 'l', 'w', 9, '$', '1', ',', 32, 0,
  /* 13012 */ 'r', 'o', 'l', 'w', 9, '$', '1', ',', 32, 0,
  /* 13022 */ 's', 'a', 'r', 'w', 9, '$', '1', ',', 32, 0,
  /* 13032 */ 'r', 'c', 'r', 'w', 9, '$', '1', ',', 32, 0,
  /* 13042 */ 's', 'h', 'r', 'w', 9, '$', '1', ',', 32, 0,
  /* 13052 */ 'r', 'o', 'r', 'w', 9, '$', '1', ',', 32, 0,
  /* 13062 */ 'm', 'o', 'v', 'a', 'b', 's', 'b', 9, '%', 'a', 'l', ',', 32, 0,
  /* 13076 */ 's', 't', 'o', 's', 'b', 9, '%', 'a', 'l', ',', 32, 0,
  /* 13088 */ 'o', 'u', 't', 'b', 9, '%', 'a', 'l', ',', 32, 0,
  /* 13099 */ 'm', 'o', 'v', 'b', 9, '%', 'a', 'l', ',', 32, 0,
  /* 13110 */ 's', 'a', 'l', 'b', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13121 */ 'r', 'c', 'l', 'b', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13132 */ 's', 'h', 'l', 'b', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13143 */ 'r', 'o', 'l', 'b', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13154 */ 's', 'a', 'r', 'b', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13165 */ 'r', 'c', 'r', 'b', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13176 */ 's', 'h', 'r', 'b', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13187 */ 'r', 'o', 'r', 'b', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13198 */ 's', 'h', 'l', 'd', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13210 */ 's', 'h', 'r', 'd', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13222 */ 's', 'a', 'l', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13233 */ 'r', 'c', 'l', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13244 */ 's', 'h', 'l', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13255 */ 'r', 'o', 'l', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13266 */ 's', 'a', 'r', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13277 */ 'r', 'c', 'r', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13288 */ 's', 'h', 'r', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13299 */ 'r', 'o', 'r', 'l', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13310 */ 's', 'h', 'l', 'd', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13322 */ 's', 'h', 'r', 'd', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13334 */ 's', 'a', 'l', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13345 */ 'r', 'c', 'l', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13356 */ 's', 'h', 'l', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13367 */ 'r', 'o', 'l', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13378 */ 's', 'a', 'r', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13389 */ 'r', 'c', 'r', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13400 */ 's', 'h', 'r', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13411 */ 'r', 'o', 'r', 'q', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13422 */ 's', 'h', 'l', 'd', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13434 */ 's', 'h', 'r', 'd', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13446 */ 's', 'a', 'l', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13457 */ 'r', 'c', 'l', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13468 */ 's', 'h', 'l', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13479 */ 'r', 'o', 'l', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13490 */ 's', 'a', 'r', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13501 */ 'r', 'c', 'r', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13512 */ 's', 'h', 'r', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13523 */ 'r', 'o', 'r', 'w', 9, '%', 'c', 'l', ',', 32, 0,
  /* 13534 */ 'x', 'c', 'h', 'g', 'w', 9, '%', 'a', 'x', ',', 32, 0,
  /* 13546 */ 'm', 'o', 'v', 'a', 'b', 's', 'w', 9, '%', 'a', 'x', ',', 32, 0,
  /* 13560 */ 's', 't', 'o', 's', 'w', 9, '%', 'a', 'x', ',', 32, 0,
  /* 13572 */ 'o', 'u', 't', 'w', 9, '%', 'a', 'x', ',', 32, 0,
  /* 13583 */ 'm', 'o', 'v', 'w', 9, '%', 'a', 'x', ',', 32, 0,
  /* 13594 */ 'x', 'c', 'h', 'g', 'l', 9, '%', 'e', 'a', 'x', ',', 32, 0,
  /* 13607 */ 'm', 'o', 'v', 'a', 'b', 's', 'l', 9, '%', 'e', 'a', 'x', ',', 32, 0,
  /* 13622 */ 's', 't', 'o', 's', 'l', 9, '%', 'e', 'a', 'x', ',', 32, 0,
  /* 13635 */ 'o', 'u', 't', 'l', 9, '%', 'e', 'a', 'x', ',', 32, 0,
  /* 13647 */ 'm', 'o', 'v', 'l', 9, '%', 'e', 'a', 'x', ',', 32, 0,
  /* 13659 */ 'x', 'c', 'h', 'g', 'q', 9, '%', 'r', 'a', 'x', ',', 32, 0,
  /* 13672 */ 'm', 'o', 'v', 'a', 'b', 's', 'q', 9, '%', 'r', 'a', 'x', ',', 32, 0,
  /* 13687 */ 's', 't', 'o', 's', 'q', 9, '%', 'r', 'a', 'x', ',', 32, 0,
  /* 13700 */ 'm', 'o', 'v', 'q', 9, '%', 'r', 'a', 'x', ',', 32, 0,
  /* 13712 */ 'i', 'n', 's', 'b', 9, '%', 'd', 'x', ',', 32, 0,
  /* 13723 */ 'i', 'n', 's', 'l', 9, '%', 'd', 'x', ',', 32, 0,
  /* 13734 */ 'i', 'n', 's', 'w', 9, '%', 'd', 'x', ',', 32, 0,
  /* 13745 */ 'v', 'e', 'x', 'p', '2', 'p', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13761 */ 'v', 'c', 'v', 't', 'p', 's', '2', 'p', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13779 */ 'v', 'r', 'c', 'p', '2', '8', 'p', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13796 */ 'v', 'r', 's', 'q', 'r', 't', '2', '8', 'p', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13815 */ 'v', 'm', 'i', 'n', 'p', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13830 */ 'v', 'g', 'e', 't', 'e', 'x', 'p', 'p', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13848 */ 'v', 'm', 'a', 'x', 'p', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13863 */ 'v', 'c', 'v', 't', 's', 's', '2', 's', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13881 */ 'v', 'r', 'c', 'p', '2', '8', 's', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13898 */ 'v', 'r', 's', 'q', 'r', 't', '2', '8', 's', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13917 */ 'v', 'u', 'c', 'o', 'm', 'i', 's', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13934 */ 'v', 'c', 'o', 'm', 'i', 's', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13950 */ 'v', 'm', 'i', 'n', 's', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13965 */ 'v', 'g', 'e', 't', 'e', 'x', 'p', 's', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13983 */ 'v', 'm', 'a', 'x', 's', 'd', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 13998 */ 'v', 'c', 'v', 't', 't', 's', 'd', '2', 's', 'i', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14017 */ 'v', 'c', 'v', 't', 't', 's', 's', '2', 's', 'i', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14036 */ 'v', 'c', 'v', 't', 't', 's', 'd', '2', 'u', 's', 'i', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14056 */ 'v', 'c', 'v', 't', 't', 's', 's', '2', 'u', 's', 'i', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14076 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'd', 'q', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14095 */ 'v', 'c', 'v', 't', 't', 'p', 's', '2', 'd', 'q', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14114 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'u', 'd', 'q', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14134 */ 'v', 'c', 'v', 't', 't', 'p', 's', '2', 'u', 'd', 'q', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14154 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'q', 'q', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14173 */ 'v', 'c', 'v', 't', 't', 'p', 's', '2', 'q', 'q', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14192 */ 'v', 'c', 'v', 't', 't', 'p', 'd', '2', 'u', 'q', 'q', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14212 */ 'v', 'c', 'v', 't', 't', 'p', 's', '2', 'u', 'q', 'q', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14232 */ 'v', 'c', 'v', 't', 'p', 'h', '2', 'p', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14250 */ 'v', 'e', 'x', 'p', '2', 'p', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14266 */ 'v', 'r', 'c', 'p', '2', '8', 'p', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14283 */ 'v', 'r', 's', 'q', 'r', 't', '2', '8', 'p', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14302 */ 'v', 'm', 'i', 'n', 'p', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14317 */ 'v', 'g', 'e', 't', 'e', 'x', 'p', 'p', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14335 */ 'v', 'm', 'a', 'x', 'p', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14350 */ 'v', 'r', 'c', 'p', '2', '8', 's', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14367 */ 'v', 'r', 's', 'q', 'r', 't', '2', '8', 's', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14386 */ 'v', 'u', 'c', 'o', 'm', 'i', 's', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14403 */ 'v', 'c', 'o', 'm', 'i', 's', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14419 */ 'v', 'm', 'i', 'n', 's', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14434 */ 'v', 'g', 'e', 't', 'e', 'x', 'p', 's', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14452 */ 'v', 'm', 'a', 'x', 's', 's', 9, '{', 's', 'a', 'e', '}', ',', 32, 0,
  /* 14467 */ 'f', 'b', 'l', 'd', 9, 't', 'b', 'y', 't', 'e', 32, 'p', 't', 'r', 32, 0,
  /* 14483 */ 'f', 'b', 's', 't', 'p', 9, 't', 'b', 'y', 't', 'e', 32, 'p', 't', 'r', 32, 0,
  /* 14500 */ 'l', 'c', 'a', 'l', 'l', 'l', 9, '*', 0,
  /* 14509 */ 'l', 'j', 'm', 'p', 'l', 9, '*', 0,
  /* 14517 */ 'l', 'c', 'a', 'l', 'l', 'q', 9, '*', 0,
  /* 14526 */ 'l', 'j', 'm', 'p', 'q', 9, '*', 0,
  /* 14534 */ 'l', 'c', 'a', 'l', 'l', 'w', 9, '*', 0,
  /* 14543 */ 'l', 'j', 'm', 'p', 'w', 9, '*', 0,
  /* 14551 */ '#', 32, 'X', 'R', 'a', 'y', 32, 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 32, 'P', 'a', 't', 'c', 'h', 'a', 'b', 'l', 'e', 32, 'R', 'E', 'T', '.', 0,
  /* 14582 */ '#', 32, 'X', 'R', 'a', 'y', 32, 'T', 'y', 'p', 'e', 'd', 32, 'E', 'v', 'e', 'n', 't', 32, 'L', 'o', 'g', '.', 0,
  /* 14606 */ '#', 32, 'X', 'R', 'a', 'y', 32, 'C', 'u', 's', 't', 'o', 'm', 32, 'E', 'v', 'e', 'n', 't', 32, 'L', 'o', 'g', '.', 0,
  /* 14631 */ '#', 32, 'X', 'R', 'a', 'y', 32, 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 32, 'E', 'n', 't', 'e', 'r', '.', 0,
  /* 14654 */ '#', 32, 'X', 'R', 'a', 'y', 32, 'T', 'a', 'i', 'l', 32, 'C', 'a', 'l', 'l', 32, 'E', 'x', 'i', 't', '.', 0,
  /* 14677 */ '#', 32, 'X', 'R', 'a', 'y', 32, 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 32, 'E', 'x', 'i', 't', '.', 0,
  /* 14699 */ 'u', 'd', '0', 0,
  /* 14703 */ 'x', 's', 'h', 'a', '1', 0,
  /* 14709 */ 'f', 'l', 'd', '1', 0,
  /* 14714 */ 'u', 'd', '1', 0,
  /* 14718 */ 'f', 'p', 'r', 'e', 'm', '1', 0,
  /* 14725 */ 'f', '2', 'x', 'm', '1', 0,
  /* 14731 */ 'f', 'y', 'l', '2', 'x', 'p', '1', 0,
  /* 14739 */ 'i', 'n', 't', '1', 0,
  /* 14744 */ 'e', 'n', 'd', 'b', 'r', '3', '2', 0,
  /* 14752 */ 'u', 'd', '2', 0,
  /* 14756 */ 'f', 'l', 'd', 'l', 'g', '2', 0,
  /* 14763 */ 'f', 'l', 'd', 'l', 'n', '2', 0,
  /* 14770 */ 'i', 'n', 't', '3', 0,
  /* 14775 */ 'e', 'n', 'd', 'b', 'r', '6', '4', 0,
  /* 14783 */ 'r', 'e', 'x', '6', '4', 0,
  /* 14789 */ 'd', 'a', 't', 'a', '1', '6', 0,
  /* 14796 */ 'x', 's', 'h', 'a', '2', '5', '6', 0,
  /* 14804 */ 'L', 'I', 'F', 'E', 'T', 'I', 'M', 'E', '_', 'E', 'N', 'D', 0,
  /* 14817 */ 'B', 'U', 'N', 'D', 'L', 'E', 0,
  /* 14824 */ 'D', 'B', 'G', '_', 'V', 'A', 'L', 'U', 'E', 0,
  /* 14834 */ 'D', 'B', 'G', '_', 'L', 'A', 'B', 'E', 'L', 0,
  /* 14844 */ 'L', 'I', 'F', 'E', 'T', 'I', 'M', 'E', '_', 'S', 'T', 'A', 'R', 'T', 0,
  /* 14859 */ 'a', 'a', 'a', 0,
  /* 14863 */ 'd', 'a', 'a', 0,
  /* 14867 */ 'x', 'c', 'r', 'y', 'p', 't', 'e', 'c', 'b', 0,
  /* 14877 */ 'x', 'c', 'r', 'y', 'p', 't', 'c', 'f', 'b', 0,
  /* 14887 */ 'x', 'c', 'r', 'y', 'p', 't', 'o', 'f', 'b', 0,
  /* 14897 */ 'x', 'l', 'a', 't', 'b', 0,
  /* 14903 */ 'c', 'l', 'a', 'c', 0,
  /* 14908 */ 's', 't', 'a', 'c', 0,
  /* 14913 */ 'x', 'c', 'r', 'y', 'p', 't', 'c', 'b', 'c', 0,
  /* 14923 */ 'g', 'e', 't', 's', 'e', 'c', 0,
  /* 14930 */ 's', 'a', 'l', 'c', 0,
  /* 14935 */ 'c', 'l', 'c', 0,
  /* 14939 */ 'c', 'm', 'c', 0,
  /* 14943 */ 'r', 'd', 'p', 'm', 'c', 0,
  /* 14949 */ 'v', 'm', 'f', 'u', 'n', 'c', 0,
  /* 14956 */ 'r', 'd', 't', 's', 'c', 0,
  /* 14962 */ 's', 't', 'c', 0,
  /* 14966 */ 'c', 'p', 'u', 'i', 'd', 0,
  /* 14972 */ 'c', 'l', 'd', 0,
  /* 14976 */ 'x', 'e', 'n', 'd', 0,
  /* 14981 */ 'c', 'l', 't', 'd', 0,
  /* 14986 */ 's', 't', 'd', 0,
  /* 14990 */ 'c', 'w', 't', 'd', 0,
  /* 14995 */ 'w', 'b', 'i', 'n', 'v', 'd', 0,
  /* 15002 */ 'w', 'b', 'n', 'o', 'i', 'n', 'v', 'd', 0,
  /* 15011 */ 'f', 'l', 'd', 'l', '2', 'e', 0,
  /* 15018 */ 'l', 'f', 'e', 'n', 'c', 'e', 0,
  /* 15025 */ 'm', 'f', 'e', 'n', 'c', 'e', 0,
  /* 15032 */ 's', 'f', 'e', 'n', 'c', 'e', 0,
  /* 15039 */ 'f', 's', 'c', 'a', 'l', 'e', 0,
  /* 15046 */ 'v', 'm', 'r', 'e', 's', 'u', 'm', 'e', 0,
  /* 15055 */ 'r', 'e', 'p', 'n', 'e', 0,
  /* 15061 */ 'x', 'a', 'c', 'q', 'u', 'i', 'r', 'e', 0,
  /* 15070 */ 'x', 's', 't', 'o', 'r', 'e', 0,
  /* 15077 */ 'x', 'r', 'e', 'l', 'e', 'a', 's', 'e', 0,
  /* 15086 */ 'p', 'a', 'u', 's', 'e', 0,
  /* 15092 */ 'l', 'e', 'a', 'v', 'e', 0,
  /* 15098 */ 'v', 'm', 'x', 'o', 'f', 'f', 0,
  /* 15105 */ 'l', 'a', 'h', 'f', 0,
  /* 15110 */ 's', 'a', 'h', 'f', 0,
  /* 15115 */ 'p', 'c', 'o', 'n', 'f', 'i', 'g', 0,
  /* 15123 */ 'v', 'm', 'l', 'a', 'u', 'n', 'c', 'h', 0,
  /* 15132 */ 'c', 'l', 'g', 'i', 0,
  /* 15137 */ 's', 't', 'g', 'i', 0,
  /* 15142 */ 'c', 'l', 'i', 0,
  /* 15146 */ 'f', 'l', 'd', 'p', 'i', 0,
  /* 15152 */ 's', 't', 'i', 0,
  /* 15156 */ 'l', 'o', 'c', 'k', 0,
  /* 15161 */ 'i', 'n', 'b', 9, '%', 'd', 'x', ',', 32, '%', 'a', 'l', 0,
  /* 15174 */ 'p', 'u', 's', 'h', 'a', 'l', 0,
  /* 15181 */ 'p', 'o', 'p', 'a', 'l', 0,
  /* 15187 */ 'p', 'u', 's', 'h', 'f', 'l', 0,
  /* 15194 */ 'p', 'o', 'p', 'f', 'l', 0,
  /* 15200 */ '#', 32, 'F', 'E', 'n', 't', 'r', 'y', 32, 'c', 'a', 'l', 'l', 0,
  /* 15214 */ 'v', 'm', 'm', 'c', 'a', 'l', 'l', 0,
  /* 15222 */ 'v', 'm', 'c', 'a', 'l', 'l', 0,
  /* 15229 */ 's', 'y', 's', 'c', 'a', 'l', 'l', 0,
  /* 15237 */ 'v', 'z', 'e', 'r', 'o', 'a', 'l', 'l', 0,
  /* 15246 */ 'i', 'r', 'e', 't', 'l', 0,
  /* 15252 */ 'l', 'r', 'e', 't', 'l', 0,
  /* 15258 */ 's', 'y', 's', 'r', 'e', 't', 'l', 0,
  /* 15266 */ 's', 'y', 's', 'e', 'x', 'i', 't', 'l', 0,
  /* 15275 */ 'c', 'w', 't', 'l', 0,
  /* 15280 */ 'm', 'o', 'n', 't', 'm', 'u', 'l', 0,
  /* 15288 */ 'f', 'x', 'a', 'm', 0,
  /* 15293 */ 'f', 'p', 'r', 'e', 'm', 0,
  /* 15299 */ 'v', 'p', 'c', 'o', 'm', 0,
  /* 15305 */ 'f', 's', 'e', 't', 'p', 'm', 0,
  /* 15312 */ 'r', 's', 'm', 0,
  /* 15316 */ 'f', 'p', 'a', 't', 'a', 'n', 0,
  /* 15323 */ 'f', 'p', 't', 'a', 'n', 0,
  /* 15329 */ 'f', 's', 'i', 'n', 0,
  /* 15334 */ 'c', 'l', 'z', 'e', 'r', 'o', 0,
  /* 15341 */ 'i', 'n', 't', 'o', 0,
  /* 15346 */ 'c', 'q', 't', 'o', 0,
  /* 15351 */ 'r', 'd', 't', 's', 'c', 'p', 0,
  /* 15358 */ 'r', 'e', 'p', 0,
  /* 15362 */ 'v', 'p', 'c', 'm', 'p', 0,
  /* 15368 */ 'v', 'c', 'm', 'p', 0,
  /* 15373 */ 'f', 'e', 'n', 'i', '8', '0', '8', '7', '_', 'n', 'o', 'p', 0,
  /* 15386 */ 'f', 'd', 'i', 's', 'i', '8', '0', '8', '7', '_', 'n', 'o', 'p', 0,
  /* 15400 */ 'f', 'n', 'o', 'p', 0,
  /* 15405 */ 'f', 'c', 'o', 'm', 'p', 'p', 0,
  /* 15412 */ 'f', 'u', 'c', 'o', 'm', 'p', 'p', 0,
  /* 15420 */ 's', 'a', 'v', 'e', 'p', 'r', 'e', 'v', 's', 's', 'p', 0,
  /* 15432 */ 'f', 'd', 'e', 'c', 's', 't', 'p', 0,
  /* 15440 */ 'f', 'i', 'n', 'c', 's', 't', 'p', 0,
  /* 15448 */ 'p', 'u', 's', 'h', 'f', 'q', 0,
  /* 15455 */ 'p', 'o', 'p', 'f', 'q', 0,
  /* 15461 */ 'i', 'r', 'e', 't', 'q', 0,
  /* 15467 */ 'l', 'r', 'e', 't', 'q', 0,
  /* 15473 */ 's', 'y', 's', 'r', 'e', 't', 'q', 0,
  /* 15481 */ 's', 'y', 's', 'e', 'x', 'i', 't', 'q', 0,
  /* 15490 */ 'c', 'l', 't', 'q', 0,
  /* 15495 */ 'v', 'z', 'e', 'r', 'o', 'u', 'p', 'p', 'e', 'r', 0,
  /* 15506 */ 's', 'y', 's', 'e', 'n', 't', 'e', 'r', 0,
  /* 15515 */ 'm', 'o', 'n', 'i', 't', 'o', 'r', 0,
  /* 15523 */ 'r', 'd', 'm', 's', 'r', 0,
  /* 15529 */ 'w', 'r', 'm', 's', 'r', 0,
  /* 15535 */ 'x', 'c', 'r', 'y', 'p', 't', 'c', 't', 'r', 0,
  /* 15545 */ 'a', 'a', 's', 0,
  /* 15549 */ 'd', 'a', 's', 0,
  /* 15553 */ 'f', 'a', 'b', 's', 0,
  /* 15558 */ 'p', 'u', 's', 'h', 'l', 9, '%', 'c', 's', 0,
  /* 15568 */ 'p', 'u', 's', 'h', 'w', 9, '%', 'c', 's', 0,
  /* 15578 */ 'p', 'u', 's', 'h', 'l', 9, '%', 'd', 's', 0,
  /* 15588 */ 'p', 'o', 'p', 'l', 9, '%', 'd', 's', 0,
  /* 15597 */ 'p', 'u', 's', 'h', 'w', 9, '%', 'd', 's', 0,
  /* 15607 */ 'p', 'o', 'p', 'w', 9, '%', 'd', 's', 0,
  /* 15616 */ 'p', 'u', 's', 'h', 'l', 9, '%', 'e', 's', 0,
  /* 15626 */ 'p', 'o', 'p', 'l', 9, '%', 'e', 's', 0,
  /* 15635 */ 'p', 'u', 's', 'h', 'w', 9, '%', 'e', 's', 0,
  /* 15645 */ 'p', 'o', 'p', 'w', 9, '%', 'e', 's', 0,
  /* 15654 */ 'p', 'u', 's', 'h', 'l', 9, '%', 'f', 's', 0,
  /* 15664 */ 'p', 'o', 'p', 'l', 9, '%', 'f', 's', 0,
  /* 15673 */ 'p', 'u', 's', 'h', 'q', 9, '%', 'f', 's', 0,
  /* 15683 */ 'p', 'o', 'p', 'q', 9, '%', 'f', 's', 0,
  /* 15692 */ 'p', 'u', 's', 'h', 'w', 9, '%', 'f', 's', 0,
  /* 15702 */ 'p', 'o', 'p', 'w', 9, '%', 'f', 's', 0,
  /* 15711 */ 'p', 'u', 's', 'h', 'l', 9, '%', 'g', 's', 0,
  /* 15721 */ 'p', 'o', 'p', 'l', 9, '%', 'g', 's', 0,
  /* 15730 */ 'p', 'u', 's', 'h', 'q', 9, '%', 'g', 's', 0,
  /* 15740 */ 'p', 'o', 'p', 'q', 9, '%', 'g', 's', 0,
  /* 15749 */ 'p', 'u', 's', 'h', 'w', 9, '%', 'g', 's', 0,
  /* 15759 */ 'p', 'o', 'p', 'w', 9, '%', 'g', 's', 0,
  /* 15768 */ 's', 'w', 'a', 'p', 'g', 's', 0,
  /* 15775 */ 'f', 'c', 'h', 's', 0,
  /* 15780 */ 'e', 'n', 'c', 'l', 's', 0,
  /* 15786 */ 'f', 'e', 'm', 'm', 's', 0,
  /* 15792 */ 'f', 'c', 'o', 's', 0,
  /* 15797 */ 'f', 's', 'i', 'n', 'c', 'o', 's', 0,
  /* 15805 */ 'p', 'u', 's', 'h', 'l', 9, '%', 's', 's', 0,
  /* 15815 */ 'p', 'o', 'p', 'l', 9, '%', 's', 's', 0,
  /* 15824 */ 'p', 'u', 's', 'h', 'w', 9, '%', 's', 's', 0,
  /* 15834 */ 'p', 'o', 'p', 'w', 9, '%', 's', 's', 0,
  /* 15843 */ 'c', 'l', 't', 's', 0,
  /* 15848 */ 'f', 'l', 'd', 'l', '2', 't', 0,
  /* 15855 */ 'f', 'x', 't', 'r', 'a', 'c', 't', 0,
  /* 15863 */ 'm', 'w', 'a', 'i', 't', 0,
  /* 15869 */ 'f', 'n', 'i', 'n', 'i', 't', 0,
  /* 15876 */ 'h', 'l', 't', 0,
  /* 15880 */ 'f', 'r', 'n', 'd', 'i', 'n', 't', 0,
  /* 15888 */ 'f', 's', 'q', 'r', 't', 0,
  /* 15894 */ 'x', 't', 'e', 's', 't', 0,
  /* 15900 */ 'f', 't', 's', 't', 0,
  /* 15905 */ 'e', 'n', 'c', 'l', 'u', 0,
  /* 15911 */ 'r', 'd', 'p', 'k', 'r', 'u', 0,
  /* 15918 */ 'w', 'r', 'p', 'k', 'r', 'u', 0,
  /* 15925 */ 'x', 'g', 'e', 't', 'b', 'v', 0,
  /* 15932 */ 'x', 's', 'e', 't', 'b', 'v', 0,
  /* 15939 */ 'e', 'n', 'c', 'l', 'v', 0,
  /* 15945 */ 'p', 'u', 's', 'h', 'a', 'w', 0,
  /* 15952 */ 'p', 'o', 'p', 'a', 'w', 0,
  /* 15958 */ 'p', 'u', 's', 'h', 'f', 'w', 0,
  /* 15965 */ 'p', 'o', 'p', 'f', 'w', 0,
  /* 15971 */ 'c', 'b', 't', 'w', 0,
  /* 15976 */ 'i', 'r', 'e', 't', 'w', 0,
  /* 15982 */ 'l', 'r', 'e', 't', 'w', 0,
  /* 15988 */ 'f', 'y', 'l', '2', 'x', 0,
  /* 15994 */ 'f', 'n', 's', 't', 's', 'w', 9, '%', 'a', 'x', 0,
  /* 16005 */ 'i', 'n', 'w', 9, '%', 'd', 'x', ',', 32, '%', 'a', 'x', 0,
  /* 16018 */ 'v', 'm', 'l', 'o', 'a', 'd', 9, '%', 'e', 'a', 'x', 0,
  /* 16030 */ 'v', 'm', 's', 'a', 'v', 'e', 9, '%', 'e', 'a', 'x', 0,
  /* 16042 */ 'v', 'm', 'r', 'u', 'n', 9, '%', 'e', 'a', 'x', 0,
  /* 16053 */ 's', 'k', 'i', 'n', 'i', 't', 9, '%', 'e', 'a', 'x', 0,
  /* 16065 */ 'i', 'n', 'l', 9, '%', 'd', 'x', ',', 32, '%', 'e', 'a', 'x', 0,
  /* 16079 */ 'v', 'm', 'l', 'o', 'a', 'd', 9, '%', 'r', 'a', 'x', 0,
  /* 16091 */ 'v', 'm', 's', 'a', 'v', 'e', 9, '%', 'r', 'a', 'x', 0,
  /* 16103 */ 'v', 'm', 'r', 'u', 'n', 9, '%', 'r', 'a', 'x', 0,
  /* 16114 */ 'i', 'n', 'v', 'l', 'p', 'g', 'a', 9, '%', 'e', 'a', 'x', ',', 32, '%', 'e', 'c', 'x', 0,
  /* 16133 */ 'i', 'n', 'v', 'l', 'p', 'g', 'a', 9, '%', 'r', 'a', 'x', ',', 32, '%', 'e', 'c', 'x', 0,
  /* 16152 */ 'o', 'u', 't', 'b', 9, '%', 'a', 'l', ',', 32, '%', 'd', 'x', 0,
  /* 16166 */ 'o', 'u', 't', 'w', 9, '%', 'a', 'x', ',', 32, '%', 'd', 'x', 0,
  /* 16180 */ 'o', 'u', 't', 'l', 9, '%', 'e', 'a', 'x', ',', 32, '%', 'd', 'x', 0,
  /* 16195 */ 'f', 'n', 'c', 'l', 'e', 'x', 0,
  /* 16202 */ 'm', 'o', 'n', 'i', 't', 'o', 'r', 'x', 0,
  /* 16211 */ 'm', 'w', 'a', 'i', 't', 'x', 0,
  /* 16218 */ 's', 'e', 't', 's', 's', 'b', 's', 'y', 0,
  /* 16227 */ 'f', 'l', 'd', 'z', 0,
  };
#endif

  static const uint32_t OpInfo0[] = {
    0U,	// PHI
    0U,	// INLINEASM
    0U,	// CFI_INSTRUCTION
    0U,	// EH_LABEL
    0U,	// GC_LABEL
    0U,	// ANNOTATION_LABEL
    0U,	// KILL
    0U,	// EXTRACT_SUBREG
    0U,	// INSERT_SUBREG
    0U,	// IMPLICIT_DEF
    0U,	// SUBREG_TO_REG
    0U,	// COPY_TO_REGCLASS
    14825U,	// DBG_VALUE
    14835U,	// DBG_LABEL
    0U,	// REG_SEQUENCE
    0U,	// COPY
    14818U,	// BUNDLE
    14845U,	// LIFETIME_START
    14805U,	// LIFETIME_END
    0U,	// STACKMAP
    15201U,	// FENTRY_CALL
    0U,	// PATCHPOINT
    0U,	// LOAD_STACK_GUARD
    0U,	// STATEPOINT
    0U,	// LOCAL_ESCAPE
    0U,	// FAULTING_OP
    0U,	// PATCHABLE_OP
    14632U,	// PATCHABLE_FUNCTION_ENTER
    14552U,	// PATCHABLE_RET
    14678U,	// PATCHABLE_FUNCTION_EXIT
    14655U,	// PATCHABLE_TAIL_CALL
    14607U,	// PATCHABLE_EVENT_CALL
    14583U,	// PATCHABLE_TYPED_EVENT_CALL
    0U,	// ICALL_BRANCH_FUNNEL
    0U,	// G_ADD
    0U,	// G_SUB
    0U,	// G_MUL
    0U,	// G_SDIV
    0U,	// G_UDIV
    0U,	// G_SREM
    0U,	// G_UREM
    0U,	// G_AND
    0U,	// G_OR
    0U,	// G_XOR
    0U,	// G_IMPLICIT_DEF
    0U,	// G_PHI
    0U,	// G_FRAME_INDEX
    0U,	// G_GLOBAL_VALUE
    0U,	// G_EXTRACT
    0U,	// G_UNMERGE_VALUES
    0U,	// G_INSERT
    0U,	// G_MERGE_VALUES
    0U,	// G_PTRTOINT
    0U,	// G_INTTOPTR
    0U,	// G_BITCAST
    0U,	// G_LOAD
    0U,	// G_SEXTLOAD
    0U,	// G_ZEXTLOAD
    0U,	// G_STORE
    0U,	// G_ATOMIC_CMPXCHG_WITH_SUCCESS
    0U,	// G_ATOMIC_CMPXCHG
    0U,	// G_ATOMICRMW_XCHG
    0U,	// G_ATOMICRMW_ADD
    0U,	// G_ATOMICRMW_SUB
    0U,	// G_ATOMICRMW_AND
    0U,	// G_ATOMICRMW_NAND
    0U,	// G_ATOMICRMW_OR
    0U,	// G_ATOMICRMW_XOR
    0U,	// G_ATOMICRMW_MAX
    0U,	// G_ATOMICRMW_MIN
    0U,	// G_ATOMICRMW_UMAX
    0U,	// G_ATOMICRMW_UMIN
    0U,	// G_BRCOND
    0U,	// G_BRINDIRECT
    0U,	// G_INTRINSIC
    0U,	// G_INTRINSIC_W_SIDE_EFFECTS
    0U,	// G_ANYEXT
    0U,	// G_TRUNC
    0U,	// G_CONSTANT
    0U,	// G_FCONSTANT
    0U,	// G_VASTART
    0U,	// G_VAARG
    0U,	// G_SEXT
    0U,	// G_ZEXT
    0U,	// G_SHL
    0U,	// G_LSHR
    0U,	// G_ASHR
    0U,	// G_ICMP
    0U,	// G_FCMP
    0U,	// G_SELECT
    0U,	// G_UADDE
    0U,	// G_USUBE
    0U,	// G_SADDO
    0U,	// G_SSUBO
    0U,	// G_UMULO
    0U,	// G_SMULO
    0U,	// G_UMULH
    0U,	// G_SMULH
    0U,	// G_FADD
    0U,	// G_FSUB
    0U,	// G_FMUL
    0U,	// G_FMA
    0U,	// G_FDIV
    0U,	// G_FREM
    0U,	// G_FPOW
    0U,	// G_FEXP
    0U,	// G_FEXP2
    0U,	// G_FLOG
    0U,	// G_FLOG2
    0U,	// G_FNEG
    0U,	// G_FPEXT
    0U,	// G_FPTRUNC
    0U,	// G_FPTOSI
    0U,	// G_FPTOUI
    0U,	// G_SITOFP
    0U,	// G_UITOFP
    0U,	// G_FABS
    0U,	// G_GEP
    0U,	// G_PTR_MASK
    0U,	// G_BR
    0U,	// G_INSERT_VECTOR_ELT
    0U,	// G_EXTRACT_VECTOR_ELT
    0U,	// G_SHUFFLE_VECTOR
    0U,	// G_BSWAP
    0U,	// G_ADDRSPACE_CAST
    0U,	// G_BLOCK_ADDR
    0U,	// AVX1_SETALLONES
    0U,	// AVX2_SETALLONES
    0U,	// AVX512_128_SET0
    0U,	// AVX512_256_SET0
    0U,	// AVX512_512_SET0
    0U,	// AVX512_512_SETALLONES
    0U,	// AVX512_512_SEXT_MASK_32
    0U,	// AVX512_512_SEXT_MASK_64
    0U,	// AVX512_FsFLD0SD
    0U,	// AVX512_FsFLD0SS
    0U,	// AVX_SET0
    0U,	// KSET0D
    0U,	// KSET0Q
    0U,	// KSET0W
    0U,	// KSET1D
    0U,	// KSET1Q
    0U,	// KSET1W
    0U,	// MMX_SET0
    0U,	// V_SET0
    0U,	// V_SETALLONES
    14860U,	// AAA
    18260U,	// AAD8i8
    22553U,	// AAM8i8
    15546U,	// AAS
    15554U,	// ABS_F
    0U,	// ABS_Fp32
    0U,	// ABS_Fp64
    0U,	// ABS_Fp80
    2124537U,	// ADC16i16
    4238073U,	// ADC16mi
    4238073U,	// ADC16mi8
    4238073U,	// ADC16mr
    6351609U,	// ADC16ri
    6351609U,	// ADC16ri8
    6367993U,	// ADC16rm
    6351609U,	// ADC16rr
    8448761U,	// ADC16rr_REV
    10507174U,	// ADC32i32
    12620710U,	// ADC32mi
    12620710U,	// ADC32mi8
    12620710U,	// ADC32mr
    6345638U,	// ADC32ri
    6345638U,	// ADC32ri8
    283202470U,	// ADC32rm
    6345638U,	// ADC32rr
    8442790U,	// ADC32rr_REV
    16800213U,	// ADC64i32
    18913749U,	// ADC64mi32
    18913749U,	// ADC64mi8
    18913749U,	// ADC64mr
    6347221U,	// ADC64ri32
    6347221U,	// ADC64ri8
    283220437U,	// ADC64rm
    6347221U,	// ADC64rr
    8444373U,	// ADC64rr_REV
    20988865U,	// ADC8i8
    23102401U,	// ADC8mi
    23102401U,	// ADC8mi8
    23102401U,	// ADC8mr
    6341569U,	// ADC8ri
    6341569U,	// ADC8ri8
    6407105U,	// ADC8rm
    6341569U,	// ADC8rr
    8438721U,	// ADC8rr_REV
    551638976U,	// ADCX32rm
    8443840U,	// ADCX32rr
    551657684U,	// ADCX64rm
    8446164U,	// ADCX64rr
    2124579U,	// ADD16i16
    4238115U,	// ADD16mi
    4238115U,	// ADD16mi8
    4238115U,	// ADD16mr
    6351651U,	// ADD16ri
    6351651U,	// ADD16ri8
    6368035U,	// ADD16rm
    6351651U,	// ADD16rr
    8448803U,	// ADD16rr_REV
    10507240U,	// ADD32i32
    12620776U,	// ADD32mi
    12620776U,	// ADD32mi8
    12620776U,	// ADD32mr
    6345704U,	// ADD32ri
    6345704U,	// ADD32ri8
    283202536U,	// ADD32rm
    6345704U,	// ADD32rr
    8442856U,	// ADD32rr_REV
    16800337U,	// ADD64i32
    18913873U,	// ADD64mi32
    18913873U,	// ADD64mi8
    18913873U,	// ADD64mr
    6347345U,	// ADD64ri32
    6347345U,	// ADD64ri8
    283220561U,	// ADD64rm
    6347345U,	// ADD64rr
    8444497U,	// ADD64rr_REV
    20988900U,	// ADD8i8
    23102436U,	// ADD8mi
    23102436U,	// ADD8mi8
    23102436U,	// ADD8mr
    6341604U,	// ADD8ri
    6341604U,	// ADD8ri8
    6407140U,	// ADD8rm
    6341604U,	// ADD8rr
    8438756U,	// ADD8rr_REV
    8522549U,	// ADDPDrm
    8440629U,	// ADDPDrr
    8528946U,	// ADDPSrm
    8447026U,	// ADDPSrr
    551702253U,	// ADDSDrm
    551702253U,	// ADDSDrm_Int
    8441581U,	// ADDSDrr
    8441581U,	// ADDSDrr_Int
    551725033U,	// ADDSSrm
    551725033U,	// ADDSSrm_Int
    8447977U,	// ADDSSrr
    8447977U,	// ADDSSrr_Int
    8522422U,	// ADDSUBPDrm
    8440502U,	// ADDSUBPDrr
    8528819U,	// ADDSUBPSrm
    8446899U,	// ADDSUBPSrr
    188799U,	// ADD_F32m
    201703U,	// ADD_F64m
    221574U,	// ADD_FI16m
    234478U,	// ADD_FI32m
    22676U,	// ADD_FPrST0
    18342U,	// ADD_FST0r
    0U,	// ADD_Fp32
    0U,	// ADD_Fp32m
    0U,	// ADD_Fp64
    0U,	// ADD_Fp64m
    0U,	// ADD_Fp64m32
    0U,	// ADD_Fp80
    0U,	// ADD_Fp80m32
    0U,	// ADD_Fp80m64
    0U,	// ADD_FpI16m32
    0U,	// ADD_FpI16m64
    0U,	// ADD_FpI16m80
    0U,	// ADD_FpI32m32
    0U,	// ADD_FpI32m64
    0U,	// ADD_FpI32m80
    28967U,	// ADD_FrST0
    551638997U,	// ADOX32rm
    8443861U,	// ADOX32rr
    551657705U,	// ADOX64rm
    8446185U,	// ADOX64rr
    8644979U,	// AESDECLASTrm
    8448371U,	// AESDECLASTrr
    8636163U,	// AESDECrm
    8439555U,	// AESDECrr
    8644992U,	// AESENCLASTrm
    8448384U,	// AESENCLASTrr
    8636189U,	// AESENCrm
    8439581U,	// AESENCrr
    263956U,	// AESIMCrm
    551831316U,	// AESIMCrr
    830777754U,	// AESKEYGENASSIST128rm
    283437466U,	// AESKEYGENASSIST128rr
    2124626U,	// AND16i16
    4238162U,	// AND16mi
    4238162U,	// AND16mi8
    4238162U,	// AND16mr
    6351698U,	// AND16ri
    6351698U,	// AND16ri8
    6368082U,	// AND16rm
    6351698U,	// AND16rr
    8448850U,	// AND16rr_REV
    10507293U,	// AND32i32
    12620829U,	// AND32mi
    12620829U,	// AND32mi8
    12620829U,	// AND32mr
    6345757U,	// AND32ri
    6345757U,	// AND32ri8
    283202589U,	// AND32rm
    6345757U,	// AND32rr
    8442909U,	// AND32rr_REV
    16800448U,	// AND64i32
    18913984U,	// AND64mi32
    18913984U,	// AND64mi8
    18913984U,	// AND64mr
    6347456U,	// AND64ri32
    6347456U,	// AND64ri8
    283220672U,	// AND64rm
    6347456U,	// AND64rr
    8444608U,	// AND64rr_REV
    20988922U,	// AND8i8
    23102458U,	// AND8mi
    23102458U,	// AND8mi8
    23102458U,	// AND8mr
    6341626U,	// AND8ri
    6341626U,	// AND8ri8
    6407162U,	// AND8rm
    6341626U,	// AND8rr
    8438778U,	// AND8rr_REV
    283202964U,	// ANDN32rm
    811652500U,	// ANDN32rr
    283221318U,	// ANDN64rm
    811654470U,	// ANDN64rr
    8522824U,	// ANDNPDrm
    8440904U,	// ANDNPDrr
    8529273U,	// ANDNPSrm
    8447353U,	// ANDNPSrr
    8522598U,	// ANDPDrm
    8440678U,	// ANDPDrr
    8529018U,	// ANDPSrm
    8447098U,	// ANDPSrr
    4232691U,	// ARPL16mr
    551835123U,	// ARPL16rr
    832902782U,	// BEXTR32rm
    811652734U,	// BEXTR32rr
    835002024U,	// BEXTR64rm
    811654824U,	// BEXTR64rr
    832902782U,	// BEXTRI32mi
    811652734U,	// BEXTRI32ri
    835002024U,	// BEXTRI64mi
    811654824U,	// BEXTRI64ri
    551900475U,	// BLCFILL32rm
    551834939U,	// BLCFILL32rr
    551918777U,	// BLCFILL64rm
    551836857U,	// BLCFILL64rr
    551900381U,	// BLCI32rm
    551834845U,	// BLCI32rr
    551918694U,	// BLCI64rm
    551836774U,	// BLCI64rr
    551900089U,	// BLCIC32rm
    551834553U,	// BLCIC32rr
    551918049U,	// BLCIC64rm
    551836129U,	// BLCIC64rr
    551900415U,	// BLCMSK32rm
    551834879U,	// BLCMSK32rr
    551918724U,	// BLCMSK64rm
    551836804U,	// BLCMSK64rr
    551900839U,	// BLCS32rm
    551835303U,	// BLCS32rr
    551919313U,	// BLCS64rm
    551837393U,	// BLCS64rr
    568707958U,	// BLENDPDrmi
    1088818038U,	// BLENDPDrri
    568714378U,	// BLENDPSrmi
    1088824458U,	// BLENDPSrri
    8532389U,	// BLENDVPDrm0
    8450469U,	// BLENDVPDrr0
    8532406U,	// BLENDVPSrm0
    8450486U,	// BLENDVPSrr0
    551900485U,	// BLSFILL32rm
    551834949U,	// BLSFILL32rr
    551918787U,	// BLSFILL64rm
    551836867U,	// BLSFILL64rr
    551900395U,	// BLSI32rm
    551834859U,	// BLSI32rr
    551918708U,	// BLSI64rm
    551836788U,	// BLSI64rr
    551900097U,	// BLSIC32rm
    551834561U,	// BLSIC32rr
    551918057U,	// BLSIC64rm
    551836137U,	// BLSIC64rr
    551900424U,	// BLSMSK32rm
    551834888U,	// BLSMSK32rr
    551918733U,	// BLSMSK64rm
    551836813U,	// BLSMSK64rr
    551900779U,	// BLSR32rm
    551835243U,	// BLSR32rr
    551919234U,	// BLSR64rm
    551837314U,	// BLSR64rr
    414636U,	// BNDCL32rm
    551834540U,	// BNDCL32rr
    414636U,	// BNDCL64rm
    551834540U,	// BNDCL64rr
    415819U,	// BNDCN32rm
    551835723U,	// BNDCN32rr
    415819U,	// BNDCN64rm
    551835723U,	// BNDCN64rr
    420276U,	// BNDCU32rm
    551840180U,	// BNDCU32rr
    420276U,	// BNDCU64rm
    551840180U,	// BNDCU64rr
    421867U,	// BNDLDXrm
    414548U,	// BNDMK32rm
    414548U,	// BNDMK64rm
    18917897U,	// BNDMOV32mr
    551922185U,	// BNDMOV32rm
    33597961U,	// BNDMOV64mr
    272905U,	// BNDMOV64rm
    551840265U,	// BNDMOVrr
    551840265U,	// BNDMOVrr_REV
    35696742U,	// BNDSTXmr
    1356876031U,	// BOUNDS16rm
    1625311487U,	// BOUNDS32rm
    437231U,	// BSF16rm
    551840751U,	// BSF16rr
    551900344U,	// BSF32rm
    551834808U,	// BSF32rr
    551918645U,	// BSF64rm
    551836725U,	// BSF64rr
    437666U,	// BSR16rm
    551841186U,	// BSR16rr
    551900773U,	// BSR32rm
    551835237U,	// BSR32rr
    551919228U,	// BSR64rm
    551837308U,	// BSR64rr
    27908U,	// BSWAP16r_BAD
    21937U,	// BSWAP32r
    23920U,	// BSWAP64r
    4239024U,	// BT16mi8
    4239024U,	// BT16mr
    551841456U,	// BT16ri8
    551841456U,	// BT16rr
    12621598U,	// BT32mi8
    12621598U,	// BT32mr
    551835422U,	// BT32ri8
    551835422U,	// BT32rr
    18915152U,	// BT64mi8
    18915152U,	// BT64mr
    551837520U,	// BT64ri8
    551837520U,	// BT64rr
    4238098U,	// BTC16mi8
    4238098U,	// BTC16mr
    6351634U,	// BTC16ri8
    6351634U,	// BTC16rr
    12620760U,	// BTC32mi8
    12620760U,	// BTC32mr
    6345688U,	// BTC32ri8
    6345688U,	// BTC32rr
    18913792U,	// BTC64mi8
    18913792U,	// BTC64mr
    6347264U,	// BTC64ri8
    6347264U,	// BTC64rr
    4238769U,	// BTR16mi8
    4238769U,	// BTR16mr
    6352305U,	// BTR16ri8
    6352305U,	// BTR16rr
    12621426U,	// BTR32mi8
    12621426U,	// BTR32mr
    6346354U,	// BTR32ri8
    6346354U,	// BTR32rr
    18914962U,	// BTR64mi8
    18914962U,	// BTR64mr
    6348434U,	// BTR64ri8
    6348434U,	// BTR64rr
    4238966U,	// BTS16mi8
    4238966U,	// BTS16mr
    6352502U,	// BTS16ri8
    6352502U,	// BTS16rr
    12621577U,	// BTS32mi8
    12621577U,	// BTS32mr
    6346505U,	// BTS32ri8
    6346505U,	// BTS32rr
    18915129U,	// BTS64mi8
    18915129U,	// BTS64mr
    6348601U,	// BTS64ri8
    6348601U,	// BTS64rr
    832902372U,	// BZHI32rm
    811652324U,	// BZHI32rr
    835001453U,	// BZHI64rm
    811654253U,	// BZHI64rr
    227528U,	// CALL16m
    227528U,	// CALL16m_NT
    30920U,	// CALL16r
    30920U,	// CALL16r_NT
    243878U,	// CALL32m
    243878U,	// CALL32m_NT
    30886U,	// CALL32r
    30886U,	// CALL32r_NT
    456887U,	// CALL64m
    456887U,	// CALL64m_NT
    466098U,	// CALL64pcrel32
    30903U,	// CALL64r
    30903U,	// CALL64r_NT
    470120U,	// CALLpcrel16
    464180U,	// CALLpcrel32
    15972U,	// CBW
    14982U,	// CDQ
    15491U,	// CDQE
    15776U,	// CHS_F
    0U,	// CHS_Fp32
    0U,	// CHS_Fp64
    0U,	// CHS_Fp80
    14904U,	// CLAC
    14936U,	// CLC
    14973U,	// CLD
    479759U,	// CLDEMOTE
    479872U,	// CLFLUSH
    485710U,	// CLFLUSHOPT
    15133U,	// CLGI
    15143U,	// CLI
    241839U,	// CLRSSBSY
    15844U,	// CLTS
    476848U,	// CLWB
    15335U,	// CLZEROr
    14940U,	// CMC
    8464973U,	// CMOVA16rm
    8448589U,	// CMOVA16rr
    551637865U,	// CMOVA32rm
    8442729U,	// CMOVA32rr
    551655804U,	// CMOVA64rm
    8444284U,	// CMOVA64rr
    8465331U,	// CMOVAE16rm
    8448947U,	// CMOVAE16rr
    551638083U,	// CMOVAE32rm
    8442947U,	// CMOVAE32rr
    551656375U,	// CMOVAE64rm
    8444855U,	// CMOVAE64rr
    8465107U,	// CMOVB16rm
    8448723U,	// CMOVB16rr
    551637910U,	// CMOVB32rm
    8442774U,	// CMOVB32rr
    551655855U,	// CMOVB64rm
    8444335U,	// CMOVB64rr
    8465340U,	// CMOVBE16rm
    8448956U,	// CMOVBE16rr
    551638092U,	// CMOVBE32rm
    8442956U,	// CMOVBE32rr
    551656384U,	// CMOVBE64rm
    8444864U,	// CMOVBE64rr
    37769640U,	// CMOVBE_F
    0U,	// CMOVBE_Fp32
    0U,	// CMOVBE_Fp64
    0U,	// CMOVBE_Fp80
    37766817U,	// CMOVB_F
    0U,	// CMOVB_Fp32
    0U,	// CMOVB_Fp64
    0U,	// CMOVB_Fp80
    8465376U,	// CMOVE16rm
    8448992U,	// CMOVE16rr
    551638192U,	// CMOVE32rm
    8443056U,	// CMOVE32rr
    551656493U,	// CMOVE64rm
    8444973U,	// CMOVE64rr
    37769780U,	// CMOVE_F
    0U,	// CMOVE_Fp32
    0U,	// CMOVE_Fp64
    0U,	// CMOVE_Fp80
    8465429U,	// CMOVG16rm
    8449045U,	// CMOVG16rr
    551638222U,	// CMOVG32rm
    8443086U,	// CMOVG32rr
    551656535U,	// CMOVG64rm
    8445015U,	// CMOVG64rr
    8465349U,	// CMOVGE16rm
    8448965U,	// CMOVGE16rr
    551638101U,	// CMOVGE32rm
    8442965U,	// CMOVGE32rr
    551656393U,	// CMOVGE64rm
    8444873U,	// CMOVGE64rr
    8465573U,	// CMOVL16rm
    8449189U,	// CMOVL16rr
    551638397U,	// CMOVL32rm
    8443261U,	// CMOVL32rr
    551656717U,	// CMOVL64rm
    8445197U,	// CMOVL64rr
    8465358U,	// CMOVLE16rm
    8448974U,	// CMOVLE16rr
    551638110U,	// CMOVLE32rm
    8442974U,	// CMOVLE32rr
    551656402U,	// CMOVLE64rm
    8444882U,	// CMOVLE64rr
    37769623U,	// CMOVNBE_F
    0U,	// CMOVNBE_Fp32
    0U,	// CMOVNBE_Fp64
    0U,	// CMOVNBE_Fp80
    37766372U,	// CMOVNB_F
    0U,	// CMOVNB_Fp32
    0U,	// CMOVNB_Fp64
    0U,	// CMOVNB_Fp80
    8465367U,	// CMOVNE16rm
    8448983U,	// CMOVNE16rr
    551638119U,	// CMOVNE32rm
    8442983U,	// CMOVNE32rr
    551656411U,	// CMOVNE64rm
    8444891U,	// CMOVNE64rr
    37769713U,	// CMOVNE_F
    0U,	// CMOVNE_Fp32
    0U,	// CMOVNE_Fp64
    0U,	// CMOVNE_Fp80
    8465651U,	// CMOVNO16rm
    8449267U,	// CMOVNO16rr
    551638432U,	// CMOVNO32rm
    8443296U,	// CMOVNO32rr
    551656799U,	// CMOVNO64rm
    8445279U,	// CMOVNO64rr
    8465691U,	// CMOVNP16rm
    8449307U,	// CMOVNP16rr
    551638494U,	// CMOVNP32rm
    8443358U,	// CMOVNP32rr
    551656839U,	// CMOVNP64rm
    8445319U,	// CMOVNP64rr
    37775803U,	// CMOVNP_F
    0U,	// CMOVNP_Fp32
    0U,	// CMOVNP_Fp64
    0U,	// CMOVNP_Fp80
    8465992U,	// CMOVNS16rm
    8449608U,	// CMOVNS16rr
    551638733U,	// CMOVNS32rm
    8443597U,	// CMOVNS32rr
    551657198U,	// CMOVNS64rm
    8445678U,	// CMOVNS64rr
    8465660U,	// CMOVO16rm
    8449276U,	// CMOVO16rr
    551638441U,	// CMOVO32rm
    8443305U,	// CMOVO32rr
    551656808U,	// CMOVO64rm
    8445288U,	// CMOVO64rr
    8465712U,	// CMOVP16rm
    8449328U,	// CMOVP16rr
    551638545U,	// CMOVP32rm
    8443409U,	// CMOVP32rr
    551656877U,	// CMOVP64rm
    8445357U,	// CMOVP64rr
    37775842U,	// CMOVP_F
    0U,	// CMOVP_Fp32
    0U,	// CMOVP_Fp64
    0U,	// CMOVP_Fp80
    8466079U,	// CMOVS16rm
    8449695U,	// CMOVS16rr
    551638806U,	// CMOVS32rm
    8443670U,	// CMOVS32rr
    551657279U,	// CMOVS64rm
    8445759U,	// CMOVS64rr
    2125070U,	// CMP16i16
    4238606U,	// CMP16mi
    4238606U,	// CMP16mi8
    4238606U,	// CMP16mr
    551841038U,	// CMP16ri
    551841038U,	// CMP16ri8
    437518U,	// CMP16rm
    551841038U,	// CMP16rr
    551841038U,	// CMP16rr_REV
    10507712U,	// CMP32i32
    12621248U,	// CMP32mi
    12621248U,	// CMP32mi8
    12621248U,	// CMP32mr
    551835072U,	// CMP32ri
    551835072U,	// CMP32ri8
    551900608U,	// CMP32rm
    551835072U,	// CMP32rr
    551835072U,	// CMP32rr_REV
    16801153U,	// CMP64i32
    18914689U,	// CMP64mi32
    18914689U,	// CMP64mi8
    18914689U,	// CMP64mr
    551837057U,	// CMP64ri32
    551837057U,	// CMP64ri8
    551918977U,	// CMP64rm
    551837057U,	// CMP64rr
    551837057U,	// CMP64rr_REV
    20989167U,	// CMP8i8
    23102703U,	// CMP8mi
    23102703U,	// CMP8mi8
    23102703U,	// CMP8mr
    551830767U,	// CMP8ri
    551830767U,	// CMP8ri8
    492783U,	// CMP8rm
    551830767U,	// CMP8rr
    551830767U,	// CMP8rr_REV
    1919417349U,	// CMPPDrmi
    568708192U,	// CMPPDrmi_alt
    1114127365U,	// CMPPDrri
    1088818272U,	// CMPPDrri_alt
    1921514501U,	// CMPPSrmi
    568714649U,	// CMPPSrmi_alt
    1116224517U,	// CMPPSrri
    1088824729U,	// CMPPSrri_alt
    2162705875U,	// CMPSB
    2460482565U,	// CMPSDrm
    2460482565U,	// CMPSDrm_Int
    851824504U,	// CMPSDrm_alt
    1118321669U,	// CMPSDrr
    1118321669U,	// CMPSDrr_Int
    1088819064U,	// CMPSDrr_alt
    2699597526U,	// CMPSL
    2968051447U,	// CMPSQ
    3269983237U,	// CMPSSrm
    3269983237U,	// CMPSSrm_Int
    856025225U,	// CMPSSrm_alt
    1122515973U,	// CMPSSrr
    1122515973U,	// CMPSSrr_Int
    1088825481U,	// CMPSSrr_alt
    3504942673U,	// CMPSW
    607124U,	// CMPXCHG16B
    4238339U,	// CMPXCHG16rm
    551840771U,	// CMPXCHG16rr
    12620996U,	// CMPXCHG32rm
    551834820U,	// CMPXCHG32rr
    18914369U,	// CMPXCHG64rm
    551836737U,	// CMPXCHG64rr
    443296U,	// CMPXCHG8B
    23102520U,	// CMPXCHG8rm
    551830584U,	// CMPXCHG8rr
    552177472U,	// COMISDrm
    552177472U,	// COMISDrm_Int
    551833408U,	// COMISDrr
    551833408U,	// COMISDrr_Int
    552200274U,	// COMISSrm
    552200274U,	// COMISSrm_Int
    551839826U,	// COMISSrr
    551839826U,	// COMISSrr_Int
    22707U,	// COMP_FST0r
    21186U,	// COM_FIPr
    21129U,	// COM_FIr
    22558U,	// COM_FST0r
    15793U,	// COS_F
    0U,	// COS_Fp32
    0U,	// COS_Fp64
    0U,	// COS_Fp80
    14967U,	// CPUID
    15347U,	// CQO
    6367761U,	// CRC32r32m16
    283202395U,	// CRC32r32m32
    6407011U,	// CRC32r32m8
    6351377U,	// CRC32r32r16
    6345563U,	// CRC32r32r32
    6341475U,	// CRC32r32r8
    283220262U,	// CRC32r64m64
    6407011U,	// CRC32r64m8
    6347046U,	// CRC32r64r64
    6341475U,	// CRC32r64r8
    551913949U,	// CVTDQ2PDrm
    551832029U,	// CVTDQ2PDrr
    271085U,	// CVTDQ2PSrm
    551838445U,	// CVTDQ2PSrr
    662035U,	// CVTPD2DQrm
    551836179U,	// CVTPD2DQrr
    664237U,	// CVTPD2PSrm
    551838381U,	// CVTPD2PSrr
    662067U,	// CVTPS2DQrm
    551836211U,	// CVTPS2DQrr
    552176139U,	// CVTPS2PDrm
    551832075U,	// CVTPS2PDrr
    552178433U,	// CVTSD2SI64rm_Int
    551834369U,	// CVTSD2SI64rr_Int
    552178433U,	// CVTSD2SIrm_Int
    551834369U,	// CVTSD2SIrr_Int
    552183644U,	// CVTSD2SSrm
    551708508U,	// CVTSD2SSrm_Int
    551839580U,	// CVTSD2SSrr
    8447836U,	// CVTSD2SSrr_Int
    551900203U,	// CVTSI2SDrm
    551638059U,	// CVTSI2SDrm_Int
    551834667U,	// CVTSI2SDrr
    8442923U,	// CVTSI2SDrr_Int
    551900907U,	// CVTSI2SSrm
    551638763U,	// CVTSI2SSrm_Int
    551835371U,	// CVTSI2SSrr
    8443627U,	// CVTSI2SSrr_Int
    551918392U,	// CVTSI642SDrm
    551656248U,	// CVTSI642SDrm_Int
    551836472U,	// CVTSI642SDrr
    8444728U,	// CVTSI642SDrr_Int
    551919359U,	// CVTSI642SSrm
    551657215U,	// CVTSI642SSrm_Int
    551837439U,	// CVTSI642SSrr
    8445695U,	// CVTSI642SSrr_Int
    552193625U,	// CVTSS2SDrm
    551718489U,	// CVTSS2SDrm_Int
    551833177U,	// CVTSS2SDrr
    8441433U,	// CVTSS2SDrr_Int
    552194840U,	// CVTSS2SI64rm_Int
    551834392U,	// CVTSS2SI64rr_Int
    552194840U,	// CVTSS2SIrm_Int
    551834392U,	// CVTSS2SIrr_Int
    662023U,	// CVTTPD2DQrm
    551836167U,	// CVTTPD2DQrr
    662055U,	// CVTTPS2DQrm
    551836199U,	// CVTTPS2DQrr
    552178421U,	// CVTTSD2SI64rm
    552178421U,	// CVTTSD2SI64rm_Int
    551834357U,	// CVTTSD2SI64rr
    551834357U,	// CVTTSD2SI64rr_Int
    552178421U,	// CVTTSD2SIrm
    552178421U,	// CVTTSD2SIrm_Int
    551834357U,	// CVTTSD2SIrr
    551834357U,	// CVTTSD2SIrr_Int
    552194828U,	// CVTTSS2SI64rm
    552194828U,	// CVTTSS2SI64rm_Int
    551834380U,	// CVTTSS2SI64rr
    551834380U,	// CVTTSS2SI64rr_Int
    552194828U,	// CVTTSS2SIrm
    552194828U,	// CVTTSS2SIrm_Int
    551834380U,	// CVTTSS2SIrr
    551834380U,	// CVTTSS2SIrr_Int
    14991U,	// CWD
    15276U,	// CWDE
    14864U,	// DAA
    15550U,	// DAS
    14790U,	// DATA16_PREFIX
    224006U,	// DEC16m
    27398U,	// DEC16r
    27398U,	// DEC16r_alt
    234419U,	// DEC32m
    21427U,	// DEC32r
    21427U,	// DEC32r_alt
    448987U,	// DEC64m
    23003U,	// DEC64r
    476103U,	// DEC8m
    17351U,	// DEC8r
    225170U,	// DIV16m
    28562U,	// DIV16r
    235413U,	// DIV32m
    22421U,	// DIV32r
    450645U,	// DIV64m
    24661U,	// DIV64r
    476827U,	// DIV8m
    18075U,	// DIV8r
    8523071U,	// DIVPDrm
    8441151U,	// DIVPDrr
    8529568U,	// DIVPSrm
    8447648U,	// DIVPSrr
    190174U,	// DIVR_F32m
    202374U,	// DIVR_F64m
    222950U,	// DIVR_FI16m
    235150U,	// DIVR_FI32m
    22815U,	// DIVR_FPrST0
    24937U,	// DIVR_FST0r
    0U,	// DIVR_Fp32m
    0U,	// DIVR_Fp64m
    0U,	// DIVR_Fp64m32
    0U,	// DIVR_Fp80m32
    0U,	// DIVR_Fp80m64
    0U,	// DIVR_FpI16m32
    0U,	// DIVR_FpI16m64
    0U,	// DIVR_FpI16m80
    0U,	// DIVR_FpI32m32
    0U,	// DIVR_FpI32m64
    0U,	// DIVR_FpI32m80
    29042U,	// DIVR_FrST0
    551702526U,	// DIVSDrm
    551702526U,	// DIVSDrm_Int
    8441854U,	// DIVSDrr
    8441854U,	// DIVSDrr_Int
    551725278U,	// DIVSSrm
    551725278U,	// DIVSSrm_Int
    8448222U,	// DIVSSrr
    8448222U,	// DIVSSrr_Int
    190737U,	// DIV_F32m
    202644U,	// DIV_F64m
    223512U,	// DIV_FI16m
    235419U,	// DIV_FI32m
    22753U,	// DIV_FPrST0
    27114U,	// DIV_FST0r
    0U,	// DIV_Fp32
    0U,	// DIV_Fp32m
    0U,	// DIV_Fp64
    0U,	// DIV_Fp64m
    0U,	// DIV_Fp64m32
    0U,	// DIV_Fp80
    0U,	// DIV_Fp80m32
    0U,	// DIV_Fp80m64
    0U,	// DIV_FpI16m32
    0U,	// DIV_FpI16m64
    0U,	// DIV_FpI16m80
    0U,	// DIV_FpI32m32
    0U,	// DIV_FpI32m64
    0U,	// DIV_FpI32m80
    29027U,	// DIV_FrST0
    568708185U,	// DPPDrmi
    1088818265U,	// DPPDrri
    568714642U,	// DPPSrmi
    1088824722U,	// DPPSrri
    15781U,	// ENCLS
    15906U,	// ENCLU
    15940U,	// ENCLV
    14745U,	// ENDBR32
    14776U,	// ENDBR64
    283140374U,	// ENTER
    3810829867U,	// EXTRACTPSmr
    283436587U,	// EXTRACTPSrr
    6348457U,	// EXTRQ
    4041612969U,	// EXTRQI
    14726U,	// F2XM1
    551840871U,	// FARCALL16i
    686279U,	// FARCALL16m
    551834931U,	// FARCALL32i
    686245U,	// FARCALL32m
    686262U,	// FARCALL64
    54816020U,	// FARJMP16i
    686288U,	// FARJMP16m
    54810054U,	// FARJMP32i
    686254U,	// FARJMP32m
    686271U,	// FARJMP64
    702596U,	// FBLDm
    702612U,	// FBSTPm
    188893U,	// FCOM32m
    202117U,	// FCOM64m
    189790U,	// FCOMP32m
    202189U,	// FCOMP64m
    15406U,	// FCOMPP
    15433U,	// FDECSTP
    15387U,	// FDISI8087_NOP
    15787U,	// FEMMS
    15374U,	// FENI8087_NOP
    20913U,	// FFREE
    22683U,	// FFREEP
    221668U,	// FICOM16m
    234892U,	// FICOM32m
    222566U,	// FICOMP16m
    234965U,	// FICOMP32m
    15441U,	// FINCSTP
    223999U,	// FLDCW16m
    190960U,	// FLDENVm
    15012U,	// FLDL2E
    15849U,	// FLDL2T
    14757U,	// FLDLG2
    14764U,	// FLDLN2
    15147U,	// FLDPI
    16196U,	// FNCLEX
    15870U,	// FNINIT
    15401U,	// FNOP
    224024U,	// FNSTCW16m
    15995U,	// FNSTSW16r
    224892U,	// FNSTSWm
    15317U,	// FPATAN
    28981U,	// FPNCEST0r
    15294U,	// FPREM
    14719U,	// FPREM1
    15324U,	// FPTAN
    15881U,	// FRNDINT
    188727U,	// FRSTORm
    184868U,	// FSAVEm
    15040U,	// FSCALE
    15306U,	// FSETPM
    15798U,	// FSINCOS
    190968U,	// FSTENVm
    15289U,	// FXAM
    680255U,	// FXRSTOR
    672071U,	// FXRSTOR64
    676396U,	// FXSAVE
    672061U,	// FXSAVE64
    15856U,	// FXTRACT
    15989U,	// FYL2X
    14732U,	// FYL2XP1
    14924U,	// GETSEC
    593872181U,	// GF2P8AFFINEINVQBrmi
    1088816437U,	// GF2P8AFFINEINVQBrri
    593872118U,	// GF2P8AFFINEQBrmi
    1088816374U,	// GF2P8AFFINEQBrri
    8635518U,	// GF2P8MULBrm
    8438910U,	// GF2P8MULBrr
    8522557U,	// HADDPDrm
    8440637U,	// HADDPDrr
    8528954U,	// HADDPSrm
    8447034U,	// HADDPSrr
    15877U,	// HLT
    8522444U,	// HSUBPDrm
    8440524U,	// HSUBPDrr
    8528841U,	// HSUBPSrm
    8446921U,	// HSUBPSrr
    225169U,	// IDIV16m
    28561U,	// IDIV16r
    235420U,	// IDIV32m
    22428U,	// IDIV32r
    450644U,	// IDIV64m
    24660U,	// IDIV64r
    476826U,	// IDIV8m
    18074U,	// IDIV8r
    221588U,	// ILD_F16m
    234515U,	// ILD_F32m
    447781U,	// ILD_F64m
    0U,	// ILD_Fp16m32
    0U,	// ILD_Fp16m64
    0U,	// ILD_Fp16m80
    0U,	// ILD_Fp32m32
    0U,	// ILD_Fp32m64
    0U,	// ILD_Fp32m80
    0U,	// ILD_Fp64m32
    0U,	// ILD_Fp64m64
    0U,	// ILD_Fp64m80
    224414U,	// IMUL16m
    27806U,	// IMUL16r
    8465566U,	// IMUL16rm
    59059358U,	// IMUL16rmi
    59059358U,	// IMUL16rmi8
    8449182U,	// IMUL16rr
    811658398U,	// IMUL16rri
    811658398U,	// IMUL16rri8
    234870U,	// IMUL32m
    21878U,	// IMUL32r
    551638390U,	// IMUL32rm
    832902518U,	// IMUL32rmi
    832902518U,	// IMUL32rmi8
    8443254U,	// IMUL32rr
    811652470U,	// IMUL32rri
    811652470U,	// IMUL32rri8
    449798U,	// IMUL64m
    23814U,	// IMUL64r
    551656710U,	// IMUL64rm
    835001606U,	// IMUL64rmi32
    835001606U,	// IMUL64rmi8
    8445190U,	// IMUL64rr
    811654406U,	// IMUL64rri32
    811654406U,	// IMUL64rri8
    476297U,	// IMUL8m
    17545U,	// IMUL8r
    2813166U,	// IN16ri
    16006U,	// IN16rr
    11195803U,	// IN32ri
    16066U,	// IN32rr
    21677279U,	// IN8ri
    15162U,	// IN8rr
    224012U,	// INC16m
    27404U,	// INC16r
    27404U,	// INC16r_alt
    234450U,	// INC32m
    21458U,	// INC32r
    21458U,	// INC32r_alt
    449018U,	// INC64m
    23034U,	// INC64r
    476109U,	// INC8m
    17357U,	// INC8r
    19684U,	// INCSSPD
    23964U,	// INCSSPQ
    554385U,	// INSB
    856024653U,	// INSERTPSrm
    1088824909U,	// INSERTPSrr
    6348745U,	// INSERTQ
    15409097U,	// INSERTQI
    570780U,	// INSL
    603559U,	// INSW
    715063U,	// INT
    14740U,	// INT1
    14771U,	// INT3
    15342U,	// INTO
    14998U,	// INVD
    272700U,	// INVEPT32
    272700U,	// INVEPT64
    479808U,	// INVLPG
    16115U,	// INVLPGA32
    16134U,	// INVLPGA64
    264267U,	// INVPCID32
    264267U,	// INVPCID64
    264283U,	// INVVPID32
    264283U,	// INVVPID64
    15977U,	// IRET16
    15247U,	// IRET32
    15462U,	// IRET64
    222850U,	// ISTT_FP16m
    235016U,	// ISTT_FP32m
    447838U,	// ISTT_FP64m
    0U,	// ISTT_Fp16m32
    0U,	// ISTT_Fp16m64
    0U,	// ISTT_Fp16m80
    0U,	// ISTT_Fp32m32
    0U,	// ISTT_Fp32m64
    0U,	// ISTT_Fp32m80
    0U,	// ISTT_Fp64m32
    0U,	// ISTT_Fp64m64
    0U,	// ISTT_Fp64m80
    223498U,	// IST_F16m
    235391U,	// IST_F32m
    222842U,	// IST_FP16m
    235008U,	// IST_FP32m
    447829U,	// IST_FP64m
    0U,	// IST_Fp16m32
    0U,	// IST_Fp16m64
    0U,	// IST_Fp16m80
    0U,	// IST_Fp32m32
    0U,	// IST_Fp32m64
    0U,	// IST_Fp32m80
    0U,	// IST_Fp64m32
    0U,	// IST_Fp64m64
    0U,	// IST_Fp64m80
    463238U,	// JAE_1
    463238U,	// JAE_2
    463238U,	// JAE_4
    459576U,	// JA_1
    459576U,	// JA_2
    459576U,	// JA_4
    463250U,	// JBE_1
    463250U,	// JBE_2
    463250U,	// JBE_4
    459850U,	// JB_1
    459850U,	// JB_2
    459850U,	// JB_4
    471308U,	// JCXZ
    471301U,	// JECXZ
    463309U,	// JE_1
    463309U,	// JE_2
    463309U,	// JE_4
    463288U,	// JGE_1
    463288U,	// JGE_2
    463288U,	// JGE_4
    463420U,	// JG_1
    463420U,	// JG_2
    463420U,	// JG_4
    463313U,	// JLE_1
    463313U,	// JLE_2
    463313U,	// JLE_4
    464123U,	// JL_1
    464123U,	// JL_2
    464123U,	// JL_4
    227537U,	// JMP16m
    227537U,	// JMP16m_NT
    30929U,	// JMP16r
    30929U,	// JMP16r_NT
    243887U,	// JMP32m
    243887U,	// JMP32m_NT
    30895U,	// JMP32r
    30895U,	// JMP32r_NT
    456896U,	// JMP64m
    456896U,	// JMP64m_NT
    30912U,	// JMP64r
    30912U,	// JMP64r_NT
    465070U,	// JMP_1
    465070U,	// JMP_2
    465070U,	// JMP_4
    463325U,	// JNE_1
    463325U,	// JNE_2
    463325U,	// JNE_4
    465012U,	// JNO_1
    465012U,	// JNO_2
    465012U,	// JNO_4
    465090U,	// JNP_1
    465090U,	// JNP_2
    465090U,	// JNP_4
    467444U,	// JNS_1
    467444U,	// JNS_2
    467444U,	// JNS_4
    465008U,	// JO_1
    465008U,	// JO_2
    465008U,	// JO_4
    465059U,	// JP_1
    465059U,	// JP_2
    465059U,	// JP_4
    471314U,	// JRCXZ
    467402U,	// JS_1
    467402U,	// JS_2
    467402U,	// JS_4
    811647971U,	// KADDBrr
    811648949U,	// KADDDrr
    811653712U,	// KADDQrr
    811658025U,	// KADDWrr
    811647993U,	// KANDBrr
    811648973U,	// KANDDrr
    811648206U,	// KANDNBrr
    811649244U,	// KANDNDrr
    811654469U,	// KANDNQrr
    811658461U,	// KANDNWrr
    811653823U,	// KANDQrr
    811658065U,	// KANDWrr
    551831209U,	// KMOVBkk
    493225U,	// KMOVBkm
    551831209U,	// KMOVBkr
    23103145U,	// KMOVBmk
    551831209U,	// KMOVBrk
    551833826U,	// KMOVDkk
    551899362U,	// KMOVDkm
    551833826U,	// KMOVDkr
    12620002U,	// KMOVDmk
    551833826U,	// KMOVDrk
    551837819U,	// KMOVQkk
    551919739U,	// KMOVQkm
    551837819U,	// KMOVQkr
    18915451U,	// KMOVQmk
    551837819U,	// KMOVQrk
    551841706U,	// KMOVWkk
    438186U,	// KMOVWkm
    551841706U,	// KMOVWkr
    4239274U,	// KMOVWmk
    551841706U,	// KMOVWrk
    551831093U,	// KNOTBrr
    551833682U,	// KNOTDrr
    551837626U,	// KNOTQrr
    551841546U,	// KNOTWrr
    811648354U,	// KORBrr
    811650468U,	// KORDrr
    811654736U,	// KORQrr
    551831130U,	// KORTESTBrr
    551833719U,	// KORTESTDrr
    551837672U,	// KORTESTQrr
    551841583U,	// KORTESTWrr
    811658631U,	// KORWrr
    283427955U,	// KSHIFTLBri
    283429019U,	// KSHIFTLDri
    283434236U,	// KSHIFTLQri
    283438228U,	// KSHIFTLWri
    283428230U,	// KSHIFTRBri
    283430361U,	// KSHIFTRDri
    283434648U,	// KSHIFTRQri
    283438519U,	// KSHIFTRWri
    551831122U,	// KTESTBrr
    551833711U,	// KTESTDrr
    551837664U,	// KTESTQrr
    551841575U,	// KTESTWrr
    811657881U,	// KUNPCKBWrr
    811653765U,	// KUNPCKDQrr
    811651363U,	// KUNPCKWDrr
    811648360U,	// KXNORBrr
    811650474U,	// KXNORDrr
    811654742U,	// KXNORQrr
    811658637U,	// KXNORWrr
    811648374U,	// KXORBrr
    811650497U,	// KXORDrr
    811654765U,	// KXORQrr
    811658651U,	// KXORWrr
    15106U,	// LAHF
    437600U,	// LAR16rm
    551841120U,	// LAR16rr
    431664U,	// LAR32rm
    551835184U,	// LAR32rr
    433720U,	// LAR64rm
    551837240U,	// LAR64rr
    272837U,	// LDDQUrm
    237910U,	// LDMXCSR
    749088U,	// LDS16rm
    743086U,	// LDS32rm
    16228U,	// LD_F0
    14710U,	// LD_F1
    188814U,	// LD_F32m
    201734U,	// LD_F64m
    698656U,	// LD_F80m
    0U,	// LD_Fp032
    0U,	// LD_Fp064
    0U,	// LD_Fp080
    0U,	// LD_Fp132
    0U,	// LD_Fp164
    0U,	// LD_Fp180
    0U,	// LD_Fp32m
    0U,	// LD_Fp32m64
    0U,	// LD_Fp32m80
    0U,	// LD_Fp64m
    0U,	// LD_Fp64m80
    0U,	// LD_Fp80m
    18532U,	// LD_Frr
    420407U,	// LEA16r
    414563U,	// LEA32r
    414563U,	// LEA64_32r
    416102U,	// LEA64r
    15093U,	// LEAVE
    15093U,	// LEAVE64
    749101U,	// LES16rm
    743099U,	// LES32rm
    15019U,	// LFENCE
    749107U,	// LFS16rm
    743105U,	// LFS32rm
    745183U,	// LFS64rm
    683701U,	// LGDT16m
    677667U,	// LGDT32m
    679778U,	// LGDT64m
    749113U,	// LGS16rm
    743111U,	// LGS32rm
    745925U,	// LGS64rm
    683715U,	// LIDT16m
    677681U,	// LIDT32m
    679792U,	// LIDT64m
    224977U,	// LLDT16m
    28369U,	// LLDT16r
    17363U,	// LLWPCB
    17363U,	// LLWPCB64
    225211U,	// LMSW16m
    28603U,	// LMSW16r
    15157U,	// LOCK_PREFIX
    21726659U,	// LODSB
    11261620U,	// LODSL
    794328U,	// LODSQ
    2911782U,	// LODSW
    465107U,	// LOOP
    463354U,	// LOOPE
    463330U,	// LOOPNE
    22342U,	// LRETIL
    24453U,	// LRETIQ
    28383U,	// LRETIW
    15253U,	// LRETL
    15468U,	// LRETQ
    15983U,	// LRETW
    437390U,	// LSL16rm
    551840910U,	// LSL16rr
    431464U,	// LSL32rm
    551834984U,	// LSL32rr
    433390U,	// LSL64rm
    551836910U,	// LSL64rr
    749168U,	// LSS16rm
    743171U,	// LSS32rm
    745252U,	// LSS64rm
    224705U,	// LTRm
    28097U,	// LTRr
    832905708U,	// LWPINS32rmi
    811655660U,	// LWPINS32rri
    832905708U,	// LWPINS64rmi
    811655660U,	// LWPINS64rri
    832902001U,	// LWPVAL32rmi
    811651953U,	// LWPVAL32rri
    832902001U,	// LWPVAL64rmi
    811651953U,	// LWPVAL64rri
    438010U,	// LZCNT16rm
    551841530U,	// LZCNT16rr
    551901020U,	// LZCNT32rm
    551835484U,	// LZCNT32rr
    551919522U,	// LZCNT64rm
    551837602U,	// LZCNT64rr
    551840205U,	// MASKMOVDQU
    551840205U,	// MASKMOVDQU64
    8523091U,	// MAXCPDrm
    8441171U,	// MAXCPDrr
    8529588U,	// MAXCPSrm
    8447668U,	// MAXCPSrr
    551702543U,	// MAXCSDrm
    8441871U,	// MAXCSDrr
    551725294U,	// MAXCSSrm
    8448238U,	// MAXCSSrr
    8523091U,	// MAXPDrm
    8441171U,	// MAXPDrr
    8529588U,	// MAXPSrm
    8447668U,	// MAXPSrr
    551702543U,	// MAXSDrm
    551702543U,	// MAXSDrm_Int
    8441871U,	// MAXSDrr
    8441871U,	// MAXSDrr_Int
    551725294U,	// MAXSSrm
    551725294U,	// MAXSSrm_Int
    8448238U,	// MAXSSrr
    8448238U,	// MAXSSrr_Int
    15026U,	// MFENCE
    8522833U,	// MINCPDrm
    8440913U,	// MINCPDrr
    8529282U,	// MINCPSrm
    8447362U,	// MINCPSrr
    551702376U,	// MINCSDrm
    8441704U,	// MINCSDrr
    551725177U,	// MINCSSrm
    8448121U,	// MINCSSrr
    8522833U,	// MINPDrm
    8440913U,	// MINPDrr
    8529282U,	// MINPSrm
    8447362U,	// MINPSrr
    551702376U,	// MINSDrm
    551702376U,	// MINSDrm_Int
    8441704U,	// MINSDrr
    8441704U,	// MINSDrr_Int
    551725177U,	// MINSSrm
    551725177U,	// MINSSrm_Int
    8448121U,	// MINSSrr
    8448121U,	// MINSSrr_Int
    660131U,	// MMX_CVTPD2PIirm
    551834275U,	// MMX_CVTPD2PIirr
    551913917U,	// MMX_CVTPI2PDirm
    551831997U,	// MMX_CVTPI2PDirr
    551658189U,	// MMX_CVTPI2PSirm
    8446669U,	// MMX_CVTPI2PSirr
    552178360U,	// MMX_CVTPS2PIirm
    551834296U,	// MMX_CVTPS2PIirr
    660120U,	// MMX_CVTTPD2PIirm
    551834264U,	// MMX_CVTTPD2PIirr
    552178349U,	// MMX_CVTTPS2PIirm
    551834285U,	// MMX_CVTTPS2PIirr
    15788U,	// MMX_EMMS
    551837816U,	// MMX_MASKMOVQ
    551837816U,	// MMX_MASKMOVQ64
    18915452U,	// MMX_MOVD64from64rm
    551837820U,	// MMX_MOVD64from64rr
    551833827U,	// MMX_MOVD64grr
    12620003U,	// MMX_MOVD64mr
    551899363U,	// MMX_MOVD64rm
    551833827U,	// MMX_MOVD64rr
    551919740U,	// MMX_MOVD64to64rm
    551837820U,	// MMX_MOVD64to64rr
    551835987U,	// MMX_MOVDQ2Qrr
    551835987U,	// MMX_MOVFR642Qrr
    18915250U,	// MMX_MOVNTQmr
    551836189U,	// MMX_MOVQ2DQrr
    551836189U,	// MMX_MOVQ2FR64rr
    18915452U,	// MMX_MOVQ64mr
    551919740U,	// MMX_MOVQ64rm
    551837820U,	// MMX_MOVQ64rr
    551837820U,	// MMX_MOVQ64rr_REV
    551912865U,	// MMX_PABSBrm
    551830945U,	// MMX_PABSBrr
    551915206U,	// MMX_PABSDrm
    551833286U,	// MMX_PABSDrr
    551923166U,	// MMX_PABSWrm
    551841246U,	// MMX_PABSWrr
    551660416U,	// MMX_PACKSSDWirm
    8448896U,	// MMX_PACKSSDWirr
    551650999U,	// MMX_PACKSSWBirm
    8439479U,	// MMX_PACKSSWBirr
    551651010U,	// MMX_PACKUSWBirm
    8439490U,	// MMX_PACKUSWBirr
    551650283U,	// MMX_PADDBirm
    8438763U,	// MMX_PADDBirr
    551651261U,	// MMX_PADDDirm
    8439741U,	// MMX_PADDDirr
    551656024U,	// MMX_PADDQirm
    8444504U,	// MMX_PADDQirr
    551650747U,	// MMX_PADDSBirm
    8439227U,	// MMX_PADDSBirr
    551661080U,	// MMX_PADDSWirm
    8449560U,	// MMX_PADDSWirr
    551650809U,	// MMX_PADDUSBirm
    8439289U,	// MMX_PADDUSBirr
    551661206U,	// MMX_PADDUSWirm
    8449686U,	// MMX_PADDUSWirr
    551660337U,	// MMX_PADDWirm
    8448817U,	// MMX_PADDWirr
    866509086U,	// MMX_PALIGNRrmi
    1088823582U,	// MMX_PALIGNRrri
    551655507U,	// MMX_PANDNirm
    8443987U,	// MMX_PANDNirr
    551651542U,	// MMX_PANDirm
    8440022U,	// MMX_PANDirr
    551650371U,	// MMX_PAVGBirm
    8438851U,	// MMX_PAVGBirr
    551660558U,	// MMX_PAVGWirm
    8449038U,	// MMX_PAVGWirr
    551650566U,	// MMX_PCMPEQBirm
    8439046U,	// MMX_PCMPEQBirr
    551652708U,	// MMX_PCMPEQDirm
    8441188U,	// MMX_PCMPEQDirr
    551660857U,	// MMX_PCMPEQWirm
    8449337U,	// MMX_PCMPEQWirr
    551650850U,	// MMX_PCMPGTBirm
    8439330U,	// MMX_PCMPGTBirr
    551653429U,	// MMX_PCMPGTDirm
    8441909U,	// MMX_PCMPGTDirr
    551661287U,	// MMX_PCMPGTWirm
    8449767U,	// MMX_PCMPGTWirr
    283438542U,	// MMX_PEXTRWrr
    551651245U,	// MMX_PHADDDrm
    8439725U,	// MMX_PHADDDrr
    551661070U,	// MMX_PHADDSWrm
    8449550U,	// MMX_PHADDSWrr
    551660321U,	// MMX_PHADDWrm
    8448801U,	// MMX_PHADDWrr
    551651199U,	// MMX_PHSUBDrm
    8439679U,	// MMX_PHSUBDrr
    551661051U,	// MMX_PHSUBSWrm
    8449531U,	// MMX_PHSUBSWrr
    551660227U,	// MMX_PHSUBWrm
    8448707U,	// MMX_PHSUBWrr
    600173993U,	// MMX_PINSRWrm
    1088826793U,	// MMX_PINSRWrr
    551661039U,	// MMX_PMADDUBSWrm
    8449519U,	// MMX_PMADDUBSWrr
    551653646U,	// MMX_PMADDWDirm
    8442126U,	// MMX_PMADDWDirr
    551661224U,	// MMX_PMAXSWirm
    8449704U,	// MMX_PMAXSWirr
    551650951U,	// MMX_PMAXUBirm
    8439431U,	// MMX_PMAXUBirr
    551661120U,	// MMX_PMINSWirm
    8449600U,	// MMX_PMINSWirr
    551650926U,	// MMX_PMINUBirm
    8439406U,	// MMX_PMINUBirr
    551830607U,	// MMX_PMOVMSKBrr
    551661145U,	// MMX_PMULHRSWrm
    8449625U,	// MMX_PMULHRSWrr
    551661370U,	// MMX_PMULHUWirm
    8449850U,	// MMX_PMULHUWirr
    551660595U,	// MMX_PMULHWirm
    8449075U,	// MMX_PMULHWirr
    551660664U,	// MMX_PMULLWirm
    8449144U,	// MMX_PMULLWirr
    551656344U,	// MMX_PMULUDQirm
    8444824U,	// MMX_PMULUDQirr
    551657768U,	// MMX_PORirm
    8446248U,	// MMX_PORirr
    551660136U,	// MMX_PSADBWirm
    8448616U,	// MMX_PSADBWirr
    551650346U,	// MMX_PSHUFBrm
    8438826U,	// MMX_PSHUFBrr
    834972661U,	// MMX_PSHUFWmi
    283438069U,	// MMX_PSHUFWri
    551650519U,	// MMX_PSIGNBrm
    8438999U,	// MMX_PSIGNBrr
    551651575U,	// MMX_PSIGNDrm
    8440055U,	// MMX_PSIGNDrr
    551660774U,	// MMX_PSIGNWrm
    8449254U,	// MMX_PSIGNWrr
    551864434U,	// MMX_PSLLDri
    551651442U,	// MMX_PSLLDrm
    8439922U,	// MMX_PSLLDrr
    551869646U,	// MMX_PSLLQri
    551656654U,	// MMX_PSLLQrm
    8445134U,	// MMX_PSLLQrr
    551873648U,	// MMX_PSLLWri
    551660656U,	// MMX_PSLLWrm
    8449136U,	// MMX_PSLLWrr
    551864162U,	// MMX_PSRADri
    551651170U,	// MMX_PSRADrm
    8439650U,	// MMX_PSRADrr
    551873094U,	// MMX_PSRAWri
    551660102U,	// MMX_PSRAWrm
    8448582U,	// MMX_PSRAWrr
    551864459U,	// MMX_PSRLDri
    551651467U,	// MMX_PSRLDrm
    8439947U,	// MMX_PSRLDrr
    551869671U,	// MMX_PSRLQri
    551656679U,	// MMX_PSRLQrm
    8445159U,	// MMX_PSRLQrr
    551873671U,	// MMX_PSRLWri
    551660679U,	// MMX_PSRLWrm
    8449159U,	// MMX_PSRLWrr
    551650234U,	// MMX_PSUBBirm
    8438714U,	// MMX_PSUBBirr
    551651208U,	// MMX_PSUBDirm
    8439688U,	// MMX_PSUBDirr
    551655848U,	// MMX_PSUBQirm
    8444328U,	// MMX_PSUBQirr
    551650738U,	// MMX_PSUBSBirm
    8439218U,	// MMX_PSUBSBirr
    551661061U,	// MMX_PSUBSWirm
    8449541U,	// MMX_PSUBSWirr
    551650799U,	// MMX_PSUBUSBirm
    8439279U,	// MMX_PSUBUSBirr
    551661196U,	// MMX_PSUBUSWirm
    8449676U,	// MMX_PSUBUSWirr
    551660236U,	// MMX_PSUBWirm
    8448716U,	// MMX_PSUBWirr
    551660174U,	// MMX_PUNPCKHBWirm
    8448654U,	// MMX_PUNPCKHBWirr
    551656058U,	// MMX_PUNPCKHDQirm
    8444538U,	// MMX_PUNPCKHDQirr
    551653656U,	// MMX_PUNPCKHWDirm
    8442136U,	// MMX_PUNPCKHWDirr
    551643812U,	// MMX_PUNPCKLBWirm
    8448676U,	// MMX_PUNPCKLBWirr
    551639705U,	// MMX_PUNPCKLDQirm
    8444569U,	// MMX_PUNPCKLDQirr
    551637294U,	// MMX_PUNPCKLWDirm
    8442158U,	// MMX_PUNPCKLWDirr
    551657801U,	// MMX_PXORirm
    8446281U,	// MMX_PXORirr
    16203U,	// MONITORXrrr
    15516U,	// MONITORrrr
    15281U,	// MONTMUL
    2928555U,	// MOV16ao16
    2928555U,	// MOV16ao32
    2928101U,	// MOV16ao64
    4239275U,	// MOV16mi
    4239275U,	// MOV16mr
    4239275U,	// MOV16ms
    832784U,	// MOV16o16a
    832784U,	// MOV16o32a
    832747U,	// MOV16o64a
    551841707U,	// MOV16ri
    551841707U,	// MOV16ri_alt
    438187U,	// MOV16rm
    551841707U,	// MOV16rr
    551841707U,	// MOV16rr_REV
    551841707U,	// MOV16rs
    438187U,	// MOV16sm
    551841707U,	// MOV16sr
    11327395U,	// MOV32ao16
    11327395U,	// MOV32ao32
    11327134U,	// MOV32ao64
    551835555U,	// MOV32cr
    551835555U,	// MOV32dr
    12621731U,	// MOV32mi
    12621731U,	// MOV32mr
    849232U,	// MOV32o16a
    849232U,	// MOV32o32a
    849192U,	// MOV32o64a
    551835555U,	// MOV32rc
    551835555U,	// MOV32rd
    551835555U,	// MOV32ri
    551835555U,	// MOV32ri_alt
    551901091U,	// MOV32rm
    551835555U,	// MOV32rr
    551835555U,	// MOV32rr_REV
    551835555U,	// MOV32rs
    551835555U,	// MOV32sr
    17637500U,	// MOV64ao32
    17637064U,	// MOV64ao64
    551837820U,	// MOV64cr
    551837820U,	// MOV64dr
    18915452U,	// MOV64mi32
    18915452U,	// MOV64mr
    865669U,	// MOV64o32a
    865641U,	// MOV64o64a
    551837820U,	// MOV64rc
    551837820U,	// MOV64rd
    551837384U,	// MOV64ri
    551837820U,	// MOV64ri32
    551919740U,	// MOV64rm
    551837820U,	// MOV64rr
    551837820U,	// MOV64rr_REV
    551837820U,	// MOV64rs
    551837820U,	// MOV64sr
    551919740U,	// MOV64toPQIrm
    551837820U,	// MOV64toPQIrr
    551919740U,	// MOV64toSDrm
    551837820U,	// MOV64toSDrr
    21841571U,	// MOV8ao16
    21841571U,	// MOV8ao32
    21841320U,	// MOV8ao64
    23103139U,	// MOV8mi
    23103139U,	// MOV8mr
    23103139U,	// MOV8mr_NOREX
    881452U,	// MOV8o16a
    881452U,	// MOV8o32a
    881415U,	// MOV8o64a
    551831203U,	// MOV8ri
    551831203U,	// MOV8ri_alt
    493219U,	// MOV8rm
    493219U,	// MOV8rm_NOREX
    551831203U,	// MOV8rr
    551831203U,	// MOV8rr_NOREX
    551831203U,	// MOV8rr_REV
    65047203U,	// MOVAPDmr
    658083U,	// MOVAPDrm
    551832227U,	// MOVAPDrr
    551832227U,	// MOVAPDrr_REV
    65053608U,	// MOVAPSmr
    664488U,	// MOVAPSrm
    551838632U,	// MOVAPSrr
    551838632U,	// MOVAPSrr_REV
    4238269U,	// MOVBE16mr
    437181U,	// MOVBE16rm
    12620877U,	// MOVBE32mr
    551900237U,	// MOVBE32rm
    18914241U,	// MOVBE64mr
    551918529U,	// MOVBE64rm
    552179968U,	// MOVDDUPrm
    551835904U,	// MOVDDUPrr
    551899363U,	// MOVDI2PDIrm
    551833827U,	// MOVDI2PDIrr
    551899363U,	// MOVDI2SSrm
    551833827U,	// MOVDI2SSrr
    552436617U,	// MOVDIR64B16
    552436617U,	// MOVDIR64B32
    552436617U,	// MOVDIR64B64
    12620499U,	// MOVDIRI32
    18911955U,	// MOVDIRI64
    33588040U,	// MOVDQAmr
    262984U,	// MOVDQArm
    551830344U,	// MOVDQArr
    551830344U,	// MOVDQArr_REV
    33597905U,	// MOVDQUmr
    272849U,	// MOVDQUrm
    551840209U,	// MOVDQUrr
    551840209U,	// MOVDQUrr_REV
    8447254U,	// MOVHLPSrr
    67144676U,	// MOVHPDmr
    551701476U,	// MOVHPDrm
    67151106U,	// MOVHPSmr
    551707906U,	// MOVHPSrm
    8447224U,	// MOVLHPSrr
    67144726U,	// MOVLPDmr
    551701526U,	// MOVLPDrm
    67151166U,	// MOVLPSmr
    551707966U,	// MOVLPSrm
    551832557U,	// MOVMSKPDrr
    551838987U,	// MOVMSKPSrr
    262973U,	// MOVNTDQArm
    65051473U,	// MOVNTDQmr
    18914427U,	// MOVNTI_64mr
    12621042U,	// MOVNTImr
    65047823U,	// MOVNTPDmr
    65054275U,	// MOVNTPSmr
    67145683U,	// MOVNTSD
    69249203U,	// MOVNTSS
    12620003U,	// MOVPDI2DImr
    551833827U,	// MOVPDI2DIrr
    18915452U,	// MOVPQI2QImr
    551837820U,	// MOVPQI2QIrr
    18915452U,	// MOVPQIto64mr
    551837820U,	// MOVPQIto64rr
    551919740U,	// MOVQI2PQIrm
    902667U,	// MOVSB
    67145734U,	// MOVSDmr
    552177670U,	// MOVSDrm
    8441862U,	// MOVSDrr
    8441862U,	// MOVSDrr_REV
    18915452U,	// MOVSDto64mr
    551837820U,	// MOVSDto64rr
    661770U,	// MOVSHDUPrm
    551835914U,	// MOVSHDUPrr
    923415U,	// MOVSL
    661781U,	// MOVSLDUPrm
    551835925U,	// MOVSLDUPrr
    941888U,	// MOVSQ
    12620003U,	// MOVSS2DImr
    551833827U,	// MOVSS2DIrr
    69249254U,	// MOVSSmr
    552200422U,	// MOVSSrm
    8448230U,	// MOVSSrr
    8448230U,	// MOVSSrr_REV
    962208U,	// MOVSW
    438228U,	// MOVSX16rm16
    502447U,	// MOVSX16rm8
    551841748U,	// MOVSX16rr16
    551840431U,	// MOVSX16rr8
    432048U,	// MOVSX32rm16
    496511U,	// MOVSX32rm8
    496511U,	// MOVSX32rm8_NOREX
    551835568U,	// MOVSX32rr16
    551834495U,	// MOVSX32rr8
    551834495U,	// MOVSX32rr8_NOREX
    434339U,	// MOVSX64rm16
    551902452U,	// MOVSX64rm32
    498068U,	// MOVSX64rm8
    551837859U,	// MOVSX64rr16
    551836916U,	// MOVSX64rr32
    551836052U,	// MOVSX64rr8
    65047851U,	// MOVUPDmr
    658731U,	// MOVUPDrm
    551832875U,	// MOVUPDrr
    551832875U,	// MOVUPDrr_REV
    65054348U,	// MOVUPSmr
    665228U,	// MOVUPSrm
    551839372U,	// MOVUPSrr
    551839372U,	// MOVUPSrr_REV
    551837820U,	// MOVZPQILo2PQIrr
    438236U,	// MOVZX16rm16
    502513U,	// MOVZX16rm8
    551841756U,	// MOVZX16rr16
    551840497U,	// MOVZX16rr8
    432056U,	// MOVZX32rm16
    496542U,	// MOVZX32rm8
    496542U,	// MOVZX32rm8_NOREX
    551835576U,	// MOVZX32rr16
    551834526U,	// MOVZX32rr8
    551834526U,	// MOVZX32rr8_NOREX
    434380U,	// MOVZX64rm16
    498125U,	// MOVZX64rm8
    551837900U,	// MOVZX64rr16
    551836109U,	// MOVZX64rr8
    593881713U,	// MPSADBWrmi
    1088825969U,	// MPSADBWrri
    224415U,	// MUL16m
    27807U,	// MUL16r
    234863U,	// MUL32m
    21871U,	// MUL32r
    449799U,	// MUL64m
    23815U,	// MUL64r
    476291U,	// MUL8m
    17539U,	// MUL8r
    8522766U,	// MULPDrm
    8440846U,	// MULPDrr
    8529206U,	// MULPSrm
    8447286U,	// MULPSrr
    551702354U,	// MULSDrm
    551702354U,	// MULSDrm_Int
    8441682U,	// MULSDrr
    8441682U,	// MULSDrr_Int
    551725156U,	// MULSSrm
    551725156U,	// MULSSrm_Int
    8448100U,	// MULSSrr
    8448100U,	// MULSSrr_Int
    283203534U,	// MULX32rm
    811653070U,	// MULX32rr
    283222242U,	// MULX64rm
    811655394U,	// MULX64rr
    188878U,	// MUL_F32m
    202094U,	// MUL_F64m
    221653U,	// MUL_FI16m
    234869U,	// MUL_FI32m
    22695U,	// MUL_FPrST0
    22414U,	// MUL_FST0r
    0U,	// MUL_Fp32
    0U,	// MUL_Fp32m
    0U,	// MUL_Fp64
    0U,	// MUL_Fp64m
    0U,	// MUL_Fp64m32
    0U,	// MUL_Fp80
    0U,	// MUL_Fp80m32
    0U,	// MUL_Fp80m64
    0U,	// MUL_FpI16m32
    0U,	// MUL_FpI16m64
    0U,	// MUL_FpI16m80
    0U,	// MUL_FpI32m32
    0U,	// MUL_FpI32m64
    0U,	// MUL_FpI32m80
    28998U,	// MUL_FrST0
    16212U,	// MWAITXrrr
    15864U,	// MWAITrr
    224253U,	// NEG16m
    27645U,	// NEG16r
    234686U,	// NEG32m
    21694U,	// NEG32r
    449595U,	// NEG64m
    23611U,	// NEG64r
    476210U,	// NEG8m
    17458U,	// NEG8r
    15383U,	// NOOP
    224548U,	// NOOP18_16m4
    224548U,	// NOOP18_16m5
    224548U,	// NOOP18_16m6
    224548U,	// NOOP18_16m7
    27940U,	// NOOP18_16r4
    27940U,	// NOOP18_16r5
    27940U,	// NOOP18_16r6
    27940U,	// NOOP18_16r7
    234983U,	// NOOP18_m4
    234983U,	// NOOP18_m5
    234983U,	// NOOP18_m6
    234983U,	// NOOP18_m7
    21991U,	// NOOP18_r4
    21991U,	// NOOP18_r5
    21991U,	// NOOP18_r6
    21991U,	// NOOP18_r7
    283138254U,	// NOOP19rr
    234983U,	// NOOPL
    234983U,	// NOOPL_19
    234983U,	// NOOPL_1d
    234983U,	// NOOPL_1e
    21991U,	// NOOPLr
    449936U,	// NOOPQ
    23952U,	// NOOPQr
    224548U,	// NOOPW
    224548U,	// NOOPW_19
    224548U,	// NOOPW_1c
    224548U,	// NOOPW_1d
    224548U,	// NOOPW_1e
    27940U,	// NOOPWr
    225035U,	// NOT16m
    28427U,	// NOT16r
    235372U,	// NOT32m
    22380U,	// NOT32r
    450491U,	// NOT64m
    24507U,	// NOT64r
    476726U,	// NOT8m
    17974U,	// NOT8r
    2125192U,	// OR16i16
    4238728U,	// OR16mi
    4238728U,	// OR16mi8
    4238728U,	// OR16mr
    6352264U,	// OR16ri
    6352264U,	// OR16ri8
    6368648U,	// OR16rm
    6352264U,	// OR16rr
    8449416U,	// OR16rr_REV
    10507866U,	// OR32i32
    12621402U,	// OR32mi
    12621402U,	// OR32mi8
    12621402U,	// OR32mr
    6346330U,	// OR32ri
    6346330U,	// OR32ri8
    283203162U,	// OR32rm
    6346330U,	// OR32rr
    8443482U,	// OR32rr_REV
    16801361U,	// OR64i32
    18914897U,	// OR64mi32
    18914897U,	// OR64mi8
    18914897U,	// OR64mr
    6348369U,	// OR64ri32
    6348369U,	// OR64ri8
    283221585U,	// OR64rm
    6348369U,	// OR64rr
    8445521U,	// OR64rr_REV
    20989283U,	// OR8i8
    23102819U,	// OR8mi
    23102819U,	// OR8mi8
    23102819U,	// OR8mr
    6341987U,	// OR8ri
    6341987U,	// OR8ri8
    6407523U,	// OR8rm
    6341987U,	// OR8rr
    8439139U,	// OR8rr_REV
    8522954U,	// ORPDrm
    8441034U,	// ORPDrr
    8529411U,	// ORPSrm
    8447491U,	// ORPSrr
    718085U,	// OUT16ir
    16167U,	// OUT16rr
    718148U,	// OUT32ir
    16181U,	// OUT32rr
    717601U,	// OUT8ir
    16153U,	// OUT8rr
    72058343U,	// OUTSB
    72079119U,	// OUTSL
    72117892U,	// OUTSW
    263585U,	// PABSBrm
    551830945U,	// PABSBrr
    265926U,	// PABSDrm
    551833286U,	// PABSDrr
    273886U,	// PABSWrm
    551841246U,	// PABSWrr
    8645504U,	// PACKSSDWrm
    8448896U,	// PACKSSDWrr
    8636087U,	// PACKSSWBrm
    8439479U,	// PACKSSWBrr
    8645515U,	// PACKUSDWrm
    8448907U,	// PACKUSDWrr
    8636098U,	// PACKUSWBrm
    8439490U,	// PACKUSWBrr
    8635371U,	// PADDBrm
    8438763U,	// PADDBrr
    8636349U,	// PADDDrm
    8439741U,	// PADDDrr
    8641112U,	// PADDQrm
    8444504U,	// PADDQrr
    8635835U,	// PADDSBrm
    8439227U,	// PADDSBrr
    8646168U,	// PADDSWrm
    8449560U,	// PADDSWrr
    8635897U,	// PADDUSBrm
    8439289U,	// PADDUSBrr
    8646294U,	// PADDUSWrm
    8449686U,	// PADDUSWrr
    8645425U,	// PADDWrm
    8448817U,	// PADDWrr
    593879326U,	// PALIGNRrmi
    1088823582U,	// PALIGNRrri
    8640595U,	// PANDNrm
    8443987U,	// PANDNrr
    8636630U,	// PANDrm
    8440022U,	// PANDrr
    15087U,	// PAUSE
    8635459U,	// PAVGBrm
    8438851U,	// PAVGBrr
    551650818U,	// PAVGUSBrm
    8439298U,	// PAVGUSBrr
    8645646U,	// PAVGWrm
    8449038U,	// PAVGWrr
    8647060U,	// PBLENDVBrm0
    8450452U,	// PBLENDVBrr0
    593881965U,	// PBLENDWrmi
    1088826221U,	// PBLENDWrri
    593877770U,	// PCLMULQDQrm
    1088822026U,	// PCLMULQDQrr
    8635654U,	// PCMPEQBrm
    8439046U,	// PCMPEQBrr
    8637796U,	// PCMPEQDrm
    8441188U,	// PCMPEQDrr
    8642020U,	// PCMPEQQrm
    8445412U,	// PCMPEQQrr
    8645945U,	// PCMPEQWrm
    8449337U,	// PCMPEQWrr
    830771933U,	// PCMPESTRIrm
    283431645U,	// PCMPESTRIrr
    830773300U,	// PCMPESTRMrm
    283433012U,	// PCMPESTRMrr
    8635938U,	// PCMPGTBrm
    8439330U,	// PCMPGTBrr
    8638517U,	// PCMPGTDrm
    8441909U,	// PCMPGTDrr
    8642445U,	// PCMPGTQrm
    8445837U,	// PCMPGTQrr
    8646375U,	// PCMPGTWrm
    8449767U,	// PCMPGTWrr
    830771945U,	// PCMPISTRIrm
    283431657U,	// PCMPISTRIrr
    830773312U,	// PCMPISTRMrm
    283433024U,	// PCMPISTRMrr
    15116U,	// PCONFIG
    283203001U,	// PDEP32rm
    811652537U,	// PDEP32rr
    283221368U,	// PDEP64rm
    811654520U,	// PDEP64rr
    283203462U,	// PEXT32rm
    811652998U,	// PEXT32rr
    283222002U,	// PEXT64rm
    811655154U,	// PEXT64rr
    321160593U,	// PEXTRBmr
    283428241U,	// PEXTRBrr
    589598180U,	// PEXTRDmr
    283430372U,	// PEXTRDrr
    858037937U,	// PEXTRQmr
    283434673U,	// PEXTRQrr
    1126477262U,	// PEXTRWmr
    283438542U,	// PEXTRWrr
    283438542U,	// PEXTRWrr_REV
    551913540U,	// PF2IDrm
    551831620U,	// PF2IDrr
    551922754U,	// PF2IWrm
    551840834U,	// PF2IWrr
    551651050U,	// PFACCrm
    8439530U,	// PFACCrr
    551651237U,	// PFADDrm
    8439717U,	// PFADDrr
    551656420U,	// PFCMPEQrm
    8444900U,	// PFCMPEQrr
    551653821U,	// PFCMPGErm
    8442301U,	// PFCMPGErr
    551659814U,	// PFCMPGTrm
    8448294U,	// PFCMPGTrr
    551661540U,	// PFMAXrm
    8450020U,	// PFMAXrr
    551655522U,	// PFMINrm
    8444002U,	// PFMINrr
    551655309U,	// PFMULrm
    8443789U,	// PFMULrr
    551651057U,	// PFNACCrm
    8439537U,	// PFNACCrr
    551651065U,	// PFPNACCrm
    8439545U,	// PFPNACCrr
    551649327U,	// PFRCPIT1rm
    8437807U,	// PFRCPIT1rr
    551649416U,	// PFRCPIT2rm
    8437896U,	// PFRCPIT2rr
    551917709U,	// PFRCPrm
    551835789U,	// PFRCPrr
    551649337U,	// PFRSQIT1rm
    8437817U,	// PFRSQIT1rr
    551922025U,	// PFRSQRTrm
    551840105U,	// PFRSQRTrr
    551657742U,	// PFSUBRrm
    8446222U,	// PFSUBRrr
    551650943U,	// PFSUBrm
    8439423U,	// PFSUBrr
    8636333U,	// PHADDDrm
    8439725U,	// PHADDDrr
    8646158U,	// PHADDSWrm
    8449550U,	// PHADDSWrr
    8645409U,	// PHADDWrm
    8448801U,	// PHADDWrr
    274271U,	// PHMINPOSUWrm
    551841631U,	// PHMINPOSUWrr
    8636287U,	// PHSUBDrm
    8439679U,	// PHSUBDrr
    8646139U,	// PHSUBSWrm
    8449531U,	// PHSUBSWrr
    8645315U,	// PHSUBWrm
    8448707U,	// PHSUBWrr
    551913512U,	// PI2FDrm
    551831592U,	// PI2FDrr
    551922664U,	// PI2FWrm
    551840744U,	// PI2FWrr
    879084926U,	// PINSRBrm
    1088816510U,	// PINSRBrr
    881184209U,	// PINSRDrm
    1088818641U,	// PINSRDrr
    866508426U,	// PINSRQrm
    1088822922U,	// PINSRQrr
    600173993U,	// PINSRWrm
    1088826793U,	// PINSRWrr
    8646127U,	// PMADDUBSWrm
    8449519U,	// PMADDUBSWrr
    8638734U,	// PMADDWDrm
    8442126U,	// PMADDWDrr
    8635923U,	// PMAXSBrm
    8439315U,	// PMAXSBrr
    8638478U,	// PMAXSDrm
    8441870U,	// PMAXSDrr
    8646312U,	// PMAXSWrm
    8449704U,	// PMAXSWrr
    8636039U,	// PMAXUBrm
    8439431U,	// PMAXUBrr
    8638621U,	// PMAXUDrm
    8442013U,	// PMAXUDrr
    8646508U,	// PMAXUWrm
    8449900U,	// PMAXUWrr
    8635851U,	// PMINSBrm
    8439243U,	// PMINSBrr
    8638311U,	// PMINSDrm
    8441703U,	// PMINSDrr
    8646208U,	// PMINSWrm
    8449600U,	// PMINSWrr
    8636014U,	// PMINUBrm
    8439406U,	// PMINUBrr
    8638603U,	// PMINUDrm
    8441995U,	// PMINUDrr
    8646477U,	// PMINUWrm
    8449869U,	// PMINUWrr
    551830607U,	// PMOVMSKBrr
    551896976U,	// PMOVSXBDrm
    551831440U,	// PMOVSXBDrr
    432568U,	// PMOVSXBQrm
    551836088U,	// PMOVSXBQrr
    551922396U,	// PMOVSXBWrm
    551840476U,	// PMOVSXBWrr
    551918498U,	// PMOVSXDQrm
    551836578U,	// PMOVSXDQrr
    551915889U,	// PMOVSXWDrm
    551833969U,	// PMOVSXWDrr
    551903415U,	// PMOVSXWQrm
    551837879U,	// PMOVSXWQrr
    551896987U,	// PMOVZXBDrm
    551831451U,	// PMOVZXBDrr
    432579U,	// PMOVZXBQrm
    551836099U,	// PMOVZXBQrr
    551922407U,	// PMOVZXBWrm
    551840487U,	// PMOVZXBWrr
    551918509U,	// PMOVZXDQrm
    551836589U,	// PMOVZXDQrr
    551915900U,	// PMOVZXWDrm
    551833980U,	// PMOVZXWDrr
    551903426U,	// PMOVZXWQrm
    551837890U,	// PMOVZXWQrr
    8641207U,	// PMULDQrm
    8444599U,	// PMULDQrr
    8646233U,	// PMULHRSWrm
    8449625U,	// PMULHRSWrr
    551660920U,	// PMULHRWrm
    8449400U,	// PMULHRWrr
    8646458U,	// PMULHUWrm
    8449850U,	// PMULHUWrr
    8645683U,	// PMULHWrm
    8449075U,	// PMULHWrr
    8636538U,	// PMULLDrm
    8439930U,	// PMULLDrr
    8645752U,	// PMULLWrm
    8449144U,	// PMULLWrr
    8641432U,	// PMULUDQrm
    8444824U,	// PMULUDQrr
    27946U,	// POP16r
    224554U,	// POP16rmm
    27946U,	// POP16rmr
    21997U,	// POP32r
    234989U,	// POP32rmm
    21997U,	// POP32rmr
    23958U,	// POP64r
    449942U,	// POP64rmm
    23958U,	// POP64rmr
    15953U,	// POPA16
    15182U,	// POPA32
    438001U,	// POPCNT16rm
    551841521U,	// POPCNT16rr
    551901011U,	// POPCNT32rm
    551835475U,	// POPCNT32rr
    551919511U,	// POPCNT64rm
    551837591U,	// POPCNT64rr
    15608U,	// POPDS16
    15589U,	// POPDS32
    15646U,	// POPES16
    15627U,	// POPES32
    15966U,	// POPF16
    15195U,	// POPF32
    15456U,	// POPF64
    15703U,	// POPFS16
    15665U,	// POPFS32
    15684U,	// POPFS64
    15760U,	// POPGS16
    15722U,	// POPGS32
    15741U,	// POPGS64
    15835U,	// POPSS16
    15816U,	// POPSS32
    8642856U,	// PORrm
    8446248U,	// PORrr
    479822U,	// PREFETCH
    475990U,	// PREFETCHNTA
    475137U,	// PREFETCHT0
    475171U,	// PREFETCHT1
    475260U,	// PREFETCHT2
    486429U,	// PREFETCHW
    475203U,	// PREFETCHWT1
    8645224U,	// PSADBWrm
    8448616U,	// PSADBWrr
    8635434U,	// PSHUFBrm
    8438826U,	// PSHUFBrr
    830769200U,	// PSHUFDmi
    283428912U,	// PSHUFDri
    830778409U,	// PSHUFHWmi
    283438121U,	// PSHUFHWri
    830778454U,	// PSHUFLWmi
    283438166U,	// PSHUFLWri
    8635607U,	// PSIGNBrm
    8438999U,	// PSIGNBrr
    8636663U,	// PSIGNDrm
    8440055U,	// PSIGNDrr
    8645862U,	// PSIGNWrm
    8449254U,	// PSIGNWrr
    551869093U,	// PSLLDQri
    551864434U,	// PSLLDri
    8636530U,	// PSLLDrm
    8439922U,	// PSLLDrr
    551869646U,	// PSLLQri
    8641742U,	// PSLLQrm
    8445134U,	// PSLLQrr
    551873648U,	// PSLLWri
    8645744U,	// PSLLWrm
    8449136U,	// PSLLWrr
    551864162U,	// PSRADri
    8636258U,	// PSRADrm
    8439650U,	// PSRADrr
    551873094U,	// PSRAWri
    8645190U,	// PSRAWrm
    8448582U,	// PSRAWrr
    551869102U,	// PSRLDQri
    551864459U,	// PSRLDri
    8636555U,	// PSRLDrm
    8439947U,	// PSRLDrr
    551869671U,	// PSRLQri
    8641767U,	// PSRLQrm
    8445159U,	// PSRLQrr
    551873671U,	// PSRLWri
    8645767U,	// PSRLWrm
    8449159U,	// PSRLWrr
    8635322U,	// PSUBBrm
    8438714U,	// PSUBBrr
    8636296U,	// PSUBDrm
    8439688U,	// PSUBDrr
    8640936U,	// PSUBQrm
    8444328U,	// PSUBQrr
    8635826U,	// PSUBSBrm
    8439218U,	// PSUBSBrr
    8646149U,	// PSUBSWrm
    8449541U,	// PSUBSWrr
    8635887U,	// PSUBUSBrm
    8439279U,	// PSUBUSBrr
    8646284U,	// PSUBUSWrm
    8449676U,	// PSUBUSWrr
    8645324U,	// PSUBWrm
    8448716U,	// PSUBWrr
    551914155U,	// PSWAPDrm
    551832235U,	// PSWAPDrr
    665997U,	// PTESTrm
    551840141U,	// PTESTrr
    449571U,	// PTWRITE64m
    23587U,	// PTWRITE64r
    234662U,	// PTWRITEm
    21670U,	// PTWRITEr
    8645262U,	// PUNPCKHBWrm
    8448654U,	// PUNPCKHBWrr
    8641146U,	// PUNPCKHDQrm
    8444538U,	// PUNPCKHDQrr
    8641264U,	// PUNPCKHQDQrm
    8444656U,	// PUNPCKHQDQrr
    8638744U,	// PUNPCKHWDrm
    8442136U,	// PUNPCKHWDrr
    8645284U,	// PUNPCKLBWrm
    8448676U,	// PUNPCKLBWrr
    8641177U,	// PUNPCKLDQrm
    8444569U,	// PUNPCKLDQrr
    8641277U,	// PUNPCKLQDQrm
    8444669U,	// PUNPCKLQDQrr
    8638766U,	// PUNPCKLWDrm
    8442158U,	// PUNPCKLWDrr
    27707U,	// PUSH16i8
    27707U,	// PUSH16r
    224315U,	// PUSH16rmm
    27707U,	// PUSH16rmr
    21718U,	// PUSH32i8
    21718U,	// PUSH32r
    234710U,	// PUSH32rmm
    21718U,	// PUSH32rmr
    23647U,	// PUSH64i32
    23647U,	// PUSH64i8
    23647U,	// PUSH64r
    449631U,	// PUSH64rmm
    23647U,	// PUSH64rmr
    15946U,	// PUSHA16
    15175U,	// PUSHA32
    15569U,	// PUSHCS16
    15559U,	// PUSHCS32
    15598U,	// PUSHDS16
    15579U,	// PUSHDS32
    15636U,	// PUSHES16
    15617U,	// PUSHES32
    15959U,	// PUSHF16
    15188U,	// PUSHF32
    15449U,	// PUSHF64
    15693U,	// PUSHFS16
    15655U,	// PUSHFS32
    15674U,	// PUSHFS64
    15750U,	// PUSHGS16
    15712U,	// PUSHGS32
    15731U,	// PUSHGS64
    15825U,	// PUSHSS16
    15806U,	// PUSHSS32
    27707U,	// PUSHi16
    21718U,	// PUSHi32
    8642889U,	// PXORrm
    8446281U,	// PXORrr
    224335U,	// RCL16m1
    226450U,	// RCL16mCL
    1089399887U,	// RCL16mi
    29377U,	// RCL16r1
    29842U,	// RCL16rCL
    551873615U,	// RCL16ri
    234783U,	// RCL32m1
    242610U,	// RCL32mCL
    552523039U,	// RCL32mi
    29217U,	// RCL32r1
    29618U,	// RCL32rCL
    551867679U,	// RCL32ri
    449700U,	// RCL64m1
    455714U,	// RCL64mCL
    820960420U,	// RCL64mi
    29297U,	// RCL64r1
    29730U,	// RCL64rCL
    551869604U,	// RCL64ri
    476255U,	// RCL8m1
    488258U,	// RCL8mCL
    284083295U,	// RCL8mi
    29137U,	// RCL8r1
    29506U,	// RCL8rCL
    551863391U,	// RCL8ri
    664970U,	// RCPPSm
    551839114U,	// RCPPSr
    552200321U,	// RCPSSm
    551725185U,	// RCPSSm_Int
    551839873U,	// RCPSSr
    8448129U,	// RCPSSr_Int
    226025U,	// RCR16m1
    226494U,	// RCR16mCL
    1089400172U,	// RCR16mi
    29417U,	// RCR16r1
    29886U,	// RCR16rCL
    551873900U,	// RCR16ri
    242249U,	// RCR32m1
    242654U,	// RCR32mCL
    552523341U,	// RCR32mi
    29257U,	// RCR32r1
    29662U,	// RCR32rCL
    551867981U,	// RCR32ri
    455321U,	// RCR64m1
    455758U,	// RCR64mCL
    820960836U,	// RCR64mi
    29337U,	// RCR64r1
    29774U,	// RCR64rCL
    551870020U,	// RCR64ri
    487929U,	// RCR8m1
    488302U,	// RCR8mCL
    284083542U,	// RCR8mi
    29177U,	// RCR8r1
    29550U,	// RCR8rCL
    551863638U,	// RCR8ri
    21616U,	// RDFSBASE
    23533U,	// RDFSBASE64
    21638U,	// RDGSBASE
    23555U,	// RDGSBASE64
    15524U,	// RDMSR
    18516U,	// RDPID32
    18516U,	// RDPID64
    15912U,	// RDPKRUr
    14944U,	// RDPMC
    27491U,	// RDRAND16r
    21530U,	// RDRAND32r
    23257U,	// RDRAND64r
    27455U,	// RDSEED16r
    21501U,	// RDSEED32r
    23152U,	// RDSEED64r
    19693U,	// RDSSPD
    23973U,	// RDSSPQ
    14957U,	// RDTSC
    15352U,	// RDTSCP
    15056U,	// REPNE_PREFIX
    15359U,	// REP_PREFIX
    22343U,	// RETIL
    24454U,	// RETIQ
    28384U,	// RETIW
    15248U,	// RETL
    15463U,	// RETQ
    15978U,	// RETW
    14784U,	// REX64_PREFIX
    224384U,	// ROL16m1
    226472U,	// ROL16mCL
    1089399936U,	// ROL16mi
    29397U,	// ROL16r1
    29864U,	// ROL16rCL
    551873664U,	// ROL16ri
    234831U,	// ROL32m1
    242632U,	// ROL32mCL
    552523087U,	// ROL32mi
    29237U,	// ROL32r1
    29640U,	// ROL32rCL
    551867727U,	// ROL32ri
    449760U,	// ROL64m1
    455736U,	// ROL64mCL
    820960480U,	// ROL64mi
    29317U,	// ROL64r1
    29752U,	// ROL64rCL
    551869664U,	// ROL64ri
    476269U,	// ROL8m1
    488280U,	// ROL8mCL
    284083309U,	// ROL8mi
    29157U,	// ROL8r1
    29528U,	// ROL8rCL
    551863405U,	// ROL8ri
    224661U,	// ROR16m1
    226516U,	// ROR16mCL
    1089400213U,	// ROR16mi
    29437U,	// ROR16r1
    29908U,	// ROR16rCL
    551873941U,	// ROR16ri
    235097U,	// ROR32m1
    242676U,	// ROR32mCL
    552523353U,	// ROR32mi
    29277U,	// ROR32r1
    29684U,	// ROR32rCL
    551867993U,	// ROR32ri
    450151U,	// ROR64m1
    455780U,	// ROR64mCL
    820960871U,	// ROR64mi
    29357U,	// ROR64r1
    29796U,	// ROR64rCL
    551870055U,	// ROR64ri
    476528U,	// ROR8m1
    488324U,	// ROR8mCL
    284083568U,	// ROR8mi
    29197U,	// ROR8r1
    29572U,	// ROR8rCL
    551863664U,	// ROR8ri
    832870378U,	// RORX32mi
    283432938U,	// RORX32ri
    834969854U,	// RORX64mi
    283435262U,	// RORX64ri
    77892480U,	// ROUNDPDm
    283429760U,	// ROUNDPDr
    77898900U,	// ROUNDPSm
    283436180U,	// ROUNDPSr
    885296904U,	// ROUNDSDm
    851824392U,	// ROUNDSDm_Int
    283430664U,	// ROUNDSDr
    1088818952U,	// ROUNDSDr_Int
    887400474U,	// ROUNDSSm
    856025114U,	// ROUNDSSm_Int
    283437082U,	// ROUNDSSr
    1088825370U,	// ROUNDSSr_Int
    15313U,	// RSM
    665176U,	// RSQRTPSm
    551839320U,	// RSQRTPSr
    552200381U,	// RSQRTSSm
    551725245U,	// RSQRTSSm_Int
    551839933U,	// RSQRTSSr
    8448189U,	// RSQRTSSr_Int
    235753U,	// RSTORSSP
    15111U,	// SAHF
    224329U,	// SAL16m1
    226439U,	// SAL16mCL
    4238409U,	// SAL16mi
    29367U,	// SAL16r1
    29831U,	// SAL16rCL
    8449097U,	// SAL16ri
    234777U,	// SAL32m1
    242599U,	// SAL32mCL
    12621081U,	// SAL32mi
    29207U,	// SAL32r1
    29607U,	// SAL32rCL
    8443161U,	// SAL32ri
    449694U,	// SAL64m1
    455703U,	// SAL64mCL
    18914462U,	// SAL64mi
    29287U,	// SAL64r1
    29719U,	// SAL64rCL
    8445086U,	// SAL64ri
    476249U,	// SAL8m1
    488247U,	// SAL8mCL
    23102553U,	// SAL8mi
    29127U,	// SAL8r1
    29495U,	// SAL8rCL
    8438873U,	// SAL8ri
    14931U,	// SALC
    224614U,	// SAR16m1
    226483U,	// SAR16mCL
    1089400166U,	// SAR16mi
    29407U,	// SAR16r1
    29875U,	// SAR16rCL
    551873894U,	// SAR16ri
    235062U,	// SAR32m1
    242643U,	// SAR32mCL
    552523318U,	// SAR32mi
    29247U,	// SAR32r1
    29651U,	// SAR32rCL
    551867958U,	// SAR32ri
    450110U,	// SAR64m1
    455747U,	// SAR64mCL
    820960830U,	// SAR64mi
    29327U,	// SAR64r1
    29763U,	// SAR64rCL
    551870014U,	// SAR64ri
    476496U,	// SAR8m1
    488291U,	// SAR8mCL
    284083536U,	// SAR8mi
    29167U,	// SAR8r1
    29539U,	// SAR8rCL
    551863632U,	// SAR8ri
    832903132U,	// SARX32rm
    811653084U,	// SARX32rr
    835002608U,	// SARX64rm
    811655408U,	// SARX64rr
    15421U,	// SAVEPREVSSP
    2124373U,	// SBB16i16
    4237909U,	// SBB16mi
    4237909U,	// SBB16mi8
    4237909U,	// SBB16mr
    6351445U,	// SBB16ri
    6351445U,	// SBB16ri8
    6367829U,	// SBB16rm
    6351445U,	// SBB16rr
    8448597U,	// SBB16rr_REV
    10507129U,	// SBB32i32
    12620665U,	// SBB32mi
    12620665U,	// SBB32mi8
    12620665U,	// SBB32mr
    6345593U,	// SBB32ri
    6345593U,	// SBB32ri8
    283202425U,	// SBB32rm
    6345593U,	// SBB32rr
    8442745U,	// SBB32rr_REV
    16800132U,	// SBB64i32
    18913668U,	// SBB64mi32
    18913668U,	// SBB64mi8
    18913668U,	// SBB64mr
    6347140U,	// SBB64ri32
    6347140U,	// SBB64ri8
    283220356U,	// SBB64rm
    6347140U,	// SBB64rr
    8444292U,	// SBB64rr_REV
    20988851U,	// SBB8i8
    23102387U,	// SBB8mi
    23102387U,	// SBB8mi8
    23102387U,	// SBB8mr
    6341555U,	// SBB8ri
    6341555U,	// SBB8ri8
    6407091U,	// SBB8rm
    6341555U,	// SBB8rr
    8438707U,	// SBB8rr_REV
    21513625U,	// SCASB
    11048599U,	// SCASL
    17358521U,	// SCASQ
    2698710U,	// SCASW
    479627U,	// SETAEm
    20875U,	// SETAEr
    475984U,	// SETAm
    17232U,	// SETAr
    479649U,	// SETBEm
    20897U,	// SETBEr
    476699U,	// SETBm
    17947U,	// SETBr
    479753U,	// SETEm
    21001U,	// SETEr
    479686U,	// SETGEm
    20934U,	// SETGEr
    479816U,	// SETGm
    21064U,	// SETGr
    479702U,	// SETLEm
    20950U,	// SETLEr
    481101U,	// SETLm
    22349U,	// SETLr
    479722U,	// SETNEm
    20970U,	// SETNEr
    481401U,	// SETNOm
    22649U,	// SETNOr
    481479U,	// SETNPm
    22727U,	// SETNPr
    483833U,	// SETNSm
    25081U,	// SETNSr
    481408U,	// SETOm
    22656U,	// SETOr
    481523U,	// SETPm
    22771U,	// SETPr
    16219U,	// SETSSBSY
    485630U,	// SETSm
    26878U,	// SETSr
    15033U,	// SFENCE
    683708U,	// SGDT16m
    677674U,	// SGDT32m
    679785U,	// SGDT64m
    8634381U,	// SHA1MSG1rm
    8437773U,	// SHA1MSG1rr
    8634470U,	// SHA1MSG2rm
    8437862U,	// SHA1MSG2rr
    8639001U,	// SHA1NEXTErm
    8442393U,	// SHA1NEXTErr
    593871230U,	// SHA1RNDS4rmi
    1088815486U,	// SHA1RNDS4rri
    8634391U,	// SHA256MSG1rm
    8437783U,	// SHA256MSG1rr
    8634480U,	// SHA256MSG2rm
    8437872U,	// SHA256MSG2rr
    8647040U,	// SHA256RNDS2rm
    8450432U,	// SHA256RNDS2rr
    224353U,	// SHL16m1
    226461U,	// SHL16mCL
    1089399905U,	// SHL16mi
    29387U,	// SHL16r1
    29853U,	// SHL16rCL
    551873633U,	// SHL16ri
    234797U,	// SHL32m1
    242621U,	// SHL32mCL
    552523053U,	// SHL32mi
    29227U,	// SHL32r1
    29629U,	// SHL32rCL
    551867693U,	// SHL32ri
    449708U,	// SHL64m1
    455725U,	// SHL64mCL
    820960428U,	// SHL64mi
    29307U,	// SHL64r1
    29741U,	// SHL64rCL
    551869612U,	// SHL64ri
    476263U,	// SHL8m1
    488269U,	// SHL8mCL
    284083303U,	// SHL8mi
    29147U,	// SHL8r1
    29517U,	// SHL8rCL
    551863399U,	// SHL8ri
    4240495U,	// SHLD16mrCL
    1126476618U,	// SHLD16mri8
    8451183U,	// SHLD16rrCL
    1088826186U,	// SHLD16rri8
    12628879U,	// SHLD32mrCL
    589599756U,	// SHLD32mri8
    8450959U,	// SHLD32rrCL
    1088820236U,	// SHLD32rri8
    18920447U,	// SHLD64mrCL
    858036881U,	// SHLD64mri8
    8451071U,	// SHLD64rrCL
    1088821905U,	// SHLD64rri8
    832903111U,	// SHLX32rm
    811653063U,	// SHLX32rr
    835002587U,	// SHLX64rm
    811655387U,	// SHLX64rr
    224641U,	// SHR16m1
    226505U,	// SHR16mCL
    1089400193U,	// SHR16mi
    29427U,	// SHR16r1
    29897U,	// SHR16rCL
    551873921U,	// SHR16ri
    235091U,	// SHR32m1
    242665U,	// SHR32mCL
    552523347U,	// SHR32mi
    29267U,	// SHR32r1
    29673U,	// SHR32rCL
    551867987U,	// SHR32ri
    450122U,	// SHR64m1
    455769U,	// SHR64mCL
    820960842U,	// SHR64mi
    29347U,	// SHR64r1
    29785U,	// SHR64rCL
    551870026U,	// SHR64ri
    476508U,	// SHR8m1
    488313U,	// SHR8mCL
    284083548U,	// SHR8mi
    29187U,	// SHR8r1
    29561U,	// SHR8rCL
    551863644U,	// SHR8ri
    4240507U,	// SHRD16mrCL
    1126476664U,	// SHRD16mri8
    8451195U,	// SHRD16rrCL
    1088826232U,	// SHRD16rri8
    12628891U,	// SHRD32mrCL
    589599779U,	// SHRD32mri8
    8450971U,	// SHRD32rrCL
    1088820259U,	// SHRD32rri8
    18920459U,	// SHRD64mrCL
    858037040U,	// SHRD64mri8
    8451083U,	// SHRD64rrCL
    1088822064U,	// SHRD64rri8
    832903139U,	// SHRX32rm
    811653091U,	// SHRX32rr
    835002615U,	// SHRX64rm
    811655415U,	// SHRX64rr
    568708048U,	// SHUFPDrmi
    1088818128U,	// SHUFPDrri
    568714468U,	// SHUFPSrmi
    1088824548U,	// SHUFPSrri
    683722U,	// SIDT16m
    677688U,	// SIDT32m
    679799U,	// SIDT64m
    15330U,	// SIN_F
    0U,	// SIN_Fp32
    0U,	// SIN_Fp64
    0U,	// SIN_Fp80
    16054U,	// SKINIT
    224984U,	// SLDT16m
    28376U,	// SLDT16r
    22335U,	// SLDT32r
    24446U,	// SLDT64r
    17371U,	// SLWPCB
    17371U,	// SLWPCB64
    225218U,	// SMSW16m
    28610U,	// SMSW16r
    22441U,	// SMSW32r
    24732U,	// SMSW64r
    658713U,	// SQRTPDm
    551832857U,	// SQRTPDr
    665177U,	// SQRTPSm
    551839321U,	// SQRTPSr
    552177629U,	// SQRTSDm
    551702493U,	// SQRTSDm_Int
    551833565U,	// SQRTSDr
    8441821U,	// SQRTSDr_Int
    552200382U,	// SQRTSSm
    551725246U,	// SQRTSSm_Int
    551839934U,	// SQRTSSr
    8448190U,	// SQRTSSr_Int
    15889U,	// SQRT_F
    0U,	// SQRT_Fp32
    0U,	// SQRT_Fp64
    0U,	// SQRT_Fp80
    14909U,	// STAC
    14963U,	// STC
    14987U,	// STD
    15138U,	// STGI
    15153U,	// STI
    237920U,	// STMXCSR
    553749U,	// STOSB
    570679U,	// STOSL
    587128U,	// STOSQ
    603385U,	// STOSW
    28103U,	// STR16r
    22136U,	// STR32r
    24226U,	// STR64r
    224711U,	// STRm
    190724U,	// ST_F32m
    202617U,	// ST_F64m
    190067U,	// ST_FP32m
    202233U,	// ST_FP64m
    698714U,	// ST_FP80m
    22777U,	// ST_FPrr
    0U,	// ST_Fp32m
    0U,	// ST_Fp64m
    0U,	// ST_Fp64m32
    0U,	// ST_Fp80m32
    0U,	// ST_Fp80m64
    0U,	// ST_FpP32m
    0U,	// ST_FpP64m
    0U,	// ST_FpP64m32
    0U,	// ST_FpP80m
    0U,	// ST_FpP80m32
    0U,	// ST_FpP80m64
    27028U,	// ST_Frr
    2124485U,	// SUB16i16
    4238021U,	// SUB16mi
    4238021U,	// SUB16mi8
    4238021U,	// SUB16mr
    6351557U,	// SUB16ri
    6351557U,	// SUB16ri8
    6367941U,	// SUB16rm
    6351557U,	// SUB16rr
    8448709U,	// SUB16rr_REV
    10507144U,	// SUB32i32
    12620680U,	// SUB32mi
    12620680U,	// SUB32mi8
    12620680U,	// SUB32mr
    6345608U,	// SUB32ri
    6345608U,	// SUB32ri8
    283202440U,	// SUB32rm
    6345608U,	// SUB32rr
    8442760U,	// SUB32rr_REV
    16800169U,	// SUB64i32
    18913705U,	// SUB64mi32
    18913705U,	// SUB64mi8
    18913705U,	// SUB64mr
    6347177U,	// SUB64ri32
    6347177U,	// SUB64ri8
    283220393U,	// SUB64rm
    6347177U,	// SUB64rr
    8444329U,	// SUB64rr_REV
    20988859U,	// SUB8i8
    23102395U,	// SUB8mi
    23102395U,	// SUB8mi8
    23102395U,	// SUB8mr
    6341563U,	// SUB8ri
    6341563U,	// SUB8ri8
    6407099U,	// SUB8rm
    6341563U,	// SUB8rr
    8438715U,	// SUB8rr_REV
    8522425U,	// SUBPDrm
    8440505U,	// SUBPDrr
    8528822U,	// SUBPSrm
    8446902U,	// SUBPSrr
    190148U,	// SUBR_F32m
    202300U,	// SUBR_F64m
    222924U,	// SUBR_FI16m
    235076U,	// SUBR_FI32m
    22662U,	// SUBR_FPrST0
    24847U,	// SUBR_FST0r
    0U,	// SUBR_Fp32m
    0U,	// SUBR_Fp64m
    0U,	// SUBR_Fp64m32
    0U,	// SUBR_Fp80m32
    0U,	// SUBR_Fp80m64
    0U,	// SUBR_FpI16m32
    0U,	// SUBR_FpI16m64
    0U,	// SUBR_FpI16m80
    0U,	// SUBR_FpI32m32
    0U,	// SUBR_FpI32m64
    0U,	// SUBR_FpI32m80
    28953U,	// SUBR_FrST0
    551702224U,	// SUBSDrm
    551702224U,	// SUBSDrm_Int
    8441552U,	// SUBSDrr
    8441552U,	// SUBSDrr_Int
    551725003U,	// SUBSSrm
    551725003U,	// SUBSSrm_Int
    8447947U,	// SUBSSrr
    8447947U,	// SUBSSrr_Int
    188784U,	// SUB_F32m
    201607U,	// SUB_F64m
    221559U,	// SUB_FI16m
    234382U,	// SUB_FI32m
    22745U,	// SUB_FPrST0
    18048U,	// SUB_FST0r
    0U,	// SUB_Fp32
    0U,	// SUB_Fp32m
    0U,	// SUB_Fp64
    0U,	// SUB_Fp64m
    0U,	// SUB_Fp64m32
    0U,	// SUB_Fp80
    0U,	// SUB_Fp80m32
    0U,	// SUB_Fp80m64
    0U,	// SUB_FpI16m32
    0U,	// SUB_FpI16m64
    0U,	// SUB_FpI16m80
    0U,	// SUB_FpI32m32
    0U,	// SUB_FpI32m64
    0U,	// SUB_FpI32m80
    29012U,	// SUB_FrST0
    15769U,	// SWAPGS
    15230U,	// SYSCALL
    15507U,	// SYSENTER
    15267U,	// SYSEXIT
    15482U,	// SYSEXIT64
    15259U,	// SYSRET
    15474U,	// SYSRET64
    551900105U,	// T1MSKC32rm
    551834569U,	// T1MSKC32rr
    551918065U,	// T1MSKC64rm
    551836145U,	// T1MSKC64rr
    2125608U,	// TEST16i16
    4239144U,	// TEST16mi
    4239144U,	// TEST16mi_alt
    4239144U,	// TEST16mr
    551841576U,	// TEST16ri
    551841576U,	// TEST16ri_alt
    551841576U,	// TEST16rr
    10508146U,	// TEST32i32
    12621682U,	// TEST32mi
    12621682U,	// TEST32mi_alt
    12621682U,	// TEST32mr
    551835506U,	// TEST32ri
    551835506U,	// TEST32ri_alt
    551835506U,	// TEST32rr
    16801761U,	// TEST64i32
    18915297U,	// TEST64mi32
    18915297U,	// TEST64mi32_alt
    18915297U,	// TEST64mr
    551837665U,	// TEST64ri32
    551837665U,	// TEST64ri32_alt
    551837665U,	// TEST64rr
    20989523U,	// TEST8i8
    23103059U,	// TEST8mi
    23103059U,	// TEST8mi_alt
    23103059U,	// TEST8mr
    551831123U,	// TEST8ri
    551831123U,	// TEST8ri_alt
    551831123U,	// TEST8rr
    20993U,	// TPAUSE
    15901U,	// TST_F
    0U,	// TST_Fp32
    0U,	// TST_Fp64
    0U,	// TST_Fp80
    438018U,	// TZCNT16rm
    551841538U,	// TZCNT16rr
    551901028U,	// TZCNT32rm
    551835492U,	// TZCNT32rr
    551919530U,	// TZCNT64rm
    551837610U,	// TZCNT64rr
    551900433U,	// TZMSK32rm
    551834897U,	// TZMSK32rr
    551918742U,	// TZMSK64rm
    551836822U,	// TZMSK64rr
    552177471U,	// UCOMISDrm
    552177471U,	// UCOMISDrm_Int
    551833407U,	// UCOMISDrr
    551833407U,	// UCOMISDrr_Int
    552200273U,	// UCOMISSrm
    552200273U,	// UCOMISSrm_Int
    551839825U,	// UCOMISSrr
    551839825U,	// UCOMISSrr_Int
    21194U,	// UCOM_FIPr
    21136U,	// UCOM_FIr
    15413U,	// UCOM_FPPr
    22714U,	// UCOM_FPr
    0U,	// UCOM_FpIr32
    0U,	// UCOM_FpIr64
    0U,	// UCOM_FpIr80
    0U,	// UCOM_Fpr32
    0U,	// UCOM_Fpr64
    0U,	// UCOM_Fpr80
    22564U,	// UCOM_Fr
    14700U,	// UD0
    14715U,	// UD1
    14753U,	// UD2
    24877U,	// UMONITOR16
    24877U,	// UMONITOR32
    24877U,	// UMONITOR64
    26927U,	// UMWAIT
    8522713U,	// UNPCKHPDrm
    8440793U,	// UNPCKHPDrr
    8529133U,	// UNPCKHPSrm
    8447213U,	// UNPCKHPSrr
    8522755U,	// UNPCKLPDrm
    8440835U,	// UNPCKLPDrr
    8529195U,	// UNPCKLPSrm
    8447275U,	// UNPCKLPSrr
    890184770U,	// V4FMADDPSrm
    86991938U,	// V4FMADDPSrmk
    89089090U,	// V4FMADDPSrmkz
    890185701U,	// V4FMADDSSrm
    86992869U,	// V4FMADDSSrmk
    89090021U,	// V4FMADDSSrmkz
    890184791U,	// V4FNMADDPSrm
    86991959U,	// V4FNMADDPSrmk
    89089111U,	// V4FNMADDPSrmkz
    890185722U,	// V4FNMADDSSrm
    86992890U,	// V4FNMADDSSrmk
    89090042U,	// V4FNMADDSSrmkz
    812616538U,	// VADDPDYrm
    811649882U,	// VADDPDYrr
    811731802U,	// VADDPDZ128rm
    358763354U,	// VADDPDZ128rmb
    1433389914U,	// VADDPDZ128rmbk
    1164970842U,	// VADDPDZ128rmbkz
    86985562U,	// VADDPDZ128rmk
    890178394U,	// VADDPDZ128rmkz
    811649882U,	// VADDPDZ128rr
    87051098U,	// VADDPDZ128rrk
    890276698U,	// VADDPDZ128rrkz
    812616538U,	// VADDPDZ256rm
    360860506U,	// VADDPDZ256rmb
    1435487066U,	// VADDPDZ256rmbk
    1167067994U,	// VADDPDZ256rmbkz
    87083866U,	// VADDPDZ256rmk
    890309466U,	// VADDPDZ256rmkz
    811649882U,	// VADDPDZ256rr
    87051098U,	// VADDPDZ256rrk
    890276698U,	// VADDPDZ256rrkz
    812731226U,	// VADDPDZrm
    362957658U,	// VADDPDZrmb
    1437584218U,	// VADDPDZrmbk
    1169165146U,	// VADDPDZrmbkz
    87133018U,	// VADDPDZrmk
    890358618U,	// VADDPDZrmkz
    811649882U,	// VADDPDZrr
    812780378U,	// VADDPDZrrb
    87182170U,	// VADDPDZrrbk
    890407770U,	// VADDPDZrrbkz
    87051098U,	// VADDPDZrrk
    890276698U,	// VADDPDZrrkz
    811731802U,	// VADDPDrm
    811649882U,	// VADDPDrr
    812622958U,	// VADDPSYrm
    811656302U,	// VADDPSYrr
    811738222U,	// VADDPSZ128rm
    360883310U,	// VADDPSZ128rmb
    1435690094U,	// VADDPSZ128rmbk
    1167271022U,	// VADDPSZ128rmbkz
    86991982U,	// VADDPSZ128rmk
    890184814U,	// VADDPSZ128rmkz
    811656302U,	// VADDPSZ128rr
    87057518U,	// VADDPSZ128rrk
    890283118U,	// VADDPSZ128rrkz
    812622958U,	// VADDPSZ256rm
    362980462U,	// VADDPSZ256rmb
    1437787246U,	// VADDPSZ256rmbk
    1169368174U,	// VADDPSZ256rmbkz
    87090286U,	// VADDPSZ256rmk
    890315886U,	// VADDPSZ256rmkz
    811656302U,	// VADDPSZ256rr
    87057518U,	// VADDPSZ256rrk
    890283118U,	// VADDPSZ256rrkz
    812737646U,	// VADDPSZrm
    365077614U,	// VADDPSZrmb
    1439884398U,	// VADDPSZrmbk
    1171465326U,	// VADDPSZrmbkz
    87139438U,	// VADDPSZrmk
    890365038U,	// VADDPSZrmkz
    811656302U,	// VADDPSZrr
    812786798U,	// VADDPSZrrb
    87188590U,	// VADDPSZrrbk
    890414190U,	// VADDPSZrrbkz
    87057518U,	// VADDPSZrrk
    890283118U,	// VADDPSZrrkz
    811738222U,	// VADDPSrm
    811656302U,	// VADDPSrr
    283266815U,	// VADDSDZrm
    283266815U,	// VADDSDZrm_Int
    1357893375U,	// VADDSDZrm_Intk
    1089474303U,	// VADDSDZrm_Intkz
    811650815U,	// VADDSDZrr
    811650815U,	// VADDSDZrr_Int
    87052031U,	// VADDSDZrr_Intk
    890277631U,	// VADDSDZrr_Intkz
    812781311U,	// VADDSDZrrb_Int
    87183103U,	// VADDSDZrrb_Intk
    890408703U,	// VADDSDZrrb_Intkz
    283266815U,	// VADDSDrm
    283266815U,	// VADDSDrm_Int
    811650815U,	// VADDSDrr
    811650815U,	// VADDSDrr_Int
    283289617U,	// VADDSSZrm
    283289617U,	// VADDSSZrm_Int
    1358096401U,	// VADDSSZrm_Intk
    1089677329U,	// VADDSSZrm_Intkz
    811657233U,	// VADDSSZrr
    811657233U,	// VADDSSZrr_Int
    87058449U,	// VADDSSZrr_Intk
    890284049U,	// VADDSSZrr_Intkz
    812787729U,	// VADDSSZrrb_Int
    87189521U,	// VADDSSZrrb_Intk
    890415121U,	// VADDSSZrrb_Intkz
    283289617U,	// VADDSSrm
    283289617U,	// VADDSSrm_Int
    811657233U,	// VADDSSrr
    811657233U,	// VADDSSrr_Int
    812616384U,	// VADDSUBPDYrm
    811649728U,	// VADDSUBPDYrr
    811731648U,	// VADDSUBPDrm
    811649728U,	// VADDSUBPDrr
    812622781U,	// VADDSUBPSYrm
    811656125U,	// VADDSUBPSYrr
    811738045U,	// VADDSUBPSrm
    811656125U,	// VADDSUBPSrr
    812870002U,	// VAESDECLASTYrm
    811657586U,	// VAESDECLASTYrr
    811854194U,	// VAESDECLASTZ128rm
    811657586U,	// VAESDECLASTZ128rr
    812870002U,	// VAESDECLASTZ256rm
    811657586U,	// VAESDECLASTZ256rr
    812886386U,	// VAESDECLASTZrm
    811657586U,	// VAESDECLASTZrr
    811854194U,	// VAESDECLASTrm
    811657586U,	// VAESDECLASTrr
    812861186U,	// VAESDECYrm
    811648770U,	// VAESDECYrr
    811845378U,	// VAESDECZ128rm
    811648770U,	// VAESDECZ128rr
    812861186U,	// VAESDECZ256rm
    811648770U,	// VAESDECZ256rr
    812877570U,	// VAESDECZrm
    811648770U,	// VAESDECZrr
    811845378U,	// VAESDECrm
    811648770U,	// VAESDECrr
    812870015U,	// VAESENCLASTYrm
    811657599U,	// VAESENCLASTYrr
    811854207U,	// VAESENCLASTZ128rm
    811657599U,	// VAESENCLASTZ128rr
    812870015U,	// VAESENCLASTZ256rm
    811657599U,	// VAESENCLASTZ256rr
    812886399U,	// VAESENCLASTZrm
    811657599U,	// VAESENCLASTZrr
    811854207U,	// VAESENCLASTrm
    811657599U,	// VAESENCLASTrr
    812861212U,	// VAESENCYrm
    811648796U,	// VAESENCYrr
    811845404U,	// VAESENCZ128rm
    811648796U,	// VAESENCZ128rr
    812861212U,	// VAESENCZ256rm
    811648796U,	// VAESENCZ256rr
    812877596U,	// VAESENCZrm
    811648796U,	// VAESENCZrr
    811845404U,	// VAESENCrm
    811648796U,	// VAESENCrr
    263955U,	// VAESIMCrm
    551831315U,	// VAESIMCrr
    830777753U,	// VAESKEYGENASSIST128rm
    283437465U,	// VAESKEYGENASSIST128rr
    1686489325U,	// VALIGNDZ128rmbi
    1710475501U,	// VALIGNDZ128rmbik
    1712589037U,	// VALIGNDZ128rmbikz
    325437677U,	// VALIGNDZ128rmi
    1983105261U,	// VALIGNDZ128rmik
    1179912429U,	// VALIGNDZ128rmikz
    1088817389U,	// VALIGNDZ128rri
    2163132653U,	// VALIGNDZ128rrik
    1357580525U,	// VALIGNDZ128rrikz
    2491795693U,	// VALIGNDZ256rmbi
    2515781869U,	// VALIGNDZ256rmbik
    2517895405U,	// VALIGNDZ256rmbikz
    375769325U,	// VALIGNDZ256rmi
    1989396717U,	// VALIGNDZ256rmik
    1186203885U,	// VALIGNDZ256rmikz
    1088817389U,	// VALIGNDZ256rri
    2163132653U,	// VALIGNDZ256rrik
    1357580525U,	// VALIGNDZ256rrikz
    2760231149U,	// VALIGNDZrmbi
    2784217325U,	// VALIGNDZrmbik
    2786330861U,	// VALIGNDZrmbikz
    382060781U,	// VALIGNDZrmi
    1995688173U,	// VALIGNDZrmik
    1192495341U,	// VALIGNDZrmikz
    1088817389U,	// VALIGNDZrri
    2163132653U,	// VALIGNDZrrik
    1357580525U,	// VALIGNDZrrikz
    3013991766U,	// VALIGNQZ128rmbi
    3073629526U,	// VALIGNQZ128rmbik
    3075743062U,	// VALIGNQZ128rmbikz
    325442902U,	// VALIGNQZ128rmi
    1983110486U,	// VALIGNQZ128rmik
    1179917654U,	// VALIGNQZ128rmikz
    1088822614U,	// VALIGNQZ128rri
    2163137878U,	// VALIGNQZ128rrik
    1357585750U,	// VALIGNQZ128rrikz
    1671814486U,	// VALIGNQZ256rmbi
    1731452246U,	// VALIGNQZ256rmbik
    1733565782U,	// VALIGNQZ256rmbikz
    375774550U,	// VALIGNQZ256rmi
    1989401942U,	// VALIGNQZ256rmik
    1186209110U,	// VALIGNQZ256rmikz
    1088822614U,	// VALIGNQZ256rri
    2163137878U,	// VALIGNQZ256rrik
    1357585750U,	// VALIGNQZ256rrikz
    2477120854U,	// VALIGNQZrmbi
    2536758614U,	// VALIGNQZrmbik
    2538872150U,	// VALIGNQZrmbikz
    382066006U,	// VALIGNQZrmi
    1995693398U,	// VALIGNQZrmik
    1192500566U,	// VALIGNQZrmikz
    1088822614U,	// VALIGNQZrri
    2163137878U,	// VALIGNQZrrik
    1357585750U,	// VALIGNQZrrikz
    812616775U,	// VANDNPDYrm
    811650119U,	// VANDNPDYrr
    811732039U,	// VANDNPDZ128rm
    358763591U,	// VANDNPDZ128rmb
    1433390151U,	// VANDNPDZ128rmbk
    1164971079U,	// VANDNPDZ128rmbkz
    86985799U,	// VANDNPDZ128rmk
    890178631U,	// VANDNPDZ128rmkz
    811650119U,	// VANDNPDZ128rr
    87051335U,	// VANDNPDZ128rrk
    890276935U,	// VANDNPDZ128rrkz
    812616775U,	// VANDNPDZ256rm
    360860743U,	// VANDNPDZ256rmb
    1435487303U,	// VANDNPDZ256rmbk
    1167068231U,	// VANDNPDZ256rmbkz
    87084103U,	// VANDNPDZ256rmk
    890309703U,	// VANDNPDZ256rmkz
    811650119U,	// VANDNPDZ256rr
    87051335U,	// VANDNPDZ256rrk
    890276935U,	// VANDNPDZ256rrkz
    812731463U,	// VANDNPDZrm
    362957895U,	// VANDNPDZrmb
    1437584455U,	// VANDNPDZrmbk
    1169165383U,	// VANDNPDZrmbkz
    87133255U,	// VANDNPDZrmk
    890358855U,	// VANDNPDZrmkz
    811650119U,	// VANDNPDZrr
    87051335U,	// VANDNPDZrrk
    890276935U,	// VANDNPDZrrkz
    811732039U,	// VANDNPDrm
    811650119U,	// VANDNPDrr
    812623224U,	// VANDNPSYrm
    811656568U,	// VANDNPSYrr
    811738488U,	// VANDNPSZ128rm
    360883576U,	// VANDNPSZ128rmb
    1435690360U,	// VANDNPSZ128rmbk
    1167271288U,	// VANDNPSZ128rmbkz
    86992248U,	// VANDNPSZ128rmk
    890185080U,	// VANDNPSZ128rmkz
    811656568U,	// VANDNPSZ128rr
    87057784U,	// VANDNPSZ128rrk
    890283384U,	// VANDNPSZ128rrkz
    812623224U,	// VANDNPSZ256rm
    362980728U,	// VANDNPSZ256rmb
    1437787512U,	// VANDNPSZ256rmbk
    1169368440U,	// VANDNPSZ256rmbkz
    87090552U,	// VANDNPSZ256rmk
    890316152U,	// VANDNPSZ256rmkz
    811656568U,	// VANDNPSZ256rr
    87057784U,	// VANDNPSZ256rrk
    890283384U,	// VANDNPSZ256rrkz
    812737912U,	// VANDNPSZrm
    365077880U,	// VANDNPSZrmb
    1439884664U,	// VANDNPSZrmbk
    1171465592U,	// VANDNPSZrmbkz
    87139704U,	// VANDNPSZrmk
    890365304U,	// VANDNPSZrmkz
    811656568U,	// VANDNPSZrr
    87057784U,	// VANDNPSZrrk
    890283384U,	// VANDNPSZrrkz
    811738488U,	// VANDNPSrm
    811656568U,	// VANDNPSrr
    812616557U,	// VANDPDYrm
    811649901U,	// VANDPDYrr
    811731821U,	// VANDPDZ128rm
    358763373U,	// VANDPDZ128rmb
    1433389933U,	// VANDPDZ128rmbk
    1164970861U,	// VANDPDZ128rmbkz
    86985581U,	// VANDPDZ128rmk
    890178413U,	// VANDPDZ128rmkz
    811649901U,	// VANDPDZ128rr
    87051117U,	// VANDPDZ128rrk
    890276717U,	// VANDPDZ128rrkz
    812616557U,	// VANDPDZ256rm
    360860525U,	// VANDPDZ256rmb
    1435487085U,	// VANDPDZ256rmbk
    1167068013U,	// VANDPDZ256rmbkz
    87083885U,	// VANDPDZ256rmk
    890309485U,	// VANDPDZ256rmkz
    811649901U,	// VANDPDZ256rr
    87051117U,	// VANDPDZ256rrk
    890276717U,	// VANDPDZ256rrkz
    812731245U,	// VANDPDZrm
    362957677U,	// VANDPDZrmb
    1437584237U,	// VANDPDZrmbk
    1169165165U,	// VANDPDZrmbkz
    87133037U,	// VANDPDZrmk
    890358637U,	// VANDPDZrmkz
    811649901U,	// VANDPDZrr
    87051117U,	// VANDPDZrrk
    890276717U,	// VANDPDZrrkz
    811731821U,	// VANDPDrm
    811649901U,	// VANDPDrr
    812622977U,	// VANDPSYrm
    811656321U,	// VANDPSYrr
    811738241U,	// VANDPSZ128rm
    360883329U,	// VANDPSZ128rmb
    1435690113U,	// VANDPSZ128rmbk
    1167271041U,	// VANDPSZ128rmbkz
    86992001U,	// VANDPSZ128rmk
    890184833U,	// VANDPSZ128rmkz
    811656321U,	// VANDPSZ128rr
    87057537U,	// VANDPSZ128rrk
    890283137U,	// VANDPSZ128rrkz
    812622977U,	// VANDPSZ256rm
    362980481U,	// VANDPSZ256rmb
    1437787265U,	// VANDPSZ256rmbk
    1169368193U,	// VANDPSZ256rmbkz
    87090305U,	// VANDPSZ256rmk
    890315905U,	// VANDPSZ256rmkz
    811656321U,	// VANDPSZ256rr
    87057537U,	// VANDPSZ256rrk
    890283137U,	// VANDPSZ256rrkz
    812737665U,	// VANDPSZrm
    365077633U,	// VANDPSZrmb
    1439884417U,	// VANDPSZrmbk
    1171465345U,	// VANDPSZrmbkz
    87139457U,	// VANDPSZrmk
    890365057U,	// VANDPSZrmkz
    811656321U,	// VANDPSZrr
    87057537U,	// VANDPSZrrk
    890283137U,	// VANDPSZrrkz
    811738241U,	// VANDPSrm
    811656321U,	// VANDPSrr
    811732006U,	// VBLENDMPDZ128rm
    358763558U,	// VBLENDMPDZ128rmb
    1164971046U,	// VBLENDMPDZ128rmbk
    1164971046U,	// VBLENDMPDZ128rmbkz
    890178598U,	// VBLENDMPDZ128rmk
    890178598U,	// VBLENDMPDZ128rmkz
    811650086U,	// VBLENDMPDZ128rr
    890276902U,	// VBLENDMPDZ128rrk
    890276902U,	// VBLENDMPDZ128rrkz
    812616742U,	// VBLENDMPDZ256rm
    360860710U,	// VBLENDMPDZ256rmb
    1167068198U,	// VBLENDMPDZ256rmbk
    1167068198U,	// VBLENDMPDZ256rmbkz
    890309670U,	// VBLENDMPDZ256rmk
    890309670U,	// VBLENDMPDZ256rmkz
    811650086U,	// VBLENDMPDZ256rr
    890276902U,	// VBLENDMPDZ256rrk
    890276902U,	// VBLENDMPDZ256rrkz
    812731430U,	// VBLENDMPDZrm
    362957862U,	// VBLENDMPDZrmb
    1169165350U,	// VBLENDMPDZrmbk
    1169165350U,	// VBLENDMPDZrmbkz
    890358822U,	// VBLENDMPDZrmk
    890358822U,	// VBLENDMPDZrmkz
    811650086U,	// VBLENDMPDZrr
    890276902U,	// VBLENDMPDZrrk
    890276902U,	// VBLENDMPDZrrkz
    811738438U,	// VBLENDMPSZ128rm
    360883526U,	// VBLENDMPSZ128rmb
    1167271238U,	// VBLENDMPSZ128rmbk
    1167271238U,	// VBLENDMPSZ128rmbkz
    890185030U,	// VBLENDMPSZ128rmk
    890185030U,	// VBLENDMPSZ128rmkz
    811656518U,	// VBLENDMPSZ128rr
    890283334U,	// VBLENDMPSZ128rrk
    890283334U,	// VBLENDMPSZ128rrkz
    812623174U,	// VBLENDMPSZ256rm
    362980678U,	// VBLENDMPSZ256rmb
    1169368390U,	// VBLENDMPSZ256rmbk
    1169368390U,	// VBLENDMPSZ256rmbkz
    890316102U,	// VBLENDMPSZ256rmk
    890316102U,	// VBLENDMPSZ256rmkz
    811656518U,	// VBLENDMPSZ256rr
    890283334U,	// VBLENDMPSZ256rrk
    890283334U,	// VBLENDMPSZ256rrkz
    812737862U,	// VBLENDMPSZrm
    365077830U,	// VBLENDMPSZrmb
    1171465542U,	// VBLENDMPSZrmbk
    1171465542U,	// VBLENDMPSZrmbkz
    890365254U,	// VBLENDMPSZrmk
    890365254U,	// VBLENDMPSZrmkz
    811656518U,	// VBLENDMPSZrr
    890283334U,	// VBLENDMPSZrrk
    890283334U,	// VBLENDMPSZrrkz
    392547189U,	// VBLENDPDYrmi
    1088818037U,	// VBLENDPDYrri
    300272501U,	// VBLENDPDrmi
    1088818037U,	// VBLENDPDrri
    392553609U,	// VBLENDPSYrmi
    1088824457U,	// VBLENDPSYrri
    300278921U,	// VBLENDPSrmi
    1088824457U,	// VBLENDPSrri
    393497907U,	// VBLENDVPDYrm
    890277171U,	// VBLENDVPDYrr
    301223219U,	// VBLENDVPDrm
    890277171U,	// VBLENDVPDrr
    393504404U,	// VBLENDVPSYrm
    890283668U,	// VBLENDVPSYrr
    301229716U,	// VBLENDVPSrm
    890283668U,	// VBLENDVPSrr
    656011U,	// VBROADCASTF128
    552173714U,	// VBROADCASTF32X2Z256m
    552599698U,	// VBROADCASTF32X2Z256mk
    551698578U,	// VBROADCASTF32X2Z256mkz
    551829650U,	// VBROADCASTF32X2Z256r
    3230695570U,	// VBROADCASTF32X2Z256rk
    3229663378U,	// VBROADCASTF32X2Z256rkz
    552173714U,	// VBROADCASTF32X2Zm
    552599698U,	// VBROADCASTF32X2Zmk
    551698578U,	// VBROADCASTF32X2Zmkz
    551829650U,	// VBROADCASTF32X2Zr
    3230695570U,	// VBROADCASTF32X2Zrk
    3229663378U,	// VBROADCASTF32X2Zrkz
    655794U,	// VBROADCASTF32X4Z256rm
    3230597554U,	// VBROADCASTF32X4Z256rmk
    3229745586U,	// VBROADCASTF32X4Z256rmkz
    655794U,	// VBROADCASTF32X4rm
    3230597554U,	// VBROADCASTF32X4rmk
    3229745586U,	// VBROADCASTF32X4rmkz
    1344249U,	// VBROADCASTF32X8rm
    3230728953U,	// VBROADCASTF32X8rmk
    3230630649U,	// VBROADCASTF32X8rmkz
    655581U,	// VBROADCASTF64X2Z128rm
    3230597341U,	// VBROADCASTF64X2Z128rmk
    3229745373U,	// VBROADCASTF64X2Z128rmkz
    655581U,	// VBROADCASTF64X2rm
    3230597341U,	// VBROADCASTF64X2rmk
    3229745373U,	// VBROADCASTF64X2rmkz
    1344026U,	// VBROADCASTF64X4rm
    3230728730U,	// VBROADCASTF64X4rmk
    3230630426U,	// VBROADCASTF64X4rmkz
    262850U,	// VBROADCASTI128
    551911587U,	// VBROADCASTI32X2Z128m
    552911011U,	// VBROADCASTI32X2Z128mk
    551649443U,	// VBROADCASTI32X2Z128mkz
    551829667U,	// VBROADCASTI32X2Z128r
    3230695587U,	// VBROADCASTI32X2Z128rk
    3229663395U,	// VBROADCASTI32X2Z128rkz
    551911587U,	// VBROADCASTI32X2Z256m
    552911011U,	// VBROADCASTI32X2Z256mk
    551649443U,	// VBROADCASTI32X2Z256mkz
    551829667U,	// VBROADCASTI32X2Z256r
    3230695587U,	// VBROADCASTI32X2Z256rk
    3229663395U,	// VBROADCASTI32X2Z256rkz
    551911587U,	// VBROADCASTI32X2Zm
    552911011U,	// VBROADCASTI32X2Zmk
    551649443U,	// VBROADCASTI32X2Zmkz
    551829667U,	// VBROADCASTI32X2Zr
    3230695587U,	// VBROADCASTI32X2Zrk
    3229663395U,	// VBROADCASTI32X2Zrkz
    262636U,	// VBROADCASTI32X4Z256rm
    3230990828U,	// VBROADCASTI32X4Z256rmk
    3229860332U,	// VBROADCASTI32X4Z256rmkz
    262636U,	// VBROADCASTI32X4rm
    3230990828U,	// VBROADCASTI32X4rmk
    3229860332U,	// VBROADCASTI32X4rmkz
    552944423U,	// VBROADCASTI32X8rm
    3231023911U,	// VBROADCASTI32X8rmk
    3230876455U,	// VBROADCASTI32X8rmkz
    262423U,	// VBROADCASTI64X2Z128rm
    3230990615U,	// VBROADCASTI64X2Z128rmk
    3229860119U,	// VBROADCASTI64X2Z128rmkz
    262423U,	// VBROADCASTI64X2rm
    3230990615U,	// VBROADCASTI64X2rmk
    3229860119U,	// VBROADCASTI64X2rmkz
    552944200U,	// VBROADCASTI64X4rm
    3231023688U,	// VBROADCASTI64X4rmk
    3230876232U,	// VBROADCASTI64X4rmkz
    552177637U,	// VBROADCASTSDYrm
    551833573U,	// VBROADCASTSDYrr
    552177637U,	// VBROADCASTSDZ256m
    552603621U,	// VBROADCASTSDZ256mk
    551702501U,	// VBROADCASTSDZ256mkz
    551833573U,	// VBROADCASTSDZ256r
    3230699493U,	// VBROADCASTSDZ256rk
    3229667301U,	// VBROADCASTSDZ256rkz
    552177637U,	// VBROADCASTSDZm
    552603621U,	// VBROADCASTSDZmk
    551702501U,	// VBROADCASTSDZmkz
    551833573U,	// VBROADCASTSDZr
    3230699493U,	// VBROADCASTSDZrk
    3229667301U,	// VBROADCASTSDZrkz
    552200399U,	// VBROADCASTSSYrm
    551839951U,	// VBROADCASTSSYrr
    552200399U,	// VBROADCASTSSZ128m
    552806607U,	// VBROADCASTSSZ128mk
    551725263U,	// VBROADCASTSSZ128mkz
    551839951U,	// VBROADCASTSSZ128r
    3230705871U,	// VBROADCASTSSZ128rk
    3229673679U,	// VBROADCASTSSZ128rkz
    552200399U,	// VBROADCASTSSZ256m
    552806607U,	// VBROADCASTSSZ256mk
    551725263U,	// VBROADCASTSSZ256mkz
    551839951U,	// VBROADCASTSSZ256r
    3230705871U,	// VBROADCASTSSZ256rk
    3229673679U,	// VBROADCASTSSZ256rkz
    552200399U,	// VBROADCASTSSZm
    552806607U,	// VBROADCASTSSZmk
    551725263U,	// VBROADCASTSSZmkz
    551839951U,	// VBROADCASTSSZr
    3230705871U,	// VBROADCASTSSZrk
    3229673679U,	// VBROADCASTSSZrkz
    552200399U,	// VBROADCASTSSrm
    551839951U,	// VBROADCASTSSrr
    3530030089U,	// VCMPPDYrmi
    392547423U,	// VCMPPDYrmi_alt
    1114127369U,	// VCMPPDYrri
    1088818271U,	// VCMPPDYrri_alt
    2456288265U,	// VCMPPDZ128rmbi
    2999307359U,	// VCMPPDZ128rmbi_alt
    3079933023U,	// VCMPPDZ128rmbi_altk
    3799383049U,	// VCMPPDZ128rmbik
    1919417353U,	// VCMPPDZ128rmi
    300272735U,	// VCMPPDZ128rmi_alt
    1202981983U,	// VCMPPDZ128rmi_altk
    4067818505U,	// VCMPPDZ128rmik
    1114127369U,	// VCMPPDZ128rri
    1088818271U,	// VCMPPDZ128rri_alt
    1357581407U,	// VCMPPDZ128rri_altk
    1383480329U,	// VCMPPDZ128rrik
    2456288265U,	// VCMPPDZ256rmbi
    1657130079U,	// VCMPPDZ256rmbi_alt
    1737755743U,	// VCMPPDZ256rmbi_altk
    3799383049U,	// VCMPPDZ256rmbik
    3530030089U,	// VCMPPDZ256rmi
    392547423U,	// VCMPPDZ256rmi_alt
    1205079135U,	// VCMPPDZ256rmi_altk
    41286665U,	// VCMPPDZ256rmik
    1114127369U,	// VCMPPDZ256rri
    1088818271U,	// VCMPPDZ256rri_alt
    1357581407U,	// VCMPPDZ256rri_altk
    1383480329U,	// VCMPPDZ256rrik
    2456288265U,	// VCMPPDZrmbi
    2462436447U,	// VCMPPDZrmbi_alt
    2543062111U,	// VCMPPDZrmbi_altk
    3799383049U,	// VCMPPDZrmbik
    308804617U,	// VCMPPDZrmi
    400936031U,	// VCMPPDZrmi_alt
    1209273439U,	// VCMPPDZrmi_altk
    578157577U,	// VCMPPDZrmik
    1114127369U,	// VCMPPDZrri
    1088818271U,	// VCMPPDZrri_alt
    1357581407U,	// VCMPPDZrri_altk
    1210596361U,	// VCMPPDZrrib
    1212550239U,	// VCMPPDZrrib_alt
    1481313375U,	// VCMPPDZrrib_altk
    1479949321U,	// VCMPPDZrribk
    1383480329U,	// VCMPPDZrrik
    1919417353U,	// VCMPPDrmi
    300272735U,	// VCMPPDrmi_alt
    1114127369U,	// VCMPPDrri
    1088818271U,	// VCMPPDrri_alt
    3532127241U,	// VCMPPSYrmi
    392553880U,	// VCMPPSYrmi_alt
    1116224521U,	// VCMPPSYrri
    1088824728U,	// VCMPPSYrri_alt
    3263691785U,	// VCMPPSZ128rmbi
    1661330840U,	// VCMPPSZ128rmbi_alt
    1752442264U,	// VCMPPSZ128rmbi_altk
    848690185U,	// VCMPPSZ128rmbik
    1921514505U,	// VCMPPSZ128rmi
    300279192U,	// VCMPPSZ128rmi_alt
    1202988440U,	// VCMPPSZ128rmi_altk
    4069915657U,	// VCMPPSZ128rmik
    1116224521U,	// VCMPPSZ128rri
    1088824728U,	// VCMPPSZ128rri_alt
    1357587864U,	// VCMPPSZ128rri_altk
    1385577481U,	// VCMPPSZ128rrik
    3263691785U,	// VCMPPSZ256rmbi
    2466637208U,	// VCMPPSZ256rmbi_alt
    2557748632U,	// VCMPPSZ256rmbi_altk
    848690185U,	// VCMPPSZ256rmbik
    3532127241U,	// VCMPPSZ256rmi
    392553880U,	// VCMPPSZ256rmi_alt
    1205085592U,	// VCMPPSZ256rmi_altk
    43383817U,	// VCMPPSZ256rmik
    1116224521U,	// VCMPPSZ256rri
    1088824728U,	// VCMPPSZ256rri_alt
    1357587864U,	// VCMPPSZ256rri_altk
    1385577481U,	// VCMPPSZ256rrik
    3263691785U,	// VCMPPSZrmbi
    2735072664U,	// VCMPPSZrmbi_alt
    2826184088U,	// VCMPPSZrmbi_altk
    848690185U,	// VCMPPSZrmbik
    310901769U,	// VCMPPSZrmi
    400942488U,	// VCMPPSZrmi_alt
    1209279896U,	// VCMPPSZrmi_altk
    580254729U,	// VCMPPSZrmik
    1116224521U,	// VCMPPSZrri
    1088824728U,	// VCMPPSZrri_alt
    1357587864U,	// VCMPPSZrri_altk
    1216887817U,	// VCMPPSZrrib
    1212556696U,	// VCMPPSZrrib_alt
    1481319832U,	// VCMPPSZrrib_altk
    1486240777U,	// VCMPPSZrribk
    1385577481U,	// VCMPPSZrrik
    1921514505U,	// VCMPPSrmi
    300279192U,	// VCMPPSrmi_alt
    1116224521U,	// VCMPPSrri
    1088824728U,	// VCMPPSrri_alt
    2460482569U,	// VCMPSDZrm
    2460482569U,	// VCMPSDZrm_Int
    3803577353U,	// VCMPSDZrm_Intk
    851824503U,	// VCMPSDZrmi_alt
    932450167U,	// VCMPSDZrmi_altk
    1118321673U,	// VCMPSDZrr
    1118321673U,	// VCMPSDZrr_Int
    1387674633U,	// VCMPSDZrr_Intk
    1218984969U,	// VCMPSDZrrb_Int
    1488337929U,	// VCMPSDZrrb_Intk
    1212551031U,	// VCMPSDZrrb_alt
    1481314167U,	// VCMPSDZrrb_altk
    1088819063U,	// VCMPSDZrri_alt
    1357582199U,	// VCMPSDZrri_altk
    2460482569U,	// VCMPSDrm
    2460482569U,	// VCMPSDrm_Int
    851824503U,	// VCMPSDrm_alt
    1118321673U,	// VCMPSDrr
    1118321673U,	// VCMPSDrr_Int
    1088819063U,	// VCMPSDrr_alt
    3269983241U,	// VCMPSSZrm
    3269983241U,	// VCMPSSZrm_Int
    854981641U,	// VCMPSSZrm_Intk
    856025224U,	// VCMPSSZrmi_alt
    947136648U,	// VCMPSSZrmi_altk
    1122515977U,	// VCMPSSZrr
    1122515977U,	// VCMPSSZrr_Int
    1391868937U,	// VCMPSSZrr_Intk
    1221082121U,	// VCMPSSZrrb_Int
    1490435081U,	// VCMPSSZrrb_Intk
    1212557448U,	// VCMPSSZrrb_alt
    1481320584U,	// VCMPSSZrrb_altk
    1088825480U,	// VCMPSSZrri_alt
    1357588616U,	// VCMPSSZrri_altk
    3269983241U,	// VCMPSSrm
    3269983241U,	// VCMPSSrm_Int
    856025224U,	// VCMPSSrm_alt
    1122515977U,	// VCMPSSrr
    1122515977U,	// VCMPSSrr_Int
    1088825480U,	// VCMPSSrr_alt
    552177480U,	// VCOMISDZrm
    552177480U,	// VCOMISDZrm_Int
    551833416U,	// VCOMISDZrr
    551833416U,	// VCOMISDZrr_Int
    551843439U,	// VCOMISDZrrb
    552177480U,	// VCOMISDrm
    552177480U,	// VCOMISDrm_Int
    551833416U,	// VCOMISDrr
    551833416U,	// VCOMISDrr_Int
    552200282U,	// VCOMISSZrm
    552200282U,	// VCOMISSZrm_Int
    551839834U,	// VCOMISSZrr
    551839834U,	// VCOMISSZrr_Int
    551843908U,	// VCOMISSZrrb
    552200282U,	// VCOMISSrm
    552200282U,	// VCOMISSrm_Int
    551839834U,	// VCOMISSrr
    551839834U,	// VCOMISSrr_Int
    65047797U,	// VCOMPRESSPDZ128mr
    3286568181U,	// VCOMPRESSPDZ128mrk
    551832821U,	// VCOMPRESSPDZ128rr
    3230698741U,	// VCOMPRESSPDZ128rrk
    3229666549U,	// VCOMPRESSPDZ128rrkz
    148933877U,	// VCOMPRESSPDZ256mr
    3370454261U,	// VCOMPRESSPDZ256mrk
    551832821U,	// VCOMPRESSPDZ256rr
    3230698741U,	// VCOMPRESSPDZ256rrk
    3229666549U,	// VCOMPRESSPDZ256rrkz
    151031029U,	// VCOMPRESSPDZmr
    3372551413U,	// VCOMPRESSPDZmrk
    551832821U,	// VCOMPRESSPDZrr
    3230698741U,	// VCOMPRESSPDZrrk
    3229666549U,	// VCOMPRESSPDZrrkz
    65054237U,	// VCOMPRESSPSZ128mr
    3286574621U,	// VCOMPRESSPSZ128mrk
    551839261U,	// VCOMPRESSPSZ128rr
    3230705181U,	// VCOMPRESSPSZ128rrk
    3229672989U,	// VCOMPRESSPSZ128rrkz
    148940317U,	// VCOMPRESSPSZ256mr
    3370460701U,	// VCOMPRESSPSZ256mrk
    551839261U,	// VCOMPRESSPSZ256rr
    3230705181U,	// VCOMPRESSPSZ256rrk
    3229672989U,	// VCOMPRESSPSZ256rrkz
    151037469U,	// VCOMPRESSPSZmr
    3372557853U,	// VCOMPRESSPSZmrk
    551839261U,	// VCOMPRESSPSZrr
    3230705181U,	// VCOMPRESSPSZrrk
    3229672989U,	// VCOMPRESSPSZrrkz
    264668U,	// VCVTDQ2PDYrm
    551832028U,	// VCVTDQ2PDYrr
    551913948U,	// VCVTDQ2PDZ128rm
    627395036U,	// VCVTDQ2PDZ128rmb
    628509148U,	// VCVTDQ2PDZ128rmbk
    627132892U,	// VCVTDQ2PDZ128rmbkz
    552913372U,	// VCVTDQ2PDZ128rmk
    551651804U,	// VCVTDQ2PDZ128rmkz
    551832028U,	// VCVTDQ2PDZ128rr
    3230697948U,	// VCVTDQ2PDZ128rrk
    3229665756U,	// VCVTDQ2PDZ128rrkz
    264668U,	// VCVTDQ2PDZ256rm
    629492188U,	// VCVTDQ2PDZ256rmb
    630606300U,	// VCVTDQ2PDZ256rmbk
    629230044U,	// VCVTDQ2PDZ256rmbkz
    3230992860U,	// VCVTDQ2PDZ256rmk
    3229862364U,	// VCVTDQ2PDZ256rmkz
    551832028U,	// VCVTDQ2PDZ256rr
    3230697948U,	// VCVTDQ2PDZ256rrk
    3229665756U,	// VCVTDQ2PDZ256rrkz
    552946140U,	// VCVTDQ2PDZrm
    631589340U,	// VCVTDQ2PDZrmb
    632703452U,	// VCVTDQ2PDZrmbk
    631327196U,	// VCVTDQ2PDZrmbkz
    3231025628U,	// VCVTDQ2PDZrmk
    3230878172U,	// VCVTDQ2PDZrmkz
    551832028U,	// VCVTDQ2PDZrr
    3230697948U,	// VCVTDQ2PDZrrk
    3229665756U,	// VCVTDQ2PDZrrkz
    551913948U,	// VCVTDQ2PDrm
    551832028U,	// VCVTDQ2PDrr
    552952556U,	// VCVTDQ2PSYrm
    551838444U,	// VCVTDQ2PSYrr
    271084U,	// VCVTDQ2PSZ128rm
    629498604U,	// VCVTDQ2PSZ128rmb
    630612716U,	// VCVTDQ2PSZ128rmbk
    629236460U,	// VCVTDQ2PSZ128rmbkz
    3230999276U,	// VCVTDQ2PSZ128rmk
    3229868780U,	// VCVTDQ2PSZ128rmkz
    551838444U,	// VCVTDQ2PSZ128rr
    3230704364U,	// VCVTDQ2PSZ128rrk
    3229672172U,	// VCVTDQ2PSZ128rrkz
    552952556U,	// VCVTDQ2PSZ256rm
    631595756U,	// VCVTDQ2PSZ256rmb
    632709868U,	// VCVTDQ2PSZ256rmbk
    631333612U,	// VCVTDQ2PSZ256rmbkz
    3231032044U,	// VCVTDQ2PSZ256rmk
    3230884588U,	// VCVTDQ2PSZ256rmkz
    551838444U,	// VCVTDQ2PSZ256rr
    3230704364U,	// VCVTDQ2PSZ256rrk
    3229672172U,	// VCVTDQ2PSZ256rrkz
    552444652U,	// VCVTDQ2PSZrm
    633692908U,	// VCVTDQ2PSZrmb
    634807020U,	// VCVTDQ2PSZrmbk
    633430764U,	// VCVTDQ2PSZrmbkz
    3231097580U,	// VCVTDQ2PSZrmk
    3230900972U,	// VCVTDQ2PSZrmkz
    551838444U,	// VCVTDQ2PSZrr
    1499884U,	// VCVTDQ2PSZrrb
    3230835436U,	// VCVTDQ2PSZrrbk
    3230802668U,	// VCVTDQ2PSZrrbkz
    3230704364U,	// VCVTDQ2PSZrrk
    3229672172U,	// VCVTDQ2PSZrrkz
    271084U,	// VCVTDQ2PSrm
    551838444U,	// VCVTDQ2PSrr
    1355912U,	// VCVTPD2DQYrm
    551836178U,	// VCVTPD2DQYrr
    667661U,	// VCVTPD2DQZ128rm
    627677714U,	// VCVTPD2DQZ128rmb
    628103698U,	// VCVTPD2DQZ128rmbk
    627202578U,	// VCVTPD2DQZ128rmbkz
    3230609421U,	// VCVTPD2DQZ128rmk
    3229757453U,	// VCVTPD2DQZ128rmkz
    551836178U,	// VCVTPD2DQZ128rr
    3230702098U,	// VCVTPD2DQZ128rrk
    3229669906U,	// VCVTPD2DQZ128rrkz
    1355912U,	// VCVTPD2DQZ256rm
    629774866U,	// VCVTPD2DQZ256rmb
    630200850U,	// VCVTPD2DQZ256rmbk
    629299730U,	// VCVTPD2DQZ256rmbkz
    3230740616U,	// VCVTPD2DQZ256rmk
    3230642312U,	// VCVTPD2DQZ256rmkz
    551836178U,	// VCVTPD2DQZ256rr
    3230702098U,	// VCVTPD2DQZ256rrk
    3229669906U,	// VCVTPD2DQZ256rrkz
    1514002U,	// VCVTPD2DQZrm
    631872018U,	// VCVTPD2DQZrmb
    632298002U,	// VCVTPD2DQZrmbk
    631396882U,	// VCVTPD2DQZrmbkz
    3230784018U,	// VCVTPD2DQZrmk
    3230751250U,	// VCVTPD2DQZrmkz
    551836178U,	// VCVTPD2DQZrr
    1497618U,	// VCVTPD2DQZrrb
    3230833170U,	// VCVTPD2DQZrrbk
    3230800402U,	// VCVTPD2DQZrrbkz
    3230702098U,	// VCVTPD2DQZrrk
    3229669906U,	// VCVTPD2DQZrrkz
    667661U,	// VCVTPD2DQrm
    551836178U,	// VCVTPD2DQrr
    1355961U,	// VCVTPD2PSYrm
    551838380U,	// VCVTPD2PSYrr
    667700U,	// VCVTPD2PSZ128rm
    627679916U,	// VCVTPD2PSZ128rmb
    628105900U,	// VCVTPD2PSZ128rmbk
    627204780U,	// VCVTPD2PSZ128rmbkz
    3230609460U,	// VCVTPD2PSZ128rmk
    3229757492U,	// VCVTPD2PSZ128rmkz
    551838380U,	// VCVTPD2PSZ128rr
    3230704300U,	// VCVTPD2PSZ128rrk
    3229672108U,	// VCVTPD2PSZ128rrkz
    1355961U,	// VCVTPD2PSZ256rm
    629777068U,	// VCVTPD2PSZ256rmb
    630203052U,	// VCVTPD2PSZ256rmbk
    629301932U,	// VCVTPD2PSZ256rmbkz
    3230740665U,	// VCVTPD2PSZ256rmk
    3230642361U,	// VCVTPD2PSZ256rmkz
    551838380U,	// VCVTPD2PSZ256rr
    3230704300U,	// VCVTPD2PSZ256rrk
    3229672108U,	// VCVTPD2PSZ256rrkz
    1516204U,	// VCVTPD2PSZrm
    631874220U,	// VCVTPD2PSZrmb
    632300204U,	// VCVTPD2PSZrmbk
    631399084U,	// VCVTPD2PSZrmbkz
    3230786220U,	// VCVTPD2PSZrmk
    3230753452U,	// VCVTPD2PSZrmkz
    551838380U,	// VCVTPD2PSZrr
    1499820U,	// VCVTPD2PSZrrb
    3230835372U,	// VCVTPD2PSZrrbk
    3230802604U,	// VCVTPD2PSZrrbkz
    3230704300U,	// VCVTPD2PSZrrk
    3229672108U,	// VCVTPD2PSZrrkz
    667700U,	// VCVTPD2PSrm
    551838380U,	// VCVTPD2PSrr
    662977U,	// VCVTPD2QQZ128rm
    627678657U,	// VCVTPD2QQZ128rmb
    628104641U,	// VCVTPD2QQZ128rmbk
    627203521U,	// VCVTPD2QQZ128rmbkz
    3230604737U,	// VCVTPD2QQZ128rmk
    3229752769U,	// VCVTPD2QQZ128rmkz
    551837121U,	// VCVTPD2QQZ128rr
    3230703041U,	// VCVTPD2QQZ128rrk
    3229670849U,	// VCVTPD2QQZ128rrkz
    1351105U,	// VCVTPD2QQZ256rm
    629775809U,	// VCVTPD2QQZ256rmb
    630201793U,	// VCVTPD2QQZ256rmbk
    629300673U,	// VCVTPD2QQZ256rmbkz
    3230735809U,	// VCVTPD2QQZ256rmk
    3230637505U,	// VCVTPD2QQZ256rmkz
    551837121U,	// VCVTPD2QQZ256rr
    3230703041U,	// VCVTPD2QQZ256rrk
    3229670849U,	// VCVTPD2QQZ256rrkz
    1514945U,	// VCVTPD2QQZrm
    631872961U,	// VCVTPD2QQZrmb
    632298945U,	// VCVTPD2QQZrmbk
    631397825U,	// VCVTPD2QQZrmbkz
    3230784961U,	// VCVTPD2QQZrmk
    3230752193U,	// VCVTPD2QQZrmkz
    551837121U,	// VCVTPD2QQZrr
    1498561U,	// VCVTPD2QQZrrb
    3230834113U,	// VCVTPD2QQZrrbk
    3230801345U,	// VCVTPD2QQZrrbkz
    3230703041U,	// VCVTPD2QQZrrk
    3229670849U,	// VCVTPD2QQZrrkz
    667687U,	// VCVTPD2UDQZ128rm
    627678055U,	// VCVTPD2UDQZ128rmb
    628104039U,	// VCVTPD2UDQZ128rmbk
    627202919U,	// VCVTPD2UDQZ128rmbkz
    3230609447U,	// VCVTPD2UDQZ128rmk
    3229757479U,	// VCVTPD2UDQZ128rmkz
    551836519U,	// VCVTPD2UDQZ128rr
    3230702439U,	// VCVTPD2UDQZ128rrk
    3229670247U,	// VCVTPD2UDQZ128rrkz
    1355938U,	// VCVTPD2UDQZ256rm
    629775207U,	// VCVTPD2UDQZ256rmb
    630201191U,	// VCVTPD2UDQZ256rmbk
    629300071U,	// VCVTPD2UDQZ256rmbkz
    3230740642U,	// VCVTPD2UDQZ256rmk
    3230642338U,	// VCVTPD2UDQZ256rmkz
    551836519U,	// VCVTPD2UDQZ256rr
    3230702439U,	// VCVTPD2UDQZ256rrk
    3229670247U,	// VCVTPD2UDQZ256rrkz
    1514343U,	// VCVTPD2UDQZrm
    631872359U,	// VCVTPD2UDQZrmb
    632298343U,	// VCVTPD2UDQZrmbk
    631397223U,	// VCVTPD2UDQZrmbkz
    3230784359U,	// VCVTPD2UDQZrmk
    3230751591U,	// VCVTPD2UDQZrmkz
    551836519U,	// VCVTPD2UDQZrr
    1497959U,	// VCVTPD2UDQZrrb
    3230833511U,	// VCVTPD2UDQZrrbk
    3230800743U,	// VCVTPD2UDQZrrbkz
    3230702439U,	// VCVTPD2UDQZrrk
    3229670247U,	// VCVTPD2UDQZrrkz
    663059U,	// VCVTPD2UQQZ128rm
    627678739U,	// VCVTPD2UQQZ128rmb
    628104723U,	// VCVTPD2UQQZ128rmbk
    627203603U,	// VCVTPD2UQQZ128rmbkz
    3230604819U,	// VCVTPD2UQQZ128rmk
    3229752851U,	// VCVTPD2UQQZ128rmkz
    551837203U,	// VCVTPD2UQQZ128rr
    3230703123U,	// VCVTPD2UQQZ128rrk
    3229670931U,	// VCVTPD2UQQZ128rrkz
    1351187U,	// VCVTPD2UQQZ256rm
    629775891U,	// VCVTPD2UQQZ256rmb
    630201875U,	// VCVTPD2UQQZ256rmbk
    629300755U,	// VCVTPD2UQQZ256rmbkz
    3230735891U,	// VCVTPD2UQQZ256rmk
    3230637587U,	// VCVTPD2UQQZ256rmkz
    551837203U,	// VCVTPD2UQQZ256rr
    3230703123U,	// VCVTPD2UQQZ256rrk
    3229670931U,	// VCVTPD2UQQZ256rrkz
    1515027U,	// VCVTPD2UQQZrm
    631873043U,	// VCVTPD2UQQZrmb
    632299027U,	// VCVTPD2UQQZrmbk
    631397907U,	// VCVTPD2UQQZrmbkz
    3230785043U,	// VCVTPD2UQQZrmk
    3230752275U,	// VCVTPD2UQQZrmkz
    551837203U,	// VCVTPD2UQQZrr
    1498643U,	// VCVTPD2UQQZrrb
    3230834195U,	// VCVTPD2UQQZrrbk
    3230801427U,	// VCVTPD2UQQZrrbkz
    3230703123U,	// VCVTPD2UQQZrrk
    3229670931U,	// VCVTPD2UQQZrrkz
    664247U,	// VCVTPH2PSYrm
    551838391U,	// VCVTPH2PSYrr
    552182455U,	// VCVTPH2PSZ128rm
    552608439U,	// VCVTPH2PSZ128rmk
    551707319U,	// VCVTPH2PSZ128rmkz
    551838391U,	// VCVTPH2PSZ128rr
    3230704311U,	// VCVTPH2PSZ128rrk
    3229672119U,	// VCVTPH2PSZ128rrkz
    664247U,	// VCVTPH2PSZ256rm
    3230606007U,	// VCVTPH2PSZ256rmk
    3229754039U,	// VCVTPH2PSZ256rmkz
    551838391U,	// VCVTPH2PSZ256rr
    3230704311U,	// VCVTPH2PSZ256rrk
    3229672119U,	// VCVTPH2PSZ256rrkz
    1352375U,	// VCVTPH2PSZrm
    3230737079U,	// VCVTPH2PSZrmk
    3230638775U,	// VCVTPH2PSZrmkz
    551838391U,	// VCVTPH2PSZrr
    551843737U,	// VCVTPH2PSZrrb
    3230709657U,	// VCVTPH2PSZrrbk
    3229677465U,	// VCVTPH2PSZrrbkz
    3230704311U,	// VCVTPH2PSZrrk
    3229672119U,	// VCVTPH2PSZrrkz
    552182455U,	// VCVTPH2PSrm
    551838391U,	// VCVTPH2PSrr
    1350194U,	// VCVTPS2DQYrm
    551836210U,	// VCVTPS2DQYrr
    662066U,	// VCVTPS2DQZ128rm
    629791282U,	// VCVTPS2DQZ128rmb
    630397490U,	// VCVTPS2DQZ128rmbk
    629316146U,	// VCVTPS2DQZ128rmbkz
    3230603826U,	// VCVTPS2DQZ128rmk
    3229751858U,	// VCVTPS2DQZ128rmkz
    551836210U,	// VCVTPS2DQZ128rr
    3230702130U,	// VCVTPS2DQZ128rrk
    3229669938U,	// VCVTPS2DQZ128rrkz
    1350194U,	// VCVTPS2DQZ256rm
    631888434U,	// VCVTPS2DQZ256rmb
    632494642U,	// VCVTPS2DQZ256rmbk
    631413298U,	// VCVTPS2DQZ256rmbkz
    3230734898U,	// VCVTPS2DQZ256rmk
    3230636594U,	// VCVTPS2DQZ256rmkz
    551836210U,	// VCVTPS2DQZ256rr
    3230702130U,	// VCVTPS2DQZ256rrk
    3229669938U,	// VCVTPS2DQZ256rrkz
    1514034U,	// VCVTPS2DQZrm
    633985586U,	// VCVTPS2DQZrmb
    634591794U,	// VCVTPS2DQZrmbk
    633510450U,	// VCVTPS2DQZrmbkz
    3230784050U,	// VCVTPS2DQZrmk
    3230751282U,	// VCVTPS2DQZrmkz
    551836210U,	// VCVTPS2DQZrr
    1497650U,	// VCVTPS2DQZrrb
    3230833202U,	// VCVTPS2DQZrrbk
    3230800434U,	// VCVTPS2DQZrrbkz
    3230702130U,	// VCVTPS2DQZrrk
    3229669938U,	// VCVTPS2DQZrrkz
    662066U,	// VCVTPS2DQrm
    551836210U,	// VCVTPS2DQrr
    657930U,	// VCVTPS2PDYrm
    551832074U,	// VCVTPS2PDYrr
    552176138U,	// VCVTPS2PDZ128rm
    627689994U,	// VCVTPS2PDZ128rmb
    628296202U,	// VCVTPS2PDZ128rmbk
    627214858U,	// VCVTPS2PDZ128rmbkz
    552602122U,	// VCVTPS2PDZ128rmk
    551701002U,	// VCVTPS2PDZ128rmkz
    551832074U,	// VCVTPS2PDZ128rr
    3230697994U,	// VCVTPS2PDZ128rrk
    3229665802U,	// VCVTPS2PDZ128rrkz
    657930U,	// VCVTPS2PDZ256rm
    629787146U,	// VCVTPS2PDZ256rmb
    630393354U,	// VCVTPS2PDZ256rmbk
    629312010U,	// VCVTPS2PDZ256rmbkz
    3230599690U,	// VCVTPS2PDZ256rmk
    3229747722U,	// VCVTPS2PDZ256rmkz
    551832074U,	// VCVTPS2PDZ256rr
    3230697994U,	// VCVTPS2PDZ256rrk
    3229665802U,	// VCVTPS2PDZ256rrkz
    1346058U,	// VCVTPS2PDZrm
    631884298U,	// VCVTPS2PDZrmb
    632490506U,	// VCVTPS2PDZrmbk
    631409162U,	// VCVTPS2PDZrmbkz
    3230730762U,	// VCVTPS2PDZrmk
    3230632458U,	// VCVTPS2PDZrmkz
    551832074U,	// VCVTPS2PDZrr
    551843266U,	// VCVTPS2PDZrrb
    3230709186U,	// VCVTPS2PDZrrbk
    3229676994U,	// VCVTPS2PDZrrbkz
    3230697994U,	// VCVTPS2PDZrrk
    3229665802U,	// VCVTPS2PDZrrkz
    552176138U,	// VCVTPS2PDrm
    551832074U,	// VCVTPS2PDrr
    1126470238U,	// VCVTPS2PHYmr
    283431518U,	// VCVTPS2PHYrr
    1394905694U,	// VCVTPS2PHZ128mr
    1495650910U,	// VCVTPS2PHZ128mrk
    283431518U,	// VCVTPS2PHZ128rr
    1357582942U,	// VCVTPS2PHZ128rrk
    1088819806U,	// VCVTPS2PHZ128rrkz
    1126470238U,	// VCVTPS2PHZ256mr
    1227215454U,	// VCVTPS2PHZ256mrk
    283431518U,	// VCVTPS2PHZ256rr
    1357582942U,	// VCVTPS2PHZ256rrk
    1088819806U,	// VCVTPS2PHZ256rrkz
    1663341150U,	// VCVTPS2PHZmr
    1764086366U,	// VCVTPS2PHZmrk
    283431518U,	// VCVTPS2PHZrr
    407163486U,	// VCVTPS2PHZrrb
    1481314910U,	// VCVTPS2PHZrrbk
    1212551774U,	// VCVTPS2PHZrrbkz
    1357582942U,	// VCVTPS2PHZrrk
    1088819806U,	// VCVTPS2PHZrrkz
    1394905694U,	// VCVTPS2PHmr
    283431518U,	// VCVTPS2PHrr
    552181208U,	// VCVTPS2QQZ128rm
    627695064U,	// VCVTPS2QQZ128rmb
    628301272U,	// VCVTPS2QQZ128rmbk
    627219928U,	// VCVTPS2QQZ128rmbkz
    552607192U,	// VCVTPS2QQZ128rmk
    551706072U,	// VCVTPS2QQZ128rmkz
    551837144U,	// VCVTPS2QQZ128rr
    3230703064U,	// VCVTPS2QQZ128rrk
    3229670872U,	// VCVTPS2QQZ128rrkz
    663000U,	// VCVTPS2QQZ256rm
    629792216U,	// VCVTPS2QQZ256rmb
    630398424U,	// VCVTPS2QQZ256rmbk
    629317080U,	// VCVTPS2QQZ256rmbkz
    3230604760U,	// VCVTPS2QQZ256rmk
    3229752792U,	// VCVTPS2QQZ256rmkz
    551837144U,	// VCVTPS2QQZ256rr
    3230703064U,	// VCVTPS2QQZ256rrk
    3229670872U,	// VCVTPS2QQZ256rrkz
    1351128U,	// VCVTPS2QQZrm
    631889368U,	// VCVTPS2QQZrmb
    632495576U,	// VCVTPS2QQZrmbk
    631414232U,	// VCVTPS2QQZrmbkz
    3230735832U,	// VCVTPS2QQZrmk
    3230637528U,	// VCVTPS2QQZrmkz
    551837144U,	// VCVTPS2QQZrr
    1498584U,	// VCVTPS2QQZrrb
    3230834136U,	// VCVTPS2QQZrrbk
    3230801368U,	// VCVTPS2QQZrrbkz
    3230703064U,	// VCVTPS2QQZrrk
    3229670872U,	// VCVTPS2QQZrrkz
    662400U,	// VCVTPS2UDQZ128rm
    629791616U,	// VCVTPS2UDQZ128rmb
    630397824U,	// VCVTPS2UDQZ128rmbk
    629316480U,	// VCVTPS2UDQZ128rmbkz
    3230604160U,	// VCVTPS2UDQZ128rmk
    3229752192U,	// VCVTPS2UDQZ128rmkz
    551836544U,	// VCVTPS2UDQZ128rr
    3230702464U,	// VCVTPS2UDQZ128rrk
    3229670272U,	// VCVTPS2UDQZ128rrkz
    1350528U,	// VCVTPS2UDQZ256rm
    631888768U,	// VCVTPS2UDQZ256rmb
    632494976U,	// VCVTPS2UDQZ256rmbk
    631413632U,	// VCVTPS2UDQZ256rmbkz
    3230735232U,	// VCVTPS2UDQZ256rmk
    3230636928U,	// VCVTPS2UDQZ256rmkz
    551836544U,	// VCVTPS2UDQZ256rr
    3230702464U,	// VCVTPS2UDQZ256rrk
    3229670272U,	// VCVTPS2UDQZ256rrkz
    1514368U,	// VCVTPS2UDQZrm
    633985920U,	// VCVTPS2UDQZrmb
    634592128U,	// VCVTPS2UDQZrmbk
    633510784U,	// VCVTPS2UDQZrmbkz
    3230784384U,	// VCVTPS2UDQZrmk
    3230751616U,	// VCVTPS2UDQZrmkz
    551836544U,	// VCVTPS2UDQZrr
    1497984U,	// VCVTPS2UDQZrrb
    3230833536U,	// VCVTPS2UDQZrrbk
    3230800768U,	// VCVTPS2UDQZrrbkz
    3230702464U,	// VCVTPS2UDQZrrk
    3229670272U,	// VCVTPS2UDQZrrkz
    552181292U,	// VCVTPS2UQQZ128rm
    627695148U,	// VCVTPS2UQQZ128rmb
    628301356U,	// VCVTPS2UQQZ128rmbk
    627220012U,	// VCVTPS2UQQZ128rmbkz
    552607276U,	// VCVTPS2UQQZ128rmk
    551706156U,	// VCVTPS2UQQZ128rmkz
    551837228U,	// VCVTPS2UQQZ128rr
    3230703148U,	// VCVTPS2UQQZ128rrk
    3229670956U,	// VCVTPS2UQQZ128rrkz
    663084U,	// VCVTPS2UQQZ256rm
    629792300U,	// VCVTPS2UQQZ256rmb
    630398508U,	// VCVTPS2UQQZ256rmbk
    629317164U,	// VCVTPS2UQQZ256rmbkz
    3230604844U,	// VCVTPS2UQQZ256rmk
    3229752876U,	// VCVTPS2UQQZ256rmkz
    551837228U,	// VCVTPS2UQQZ256rr
    3230703148U,	// VCVTPS2UQQZ256rrk
    3229670956U,	// VCVTPS2UQQZ256rrkz
    1351212U,	// VCVTPS2UQQZrm
    631889452U,	// VCVTPS2UQQZrmb
    632495660U,	// VCVTPS2UQQZrmbk
    631414316U,	// VCVTPS2UQQZrmbkz
    3230735916U,	// VCVTPS2UQQZrmk
    3230637612U,	// VCVTPS2UQQZrmkz
    551837228U,	// VCVTPS2UQQZrr
    1498668U,	// VCVTPS2UQQZrrb
    3230834220U,	// VCVTPS2UQQZrrbk
    3230801452U,	// VCVTPS2UQQZrrbkz
    3230703148U,	// VCVTPS2UQQZrrk
    3229670956U,	// VCVTPS2UQQZrrkz
    264691U,	// VCVTQQ2PDZ128rm
    627411443U,	// VCVTQQ2PDZ128rmb
    628410867U,	// VCVTQQ2PDZ128rmbk
    627149299U,	// VCVTQQ2PDZ128rmbkz
    3230992883U,	// VCVTQQ2PDZ128rmk
    3229862387U,	// VCVTQQ2PDZ128rmkz
    551832051U,	// VCVTQQ2PDZ128rr
    3230697971U,	// VCVTQQ2PDZ128rrk
    3229665779U,	// VCVTQQ2PDZ128rrkz
    552946163U,	// VCVTQQ2PDZ256rm
    629508595U,	// VCVTQQ2PDZ256rmb
    630508019U,	// VCVTQQ2PDZ256rmbk
    629246451U,	// VCVTQQ2PDZ256rmbkz
    3231025651U,	// VCVTQQ2PDZ256rmk
    3230878195U,	// VCVTQQ2PDZ256rmkz
    551832051U,	// VCVTQQ2PDZ256rr
    3230697971U,	// VCVTQQ2PDZ256rrk
    3229665779U,	// VCVTQQ2PDZ256rrkz
    552438259U,	// VCVTQQ2PDZrm
    631605747U,	// VCVTQQ2PDZrmb
    632605171U,	// VCVTQQ2PDZrmbk
    631343603U,	// VCVTQQ2PDZrmbkz
    3231091187U,	// VCVTQQ2PDZrmk
    3230894579U,	// VCVTQQ2PDZrmkz
    551832051U,	// VCVTQQ2PDZrr
    1493491U,	// VCVTQQ2PDZrrb
    3230829043U,	// VCVTQQ2PDZrrbk
    3230796275U,	// VCVTQQ2PDZrrbkz
    3230697971U,	// VCVTQQ2PDZrrk
    3229665779U,	// VCVTQQ2PDZrrkz
    274496U,	// VCVTQQ2PSZ128rm
    627417859U,	// VCVTQQ2PSZ128rmb
    628417283U,	// VCVTQQ2PSZ128rmbk
    627155715U,	// VCVTQQ2PSZ128rmbkz
    3231002688U,	// VCVTQQ2PSZ128rmk
    3229872192U,	// VCVTQQ2PSZ128rmkz
    551838467U,	// VCVTQQ2PSZ128rr
    3230704387U,	// VCVTQQ2PSZ128rrk
    3229672195U,	// VCVTQQ2PSZ128rrkz
    552956101U,	// VCVTQQ2PSZ256rm
    629515011U,	// VCVTQQ2PSZ256rmb
    630514435U,	// VCVTQQ2PSZ256rmbk
    629252867U,	// VCVTQQ2PSZ256rmbkz
    3231035589U,	// VCVTQQ2PSZ256rmk
    3230888133U,	// VCVTQQ2PSZ256rmkz
    551838467U,	// VCVTQQ2PSZ256rr
    3230704387U,	// VCVTQQ2PSZ256rrk
    3229672195U,	// VCVTQQ2PSZ256rrkz
    552444675U,	// VCVTQQ2PSZrm
    631612163U,	// VCVTQQ2PSZrmb
    632611587U,	// VCVTQQ2PSZrmbk
    631350019U,	// VCVTQQ2PSZrmbkz
    3231097603U,	// VCVTQQ2PSZrmk
    3230900995U,	// VCVTQQ2PSZrmkz
    551838467U,	// VCVTQQ2PSZrr
    1499907U,	// VCVTQQ2PSZrrb
    3230835459U,	// VCVTQQ2PSZrrbk
    3230802691U,	// VCVTQQ2PSZrrbkz
    3230704387U,	// VCVTQQ2PSZrrk
    3229672195U,	// VCVTQQ2PSZrrkz
    552178432U,	// VCVTSD2SI64Zrm_Int
    551834368U,	// VCVTSD2SI64Zrr_Int
    1495808U,	// VCVTSD2SI64Zrrb_Int
    552178432U,	// VCVTSD2SI64rm_Int
    551834368U,	// VCVTSD2SI64rr_Int
    552178432U,	// VCVTSD2SIZrm_Int
    551834368U,	// VCVTSD2SIZrr_Int
    1495808U,	// VCVTSD2SIZrrb_Int
    552178432U,	// VCVTSD2SIrm_Int
    551834368U,	// VCVTSD2SIrr_Int
    283273051U,	// VCVTSD2SSZrm
    283273051U,	// VCVTSD2SSZrm_Int
    1357899611U,	// VCVTSD2SSZrm_Intk
    1089480539U,	// VCVTSD2SSZrm_Intkz
    811657051U,	// VCVTSD2SSZrr
    811657051U,	// VCVTSD2SSZrr_Int
    87058267U,	// VCVTSD2SSZrr_Intk
    890283867U,	// VCVTSD2SSZrr_Intkz
    812787547U,	// VCVTSD2SSZrrb_Int
    87189339U,	// VCVTSD2SSZrrb_Intk
    890414939U,	// VCVTSD2SSZrrb_Intkz
    283273051U,	// VCVTSD2SSrm
    283273051U,	// VCVTSD2SSrm_Int
    811657051U,	// VCVTSD2SSrr
    811657051U,	// VCVTSD2SSrr_Int
    552178479U,	// VCVTSD2USI64Zrm_Int
    551834415U,	// VCVTSD2USI64Zrr_Int
    1495855U,	// VCVTSD2USI64Zrrb_Int
    552178479U,	// VCVTSD2USIZrm_Int
    551834415U,	// VCVTSD2USIZrr_Int
    1495855U,	// VCVTSD2USIZrrb_Int
    283202602U,	// VCVTSI2SDZrm
    283202602U,	// VCVTSI2SDZrm_Int
    811652138U,	// VCVTSI2SDZrr
    811652138U,	// VCVTSI2SDZrr_Int
    155243562U,	// VCVTSI2SDZrrb_Int
    283202602U,	// VCVTSI2SDrm
    283202602U,	// VCVTSI2SDrm_Int
    811652138U,	// VCVTSI2SDrr
    811652138U,	// VCVTSI2SDrr_Int
    283203306U,	// VCVTSI2SSZrm
    283203306U,	// VCVTSI2SSZrm_Int
    811652842U,	// VCVTSI2SSZrr
    811652842U,	// VCVTSI2SSZrr_Int
    155244266U,	// VCVTSI2SSZrrb_Int
    283203306U,	// VCVTSI2SSrm
    283203306U,	// VCVTSI2SSrm_Int
    811652842U,	// VCVTSI2SSrr
    811652842U,	// VCVTSI2SSrr_Int
    283220791U,	// VCVTSI642SDZrm
    283220791U,	// VCVTSI642SDZrm_Int
    811653943U,	// VCVTSI642SDZrr
    811653943U,	// VCVTSI642SDZrr_Int
    155245367U,	// VCVTSI642SDZrrb_Int
    283220791U,	// VCVTSI642SDrm
    283220791U,	// VCVTSI642SDrm_Int
    811653943U,	// VCVTSI642SDrr
    811653943U,	// VCVTSI642SDrr_Int
    283221758U,	// VCVTSI642SSZrm
    283221758U,	// VCVTSI642SSZrm_Int
    811654910U,	// VCVTSI642SSZrr
    811654910U,	// VCVTSI642SSZrr_Int
    155246334U,	// VCVTSI642SSZrrb_Int
    283221758U,	// VCVTSI642SSrm
    283221758U,	// VCVTSI642SSrm_Int
    811654910U,	// VCVTSI642SSrr
    811654910U,	// VCVTSI642SSrr_Int
    283283032U,	// VCVTSS2SDZrm
    283283032U,	// VCVTSS2SDZrm_Int
    1358089816U,	// VCVTSS2SDZrm_Intk
    1089670744U,	// VCVTSS2SDZrm_Intkz
    811650648U,	// VCVTSS2SDZrr
    811650648U,	// VCVTSS2SDZrr_Int
    87051864U,	// VCVTSS2SDZrr_Intk
    890277464U,	// VCVTSS2SDZrr_Intkz
    811660840U,	// VCVTSS2SDZrrb_Int
    87062056U,	// VCVTSS2SDZrrb_Intk
    890287656U,	// VCVTSS2SDZrrb_Intkz
    283283032U,	// VCVTSS2SDrm
    283283032U,	// VCVTSS2SDrm_Int
    811650648U,	// VCVTSS2SDrr
    811650648U,	// VCVTSS2SDrr_Int
    552194839U,	// VCVTSS2SI64Zrm_Int
    551834391U,	// VCVTSS2SI64Zrr_Int
    1495831U,	// VCVTSS2SI64Zrrb_Int
    552194839U,	// VCVTSS2SI64rm_Int
    551834391U,	// VCVTSS2SI64rr_Int
    552194839U,	// VCVTSS2SIZrm_Int
    551834391U,	// VCVTSS2SIZrr_Int
    1495831U,	// VCVTSS2SIZrrb_Int
    552194839U,	// VCVTSS2SIrm_Int
    551834391U,	// VCVTSS2SIrr_Int
    552194888U,	// VCVTSS2USI64Zrm_Int
    551834440U,	// VCVTSS2USI64Zrr_Int
    1495880U,	// VCVTSS2USI64Zrrb_Int
    552194888U,	// VCVTSS2USIZrm_Int
    551834440U,	// VCVTSS2USIZrr_Int
    1495880U,	// VCVTSS2USIZrrb_Int
    1355899U,	// VCVTTPD2DQYrm
    551836166U,	// VCVTTPD2DQYrr
    667648U,	// VCVTTPD2DQZ128rm
    627677702U,	// VCVTTPD2DQZ128rmb
    628103686U,	// VCVTTPD2DQZ128rmbk
    627202566U,	// VCVTTPD2DQZ128rmbkz
    3230609408U,	// VCVTTPD2DQZ128rmk
    3229757440U,	// VCVTTPD2DQZ128rmkz
    551836166U,	// VCVTTPD2DQZ128rr
    3230702086U,	// VCVTTPD2DQZ128rrk
    3229669894U,	// VCVTTPD2DQZ128rrkz
    1355899U,	// VCVTTPD2DQZ256rm
    629774854U,	// VCVTTPD2DQZ256rmb
    630200838U,	// VCVTTPD2DQZ256rmbk
    629299718U,	// VCVTTPD2DQZ256rmbkz
    3230740603U,	// VCVTTPD2DQZ256rmk
    3230642299U,	// VCVTTPD2DQZ256rmkz
    551836166U,	// VCVTTPD2DQZ256rr
    3230702086U,	// VCVTTPD2DQZ256rrk
    3229669894U,	// VCVTTPD2DQZ256rrkz
    1513990U,	// VCVTTPD2DQZrm
    631872006U,	// VCVTTPD2DQZrmb
    632297990U,	// VCVTTPD2DQZrmbk
    631396870U,	// VCVTTPD2DQZrmbkz
    3230784006U,	// VCVTTPD2DQZrmk
    3230751238U,	// VCVTTPD2DQZrmkz
    551836166U,	// VCVTTPD2DQZrr
    551843581U,	// VCVTTPD2DQZrrb
    3230709501U,	// VCVTTPD2DQZrrbk
    3229677309U,	// VCVTTPD2DQZrrbkz
    3230702086U,	// VCVTTPD2DQZrrk
    3229669894U,	// VCVTTPD2DQZrrkz
    667648U,	// VCVTTPD2DQrm
    551836166U,	// VCVTTPD2DQrr
    662965U,	// VCVTTPD2QQZ128rm
    627678645U,	// VCVTTPD2QQZ128rmb
    628104629U,	// VCVTTPD2QQZ128rmbk
    627203509U,	// VCVTTPD2QQZ128rmbkz
    3230604725U,	// VCVTTPD2QQZ128rmk
    3229752757U,	// VCVTTPD2QQZ128rmkz
    551837109U,	// VCVTTPD2QQZ128rr
    3230703029U,	// VCVTTPD2QQZ128rrk
    3229670837U,	// VCVTTPD2QQZ128rrkz
    1351093U,	// VCVTTPD2QQZ256rm
    629775797U,	// VCVTTPD2QQZ256rmb
    630201781U,	// VCVTTPD2QQZ256rmbk
    629300661U,	// VCVTTPD2QQZ256rmbkz
    3230735797U,	// VCVTTPD2QQZ256rmk
    3230637493U,	// VCVTTPD2QQZ256rmkz
    551837109U,	// VCVTTPD2QQZ256rr
    3230703029U,	// VCVTTPD2QQZ256rrk
    3229670837U,	// VCVTTPD2QQZ256rrkz
    1514933U,	// VCVTTPD2QQZrm
    631872949U,	// VCVTTPD2QQZrmb
    632298933U,	// VCVTTPD2QQZrmbk
    631397813U,	// VCVTTPD2QQZrmbkz
    3230784949U,	// VCVTTPD2QQZrmk
    3230752181U,	// VCVTTPD2QQZrmkz
    551837109U,	// VCVTTPD2QQZrr
    551843659U,	// VCVTTPD2QQZrrb
    3230709579U,	// VCVTTPD2QQZrrbk
    3229677387U,	// VCVTTPD2QQZrrbkz
    3230703029U,	// VCVTTPD2QQZrrk
    3229670837U,	// VCVTTPD2QQZrrkz
    667673U,	// VCVTTPD2UDQZ128rm
    627678042U,	// VCVTTPD2UDQZ128rmb
    628104026U,	// VCVTTPD2UDQZ128rmbk
    627202906U,	// VCVTTPD2UDQZ128rmbkz
    3230609433U,	// VCVTTPD2UDQZ128rmk
    3229757465U,	// VCVTTPD2UDQZ128rmkz
    551836506U,	// VCVTTPD2UDQZ128rr
    3230702426U,	// VCVTTPD2UDQZ128rrk
    3229670234U,	// VCVTTPD2UDQZ128rrkz
    1355924U,	// VCVTTPD2UDQZ256rm
    629775194U,	// VCVTTPD2UDQZ256rmb
    630201178U,	// VCVTTPD2UDQZ256rmbk
    629300058U,	// VCVTTPD2UDQZ256rmbkz
    3230740628U,	// VCVTTPD2UDQZ256rmk
    3230642324U,	// VCVTTPD2UDQZ256rmkz
    551836506U,	// VCVTTPD2UDQZ256rr
    3230702426U,	// VCVTTPD2UDQZ256rrk
    3229670234U,	// VCVTTPD2UDQZ256rrkz
    1514330U,	// VCVTTPD2UDQZrm
    631872346U,	// VCVTTPD2UDQZrmb
    632298330U,	// VCVTTPD2UDQZrmbk
    631397210U,	// VCVTTPD2UDQZrmbkz
    3230784346U,	// VCVTTPD2UDQZrmk
    3230751578U,	// VCVTTPD2UDQZrmkz
    551836506U,	// VCVTTPD2UDQZrr
    551843619U,	// VCVTTPD2UDQZrrb
    3230709539U,	// VCVTTPD2UDQZrrbk
    3229677347U,	// VCVTTPD2UDQZrrbkz
    3230702426U,	// VCVTTPD2UDQZrrk
    3229670234U,	// VCVTTPD2UDQZrrkz
    663046U,	// VCVTTPD2UQQZ128rm
    627678726U,	// VCVTTPD2UQQZ128rmb
    628104710U,	// VCVTTPD2UQQZ128rmbk
    627203590U,	// VCVTTPD2UQQZ128rmbkz
    3230604806U,	// VCVTTPD2UQQZ128rmk
    3229752838U,	// VCVTTPD2UQQZ128rmkz
    551837190U,	// VCVTTPD2UQQZ128rr
    3230703110U,	// VCVTTPD2UQQZ128rrk
    3229670918U,	// VCVTTPD2UQQZ128rrkz
    1351174U,	// VCVTTPD2UQQZ256rm
    629775878U,	// VCVTTPD2UQQZ256rmb
    630201862U,	// VCVTTPD2UQQZ256rmbk
    629300742U,	// VCVTTPD2UQQZ256rmbkz
    3230735878U,	// VCVTTPD2UQQZ256rmk
    3230637574U,	// VCVTTPD2UQQZ256rmkz
    551837190U,	// VCVTTPD2UQQZ256rr
    3230703110U,	// VCVTTPD2UQQZ256rrk
    3229670918U,	// VCVTTPD2UQQZ256rrkz
    1515014U,	// VCVTTPD2UQQZrm
    631873030U,	// VCVTTPD2UQQZrmb
    632299014U,	// VCVTTPD2UQQZrmbk
    631397894U,	// VCVTTPD2UQQZrmbkz
    3230785030U,	// VCVTTPD2UQQZrmk
    3230752262U,	// VCVTTPD2UQQZrmkz
    551837190U,	// VCVTTPD2UQQZrr
    551843697U,	// VCVTTPD2UQQZrrb
    3230709617U,	// VCVTTPD2UQQZrrbk
    3229677425U,	// VCVTTPD2UQQZrrbkz
    3230703110U,	// VCVTTPD2UQQZrrk
    3229670918U,	// VCVTTPD2UQQZrrkz
    1350182U,	// VCVTTPS2DQYrm
    551836198U,	// VCVTTPS2DQYrr
    662054U,	// VCVTTPS2DQZ128rm
    629791270U,	// VCVTTPS2DQZ128rmb
    630397478U,	// VCVTTPS2DQZ128rmbk
    629316134U,	// VCVTTPS2DQZ128rmbkz
    3230603814U,	// VCVTTPS2DQZ128rmk
    3229751846U,	// VCVTTPS2DQZ128rmkz
    551836198U,	// VCVTTPS2DQZ128rr
    3230702118U,	// VCVTTPS2DQZ128rrk
    3229669926U,	// VCVTTPS2DQZ128rrkz
    1350182U,	// VCVTTPS2DQZ256rm
    631888422U,	// VCVTTPS2DQZ256rmb
    632494630U,	// VCVTTPS2DQZ256rmbk
    631413286U,	// VCVTTPS2DQZ256rmbkz
    3230734886U,	// VCVTTPS2DQZ256rmk
    3230636582U,	// VCVTTPS2DQZ256rmkz
    551836198U,	// VCVTTPS2DQZ256rr
    3230702118U,	// VCVTTPS2DQZ256rrk
    3229669926U,	// VCVTTPS2DQZ256rrkz
    1514022U,	// VCVTTPS2DQZrm
    633985574U,	// VCVTTPS2DQZrmb
    634591782U,	// VCVTTPS2DQZrmbk
    633510438U,	// VCVTTPS2DQZrmbkz
    3230784038U,	// VCVTTPS2DQZrmk
    3230751270U,	// VCVTTPS2DQZrmkz
    551836198U,	// VCVTTPS2DQZrr
    551843600U,	// VCVTTPS2DQZrrb
    3230709520U,	// VCVTTPS2DQZrrbk
    3229677328U,	// VCVTTPS2DQZrrbkz
    3230702118U,	// VCVTTPS2DQZrrk
    3229669926U,	// VCVTTPS2DQZrrkz
    662054U,	// VCVTTPS2DQrm
    551836198U,	// VCVTTPS2DQrr
    552181196U,	// VCVTTPS2QQZ128rm
    627695052U,	// VCVTTPS2QQZ128rmb
    628301260U,	// VCVTTPS2QQZ128rmbk
    627219916U,	// VCVTTPS2QQZ128rmbkz
    552607180U,	// VCVTTPS2QQZ128rmk
    551706060U,	// VCVTTPS2QQZ128rmkz
    551837132U,	// VCVTTPS2QQZ128rr
    3230703052U,	// VCVTTPS2QQZ128rrk
    3229670860U,	// VCVTTPS2QQZ128rrkz
    662988U,	// VCVTTPS2QQZ256rm
    629792204U,	// VCVTTPS2QQZ256rmb
    630398412U,	// VCVTTPS2QQZ256rmbk
    629317068U,	// VCVTTPS2QQZ256rmbkz
    3230604748U,	// VCVTTPS2QQZ256rmk
    3229752780U,	// VCVTTPS2QQZ256rmkz
    551837132U,	// VCVTTPS2QQZ256rr
    3230703052U,	// VCVTTPS2QQZ256rrk
    3229670860U,	// VCVTTPS2QQZ256rrkz
    1351116U,	// VCVTTPS2QQZrm
    631889356U,	// VCVTTPS2QQZrmb
    632495564U,	// VCVTTPS2QQZrmbk
    631414220U,	// VCVTTPS2QQZrmbkz
    3230735820U,	// VCVTTPS2QQZrmk
    3230637516U,	// VCVTTPS2QQZrmkz
    551837132U,	// VCVTTPS2QQZrr
    551843678U,	// VCVTTPS2QQZrrb
    3230709598U,	// VCVTTPS2QQZrrbk
    3229677406U,	// VCVTTPS2QQZrrbkz
    3230703052U,	// VCVTTPS2QQZrrk
    3229670860U,	// VCVTTPS2QQZrrkz
    662387U,	// VCVTTPS2UDQZ128rm
    629791603U,	// VCVTTPS2UDQZ128rmb
    630397811U,	// VCVTTPS2UDQZ128rmbk
    629316467U,	// VCVTTPS2UDQZ128rmbkz
    3230604147U,	// VCVTTPS2UDQZ128rmk
    3229752179U,	// VCVTTPS2UDQZ128rmkz
    551836531U,	// VCVTTPS2UDQZ128rr
    3230702451U,	// VCVTTPS2UDQZ128rrk
    3229670259U,	// VCVTTPS2UDQZ128rrkz
    1350515U,	// VCVTTPS2UDQZ256rm
    631888755U,	// VCVTTPS2UDQZ256rmb
    632494963U,	// VCVTTPS2UDQZ256rmbk
    631413619U,	// VCVTTPS2UDQZ256rmbkz
    3230735219U,	// VCVTTPS2UDQZ256rmk
    3230636915U,	// VCVTTPS2UDQZ256rmkz
    551836531U,	// VCVTTPS2UDQZ256rr
    3230702451U,	// VCVTTPS2UDQZ256rrk
    3229670259U,	// VCVTTPS2UDQZ256rrkz
    1514355U,	// VCVTTPS2UDQZrm
    633985907U,	// VCVTTPS2UDQZrmb
    634592115U,	// VCVTTPS2UDQZrmbk
    633510771U,	// VCVTTPS2UDQZrmbkz
    3230784371U,	// VCVTTPS2UDQZrmk
    3230751603U,	// VCVTTPS2UDQZrmkz
    551836531U,	// VCVTTPS2UDQZrr
    551843639U,	// VCVTTPS2UDQZrrb
    3230709559U,	// VCVTTPS2UDQZrrbk
    3229677367U,	// VCVTTPS2UDQZrrbkz
    3230702451U,	// VCVTTPS2UDQZrrk
    3229670259U,	// VCVTTPS2UDQZrrkz
    552181279U,	// VCVTTPS2UQQZ128rm
    627695135U,	// VCVTTPS2UQQZ128rmb
    628301343U,	// VCVTTPS2UQQZ128rmbk
    627219999U,	// VCVTTPS2UQQZ128rmbkz
    552607263U,	// VCVTTPS2UQQZ128rmk
    551706143U,	// VCVTTPS2UQQZ128rmkz
    551837215U,	// VCVTTPS2UQQZ128rr
    3230703135U,	// VCVTTPS2UQQZ128rrk
    3229670943U,	// VCVTTPS2UQQZ128rrkz
    663071U,	// VCVTTPS2UQQZ256rm
    629792287U,	// VCVTTPS2UQQZ256rmb
    630398495U,	// VCVTTPS2UQQZ256rmbk
    629317151U,	// VCVTTPS2UQQZ256rmbkz
    3230604831U,	// VCVTTPS2UQQZ256rmk
    3229752863U,	// VCVTTPS2UQQZ256rmkz
    551837215U,	// VCVTTPS2UQQZ256rr
    3230703135U,	// VCVTTPS2UQQZ256rrk
    3229670943U,	// VCVTTPS2UQQZ256rrkz
    1351199U,	// VCVTTPS2UQQZrm
    631889439U,	// VCVTTPS2UQQZrmb
    632495647U,	// VCVTTPS2UQQZrmbk
    631414303U,	// VCVTTPS2UQQZrmbkz
    3230735903U,	// VCVTTPS2UQQZrmk
    3230637599U,	// VCVTTPS2UQQZrmkz
    551837215U,	// VCVTTPS2UQQZrr
    551843717U,	// VCVTTPS2UQQZrrb
    3230709637U,	// VCVTTPS2UQQZrrbk
    3229677445U,	// VCVTTPS2UQQZrrbkz
    3230703135U,	// VCVTTPS2UQQZrrk
    3229670943U,	// VCVTTPS2UQQZrrkz
    552178420U,	// VCVTTSD2SI64Zrm
    552178420U,	// VCVTTSD2SI64Zrm_Int
    551834356U,	// VCVTTSD2SI64Zrr
    551834356U,	// VCVTTSD2SI64Zrr_Int
    551843503U,	// VCVTTSD2SI64Zrrb_Int
    552178420U,	// VCVTTSD2SI64rm
    552178420U,	// VCVTTSD2SI64rm_Int
    551834356U,	// VCVTTSD2SI64rr
    551834356U,	// VCVTTSD2SI64rr_Int
    552178420U,	// VCVTTSD2SIZrm
    552178420U,	// VCVTTSD2SIZrm_Int
    551834356U,	// VCVTTSD2SIZrr
    551834356U,	// VCVTTSD2SIZrr_Int
    551843503U,	// VCVTTSD2SIZrrb_Int
    552178420U,	// VCVTTSD2SIrm
    552178420U,	// VCVTTSD2SIrm_Int
    551834356U,	// VCVTTSD2SIrr
    551834356U,	// VCVTTSD2SIrr_Int
    552178466U,	// VCVTTSD2USI64Zrm
    552178466U,	// VCVTTSD2USI64Zrm_Int
    551834402U,	// VCVTTSD2USI64Zrr
    551834402U,	// VCVTTSD2USI64Zrr_Int
    551843541U,	// VCVTTSD2USI64Zrrb_Int
    552178466U,	// VCVTTSD2USIZrm
    552178466U,	// VCVTTSD2USIZrm_Int
    551834402U,	// VCVTTSD2USIZrr
    551834402U,	// VCVTTSD2USIZrr_Int
    551843541U,	// VCVTTSD2USIZrrb_Int
    552194827U,	// VCVTTSS2SI64Zrm
    552194827U,	// VCVTTSS2SI64Zrm_Int
    551834379U,	// VCVTTSS2SI64Zrr
    551834379U,	// VCVTTSS2SI64Zrr_Int
    551843522U,	// VCVTTSS2SI64Zrrb_Int
    552194827U,	// VCVTTSS2SI64rm
    552194827U,	// VCVTTSS2SI64rm_Int
    551834379U,	// VCVTTSS2SI64rr
    551834379U,	// VCVTTSS2SI64rr_Int
    552194827U,	// VCVTTSS2SIZrm
    552194827U,	// VCVTTSS2SIZrm_Int
    551834379U,	// VCVTTSS2SIZrr
    551834379U,	// VCVTTSS2SIZrr_Int
    551843522U,	// VCVTTSS2SIZrrb_Int
    552194827U,	// VCVTTSS2SIrm
    552194827U,	// VCVTTSS2SIrm_Int
    551834379U,	// VCVTTSS2SIrr
    551834379U,	// VCVTTSS2SIrr_Int
    552194875U,	// VCVTTSS2USI64Zrm
    552194875U,	// VCVTTSS2USI64Zrm_Int
    551834427U,	// VCVTTSS2USI64Zrr
    551834427U,	// VCVTTSS2USI64Zrr_Int
    551843561U,	// VCVTTSS2USI64Zrrb_Int
    552194875U,	// VCVTTSS2USIZrm
    552194875U,	// VCVTTSS2USIZrm_Int
    551834427U,	// VCVTTSS2USIZrr
    551834427U,	// VCVTTSS2USIZrr_Int
    551843561U,	// VCVTTSS2USIZrrb_Int
    551913959U,	// VCVTUDQ2PDZ128rm
    627395047U,	// VCVTUDQ2PDZ128rmb
    628509159U,	// VCVTUDQ2PDZ128rmbk
    627132903U,	// VCVTUDQ2PDZ128rmbkz
    552913383U,	// VCVTUDQ2PDZ128rmk
    551651815U,	// VCVTUDQ2PDZ128rmkz
    551832039U,	// VCVTUDQ2PDZ128rr
    3230697959U,	// VCVTUDQ2PDZ128rrk
    3229665767U,	// VCVTUDQ2PDZ128rrkz
    264679U,	// VCVTUDQ2PDZ256rm
    629492199U,	// VCVTUDQ2PDZ256rmb
    630606311U,	// VCVTUDQ2PDZ256rmbk
    629230055U,	// VCVTUDQ2PDZ256rmbkz
    3230992871U,	// VCVTUDQ2PDZ256rmk
    3229862375U,	// VCVTUDQ2PDZ256rmkz
    551832039U,	// VCVTUDQ2PDZ256rr
    3230697959U,	// VCVTUDQ2PDZ256rrk
    3229665767U,	// VCVTUDQ2PDZ256rrkz
    552946151U,	// VCVTUDQ2PDZrm
    631589351U,	// VCVTUDQ2PDZrmb
    632703463U,	// VCVTUDQ2PDZrmbk
    631327207U,	// VCVTUDQ2PDZrmbkz
    3231025639U,	// VCVTUDQ2PDZrmk
    3230878183U,	// VCVTUDQ2PDZrmkz
    551832039U,	// VCVTUDQ2PDZrr
    3230697959U,	// VCVTUDQ2PDZrrk
    3229665767U,	// VCVTUDQ2PDZrrkz
    271095U,	// VCVTUDQ2PSZ128rm
    629498615U,	// VCVTUDQ2PSZ128rmb
    630612727U,	// VCVTUDQ2PSZ128rmbk
    629236471U,	// VCVTUDQ2PSZ128rmbkz
    3230999287U,	// VCVTUDQ2PSZ128rmk
    3229868791U,	// VCVTUDQ2PSZ128rmkz
    551838455U,	// VCVTUDQ2PSZ128rr
    3230704375U,	// VCVTUDQ2PSZ128rrk
    3229672183U,	// VCVTUDQ2PSZ128rrkz
    552952567U,	// VCVTUDQ2PSZ256rm
    631595767U,	// VCVTUDQ2PSZ256rmb
    632709879U,	// VCVTUDQ2PSZ256rmbk
    631333623U,	// VCVTUDQ2PSZ256rmbkz
    3231032055U,	// VCVTUDQ2PSZ256rmk
    3230884599U,	// VCVTUDQ2PSZ256rmkz
    551838455U,	// VCVTUDQ2PSZ256rr
    3230704375U,	// VCVTUDQ2PSZ256rrk
    3229672183U,	// VCVTUDQ2PSZ256rrkz
    552444663U,	// VCVTUDQ2PSZrm
    633692919U,	// VCVTUDQ2PSZrmb
    634807031U,	// VCVTUDQ2PSZrmbk
    633430775U,	// VCVTUDQ2PSZrmbkz
    3231097591U,	// VCVTUDQ2PSZrmk
    3230900983U,	// VCVTUDQ2PSZrmkz
    551838455U,	// VCVTUDQ2PSZrr
    1499895U,	// VCVTUDQ2PSZrrb
    3230835447U,	// VCVTUDQ2PSZrrbk
    3230802679U,	// VCVTUDQ2PSZrrbkz
    3230704375U,	// VCVTUDQ2PSZrrk
    3229672183U,	// VCVTUDQ2PSZrrkz
    264702U,	// VCVTUQQ2PDZ128rm
    627411454U,	// VCVTUQQ2PDZ128rmb
    628410878U,	// VCVTUQQ2PDZ128rmbk
    627149310U,	// VCVTUQQ2PDZ128rmbkz
    3230992894U,	// VCVTUQQ2PDZ128rmk
    3229862398U,	// VCVTUQQ2PDZ128rmkz
    551832062U,	// VCVTUQQ2PDZ128rr
    3230697982U,	// VCVTUQQ2PDZ128rrk
    3229665790U,	// VCVTUQQ2PDZ128rrkz
    552946174U,	// VCVTUQQ2PDZ256rm
    629508606U,	// VCVTUQQ2PDZ256rmb
    630508030U,	// VCVTUQQ2PDZ256rmbk
    629246462U,	// VCVTUQQ2PDZ256rmbkz
    3231025662U,	// VCVTUQQ2PDZ256rmk
    3230878206U,	// VCVTUQQ2PDZ256rmkz
    551832062U,	// VCVTUQQ2PDZ256rr
    3230697982U,	// VCVTUQQ2PDZ256rrk
    3229665790U,	// VCVTUQQ2PDZ256rrkz
    552438270U,	// VCVTUQQ2PDZrm
    631605758U,	// VCVTUQQ2PDZrmb
    632605182U,	// VCVTUQQ2PDZrmbk
    631343614U,	// VCVTUQQ2PDZrmbkz
    3231091198U,	// VCVTUQQ2PDZrmk
    3230894590U,	// VCVTUQQ2PDZrmkz
    551832062U,	// VCVTUQQ2PDZrr
    1493502U,	// VCVTUQQ2PDZrrb
    3230829054U,	// VCVTUQQ2PDZrrbk
    3230796286U,	// VCVTUQQ2PDZrrbkz
    3230697982U,	// VCVTUQQ2PDZrrk
    3229665790U,	// VCVTUQQ2PDZrrkz
    274508U,	// VCVTUQQ2PSZ128rm
    627417870U,	// VCVTUQQ2PSZ128rmb
    628417294U,	// VCVTUQQ2PSZ128rmbk
    627155726U,	// VCVTUQQ2PSZ128rmbkz
    3231002700U,	// VCVTUQQ2PSZ128rmk
    3229872204U,	// VCVTUQQ2PSZ128rmkz
    551838478U,	// VCVTUQQ2PSZ128rr
    3230704398U,	// VCVTUQQ2PSZ128rrk
    3229672206U,	// VCVTUQQ2PSZ128rrkz
    552956113U,	// VCVTUQQ2PSZ256rm
    629515022U,	// VCVTUQQ2PSZ256rmb
    630514446U,	// VCVTUQQ2PSZ256rmbk
    629252878U,	// VCVTUQQ2PSZ256rmbkz
    3231035601U,	// VCVTUQQ2PSZ256rmk
    3230888145U,	// VCVTUQQ2PSZ256rmkz
    551838478U,	// VCVTUQQ2PSZ256rr
    3230704398U,	// VCVTUQQ2PSZ256rrk
    3229672206U,	// VCVTUQQ2PSZ256rrkz
    552444686U,	// VCVTUQQ2PSZrm
    631612174U,	// VCVTUQQ2PSZrmb
    632611598U,	// VCVTUQQ2PSZrmbk
    631350030U,	// VCVTUQQ2PSZrmbkz
    3231097614U,	// VCVTUQQ2PSZrmk
    3230901006U,	// VCVTUQQ2PSZrmkz
    551838478U,	// VCVTUQQ2PSZrr
    1499918U,	// VCVTUQQ2PSZrrb
    3230835470U,	// VCVTUQQ2PSZrrbk
    3230802702U,	// VCVTUQQ2PSZrrbkz
    3230704398U,	// VCVTUQQ2PSZrrk
    3229672206U,	// VCVTUQQ2PSZrrkz
    283202614U,	// VCVTUSI2SDZrm
    283202614U,	// VCVTUSI2SDZrm_Int
    811652150U,	// VCVTUSI2SDZrr
    811652150U,	// VCVTUSI2SDZrr_Int
    283203318U,	// VCVTUSI2SSZrm
    283203318U,	// VCVTUSI2SSZrm_Int
    811652854U,	// VCVTUSI2SSZrr
    811652854U,	// VCVTUSI2SSZrr_Int
    155244278U,	// VCVTUSI2SSZrrb_Int
    283220803U,	// VCVTUSI642SDZrm
    283220803U,	// VCVTUSI642SDZrm_Int
    811653955U,	// VCVTUSI642SDZrr
    811653955U,	// VCVTUSI642SDZrr_Int
    155245379U,	// VCVTUSI642SDZrrb_Int
    283221770U,	// VCVTUSI642SSZrm
    283221770U,	// VCVTUSI642SSZrm_Int
    811654922U,	// VCVTUSI642SSZrr
    811654922U,	// VCVTUSI642SSZrr_Int
    155246346U,	// VCVTUSI642SSZrrb_Int
    325446245U,	// VDBPSADBWZ128rmi
    1983113829U,	// VDBPSADBWZ128rmik
    1179920997U,	// VDBPSADBWZ128rmikz
    1088825957U,	// VDBPSADBWZ128rri
    2163141221U,	// VDBPSADBWZ128rrik
    1357589093U,	// VDBPSADBWZ128rrikz
    375777893U,	// VDBPSADBWZ256rmi
    1989405285U,	// VDBPSADBWZ256rmik
    1186212453U,	// VDBPSADBWZ256rmikz
    1088825957U,	// VDBPSADBWZ256rri
    2163141221U,	// VDBPSADBWZ256rrik
    1357589093U,	// VDBPSADBWZ256rrikz
    382069349U,	// VDBPSADBWZrmi
    1995696741U,	// VDBPSADBWZrmik
    1192503909U,	// VDBPSADBWZrmikz
    1088825957U,	// VDBPSADBWZrri
    2163141221U,	// VDBPSADBWZrrik
    1357589093U,	// VDBPSADBWZrrikz
    812617022U,	// VDIVPDYrm
    811650366U,	// VDIVPDYrr
    811732286U,	// VDIVPDZ128rm
    358763838U,	// VDIVPDZ128rmb
    1433390398U,	// VDIVPDZ128rmbk
    1164971326U,	// VDIVPDZ128rmbkz
    86986046U,	// VDIVPDZ128rmk
    890178878U,	// VDIVPDZ128rmkz
    811650366U,	// VDIVPDZ128rr
    87051582U,	// VDIVPDZ128rrk
    890277182U,	// VDIVPDZ128rrkz
    812617022U,	// VDIVPDZ256rm
    360860990U,	// VDIVPDZ256rmb
    1435487550U,	// VDIVPDZ256rmbk
    1167068478U,	// VDIVPDZ256rmbkz
    87084350U,	// VDIVPDZ256rmk
    890309950U,	// VDIVPDZ256rmkz
    811650366U,	// VDIVPDZ256rr
    87051582U,	// VDIVPDZ256rrk
    890277182U,	// VDIVPDZ256rrkz
    812731710U,	// VDIVPDZrm
    362958142U,	// VDIVPDZrmb
    1437584702U,	// VDIVPDZrmbk
    1169165630U,	// VDIVPDZrmbkz
    87133502U,	// VDIVPDZrmk
    890359102U,	// VDIVPDZrmkz
    811650366U,	// VDIVPDZrr
    812780862U,	// VDIVPDZrrb
    87182654U,	// VDIVPDZrrbk
    890408254U,	// VDIVPDZrrbkz
    87051582U,	// VDIVPDZrrk
    890277182U,	// VDIVPDZrrkz
    811732286U,	// VDIVPDrm
    811650366U,	// VDIVPDrr
    812623519U,	// VDIVPSYrm
    811656863U,	// VDIVPSYrr
    811738783U,	// VDIVPSZ128rm
    360883871U,	// VDIVPSZ128rmb
    1435690655U,	// VDIVPSZ128rmbk
    1167271583U,	// VDIVPSZ128rmbkz
    86992543U,	// VDIVPSZ128rmk
    890185375U,	// VDIVPSZ128rmkz
    811656863U,	// VDIVPSZ128rr
    87058079U,	// VDIVPSZ128rrk
    890283679U,	// VDIVPSZ128rrkz
    812623519U,	// VDIVPSZ256rm
    362981023U,	// VDIVPSZ256rmb
    1437787807U,	// VDIVPSZ256rmbk
    1169368735U,	// VDIVPSZ256rmbkz
    87090847U,	// VDIVPSZ256rmk
    890316447U,	// VDIVPSZ256rmkz
    811656863U,	// VDIVPSZ256rr
    87058079U,	// VDIVPSZ256rrk
    890283679U,	// VDIVPSZ256rrkz
    812738207U,	// VDIVPSZrm
    365078175U,	// VDIVPSZrmb
    1439884959U,	// VDIVPSZrmbk
    1171465887U,	// VDIVPSZrmbkz
    87139999U,	// VDIVPSZrmk
    890365599U,	// VDIVPSZrmkz
    811656863U,	// VDIVPSZrr
    812787359U,	// VDIVPSZrrb
    87189151U,	// VDIVPSZrrbk
    890414751U,	// VDIVPSZrrbkz
    87058079U,	// VDIVPSZrrk
    890283679U,	// VDIVPSZrrkz
    811738783U,	// VDIVPSrm
    811656863U,	// VDIVPSrr
    283267069U,	// VDIVSDZrm
    283267069U,	// VDIVSDZrm_Int
    1357893629U,	// VDIVSDZrm_Intk
    1089474557U,	// VDIVSDZrm_Intkz
    811651069U,	// VDIVSDZrr
    811651069U,	// VDIVSDZrr_Int
    87052285U,	// VDIVSDZrr_Intk
    890277885U,	// VDIVSDZrr_Intkz
    812781565U,	// VDIVSDZrrb_Int
    87183357U,	// VDIVSDZrrb_Intk
    890408957U,	// VDIVSDZrrb_Intkz
    283267069U,	// VDIVSDrm
    283267069U,	// VDIVSDrm_Int
    811651069U,	// VDIVSDrr
    811651069U,	// VDIVSDrr_Int
    283289821U,	// VDIVSSZrm
    283289821U,	// VDIVSSZrm_Int
    1358096605U,	// VDIVSSZrm_Intk
    1089677533U,	// VDIVSSZrm_Intkz
    811657437U,	// VDIVSSZrr
    811657437U,	// VDIVSSZrr_Int
    87058653U,	// VDIVSSZrr_Intk
    890284253U,	// VDIVSSZrr_Intkz
    812787933U,	// VDIVSSZrrb_Int
    87189725U,	// VDIVSSZrrb_Intk
    890415325U,	// VDIVSSZrrb_Intkz
    283289821U,	// VDIVSSrm
    283289821U,	// VDIVSSrm_Int
    811657437U,	// VDIVSSrr
    811657437U,	// VDIVSSrr_Int
    300272728U,	// VDPPDrmi
    1088818264U,	// VDPPDrri
    375776657U,	// VDPPSYrmi
    1088824721U,	// VDPPSYrri
    300279185U,	// VDPPSrmi
    1088824721U,	// VDPPSrri
    221519U,	// VERRm
    24911U,	// VERRr
    224626U,	// VERWm
    28018U,	// VERWr
    1509843U,	// VEXP2PDZm
    631867859U,	// VEXP2PDZmb
    632293843U,	// VEXP2PDZmbk
    631392723U,	// VEXP2PDZmbkz
    3230779859U,	// VEXP2PDZmk
    3230747091U,	// VEXP2PDZmkz
    551832019U,	// VEXP2PDZr
    551843250U,	// VEXP2PDZrb
    3230709170U,	// VEXP2PDZrbk
    3229676978U,	// VEXP2PDZrbkz
    3230697939U,	// VEXP2PDZrk
    3229665747U,	// VEXP2PDZrkz
    1516259U,	// VEXP2PSZm
    633987811U,	// VEXP2PSZmb
    634594019U,	// VEXP2PSZmbk
    633512675U,	// VEXP2PSZmbkz
    3230786275U,	// VEXP2PSZmk
    3230753507U,	// VEXP2PSZmkz
    551838435U,	// VEXP2PSZr
    551843755U,	// VEXP2PSZrb
    3230709675U,	// VEXP2PSZrbk
    3229677483U,	// VEXP2PSZrbkz
    3230704355U,	// VEXP2PSZrk
    3229672163U,	// VEXP2PSZrkz
    658274U,	// VEXPANDPDZ128rm
    3230600034U,	// VEXPANDPDZ128rmk
    3229748066U,	// VEXPANDPDZ128rmkz
    551832418U,	// VEXPANDPDZ128rr
    3230698338U,	// VEXPANDPDZ128rrk
    3229666146U,	// VEXPANDPDZ128rrkz
    1346402U,	// VEXPANDPDZ256rm
    3230731106U,	// VEXPANDPDZ256rmk
    3230632802U,	// VEXPANDPDZ256rmkz
    551832418U,	// VEXPANDPDZ256rr
    3230698338U,	// VEXPANDPDZ256rrk
    3229666146U,	// VEXPANDPDZ256rrkz
    1510242U,	// VEXPANDPDZrm
    3230780258U,	// VEXPANDPDZrmk
    3230747490U,	// VEXPANDPDZrmkz
    551832418U,	// VEXPANDPDZrr
    3230698338U,	// VEXPANDPDZrrk
    3229666146U,	// VEXPANDPDZrrkz
    664694U,	// VEXPANDPSZ128rm
    3230606454U,	// VEXPANDPSZ128rmk
    3229754486U,	// VEXPANDPSZ128rmkz
    551838838U,	// VEXPANDPSZ128rr
    3230704758U,	// VEXPANDPSZ128rrk
    3229672566U,	// VEXPANDPSZ128rrkz
    1352822U,	// VEXPANDPSZ256rm
    3230737526U,	// VEXPANDPSZ256rmk
    3230639222U,	// VEXPANDPSZ256rmkz
    551838838U,	// VEXPANDPSZ256rr
    3230704758U,	// VEXPANDPSZ256rrk
    3229672566U,	// VEXPANDPSZ256rrkz
    1516662U,	// VEXPANDPSZrm
    3230786678U,	// VEXPANDPSZrmk
    3230753910U,	// VEXPANDPSZrmkz
    551838838U,	// VEXPANDPSZrr
    3230704758U,	// VEXPANDPSZrrk
    3229672566U,	// VEXPANDPSZrrkz
    1126466160U,	// VEXTRACTF128mr
    283427440U,	// VEXTRACTF128rr
    1126465941U,	// VEXTRACTF32x4Z256mr
    1227211157U,	// VEXTRACTF32x4Z256mrk
    283427221U,	// VEXTRACTF32x4Z256rr
    1357578645U,	// VEXTRACTF32x4Z256rrk
    1088815509U,	// VEXTRACTF32x4Z256rrkz
    1126465941U,	// VEXTRACTF32x4Zmr
    1227211157U,	// VEXTRACTF32x4Zmrk
    283427221U,	// VEXTRACTF32x4Zrr
    1357578645U,	// VEXTRACTF32x4Zrrk
    1088815509U,	// VEXTRACTF32x4Zrrkz
    1663337180U,	// VEXTRACTF32x8Zmr
    1764082396U,	// VEXTRACTF32x8Zmrk
    283427548U,	// VEXTRACTF32x8Zrr
    1357578972U,	// VEXTRACTF32x8Zrrk
    1088815836U,	// VEXTRACTF32x8Zrrkz
    1126465728U,	// VEXTRACTF64x2Z256mr
    1227210944U,	// VEXTRACTF64x2Z256mrk
    283427008U,	// VEXTRACTF64x2Z256rr
    1357578432U,	// VEXTRACTF64x2Z256rrk
    1088815296U,	// VEXTRACTF64x2Z256rrkz
    1126465728U,	// VEXTRACTF64x2Zmr
    1227210944U,	// VEXTRACTF64x2Zmrk
    283427008U,	// VEXTRACTF64x2Zrr
    1357578432U,	// VEXTRACTF64x2Zrrk
    1088815296U,	// VEXTRACTF64x2Zrrkz
    1663336957U,	// VEXTRACTF64x4Zmr
    1764082173U,	// VEXTRACTF64x4Zmrk
    283427325U,	// VEXTRACTF64x4Zrr
    1357578749U,	// VEXTRACTF64x4Zrrk
    1088815613U,	// VEXTRACTF64x4Zrrkz
    1931772583U,	// VEXTRACTI128mr
    283427495U,	// VEXTRACTI128rr
    1931772367U,	// VEXTRACTI32x4Z256mr
    2032517583U,	// VEXTRACTI32x4Z256mrk
    283427279U,	// VEXTRACTI32x4Z256rr
    1357578703U,	// VEXTRACTI32x4Z256rrk
    1088815567U,	// VEXTRACTI32x4Z256rrkz
    1931772367U,	// VEXTRACTI32x4Zmr
    2032517583U,	// VEXTRACTI32x4Zmrk
    283427279U,	// VEXTRACTI32x4Zrr
    1357578703U,	// VEXTRACTI32x4Zrrk
    1088815567U,	// VEXTRACTI32x4Zrrkz
    2200208138U,	// VEXTRACTI32x8Zmr
    2300953354U,	// VEXTRACTI32x8Zmrk
    283427594U,	// VEXTRACTI32x8Zrr
    1357579018U,	// VEXTRACTI32x8Zrrk
    1088815882U,	// VEXTRACTI32x8Zrrkz
    1931772154U,	// VEXTRACTI64x2Z256mr
    2032517370U,	// VEXTRACTI64x2Z256mrk
    283427066U,	// VEXTRACTI64x2Z256rr
    1357578490U,	// VEXTRACTI64x2Z256rrk
    1088815354U,	// VEXTRACTI64x2Z256rrkz
    1931772154U,	// VEXTRACTI64x2Zmr
    2032517370U,	// VEXTRACTI64x2Zmrk
    283427066U,	// VEXTRACTI64x2Zrr
    1357578490U,	// VEXTRACTI64x2Zrrk
    1088815354U,	// VEXTRACTI64x2Zrrkz
    2200207915U,	// VEXTRACTI64x4Zmr
    2300953131U,	// VEXTRACTI64x4Zmrk
    283427371U,	// VEXTRACTI64x4Zrr
    1357578795U,	// VEXTRACTI64x4Zrrk
    1088815659U,	// VEXTRACTI64x4Zrrkz
    3810829866U,	// VEXTRACTPSZmr
    283436586U,	// VEXTRACTPSZrr
    3810829866U,	// VEXTRACTPSmr
    283436586U,	// VEXTRACTPSrr
    3079932977U,	// VFIXUPIMMPDZ128rmbi
    3111373873U,	// VFIXUPIMMPDZ128rmbik
    3111373873U,	// VFIXUPIMMPDZ128rmbikz
    1202981937U,	// VFIXUPIMMPDZ128rmi
    2039729201U,	// VFIXUPIMMPDZ128rmik
    2576600113U,	// VFIXUPIMMPDZ128rmikz
    1357581361U,	// VFIXUPIMMPDZ128rri
    2163133489U,	// VFIXUPIMMPDZ128rrik
    2163133489U,	// VFIXUPIMMPDZ128rrikz
    1737755697U,	// VFIXUPIMMPDZ256rmbi
    1769196593U,	// VFIXUPIMMPDZ256rmbik
    1769196593U,	// VFIXUPIMMPDZ256rmbikz
    1205079089U,	// VFIXUPIMMPDZ256rmi
    2041826353U,	// VFIXUPIMMPDZ256rmik
    2578697265U,	// VFIXUPIMMPDZ256rmikz
    1357581361U,	// VFIXUPIMMPDZ256rri
    2163133489U,	// VFIXUPIMMPDZ256rrik
    2163133489U,	// VFIXUPIMMPDZ256rrikz
    2543062065U,	// VFIXUPIMMPDZrmbi
    2574502961U,	// VFIXUPIMMPDZrmbik
    2574502961U,	// VFIXUPIMMPDZrmbikz
    1209273393U,	// VFIXUPIMMPDZrmi
    2043923505U,	// VFIXUPIMMPDZrmik
    2580794417U,	// VFIXUPIMMPDZrmikz
    1357581361U,	// VFIXUPIMMPDZrri
    1481313329U,	// VFIXUPIMMPDZrrib
    2286865457U,	// VFIXUPIMMPDZrribk
    2286865457U,	// VFIXUPIMMPDZrribkz
    2163133489U,	// VFIXUPIMMPDZrrik
    2163133489U,	// VFIXUPIMMPDZrrikz
    1752442193U,	// VFIXUPIMMPSZ128rmbi
    1777591633U,	// VFIXUPIMMPSZ128rmbik
    1777591633U,	// VFIXUPIMMPSZ128rmbikz
    1202988369U,	// VFIXUPIMMPSZ128rmi
    2039735633U,	// VFIXUPIMMPSZ128rmik
    2576606545U,	// VFIXUPIMMPSZ128rmikz
    1357587793U,	// VFIXUPIMMPSZ128rri
    2163139921U,	// VFIXUPIMMPSZ128rrik
    2163139921U,	// VFIXUPIMMPSZ128rrikz
    2557748561U,	// VFIXUPIMMPSZ256rmbi
    2582898001U,	// VFIXUPIMMPSZ256rmbik
    2582898001U,	// VFIXUPIMMPSZ256rmbikz
    1205085521U,	// VFIXUPIMMPSZ256rmi
    2041832785U,	// VFIXUPIMMPSZ256rmik
    2578703697U,	// VFIXUPIMMPSZ256rmikz
    1357587793U,	// VFIXUPIMMPSZ256rri
    2163139921U,	// VFIXUPIMMPSZ256rrik
    2163139921U,	// VFIXUPIMMPSZ256rrikz
    2826184017U,	// VFIXUPIMMPSZrmbi
    2851333457U,	// VFIXUPIMMPSZrmbik
    2851333457U,	// VFIXUPIMMPSZrmbikz
    1209279825U,	// VFIXUPIMMPSZrmi
    2043929937U,	// VFIXUPIMMPSZrmik
    2580800849U,	// VFIXUPIMMPSZrmikz
    1357587793U,	// VFIXUPIMMPSZrri
    1481319761U,	// VFIXUPIMMPSZrrib
    2286871889U,	// VFIXUPIMMPSZrribk
    2286871889U,	// VFIXUPIMMPSZrribkz
    2163139921U,	// VFIXUPIMMPSZrrik
    2163139921U,	// VFIXUPIMMPSZrrikz
    932450137U,	// VFIXUPIMMSDZrmi
    963891033U,	// VFIXUPIMMSDZrmik
    963891033U,	// VFIXUPIMMSDZrmikz
    1357582169U,	// VFIXUPIMMSDZrri
    1481314137U,	// VFIXUPIMMSDZrrib
    2286866265U,	// VFIXUPIMMSDZrribk
    2286866265U,	// VFIXUPIMMSDZrribkz
    2163134297U,	// VFIXUPIMMSDZrrik
    2163134297U,	// VFIXUPIMMSDZrrikz
    947136619U,	// VFIXUPIMMSSZrmi
    972286059U,	// VFIXUPIMMSSZrmik
    972286059U,	// VFIXUPIMMSSZrmikz
    1357588587U,	// VFIXUPIMMSSZrri
    1481320555U,	// VFIXUPIMMSSZrrib
    2286872683U,	// VFIXUPIMMSSZrribk
    2286872683U,	// VFIXUPIMMSSZrribkz
    2163140715U,	// VFIXUPIMMSSZrrik
    2163140715U,	// VFIXUPIMMSSZrrikz
    890309015U,	// VFMADD132PDYm
    890276247U,	// VFMADD132PDYr
    890177943U,	// VFMADD132PDZ128m
    1164970391U,	// VFMADD132PDZ128mb
    1433389463U,	// VFMADD132PDZ128mbk
    1433389463U,	// VFMADD132PDZ128mbkz
    86985111U,	// VFMADD132PDZ128mk
    89082263U,	// VFMADD132PDZ128mkz
    890276247U,	// VFMADD132PDZ128r
    87050647U,	// VFMADD132PDZ128rk
    89147799U,	// VFMADD132PDZ128rkz
    890309015U,	// VFMADD132PDZ256m
    1167067543U,	// VFMADD132PDZ256mb
    1435486615U,	// VFMADD132PDZ256mbk
    1435486615U,	// VFMADD132PDZ256mbkz
    87083415U,	// VFMADD132PDZ256mk
    89180567U,	// VFMADD132PDZ256mkz
    890276247U,	// VFMADD132PDZ256r
    87050647U,	// VFMADD132PDZ256rk
    89147799U,	// VFMADD132PDZ256rkz
    890358167U,	// VFMADD132PDZm
    1169164695U,	// VFMADD132PDZmb
    1437583767U,	// VFMADD132PDZmbk
    1437583767U,	// VFMADD132PDZmbkz
    87132567U,	// VFMADD132PDZmk
    89229719U,	// VFMADD132PDZmkz
    890276247U,	// VFMADD132PDZr
    890407319U,	// VFMADD132PDZrb
    87181719U,	// VFMADD132PDZrbk
    89278871U,	// VFMADD132PDZrbkz
    87050647U,	// VFMADD132PDZrk
    89147799U,	// VFMADD132PDZrkz
    890177943U,	// VFMADD132PDm
    890276247U,	// VFMADD132PDr
    890315409U,	// VFMADD132PSYm
    890282641U,	// VFMADD132PSYr
    890184337U,	// VFMADD132PSZ128m
    1167270545U,	// VFMADD132PSZ128mb
    1435689617U,	// VFMADD132PSZ128mbk
    1435689617U,	// VFMADD132PSZ128mbkz
    86991505U,	// VFMADD132PSZ128mk
    89088657U,	// VFMADD132PSZ128mkz
    890282641U,	// VFMADD132PSZ128r
    87057041U,	// VFMADD132PSZ128rk
    89154193U,	// VFMADD132PSZ128rkz
    890315409U,	// VFMADD132PSZ256m
    1169367697U,	// VFMADD132PSZ256mb
    1437786769U,	// VFMADD132PSZ256mbk
    1437786769U,	// VFMADD132PSZ256mbkz
    87089809U,	// VFMADD132PSZ256mk
    89186961U,	// VFMADD132PSZ256mkz
    890282641U,	// VFMADD132PSZ256r
    87057041U,	// VFMADD132PSZ256rk
    89154193U,	// VFMADD132PSZ256rkz
    890364561U,	// VFMADD132PSZm
    1171464849U,	// VFMADD132PSZmb
    1439883921U,	// VFMADD132PSZmbk
    1439883921U,	// VFMADD132PSZmbkz
    87138961U,	// VFMADD132PSZmk
    89236113U,	// VFMADD132PSZmkz
    890282641U,	// VFMADD132PSZr
    890413713U,	// VFMADD132PSZrb
    87188113U,	// VFMADD132PSZrbk
    89285265U,	// VFMADD132PSZrbkz
    87057041U,	// VFMADD132PSZrk
    89154193U,	// VFMADD132PSZrkz
    890184337U,	// VFMADD132PSm
    890282641U,	// VFMADD132PSr
    1089474109U,	// VFMADD132SDZm
    1089474109U,	// VFMADD132SDZm_Int
    1357893181U,	// VFMADD132SDZm_Intk
    1357893181U,	// VFMADD132SDZm_Intkz
    890277437U,	// VFMADD132SDZr
    890277437U,	// VFMADD132SDZr_Int
    87051837U,	// VFMADD132SDZr_Intk
    89148989U,	// VFMADD132SDZr_Intkz
    890277437U,	// VFMADD132SDZrb
    890408509U,	// VFMADD132SDZrb_Int
    87182909U,	// VFMADD132SDZrb_Intk
    89280061U,	// VFMADD132SDZrb_Intkz
    1089474109U,	// VFMADD132SDm
    1089474109U,	// VFMADD132SDm_Int
    890277437U,	// VFMADD132SDr
    890277437U,	// VFMADD132SDr_Int
    1089677120U,	// VFMADD132SSZm
    1089677120U,	// VFMADD132SSZm_Int
    1358096192U,	// VFMADD132SSZm_Intk
    1358096192U,	// VFMADD132SSZm_Intkz
    890283840U,	// VFMADD132SSZr
    890283840U,	// VFMADD132SSZr_Int
    87058240U,	// VFMADD132SSZr_Intk
    89155392U,	// VFMADD132SSZr_Intkz
    890283840U,	// VFMADD132SSZrb
    890414912U,	// VFMADD132SSZrb_Int
    87189312U,	// VFMADD132SSZrb_Intk
    89286464U,	// VFMADD132SSZrb_Intkz
    1089677120U,	// VFMADD132SSm
    1089677120U,	// VFMADD132SSm_Int
    890283840U,	// VFMADD132SSr
    890283840U,	// VFMADD132SSr_Int
    890309211U,	// VFMADD213PDYm
    890276443U,	// VFMADD213PDYr
    890178139U,	// VFMADD213PDZ128m
    1164970587U,	// VFMADD213PDZ128mb
    1433389659U,	// VFMADD213PDZ128mbk
    1433389659U,	// VFMADD213PDZ128mbkz
    86985307U,	// VFMADD213PDZ128mk
    89082459U,	// VFMADD213PDZ128mkz
    890276443U,	// VFMADD213PDZ128r
    87050843U,	// VFMADD213PDZ128rk
    89147995U,	// VFMADD213PDZ128rkz
    890309211U,	// VFMADD213PDZ256m
    1167067739U,	// VFMADD213PDZ256mb
    1435486811U,	// VFMADD213PDZ256mbk
    1435486811U,	// VFMADD213PDZ256mbkz
    87083611U,	// VFMADD213PDZ256mk
    89180763U,	// VFMADD213PDZ256mkz
    890276443U,	// VFMADD213PDZ256r
    87050843U,	// VFMADD213PDZ256rk
    89147995U,	// VFMADD213PDZ256rkz
    890358363U,	// VFMADD213PDZm
    1169164891U,	// VFMADD213PDZmb
    1437583963U,	// VFMADD213PDZmbk
    1437583963U,	// VFMADD213PDZmbkz
    87132763U,	// VFMADD213PDZmk
    89229915U,	// VFMADD213PDZmkz
    890276443U,	// VFMADD213PDZr
    890407515U,	// VFMADD213PDZrb
    87181915U,	// VFMADD213PDZrbk
    89279067U,	// VFMADD213PDZrbkz
    87050843U,	// VFMADD213PDZrk
    89147995U,	// VFMADD213PDZrkz
    890178139U,	// VFMADD213PDm
    890276443U,	// VFMADD213PDr
    890315616U,	// VFMADD213PSYm
    890282848U,	// VFMADD213PSYr
    890184544U,	// VFMADD213PSZ128m
    1167270752U,	// VFMADD213PSZ128mb
    1435689824U,	// VFMADD213PSZ128mbk
    1435689824U,	// VFMADD213PSZ128mbkz
    86991712U,	// VFMADD213PSZ128mk
    89088864U,	// VFMADD213PSZ128mkz
    890282848U,	// VFMADD213PSZ128r
    87057248U,	// VFMADD213PSZ128rk
    89154400U,	// VFMADD213PSZ128rkz
    890315616U,	// VFMADD213PSZ256m
    1169367904U,	// VFMADD213PSZ256mb
    1437786976U,	// VFMADD213PSZ256mbk
    1437786976U,	// VFMADD213PSZ256mbkz
    87090016U,	// VFMADD213PSZ256mk
    89187168U,	// VFMADD213PSZ256mkz
    890282848U,	// VFMADD213PSZ256r
    87057248U,	// VFMADD213PSZ256rk
    89154400U,	// VFMADD213PSZ256rkz
    890364768U,	// VFMADD213PSZm
    1171465056U,	// VFMADD213PSZmb
    1439884128U,	// VFMADD213PSZmbk
    1439884128U,	// VFMADD213PSZmbkz
    87139168U,	// VFMADD213PSZmk
    89236320U,	// VFMADD213PSZmkz
    890282848U,	// VFMADD213PSZr
    890413920U,	// VFMADD213PSZrb
    87188320U,	// VFMADD213PSZrbk
    89285472U,	// VFMADD213PSZrbkz
    87057248U,	// VFMADD213PSZrk
    89154400U,	// VFMADD213PSZrkz
    890184544U,	// VFMADD213PSm
    890282848U,	// VFMADD213PSr
    1089474174U,	// VFMADD213SDZm
    1089474174U,	// VFMADD213SDZm_Int
    1357893246U,	// VFMADD213SDZm_Intk
    1357893246U,	// VFMADD213SDZm_Intkz
    890277502U,	// VFMADD213SDZr
    890277502U,	// VFMADD213SDZr_Int
    87051902U,	// VFMADD213SDZr_Intk
    89149054U,	// VFMADD213SDZr_Intkz
    890277502U,	// VFMADD213SDZrb
    890408574U,	// VFMADD213SDZrb_Int
    87182974U,	// VFMADD213SDZrb_Intk
    89280126U,	// VFMADD213SDZrb_Intkz
    1089474174U,	// VFMADD213SDm
    1089474174U,	// VFMADD213SDm_Int
    890277502U,	// VFMADD213SDr
    890277502U,	// VFMADD213SDr_Int
    1089677185U,	// VFMADD213SSZm
    1089677185U,	// VFMADD213SSZm_Int
    1358096257U,	// VFMADD213SSZm_Intk
    1358096257U,	// VFMADD213SSZm_Intkz
    890283905U,	// VFMADD213SSZr
    890283905U,	// VFMADD213SSZr_Int
    87058305U,	// VFMADD213SSZr_Intk
    89155457U,	// VFMADD213SSZr_Intkz
    890283905U,	// VFMADD213SSZrb
    890414977U,	// VFMADD213SSZrb_Int
    87189377U,	// VFMADD213SSZrb_Intk
    89286529U,	// VFMADD213SSZrb_Intkz
    1089677185U,	// VFMADD213SSm
    1089677185U,	// VFMADD213SSm_Int
    890283905U,	// VFMADD213SSr
    890283905U,	// VFMADD213SSr_Int
    890308929U,	// VFMADD231PDYm
    890276161U,	// VFMADD231PDYr
    890177857U,	// VFMADD231PDZ128m
    1164970305U,	// VFMADD231PDZ128mb
    1433389377U,	// VFMADD231PDZ128mbk
    1433389377U,	// VFMADD231PDZ128mbkz
    86985025U,	// VFMADD231PDZ128mk
    89082177U,	// VFMADD231PDZ128mkz
    890276161U,	// VFMADD231PDZ128r
    87050561U,	// VFMADD231PDZ128rk
    89147713U,	// VFMADD231PDZ128rkz
    890308929U,	// VFMADD231PDZ256m
    1167067457U,	// VFMADD231PDZ256mb
    1435486529U,	// VFMADD231PDZ256mbk
    1435486529U,	// VFMADD231PDZ256mbkz
    87083329U,	// VFMADD231PDZ256mk
    89180481U,	// VFMADD231PDZ256mkz
    890276161U,	// VFMADD231PDZ256r
    87050561U,	// VFMADD231PDZ256rk
    89147713U,	// VFMADD231PDZ256rkz
    890358081U,	// VFMADD231PDZm
    1169164609U,	// VFMADD231PDZmb
    1437583681U,	// VFMADD231PDZmbk
    1437583681U,	// VFMADD231PDZmbkz
    87132481U,	// VFMADD231PDZmk
    89229633U,	// VFMADD231PDZmkz
    890276161U,	// VFMADD231PDZr
    890407233U,	// VFMADD231PDZrb
    87181633U,	// VFMADD231PDZrbk
    89278785U,	// VFMADD231PDZrbkz
    87050561U,	// VFMADD231PDZrk
    89147713U,	// VFMADD231PDZrkz
    890177857U,	// VFMADD231PDm
    890276161U,	// VFMADD231PDr
    890315323U,	// VFMADD231PSYm
    890282555U,	// VFMADD231PSYr
    890184251U,	// VFMADD231PSZ128m
    1167270459U,	// VFMADD231PSZ128mb
    1435689531U,	// VFMADD231PSZ128mbk
    1435689531U,	// VFMADD231PSZ128mbkz
    86991419U,	// VFMADD231PSZ128mk
    89088571U,	// VFMADD231PSZ128mkz
    890282555U,	// VFMADD231PSZ128r
    87056955U,	// VFMADD231PSZ128rk
    89154107U,	// VFMADD231PSZ128rkz
    890315323U,	// VFMADD231PSZ256m
    1169367611U,	// VFMADD231PSZ256mb
    1437786683U,	// VFMADD231PSZ256mbk
    1437786683U,	// VFMADD231PSZ256mbkz
    87089723U,	// VFMADD231PSZ256mk
    89186875U,	// VFMADD231PSZ256mkz
    890282555U,	// VFMADD231PSZ256r
    87056955U,	// VFMADD231PSZ256rk
    89154107U,	// VFMADD231PSZ256rkz
    890364475U,	// VFMADD231PSZm
    1171464763U,	// VFMADD231PSZmb
    1439883835U,	// VFMADD231PSZmbk
    1439883835U,	// VFMADD231PSZmbkz
    87138875U,	// VFMADD231PSZmk
    89236027U,	// VFMADD231PSZmkz
    890282555U,	// VFMADD231PSZr
    890413627U,	// VFMADD231PSZrb
    87188027U,	// VFMADD231PSZrbk
    89285179U,	// VFMADD231PSZrbkz
    87056955U,	// VFMADD231PSZrk
    89154107U,	// VFMADD231PSZrkz
    890184251U,	// VFMADD231PSm
    890282555U,	// VFMADD231PSr
    1089474055U,	// VFMADD231SDZm
    1089474055U,	// VFMADD231SDZm_Int
    1357893127U,	// VFMADD231SDZm_Intk
    1357893127U,	// VFMADD231SDZm_Intkz
    890277383U,	// VFMADD231SDZr
    890277383U,	// VFMADD231SDZr_Int
    87051783U,	// VFMADD231SDZr_Intk
    89148935U,	// VFMADD231SDZr_Intkz
    890277383U,	// VFMADD231SDZrb
    890408455U,	// VFMADD231SDZrb_Int
    87182855U,	// VFMADD231SDZrb_Intk
    89280007U,	// VFMADD231SDZrb_Intkz
    1089474055U,	// VFMADD231SDm
    1089474055U,	// VFMADD231SDm_Int
    890277383U,	// VFMADD231SDr
    890277383U,	// VFMADD231SDr_Int
    1089677066U,	// VFMADD231SSZm
    1089677066U,	// VFMADD231SSZm_Int
    1358096138U,	// VFMADD231SSZm_Intk
    1358096138U,	// VFMADD231SSZm_Intkz
    890283786U,	// VFMADD231SSZr
    890283786U,	// VFMADD231SSZr_Int
    87058186U,	// VFMADD231SSZr_Intk
    89155338U,	// VFMADD231SSZr_Intkz
    890283786U,	// VFMADD231SSZrb
    890414858U,	// VFMADD231SSZrb_Int
    87189258U,	// VFMADD231SSZrb_Intk
    89286410U,	// VFMADD231SSZrb_Intkz
    1089677066U,	// VFMADD231SSm
    1089677066U,	// VFMADD231SSm_Int
    890283786U,	// VFMADD231SSr
    890283786U,	// VFMADD231SSr_Int
    393497413U,	// VFMADDPD4Ymr
    890309445U,	// VFMADDPD4Yrm
    890276677U,	// VFMADDPD4Yrr
    890276677U,	// VFMADDPD4Yrr_REV
    301222725U,	// VFMADDPD4mr
    890178373U,	// VFMADDPD4rm
    890276677U,	// VFMADDPD4rr
    890276677U,	// VFMADDPD4rr_REV
    393503821U,	// VFMADDPS4Ymr
    890315853U,	// VFMADDPS4Yrm
    890283085U,	// VFMADDPS4Yrr
    890283085U,	// VFMADDPS4Yrr_REV
    301229133U,	// VFMADDPS4mr
    890184781U,	// VFMADDPS4rm
    890283085U,	// VFMADDPS4rr
    890283085U,	// VFMADDPS4rr_REV
    852774634U,	// VFMADDSD4mr
    852774634U,	// VFMADDSD4mr_Int
    1089474282U,	// VFMADDSD4rm
    1089474282U,	// VFMADDSD4rm_Int
    890277610U,	// VFMADDSD4rr
    890277610U,	// VFMADDSD4rr_Int
    890277610U,	// VFMADDSD4rr_Int_REV
    890277610U,	// VFMADDSD4rr_REV
    856975344U,	// VFMADDSS4mr
    856975344U,	// VFMADDSS4mr_Int
    1089677296U,	// VFMADDSS4rm
    1089677296U,	// VFMADDSS4rm_Int
    890284016U,	// VFMADDSS4rr
    890284016U,	// VFMADDSS4rr_Int
    890284016U,	// VFMADDSS4rr_Int_REV
    890284016U,	// VFMADDSS4rr_REV
    890308956U,	// VFMADDSUB132PDYm
    890276188U,	// VFMADDSUB132PDYr
    890177884U,	// VFMADDSUB132PDZ128m
    1164970332U,	// VFMADDSUB132PDZ128mb
    1433389404U,	// VFMADDSUB132PDZ128mbk
    1433389404U,	// VFMADDSUB132PDZ128mbkz
    86985052U,	// VFMADDSUB132PDZ128mk
    89082204U,	// VFMADDSUB132PDZ128mkz
    890276188U,	// VFMADDSUB132PDZ128r
    87050588U,	// VFMADDSUB132PDZ128rk
    89147740U,	// VFMADDSUB132PDZ128rkz
    890308956U,	// VFMADDSUB132PDZ256m
    1167067484U,	// VFMADDSUB132PDZ256mb
    1435486556U,	// VFMADDSUB132PDZ256mbk
    1435486556U,	// VFMADDSUB132PDZ256mbkz
    87083356U,	// VFMADDSUB132PDZ256mk
    89180508U,	// VFMADDSUB132PDZ256mkz
    890276188U,	// VFMADDSUB132PDZ256r
    87050588U,	// VFMADDSUB132PDZ256rk
    89147740U,	// VFMADDSUB132PDZ256rkz
    890358108U,	// VFMADDSUB132PDZm
    1169164636U,	// VFMADDSUB132PDZmb
    1437583708U,	// VFMADDSUB132PDZmbk
    1437583708U,	// VFMADDSUB132PDZmbkz
    87132508U,	// VFMADDSUB132PDZmk
    89229660U,	// VFMADDSUB132PDZmkz
    890276188U,	// VFMADDSUB132PDZr
    890407260U,	// VFMADDSUB132PDZrb
    87181660U,	// VFMADDSUB132PDZrbk
    89278812U,	// VFMADDSUB132PDZrbkz
    87050588U,	// VFMADDSUB132PDZrk
    89147740U,	// VFMADDSUB132PDZrkz
    890177884U,	// VFMADDSUB132PDm
    890276188U,	// VFMADDSUB132PDr
    890315350U,	// VFMADDSUB132PSYm
    890282582U,	// VFMADDSUB132PSYr
    890184278U,	// VFMADDSUB132PSZ128m
    1167270486U,	// VFMADDSUB132PSZ128mb
    1435689558U,	// VFMADDSUB132PSZ128mbk
    1435689558U,	// VFMADDSUB132PSZ128mbkz
    86991446U,	// VFMADDSUB132PSZ128mk
    89088598U,	// VFMADDSUB132PSZ128mkz
    890282582U,	// VFMADDSUB132PSZ128r
    87056982U,	// VFMADDSUB132PSZ128rk
    89154134U,	// VFMADDSUB132PSZ128rkz
    890315350U,	// VFMADDSUB132PSZ256m
    1169367638U,	// VFMADDSUB132PSZ256mb
    1437786710U,	// VFMADDSUB132PSZ256mbk
    1437786710U,	// VFMADDSUB132PSZ256mbkz
    87089750U,	// VFMADDSUB132PSZ256mk
    89186902U,	// VFMADDSUB132PSZ256mkz
    890282582U,	// VFMADDSUB132PSZ256r
    87056982U,	// VFMADDSUB132PSZ256rk
    89154134U,	// VFMADDSUB132PSZ256rkz
    890364502U,	// VFMADDSUB132PSZm
    1171464790U,	// VFMADDSUB132PSZmb
    1439883862U,	// VFMADDSUB132PSZmbk
    1439883862U,	// VFMADDSUB132PSZmbkz
    87138902U,	// VFMADDSUB132PSZmk
    89236054U,	// VFMADDSUB132PSZmkz
    890282582U,	// VFMADDSUB132PSZr
    890413654U,	// VFMADDSUB132PSZrb
    87188054U,	// VFMADDSUB132PSZrbk
    89285206U,	// VFMADDSUB132PSZrbkz
    87056982U,	// VFMADDSUB132PSZrk
    89154134U,	// VFMADDSUB132PSZrkz
    890184278U,	// VFMADDSUB132PSm
    890282582U,	// VFMADDSUB132PSr
    890309152U,	// VFMADDSUB213PDYm
    890276384U,	// VFMADDSUB213PDYr
    890178080U,	// VFMADDSUB213PDZ128m
    1164970528U,	// VFMADDSUB213PDZ128mb
    1433389600U,	// VFMADDSUB213PDZ128mbk
    1433389600U,	// VFMADDSUB213PDZ128mbkz
    86985248U,	// VFMADDSUB213PDZ128mk
    89082400U,	// VFMADDSUB213PDZ128mkz
    890276384U,	// VFMADDSUB213PDZ128r
    87050784U,	// VFMADDSUB213PDZ128rk
    89147936U,	// VFMADDSUB213PDZ128rkz
    890309152U,	// VFMADDSUB213PDZ256m
    1167067680U,	// VFMADDSUB213PDZ256mb
    1435486752U,	// VFMADDSUB213PDZ256mbk
    1435486752U,	// VFMADDSUB213PDZ256mbkz
    87083552U,	// VFMADDSUB213PDZ256mk
    89180704U,	// VFMADDSUB213PDZ256mkz
    890276384U,	// VFMADDSUB213PDZ256r
    87050784U,	// VFMADDSUB213PDZ256rk
    89147936U,	// VFMADDSUB213PDZ256rkz
    890358304U,	// VFMADDSUB213PDZm
    1169164832U,	// VFMADDSUB213PDZmb
    1437583904U,	// VFMADDSUB213PDZmbk
    1437583904U,	// VFMADDSUB213PDZmbkz
    87132704U,	// VFMADDSUB213PDZmk
    89229856U,	// VFMADDSUB213PDZmkz
    890276384U,	// VFMADDSUB213PDZr
    890407456U,	// VFMADDSUB213PDZrb
    87181856U,	// VFMADDSUB213PDZrbk
    89279008U,	// VFMADDSUB213PDZrbkz
    87050784U,	// VFMADDSUB213PDZrk
    89147936U,	// VFMADDSUB213PDZrkz
    890178080U,	// VFMADDSUB213PDm
    890276384U,	// VFMADDSUB213PDr
    890315557U,	// VFMADDSUB213PSYm
    890282789U,	// VFMADDSUB213PSYr
    890184485U,	// VFMADDSUB213PSZ128m
    1167270693U,	// VFMADDSUB213PSZ128mb
    1435689765U,	// VFMADDSUB213PSZ128mbk
    1435689765U,	// VFMADDSUB213PSZ128mbkz
    86991653U,	// VFMADDSUB213PSZ128mk
    89088805U,	// VFMADDSUB213PSZ128mkz
    890282789U,	// VFMADDSUB213PSZ128r
    87057189U,	// VFMADDSUB213PSZ128rk
    89154341U,	// VFMADDSUB213PSZ128rkz
    890315557U,	// VFMADDSUB213PSZ256m
    1169367845U,	// VFMADDSUB213PSZ256mb
    1437786917U,	// VFMADDSUB213PSZ256mbk
    1437786917U,	// VFMADDSUB213PSZ256mbkz
    87089957U,	// VFMADDSUB213PSZ256mk
    89187109U,	// VFMADDSUB213PSZ256mkz
    890282789U,	// VFMADDSUB213PSZ256r
    87057189U,	// VFMADDSUB213PSZ256rk
    89154341U,	// VFMADDSUB213PSZ256rkz
    890364709U,	// VFMADDSUB213PSZm
    1171464997U,	// VFMADDSUB213PSZmb
    1439884069U,	// VFMADDSUB213PSZmbk
    1439884069U,	// VFMADDSUB213PSZmbkz
    87139109U,	// VFMADDSUB213PSZmk
    89236261U,	// VFMADDSUB213PSZmkz
    890282789U,	// VFMADDSUB213PSZr
    890413861U,	// VFMADDSUB213PSZrb
    87188261U,	// VFMADDSUB213PSZrbk
    89285413U,	// VFMADDSUB213PSZrbkz
    87057189U,	// VFMADDSUB213PSZrk
    89154341U,	// VFMADDSUB213PSZrkz
    890184485U,	// VFMADDSUB213PSm
    890282789U,	// VFMADDSUB213PSr
    890308870U,	// VFMADDSUB231PDYm
    890276102U,	// VFMADDSUB231PDYr
    890177798U,	// VFMADDSUB231PDZ128m
    1164970246U,	// VFMADDSUB231PDZ128mb
    1433389318U,	// VFMADDSUB231PDZ128mbk
    1433389318U,	// VFMADDSUB231PDZ128mbkz
    86984966U,	// VFMADDSUB231PDZ128mk
    89082118U,	// VFMADDSUB231PDZ128mkz
    890276102U,	// VFMADDSUB231PDZ128r
    87050502U,	// VFMADDSUB231PDZ128rk
    89147654U,	// VFMADDSUB231PDZ128rkz
    890308870U,	// VFMADDSUB231PDZ256m
    1167067398U,	// VFMADDSUB231PDZ256mb
    1435486470U,	// VFMADDSUB231PDZ256mbk
    1435486470U,	// VFMADDSUB231PDZ256mbkz
    87083270U,	// VFMADDSUB231PDZ256mk
    89180422U,	// VFMADDSUB231PDZ256mkz
    890276102U,	// VFMADDSUB231PDZ256r
    87050502U,	// VFMADDSUB231PDZ256rk
    89147654U,	// VFMADDSUB231PDZ256rkz
    890358022U,	// VFMADDSUB231PDZm
    1169164550U,	// VFMADDSUB231PDZmb
    1437583622U,	// VFMADDSUB231PDZmbk
    1437583622U,	// VFMADDSUB231PDZmbkz
    87132422U,	// VFMADDSUB231PDZmk
    89229574U,	// VFMADDSUB231PDZmkz
    890276102U,	// VFMADDSUB231PDZr
    890407174U,	// VFMADDSUB231PDZrb
    87181574U,	// VFMADDSUB231PDZrbk
    89278726U,	// VFMADDSUB231PDZrbkz
    87050502U,	// VFMADDSUB231PDZrk
    89147654U,	// VFMADDSUB231PDZrkz
    890177798U,	// VFMADDSUB231PDm
    890276102U,	// VFMADDSUB231PDr
    890315264U,	// VFMADDSUB231PSYm
    890282496U,	// VFMADDSUB231PSYr
    890184192U,	// VFMADDSUB231PSZ128m
    1167270400U,	// VFMADDSUB231PSZ128mb
    1435689472U,	// VFMADDSUB231PSZ128mbk
    1435689472U,	// VFMADDSUB231PSZ128mbkz
    86991360U,	// VFMADDSUB231PSZ128mk
    89088512U,	// VFMADDSUB231PSZ128mkz
    890282496U,	// VFMADDSUB231PSZ128r
    87056896U,	// VFMADDSUB231PSZ128rk
    89154048U,	// VFMADDSUB231PSZ128rkz
    890315264U,	// VFMADDSUB231PSZ256m
    1169367552U,	// VFMADDSUB231PSZ256mb
    1437786624U,	// VFMADDSUB231PSZ256mbk
    1437786624U,	// VFMADDSUB231PSZ256mbkz
    87089664U,	// VFMADDSUB231PSZ256mk
    89186816U,	// VFMADDSUB231PSZ256mkz
    890282496U,	// VFMADDSUB231PSZ256r
    87056896U,	// VFMADDSUB231PSZ256rk
    89154048U,	// VFMADDSUB231PSZ256rkz
    890364416U,	// VFMADDSUB231PSZm
    1171464704U,	// VFMADDSUB231PSZmb
    1439883776U,	// VFMADDSUB231PSZmbk
    1439883776U,	// VFMADDSUB231PSZmbkz
    87138816U,	// VFMADDSUB231PSZmk
    89235968U,	// VFMADDSUB231PSZmkz
    890282496U,	// VFMADDSUB231PSZr
    890413568U,	// VFMADDSUB231PSZrb
    87187968U,	// VFMADDSUB231PSZrbk
    89285120U,	// VFMADDSUB231PSZrbkz
    87056896U,	// VFMADDSUB231PSZrk
    89154048U,	// VFMADDSUB231PSZrkz
    890184192U,	// VFMADDSUB231PSm
    890282496U,	// VFMADDSUB231PSr
    393497267U,	// VFMADDSUBPD4Ymr
    890309299U,	// VFMADDSUBPD4Yrm
    890276531U,	// VFMADDSUBPD4Yrr
    890276531U,	// VFMADDSUBPD4Yrr_REV
    301222579U,	// VFMADDSUBPD4mr
    890178227U,	// VFMADDSUBPD4rm
    890276531U,	// VFMADDSUBPD4rr
    890276531U,	// VFMADDSUBPD4rr_REV
    393503664U,	// VFMADDSUBPS4Ymr
    890315696U,	// VFMADDSUBPS4Yrm
    890282928U,	// VFMADDSUBPS4Yrr
    890282928U,	// VFMADDSUBPS4Yrr_REV
    301228976U,	// VFMADDSUBPS4mr
    890184624U,	// VFMADDSUBPS4rm
    890282928U,	// VFMADDSUBPS4rr
    890282928U,	// VFMADDSUBPS4rr_REV
    890308972U,	// VFMSUB132PDYm
    890276204U,	// VFMSUB132PDYr
    890177900U,	// VFMSUB132PDZ128m
    1164970348U,	// VFMSUB132PDZ128mb
    1433389420U,	// VFMSUB132PDZ128mbk
    1433389420U,	// VFMSUB132PDZ128mbkz
    86985068U,	// VFMSUB132PDZ128mk
    89082220U,	// VFMSUB132PDZ128mkz
    890276204U,	// VFMSUB132PDZ128r
    87050604U,	// VFMSUB132PDZ128rk
    89147756U,	// VFMSUB132PDZ128rkz
    890308972U,	// VFMSUB132PDZ256m
    1167067500U,	// VFMSUB132PDZ256mb
    1435486572U,	// VFMSUB132PDZ256mbk
    1435486572U,	// VFMSUB132PDZ256mbkz
    87083372U,	// VFMSUB132PDZ256mk
    89180524U,	// VFMSUB132PDZ256mkz
    890276204U,	// VFMSUB132PDZ256r
    87050604U,	// VFMSUB132PDZ256rk
    89147756U,	// VFMSUB132PDZ256rkz
    890358124U,	// VFMSUB132PDZm
    1169164652U,	// VFMSUB132PDZmb
    1437583724U,	// VFMSUB132PDZmbk
    1437583724U,	// VFMSUB132PDZmbkz
    87132524U,	// VFMSUB132PDZmk
    89229676U,	// VFMSUB132PDZmkz
    890276204U,	// VFMSUB132PDZr
    890407276U,	// VFMSUB132PDZrb
    87181676U,	// VFMSUB132PDZrbk
    89278828U,	// VFMSUB132PDZrbkz
    87050604U,	// VFMSUB132PDZrk
    89147756U,	// VFMSUB132PDZrkz
    890177900U,	// VFMSUB132PDm
    890276204U,	// VFMSUB132PDr
    890315366U,	// VFMSUB132PSYm
    890282598U,	// VFMSUB132PSYr
    890184294U,	// VFMSUB132PSZ128m
    1167270502U,	// VFMSUB132PSZ128mb
    1435689574U,	// VFMSUB132PSZ128mbk
    1435689574U,	// VFMSUB132PSZ128mbkz
    86991462U,	// VFMSUB132PSZ128mk
    89088614U,	// VFMSUB132PSZ128mkz
    890282598U,	// VFMSUB132PSZ128r
    87056998U,	// VFMSUB132PSZ128rk
    89154150U,	// VFMSUB132PSZ128rkz
    890315366U,	// VFMSUB132PSZ256m
    1169367654U,	// VFMSUB132PSZ256mb
    1437786726U,	// VFMSUB132PSZ256mbk
    1437786726U,	// VFMSUB132PSZ256mbkz
    87089766U,	// VFMSUB132PSZ256mk
    89186918U,	// VFMSUB132PSZ256mkz
    890282598U,	// VFMSUB132PSZ256r
    87056998U,	// VFMSUB132PSZ256rk
    89154150U,	// VFMSUB132PSZ256rkz
    890364518U,	// VFMSUB132PSZm
    1171464806U,	// VFMSUB132PSZmb
    1439883878U,	// VFMSUB132PSZmbk
    1439883878U,	// VFMSUB132PSZmbkz
    87138918U,	// VFMSUB132PSZmk
    89236070U,	// VFMSUB132PSZmkz
    890282598U,	// VFMSUB132PSZr
    890413670U,	// VFMSUB132PSZrb
    87188070U,	// VFMSUB132PSZrbk
    89285222U,	// VFMSUB132PSZrbkz
    87056998U,	// VFMSUB132PSZrk
    89154150U,	// VFMSUB132PSZrkz
    890184294U,	// VFMSUB132PSm
    890282598U,	// VFMSUB132PSr
    1089474082U,	// VFMSUB132SDZm
    1089474082U,	// VFMSUB132SDZm_Int
    1357893154U,	// VFMSUB132SDZm_Intk
    1357893154U,	// VFMSUB132SDZm_Intkz
    890277410U,	// VFMSUB132SDZr
    890277410U,	// VFMSUB132SDZr_Int
    87051810U,	// VFMSUB132SDZr_Intk
    89148962U,	// VFMSUB132SDZr_Intkz
    890277410U,	// VFMSUB132SDZrb
    890408482U,	// VFMSUB132SDZrb_Int
    87182882U,	// VFMSUB132SDZrb_Intk
    89280034U,	// VFMSUB132SDZrb_Intkz
    1089474082U,	// VFMSUB132SDm
    1089474082U,	// VFMSUB132SDm_Int
    890277410U,	// VFMSUB132SDr
    890277410U,	// VFMSUB132SDr_Int
    1089677093U,	// VFMSUB132SSZm
    1089677093U,	// VFMSUB132SSZm_Int
    1358096165U,	// VFMSUB132SSZm_Intk
    1358096165U,	// VFMSUB132SSZm_Intkz
    890283813U,	// VFMSUB132SSZr
    890283813U,	// VFMSUB132SSZr_Int
    87058213U,	// VFMSUB132SSZr_Intk
    89155365U,	// VFMSUB132SSZr_Intkz
    890283813U,	// VFMSUB132SSZrb
    890414885U,	// VFMSUB132SSZrb_Int
    87189285U,	// VFMSUB132SSZrb_Intk
    89286437U,	// VFMSUB132SSZrb_Intkz
    1089677093U,	// VFMSUB132SSm
    1089677093U,	// VFMSUB132SSm_Int
    890283813U,	// VFMSUB132SSr
    890283813U,	// VFMSUB132SSr_Int
    890309168U,	// VFMSUB213PDYm
    890276400U,	// VFMSUB213PDYr
    890178096U,	// VFMSUB213PDZ128m
    1164970544U,	// VFMSUB213PDZ128mb
    1433389616U,	// VFMSUB213PDZ128mbk
    1433389616U,	// VFMSUB213PDZ128mbkz
    86985264U,	// VFMSUB213PDZ128mk
    89082416U,	// VFMSUB213PDZ128mkz
    890276400U,	// VFMSUB213PDZ128r
    87050800U,	// VFMSUB213PDZ128rk
    89147952U,	// VFMSUB213PDZ128rkz
    890309168U,	// VFMSUB213PDZ256m
    1167067696U,	// VFMSUB213PDZ256mb
    1435486768U,	// VFMSUB213PDZ256mbk
    1435486768U,	// VFMSUB213PDZ256mbkz
    87083568U,	// VFMSUB213PDZ256mk
    89180720U,	// VFMSUB213PDZ256mkz
    890276400U,	// VFMSUB213PDZ256r
    87050800U,	// VFMSUB213PDZ256rk
    89147952U,	// VFMSUB213PDZ256rkz
    890358320U,	// VFMSUB213PDZm
    1169164848U,	// VFMSUB213PDZmb
    1437583920U,	// VFMSUB213PDZmbk
    1437583920U,	// VFMSUB213PDZmbkz
    87132720U,	// VFMSUB213PDZmk
    89229872U,	// VFMSUB213PDZmkz
    890276400U,	// VFMSUB213PDZr
    890407472U,	// VFMSUB213PDZrb
    87181872U,	// VFMSUB213PDZrbk
    89279024U,	// VFMSUB213PDZrbkz
    87050800U,	// VFMSUB213PDZrk
    89147952U,	// VFMSUB213PDZrkz
    890178096U,	// VFMSUB213PDm
    890276400U,	// VFMSUB213PDr
    890315573U,	// VFMSUB213PSYm
    890282805U,	// VFMSUB213PSYr
    890184501U,	// VFMSUB213PSZ128m
    1167270709U,	// VFMSUB213PSZ128mb
    1435689781U,	// VFMSUB213PSZ128mbk
    1435689781U,	// VFMSUB213PSZ128mbkz
    86991669U,	// VFMSUB213PSZ128mk
    89088821U,	// VFMSUB213PSZ128mkz
    890282805U,	// VFMSUB213PSZ128r
    87057205U,	// VFMSUB213PSZ128rk
    89154357U,	// VFMSUB213PSZ128rkz
    890315573U,	// VFMSUB213PSZ256m
    1169367861U,	// VFMSUB213PSZ256mb
    1437786933U,	// VFMSUB213PSZ256mbk
    1437786933U,	// VFMSUB213PSZ256mbkz
    87089973U,	// VFMSUB213PSZ256mk
    89187125U,	// VFMSUB213PSZ256mkz
    890282805U,	// VFMSUB213PSZ256r
    87057205U,	// VFMSUB213PSZ256rk
    89154357U,	// VFMSUB213PSZ256rkz
    890364725U,	// VFMSUB213PSZm
    1171465013U,	// VFMSUB213PSZmb
    1439884085U,	// VFMSUB213PSZmbk
    1439884085U,	// VFMSUB213PSZmbkz
    87139125U,	// VFMSUB213PSZmk
    89236277U,	// VFMSUB213PSZmkz
    890282805U,	// VFMSUB213PSZr
    890413877U,	// VFMSUB213PSZrb
    87188277U,	// VFMSUB213PSZrbk
    89285429U,	// VFMSUB213PSZrbkz
    87057205U,	// VFMSUB213PSZrk
    89154357U,	// VFMSUB213PSZrkz
    890184501U,	// VFMSUB213PSm
    890282805U,	// VFMSUB213PSr
    1089474147U,	// VFMSUB213SDZm
    1089474147U,	// VFMSUB213SDZm_Int
    1357893219U,	// VFMSUB213SDZm_Intk
    1357893219U,	// VFMSUB213SDZm_Intkz
    890277475U,	// VFMSUB213SDZr
    890277475U,	// VFMSUB213SDZr_Int
    87051875U,	// VFMSUB213SDZr_Intk
    89149027U,	// VFMSUB213SDZr_Intkz
    890277475U,	// VFMSUB213SDZrb
    890408547U,	// VFMSUB213SDZrb_Int
    87182947U,	// VFMSUB213SDZrb_Intk
    89280099U,	// VFMSUB213SDZrb_Intkz
    1089474147U,	// VFMSUB213SDm
    1089474147U,	// VFMSUB213SDm_Int
    890277475U,	// VFMSUB213SDr
    890277475U,	// VFMSUB213SDr_Int
    1089677158U,	// VFMSUB213SSZm
    1089677158U,	// VFMSUB213SSZm_Int
    1358096230U,	// VFMSUB213SSZm_Intk
    1358096230U,	// VFMSUB213SSZm_Intkz
    890283878U,	// VFMSUB213SSZr
    890283878U,	// VFMSUB213SSZr_Int
    87058278U,	// VFMSUB213SSZr_Intk
    89155430U,	// VFMSUB213SSZr_Intkz
    890283878U,	// VFMSUB213SSZrb
    890414950U,	// VFMSUB213SSZrb_Int
    87189350U,	// VFMSUB213SSZrb_Intk
    89286502U,	// VFMSUB213SSZrb_Intkz
    1089677158U,	// VFMSUB213SSm
    1089677158U,	// VFMSUB213SSm_Int
    890283878U,	// VFMSUB213SSr
    890283878U,	// VFMSUB213SSr_Int
    890308886U,	// VFMSUB231PDYm
    890276118U,	// VFMSUB231PDYr
    890177814U,	// VFMSUB231PDZ128m
    1164970262U,	// VFMSUB231PDZ128mb
    1433389334U,	// VFMSUB231PDZ128mbk
    1433389334U,	// VFMSUB231PDZ128mbkz
    86984982U,	// VFMSUB231PDZ128mk
    89082134U,	// VFMSUB231PDZ128mkz
    890276118U,	// VFMSUB231PDZ128r
    87050518U,	// VFMSUB231PDZ128rk
    89147670U,	// VFMSUB231PDZ128rkz
    890308886U,	// VFMSUB231PDZ256m
    1167067414U,	// VFMSUB231PDZ256mb
    1435486486U,	// VFMSUB231PDZ256mbk
    1435486486U,	// VFMSUB231PDZ256mbkz
    87083286U,	// VFMSUB231PDZ256mk
    89180438U,	// VFMSUB231PDZ256mkz
    890276118U,	// VFMSUB231PDZ256r
    87050518U,	// VFMSUB231PDZ256rk
    89147670U,	// VFMSUB231PDZ256rkz
    890358038U,	// VFMSUB231PDZm
    1169164566U,	// VFMSUB231PDZmb
    1437583638U,	// VFMSUB231PDZmbk
    1437583638U,	// VFMSUB231PDZmbkz
    87132438U,	// VFMSUB231PDZmk
    89229590U,	// VFMSUB231PDZmkz
    890276118U,	// VFMSUB231PDZr
    890407190U,	// VFMSUB231PDZrb
    87181590U,	// VFMSUB231PDZrbk
    89278742U,	// VFMSUB231PDZrbkz
    87050518U,	// VFMSUB231PDZrk
    89147670U,	// VFMSUB231PDZrkz
    890177814U,	// VFMSUB231PDm
    890276118U,	// VFMSUB231PDr
    890315280U,	// VFMSUB231PSYm
    890282512U,	// VFMSUB231PSYr
    890184208U,	// VFMSUB231PSZ128m
    1167270416U,	// VFMSUB231PSZ128mb
    1435689488U,	// VFMSUB231PSZ128mbk
    1435689488U,	// VFMSUB231PSZ128mbkz
    86991376U,	// VFMSUB231PSZ128mk
    89088528U,	// VFMSUB231PSZ128mkz
    890282512U,	// VFMSUB231PSZ128r
    87056912U,	// VFMSUB231PSZ128rk
    89154064U,	// VFMSUB231PSZ128rkz
    890315280U,	// VFMSUB231PSZ256m
    1169367568U,	// VFMSUB231PSZ256mb
    1437786640U,	// VFMSUB231PSZ256mbk
    1437786640U,	// VFMSUB231PSZ256mbkz
    87089680U,	// VFMSUB231PSZ256mk
    89186832U,	// VFMSUB231PSZ256mkz
    890282512U,	// VFMSUB231PSZ256r
    87056912U,	// VFMSUB231PSZ256rk
    89154064U,	// VFMSUB231PSZ256rkz
    890364432U,	// VFMSUB231PSZm
    1171464720U,	// VFMSUB231PSZmb
    1439883792U,	// VFMSUB231PSZmbk
    1439883792U,	// VFMSUB231PSZmbkz
    87138832U,	// VFMSUB231PSZmk
    89235984U,	// VFMSUB231PSZmkz
    890282512U,	// VFMSUB231PSZr
    890413584U,	// VFMSUB231PSZrb
    87187984U,	// VFMSUB231PSZrbk
    89285136U,	// VFMSUB231PSZrbkz
    87056912U,	// VFMSUB231PSZrk
    89154064U,	// VFMSUB231PSZrkz
    890184208U,	// VFMSUB231PSm
    890282512U,	// VFMSUB231PSr
    1089474028U,	// VFMSUB231SDZm
    1089474028U,	// VFMSUB231SDZm_Int
    1357893100U,	// VFMSUB231SDZm_Intk
    1357893100U,	// VFMSUB231SDZm_Intkz
    890277356U,	// VFMSUB231SDZr
    890277356U,	// VFMSUB231SDZr_Int
    87051756U,	// VFMSUB231SDZr_Intk
    89148908U,	// VFMSUB231SDZr_Intkz
    890277356U,	// VFMSUB231SDZrb
    890408428U,	// VFMSUB231SDZrb_Int
    87182828U,	// VFMSUB231SDZrb_Intk
    89279980U,	// VFMSUB231SDZrb_Intkz
    1089474028U,	// VFMSUB231SDm
    1089474028U,	// VFMSUB231SDm_Int
    890277356U,	// VFMSUB231SDr
    890277356U,	// VFMSUB231SDr_Int
    1089677039U,	// VFMSUB231SSZm
    1089677039U,	// VFMSUB231SSZm_Int
    1358096111U,	// VFMSUB231SSZm_Intk
    1358096111U,	// VFMSUB231SSZm_Intkz
    890283759U,	// VFMSUB231SSZr
    890283759U,	// VFMSUB231SSZr_Int
    87058159U,	// VFMSUB231SSZr_Intk
    89155311U,	// VFMSUB231SSZr_Intkz
    890283759U,	// VFMSUB231SSZrb
    890414831U,	// VFMSUB231SSZrb_Int
    87189231U,	// VFMSUB231SSZrb_Intk
    89286383U,	// VFMSUB231SSZrb_Intkz
    1089677039U,	// VFMSUB231SSm
    1089677039U,	// VFMSUB231SSm_Int
    890283759U,	// VFMSUB231SSr
    890283759U,	// VFMSUB231SSr_Int
    890308999U,	// VFMSUBADD132PDYm
    890276231U,	// VFMSUBADD132PDYr
    890177927U,	// VFMSUBADD132PDZ128m
    1164970375U,	// VFMSUBADD132PDZ128mb
    1433389447U,	// VFMSUBADD132PDZ128mbk
    1433389447U,	// VFMSUBADD132PDZ128mbkz
    86985095U,	// VFMSUBADD132PDZ128mk
    89082247U,	// VFMSUBADD132PDZ128mkz
    890276231U,	// VFMSUBADD132PDZ128r
    87050631U,	// VFMSUBADD132PDZ128rk
    89147783U,	// VFMSUBADD132PDZ128rkz
    890308999U,	// VFMSUBADD132PDZ256m
    1167067527U,	// VFMSUBADD132PDZ256mb
    1435486599U,	// VFMSUBADD132PDZ256mbk
    1435486599U,	// VFMSUBADD132PDZ256mbkz
    87083399U,	// VFMSUBADD132PDZ256mk
    89180551U,	// VFMSUBADD132PDZ256mkz
    890276231U,	// VFMSUBADD132PDZ256r
    87050631U,	// VFMSUBADD132PDZ256rk
    89147783U,	// VFMSUBADD132PDZ256rkz
    890358151U,	// VFMSUBADD132PDZm
    1169164679U,	// VFMSUBADD132PDZmb
    1437583751U,	// VFMSUBADD132PDZmbk
    1437583751U,	// VFMSUBADD132PDZmbkz
    87132551U,	// VFMSUBADD132PDZmk
    89229703U,	// VFMSUBADD132PDZmkz
    890276231U,	// VFMSUBADD132PDZr
    890407303U,	// VFMSUBADD132PDZrb
    87181703U,	// VFMSUBADD132PDZrbk
    89278855U,	// VFMSUBADD132PDZrbkz
    87050631U,	// VFMSUBADD132PDZrk
    89147783U,	// VFMSUBADD132PDZrkz
    890177927U,	// VFMSUBADD132PDm
    890276231U,	// VFMSUBADD132PDr
    890315393U,	// VFMSUBADD132PSYm
    890282625U,	// VFMSUBADD132PSYr
    890184321U,	// VFMSUBADD132PSZ128m
    1167270529U,	// VFMSUBADD132PSZ128mb
    1435689601U,	// VFMSUBADD132PSZ128mbk
    1435689601U,	// VFMSUBADD132PSZ128mbkz
    86991489U,	// VFMSUBADD132PSZ128mk
    89088641U,	// VFMSUBADD132PSZ128mkz
    890282625U,	// VFMSUBADD132PSZ128r
    87057025U,	// VFMSUBADD132PSZ128rk
    89154177U,	// VFMSUBADD132PSZ128rkz
    890315393U,	// VFMSUBADD132PSZ256m
    1169367681U,	// VFMSUBADD132PSZ256mb
    1437786753U,	// VFMSUBADD132PSZ256mbk
    1437786753U,	// VFMSUBADD132PSZ256mbkz
    87089793U,	// VFMSUBADD132PSZ256mk
    89186945U,	// VFMSUBADD132PSZ256mkz
    890282625U,	// VFMSUBADD132PSZ256r
    87057025U,	// VFMSUBADD132PSZ256rk
    89154177U,	// VFMSUBADD132PSZ256rkz
    890364545U,	// VFMSUBADD132PSZm
    1171464833U,	// VFMSUBADD132PSZmb
    1439883905U,	// VFMSUBADD132PSZmbk
    1439883905U,	// VFMSUBADD132PSZmbkz
    87138945U,	// VFMSUBADD132PSZmk
    89236097U,	// VFMSUBADD132PSZmkz
    890282625U,	// VFMSUBADD132PSZr
    890413697U,	// VFMSUBADD132PSZrb
    87188097U,	// VFMSUBADD132PSZrbk
    89285249U,	// VFMSUBADD132PSZrbkz
    87057025U,	// VFMSUBADD132PSZrk
    89154177U,	// VFMSUBADD132PSZrkz
    890184321U,	// VFMSUBADD132PSm
    890282625U,	// VFMSUBADD132PSr
    890309195U,	// VFMSUBADD213PDYm
    890276427U,	// VFMSUBADD213PDYr
    890178123U,	// VFMSUBADD213PDZ128m
    1164970571U,	// VFMSUBADD213PDZ128mb
    1433389643U,	// VFMSUBADD213PDZ128mbk
    1433389643U,	// VFMSUBADD213PDZ128mbkz
    86985291U,	// VFMSUBADD213PDZ128mk
    89082443U,	// VFMSUBADD213PDZ128mkz
    890276427U,	// VFMSUBADD213PDZ128r
    87050827U,	// VFMSUBADD213PDZ128rk
    89147979U,	// VFMSUBADD213PDZ128rkz
    890309195U,	// VFMSUBADD213PDZ256m
    1167067723U,	// VFMSUBADD213PDZ256mb
    1435486795U,	// VFMSUBADD213PDZ256mbk
    1435486795U,	// VFMSUBADD213PDZ256mbkz
    87083595U,	// VFMSUBADD213PDZ256mk
    89180747U,	// VFMSUBADD213PDZ256mkz
    890276427U,	// VFMSUBADD213PDZ256r
    87050827U,	// VFMSUBADD213PDZ256rk
    89147979U,	// VFMSUBADD213PDZ256rkz
    890358347U,	// VFMSUBADD213PDZm
    1169164875U,	// VFMSUBADD213PDZmb
    1437583947U,	// VFMSUBADD213PDZmbk
    1437583947U,	// VFMSUBADD213PDZmbkz
    87132747U,	// VFMSUBADD213PDZmk
    89229899U,	// VFMSUBADD213PDZmkz
    890276427U,	// VFMSUBADD213PDZr
    890407499U,	// VFMSUBADD213PDZrb
    87181899U,	// VFMSUBADD213PDZrbk
    89279051U,	// VFMSUBADD213PDZrbkz
    87050827U,	// VFMSUBADD213PDZrk
    89147979U,	// VFMSUBADD213PDZrkz
    890178123U,	// VFMSUBADD213PDm
    890276427U,	// VFMSUBADD213PDr
    890315600U,	// VFMSUBADD213PSYm
    890282832U,	// VFMSUBADD213PSYr
    890184528U,	// VFMSUBADD213PSZ128m
    1167270736U,	// VFMSUBADD213PSZ128mb
    1435689808U,	// VFMSUBADD213PSZ128mbk
    1435689808U,	// VFMSUBADD213PSZ128mbkz
    86991696U,	// VFMSUBADD213PSZ128mk
    89088848U,	// VFMSUBADD213PSZ128mkz
    890282832U,	// VFMSUBADD213PSZ128r
    87057232U,	// VFMSUBADD213PSZ128rk
    89154384U,	// VFMSUBADD213PSZ128rkz
    890315600U,	// VFMSUBADD213PSZ256m
    1169367888U,	// VFMSUBADD213PSZ256mb
    1437786960U,	// VFMSUBADD213PSZ256mbk
    1437786960U,	// VFMSUBADD213PSZ256mbkz
    87090000U,	// VFMSUBADD213PSZ256mk
    89187152U,	// VFMSUBADD213PSZ256mkz
    890282832U,	// VFMSUBADD213PSZ256r
    87057232U,	// VFMSUBADD213PSZ256rk
    89154384U,	// VFMSUBADD213PSZ256rkz
    890364752U,	// VFMSUBADD213PSZm
    1171465040U,	// VFMSUBADD213PSZmb
    1439884112U,	// VFMSUBADD213PSZmbk
    1439884112U,	// VFMSUBADD213PSZmbkz
    87139152U,	// VFMSUBADD213PSZmk
    89236304U,	// VFMSUBADD213PSZmkz
    890282832U,	// VFMSUBADD213PSZr
    890413904U,	// VFMSUBADD213PSZrb
    87188304U,	// VFMSUBADD213PSZrbk
    89285456U,	// VFMSUBADD213PSZrbkz
    87057232U,	// VFMSUBADD213PSZrk
    89154384U,	// VFMSUBADD213PSZrkz
    890184528U,	// VFMSUBADD213PSm
    890282832U,	// VFMSUBADD213PSr
    890308913U,	// VFMSUBADD231PDYm
    890276145U,	// VFMSUBADD231PDYr
    890177841U,	// VFMSUBADD231PDZ128m
    1164970289U,	// VFMSUBADD231PDZ128mb
    1433389361U,	// VFMSUBADD231PDZ128mbk
    1433389361U,	// VFMSUBADD231PDZ128mbkz
    86985009U,	// VFMSUBADD231PDZ128mk
    89082161U,	// VFMSUBADD231PDZ128mkz
    890276145U,	// VFMSUBADD231PDZ128r
    87050545U,	// VFMSUBADD231PDZ128rk
    89147697U,	// VFMSUBADD231PDZ128rkz
    890308913U,	// VFMSUBADD231PDZ256m
    1167067441U,	// VFMSUBADD231PDZ256mb
    1435486513U,	// VFMSUBADD231PDZ256mbk
    1435486513U,	// VFMSUBADD231PDZ256mbkz
    87083313U,	// VFMSUBADD231PDZ256mk
    89180465U,	// VFMSUBADD231PDZ256mkz
    890276145U,	// VFMSUBADD231PDZ256r
    87050545U,	// VFMSUBADD231PDZ256rk
    89147697U,	// VFMSUBADD231PDZ256rkz
    890358065U,	// VFMSUBADD231PDZm
    1169164593U,	// VFMSUBADD231PDZmb
    1437583665U,	// VFMSUBADD231PDZmbk
    1437583665U,	// VFMSUBADD231PDZmbkz
    87132465U,	// VFMSUBADD231PDZmk
    89229617U,	// VFMSUBADD231PDZmkz
    890276145U,	// VFMSUBADD231PDZr
    890407217U,	// VFMSUBADD231PDZrb
    87181617U,	// VFMSUBADD231PDZrbk
    89278769U,	// VFMSUBADD231PDZrbkz
    87050545U,	// VFMSUBADD231PDZrk
    89147697U,	// VFMSUBADD231PDZrkz
    890177841U,	// VFMSUBADD231PDm
    890276145U,	// VFMSUBADD231PDr
    890315307U,	// VFMSUBADD231PSYm
    890282539U,	// VFMSUBADD231PSYr
    890184235U,	// VFMSUBADD231PSZ128m
    1167270443U,	// VFMSUBADD231PSZ128mb
    1435689515U,	// VFMSUBADD231PSZ128mbk
    1435689515U,	// VFMSUBADD231PSZ128mbkz
    86991403U,	// VFMSUBADD231PSZ128mk
    89088555U,	// VFMSUBADD231PSZ128mkz
    890282539U,	// VFMSUBADD231PSZ128r
    87056939U,	// VFMSUBADD231PSZ128rk
    89154091U,	// VFMSUBADD231PSZ128rkz
    890315307U,	// VFMSUBADD231PSZ256m
    1169367595U,	// VFMSUBADD231PSZ256mb
    1437786667U,	// VFMSUBADD231PSZ256mbk
    1437786667U,	// VFMSUBADD231PSZ256mbkz
    87089707U,	// VFMSUBADD231PSZ256mk
    89186859U,	// VFMSUBADD231PSZ256mkz
    890282539U,	// VFMSUBADD231PSZ256r
    87056939U,	// VFMSUBADD231PSZ256rk
    89154091U,	// VFMSUBADD231PSZ256rkz
    890364459U,	// VFMSUBADD231PSZm
    1171464747U,	// VFMSUBADD231PSZmb
    1439883819U,	// VFMSUBADD231PSZmbk
    1439883819U,	// VFMSUBADD231PSZmbkz
    87138859U,	// VFMSUBADD231PSZmk
    89236011U,	// VFMSUBADD231PSZmkz
    890282539U,	// VFMSUBADD231PSZr
    890413611U,	// VFMSUBADD231PSZrb
    87188011U,	// VFMSUBADD231PSZrbk
    89285163U,	// VFMSUBADD231PSZrbkz
    87056939U,	// VFMSUBADD231PSZrk
    89154091U,	// VFMSUBADD231PSZrkz
    890184235U,	// VFMSUBADD231PSm
    890282539U,	// VFMSUBADD231PSr
    393497391U,	// VFMSUBADDPD4Ymr
    890309423U,	// VFMSUBADDPD4Yrm
    890276655U,	// VFMSUBADDPD4Yrr
    890276655U,	// VFMSUBADDPD4Yrr_REV
    301222703U,	// VFMSUBADDPD4mr
    890178351U,	// VFMSUBADDPD4rm
    890276655U,	// VFMSUBADDPD4rr
    890276655U,	// VFMSUBADDPD4rr_REV
    393503788U,	// VFMSUBADDPS4Ymr
    890315820U,	// VFMSUBADDPS4Yrm
    890283052U,	// VFMSUBADDPS4Yrr
    890283052U,	// VFMSUBADDPS4Yrr_REV
    301229100U,	// VFMSUBADDPS4mr
    890184748U,	// VFMSUBADDPS4rm
    890283052U,	// VFMSUBADDPS4rr
    890283052U,	// VFMSUBADDPS4rr_REV
    393497300U,	// VFMSUBPD4Ymr
    890309332U,	// VFMSUBPD4Yrm
    890276564U,	// VFMSUBPD4Yrr
    890276564U,	// VFMSUBPD4Yrr_REV
    301222612U,	// VFMSUBPD4mr
    890178260U,	// VFMSUBPD4rm
    890276564U,	// VFMSUBPD4rr
    890276564U,	// VFMSUBPD4rr_REV
    393503697U,	// VFMSUBPS4Ymr
    890315729U,	// VFMSUBPS4Yrm
    890282961U,	// VFMSUBPS4Yrr
    890282961U,	// VFMSUBPS4Yrr_REV
    301229009U,	// VFMSUBPS4mr
    890184657U,	// VFMSUBPS4rm
    890282961U,	// VFMSUBPS4rr
    890282961U,	// VFMSUBPS4rr_REV
    852774605U,	// VFMSUBSD4mr
    852774605U,	// VFMSUBSD4mr_Int
    1089474253U,	// VFMSUBSD4rm
    1089474253U,	// VFMSUBSD4rm_Int
    890277581U,	// VFMSUBSD4rr
    890277581U,	// VFMSUBSD4rr_Int
    890277581U,	// VFMSUBSD4rr_Int_REV
    890277581U,	// VFMSUBSD4rr_REV
    856975304U,	// VFMSUBSS4mr
    856975304U,	// VFMSUBSS4mr_Int
    1089677256U,	// VFMSUBSS4rm
    1089677256U,	// VFMSUBSS4rm_Int
    890283976U,	// VFMSUBSS4rr
    890283976U,	// VFMSUBSS4rr_Int
    890283976U,	// VFMSUBSS4rr_Int_REV
    890283976U,	// VFMSUBSS4rr_REV
    890309028U,	// VFNMADD132PDYm
    890276260U,	// VFNMADD132PDYr
    890177956U,	// VFNMADD132PDZ128m
    1164970404U,	// VFNMADD132PDZ128mb
    1433389476U,	// VFNMADD132PDZ128mbk
    1433389476U,	// VFNMADD132PDZ128mbkz
    86985124U,	// VFNMADD132PDZ128mk
    89082276U,	// VFNMADD132PDZ128mkz
    890276260U,	// VFNMADD132PDZ128r
    87050660U,	// VFNMADD132PDZ128rk
    89147812U,	// VFNMADD132PDZ128rkz
    890309028U,	// VFNMADD132PDZ256m
    1167067556U,	// VFNMADD132PDZ256mb
    1435486628U,	// VFNMADD132PDZ256mbk
    1435486628U,	// VFNMADD132PDZ256mbkz
    87083428U,	// VFNMADD132PDZ256mk
    89180580U,	// VFNMADD132PDZ256mkz
    890276260U,	// VFNMADD132PDZ256r
    87050660U,	// VFNMADD132PDZ256rk
    89147812U,	// VFNMADD132PDZ256rkz
    890358180U,	// VFNMADD132PDZm
    1169164708U,	// VFNMADD132PDZmb
    1437583780U,	// VFNMADD132PDZmbk
    1437583780U,	// VFNMADD132PDZmbkz
    87132580U,	// VFNMADD132PDZmk
    89229732U,	// VFNMADD132PDZmkz
    890276260U,	// VFNMADD132PDZr
    890407332U,	// VFNMADD132PDZrb
    87181732U,	// VFNMADD132PDZrbk
    89278884U,	// VFNMADD132PDZrbkz
    87050660U,	// VFNMADD132PDZrk
    89147812U,	// VFNMADD132PDZrkz
    890177956U,	// VFNMADD132PDm
    890276260U,	// VFNMADD132PDr
    890315422U,	// VFNMADD132PSYm
    890282654U,	// VFNMADD132PSYr
    890184350U,	// VFNMADD132PSZ128m
    1167270558U,	// VFNMADD132PSZ128mb
    1435689630U,	// VFNMADD132PSZ128mbk
    1435689630U,	// VFNMADD132PSZ128mbkz
    86991518U,	// VFNMADD132PSZ128mk
    89088670U,	// VFNMADD132PSZ128mkz
    890282654U,	// VFNMADD132PSZ128r
    87057054U,	// VFNMADD132PSZ128rk
    89154206U,	// VFNMADD132PSZ128rkz
    890315422U,	// VFNMADD132PSZ256m
    1169367710U,	// VFNMADD132PSZ256mb
    1437786782U,	// VFNMADD132PSZ256mbk
    1437786782U,	// VFNMADD132PSZ256mbkz
    87089822U,	// VFNMADD132PSZ256mk
    89186974U,	// VFNMADD132PSZ256mkz
    890282654U,	// VFNMADD132PSZ256r
    87057054U,	// VFNMADD132PSZ256rk
    89154206U,	// VFNMADD132PSZ256rkz
    890364574U,	// VFNMADD132PSZm
    1171464862U,	// VFNMADD132PSZmb
    1439883934U,	// VFNMADD132PSZmbk
    1439883934U,	// VFNMADD132PSZmbkz
    87138974U,	// VFNMADD132PSZmk
    89236126U,	// VFNMADD132PSZmkz
    890282654U,	// VFNMADD132PSZr
    890413726U,	// VFNMADD132PSZrb
    87188126U,	// VFNMADD132PSZrbk
    89285278U,	// VFNMADD132PSZrbkz
    87057054U,	// VFNMADD132PSZrk
    89154206U,	// VFNMADD132PSZrkz
    890184350U,	// VFNMADD132PSm
    890282654U,	// VFNMADD132PSr
    1089474122U,	// VFNMADD132SDZm
    1089474122U,	// VFNMADD132SDZm_Int
    1357893194U,	// VFNMADD132SDZm_Intk
    1357893194U,	// VFNMADD132SDZm_Intkz
    890277450U,	// VFNMADD132SDZr
    890277450U,	// VFNMADD132SDZr_Int
    87051850U,	// VFNMADD132SDZr_Intk
    89149002U,	// VFNMADD132SDZr_Intkz
    890277450U,	// VFNMADD132SDZrb
    890408522U,	// VFNMADD132SDZrb_Int
    87182922U,	// VFNMADD132SDZrb_Intk
    89280074U,	// VFNMADD132SDZrb_Intkz
    1089474122U,	// VFNMADD132SDm
    1089474122U,	// VFNMADD132SDm_Int
    890277450U,	// VFNMADD132SDr
    890277450U,	// VFNMADD132SDr_Int
    1089677133U,	// VFNMADD132SSZm
    1089677133U,	// VFNMADD132SSZm_Int
    1358096205U,	// VFNMADD132SSZm_Intk
    1358096205U,	// VFNMADD132SSZm_Intkz
    890283853U,	// VFNMADD132SSZr
    890283853U,	// VFNMADD132SSZr_Int
    87058253U,	// VFNMADD132SSZr_Intk
    89155405U,	// VFNMADD132SSZr_Intkz
    890283853U,	// VFNMADD132SSZrb
    890414925U,	// VFNMADD132SSZrb_Int
    87189325U,	// VFNMADD132SSZrb_Intk
    89286477U,	// VFNMADD132SSZrb_Intkz
    1089677133U,	// VFNMADD132SSm
    1089677133U,	// VFNMADD132SSm_Int
    890283853U,	// VFNMADD132SSr
    890283853U,	// VFNMADD132SSr_Int
    890309224U,	// VFNMADD213PDYm
    890276456U,	// VFNMADD213PDYr
    890178152U,	// VFNMADD213PDZ128m
    1164970600U,	// VFNMADD213PDZ128mb
    1433389672U,	// VFNMADD213PDZ128mbk
    1433389672U,	// VFNMADD213PDZ128mbkz
    86985320U,	// VFNMADD213PDZ128mk
    89082472U,	// VFNMADD213PDZ128mkz
    890276456U,	// VFNMADD213PDZ128r
    87050856U,	// VFNMADD213PDZ128rk
    89148008U,	// VFNMADD213PDZ128rkz
    890309224U,	// VFNMADD213PDZ256m
    1167067752U,	// VFNMADD213PDZ256mb
    1435486824U,	// VFNMADD213PDZ256mbk
    1435486824U,	// VFNMADD213PDZ256mbkz
    87083624U,	// VFNMADD213PDZ256mk
    89180776U,	// VFNMADD213PDZ256mkz
    890276456U,	// VFNMADD213PDZ256r
    87050856U,	// VFNMADD213PDZ256rk
    89148008U,	// VFNMADD213PDZ256rkz
    890358376U,	// VFNMADD213PDZm
    1169164904U,	// VFNMADD213PDZmb
    1437583976U,	// VFNMADD213PDZmbk
    1437583976U,	// VFNMADD213PDZmbkz
    87132776U,	// VFNMADD213PDZmk
    89229928U,	// VFNMADD213PDZmkz
    890276456U,	// VFNMADD213PDZr
    890407528U,	// VFNMADD213PDZrb
    87181928U,	// VFNMADD213PDZrbk
    89279080U,	// VFNMADD213PDZrbkz
    87050856U,	// VFNMADD213PDZrk
    89148008U,	// VFNMADD213PDZrkz
    890178152U,	// VFNMADD213PDm
    890276456U,	// VFNMADD213PDr
    890315629U,	// VFNMADD213PSYm
    890282861U,	// VFNMADD213PSYr
    890184557U,	// VFNMADD213PSZ128m
    1167270765U,	// VFNMADD213PSZ128mb
    1435689837U,	// VFNMADD213PSZ128mbk
    1435689837U,	// VFNMADD213PSZ128mbkz
    86991725U,	// VFNMADD213PSZ128mk
    89088877U,	// VFNMADD213PSZ128mkz
    890282861U,	// VFNMADD213PSZ128r
    87057261U,	// VFNMADD213PSZ128rk
    89154413U,	// VFNMADD213PSZ128rkz
    890315629U,	// VFNMADD213PSZ256m
    1169367917U,	// VFNMADD213PSZ256mb
    1437786989U,	// VFNMADD213PSZ256mbk
    1437786989U,	// VFNMADD213PSZ256mbkz
    87090029U,	// VFNMADD213PSZ256mk
    89187181U,	// VFNMADD213PSZ256mkz
    890282861U,	// VFNMADD213PSZ256r
    87057261U,	// VFNMADD213PSZ256rk
    89154413U,	// VFNMADD213PSZ256rkz
    890364781U,	// VFNMADD213PSZm
    1171465069U,	// VFNMADD213PSZmb
    1439884141U,	// VFNMADD213PSZmbk
    1439884141U,	// VFNMADD213PSZmbkz
    87139181U,	// VFNMADD213PSZmk
    89236333U,	// VFNMADD213PSZmkz
    890282861U,	// VFNMADD213PSZr
    890413933U,	// VFNMADD213PSZrb
    87188333U,	// VFNMADD213PSZrbk
    89285485U,	// VFNMADD213PSZrbkz
    87057261U,	// VFNMADD213PSZrk
    89154413U,	// VFNMADD213PSZrkz
    890184557U,	// VFNMADD213PSm
    890282861U,	// VFNMADD213PSr
    1089474187U,	// VFNMADD213SDZm
    1089474187U,	// VFNMADD213SDZm_Int
    1357893259U,	// VFNMADD213SDZm_Intk
    1357893259U,	// VFNMADD213SDZm_Intkz
    890277515U,	// VFNMADD213SDZr
    890277515U,	// VFNMADD213SDZr_Int
    87051915U,	// VFNMADD213SDZr_Intk
    89149067U,	// VFNMADD213SDZr_Intkz
    890277515U,	// VFNMADD213SDZrb
    890408587U,	// VFNMADD213SDZrb_Int
    87182987U,	// VFNMADD213SDZrb_Intk
    89280139U,	// VFNMADD213SDZrb_Intkz
    1089474187U,	// VFNMADD213SDm
    1089474187U,	// VFNMADD213SDm_Int
    890277515U,	// VFNMADD213SDr
    890277515U,	// VFNMADD213SDr_Int
    1089677198U,	// VFNMADD213SSZm
    1089677198U,	// VFNMADD213SSZm_Int
    1358096270U,	// VFNMADD213SSZm_Intk
    1358096270U,	// VFNMADD213SSZm_Intkz
    890283918U,	// VFNMADD213SSZr
    890283918U,	// VFNMADD213SSZr_Int
    87058318U,	// VFNMADD213SSZr_Intk
    89155470U,	// VFNMADD213SSZr_Intkz
    890283918U,	// VFNMADD213SSZrb
    890414990U,	// VFNMADD213SSZrb_Int
    87189390U,	// VFNMADD213SSZrb_Intk
    89286542U,	// VFNMADD213SSZrb_Intkz
    1089677198U,	// VFNMADD213SSm
    1089677198U,	// VFNMADD213SSm_Int
    890283918U,	// VFNMADD213SSr
    890283918U,	// VFNMADD213SSr_Int
    890308942U,	// VFNMADD231PDYm
    890276174U,	// VFNMADD231PDYr
    890177870U,	// VFNMADD231PDZ128m
    1164970318U,	// VFNMADD231PDZ128mb
    1433389390U,	// VFNMADD231PDZ128mbk
    1433389390U,	// VFNMADD231PDZ128mbkz
    86985038U,	// VFNMADD231PDZ128mk
    89082190U,	// VFNMADD231PDZ128mkz
    890276174U,	// VFNMADD231PDZ128r
    87050574U,	// VFNMADD231PDZ128rk
    89147726U,	// VFNMADD231PDZ128rkz
    890308942U,	// VFNMADD231PDZ256m
    1167067470U,	// VFNMADD231PDZ256mb
    1435486542U,	// VFNMADD231PDZ256mbk
    1435486542U,	// VFNMADD231PDZ256mbkz
    87083342U,	// VFNMADD231PDZ256mk
    89180494U,	// VFNMADD231PDZ256mkz
    890276174U,	// VFNMADD231PDZ256r
    87050574U,	// VFNMADD231PDZ256rk
    89147726U,	// VFNMADD231PDZ256rkz
    890358094U,	// VFNMADD231PDZm
    1169164622U,	// VFNMADD231PDZmb
    1437583694U,	// VFNMADD231PDZmbk
    1437583694U,	// VFNMADD231PDZmbkz
    87132494U,	// VFNMADD231PDZmk
    89229646U,	// VFNMADD231PDZmkz
    890276174U,	// VFNMADD231PDZr
    890407246U,	// VFNMADD231PDZrb
    87181646U,	// VFNMADD231PDZrbk
    89278798U,	// VFNMADD231PDZrbkz
    87050574U,	// VFNMADD231PDZrk
    89147726U,	// VFNMADD231PDZrkz
    890177870U,	// VFNMADD231PDm
    890276174U,	// VFNMADD231PDr
    890315336U,	// VFNMADD231PSYm
    890282568U,	// VFNMADD231PSYr
    890184264U,	// VFNMADD231PSZ128m
    1167270472U,	// VFNMADD231PSZ128mb
    1435689544U,	// VFNMADD231PSZ128mbk
    1435689544U,	// VFNMADD231PSZ128mbkz
    86991432U,	// VFNMADD231PSZ128mk
    89088584U,	// VFNMADD231PSZ128mkz
    890282568U,	// VFNMADD231PSZ128r
    87056968U,	// VFNMADD231PSZ128rk
    89154120U,	// VFNMADD231PSZ128rkz
    890315336U,	// VFNMADD231PSZ256m
    1169367624U,	// VFNMADD231PSZ256mb
    1437786696U,	// VFNMADD231PSZ256mbk
    1437786696U,	// VFNMADD231PSZ256mbkz
    87089736U,	// VFNMADD231PSZ256mk
    89186888U,	// VFNMADD231PSZ256mkz
    890282568U,	// VFNMADD231PSZ256r
    87056968U,	// VFNMADD231PSZ256rk
    89154120U,	// VFNMADD231PSZ256rkz
    890364488U,	// VFNMADD231PSZm
    1171464776U,	// VFNMADD231PSZmb
    1439883848U,	// VFNMADD231PSZmbk
    1439883848U,	// VFNMADD231PSZmbkz
    87138888U,	// VFNMADD231PSZmk
    89236040U,	// VFNMADD231PSZmkz
    890282568U,	// VFNMADD231PSZr
    890413640U,	// VFNMADD231PSZrb
    87188040U,	// VFNMADD231PSZrbk
    89285192U,	// VFNMADD231PSZrbkz
    87056968U,	// VFNMADD231PSZrk
    89154120U,	// VFNMADD231PSZrkz
    890184264U,	// VFNMADD231PSm
    890282568U,	// VFNMADD231PSr
    1089474068U,	// VFNMADD231SDZm
    1089474068U,	// VFNMADD231SDZm_Int
    1357893140U,	// VFNMADD231SDZm_Intk
    1357893140U,	// VFNMADD231SDZm_Intkz
    890277396U,	// VFNMADD231SDZr
    890277396U,	// VFNMADD231SDZr_Int
    87051796U,	// VFNMADD231SDZr_Intk
    89148948U,	// VFNMADD231SDZr_Intkz
    890277396U,	// VFNMADD231SDZrb
    890408468U,	// VFNMADD231SDZrb_Int
    87182868U,	// VFNMADD231SDZrb_Intk
    89280020U,	// VFNMADD231SDZrb_Intkz
    1089474068U,	// VFNMADD231SDm
    1089474068U,	// VFNMADD231SDm_Int
    890277396U,	// VFNMADD231SDr
    890277396U,	// VFNMADD231SDr_Int
    1089677079U,	// VFNMADD231SSZm
    1089677079U,	// VFNMADD231SSZm_Int
    1358096151U,	// VFNMADD231SSZm_Intk
    1358096151U,	// VFNMADD231SSZm_Intkz
    890283799U,	// VFNMADD231SSZr
    890283799U,	// VFNMADD231SSZr_Int
    87058199U,	// VFNMADD231SSZr_Intk
    89155351U,	// VFNMADD231SSZr_Intkz
    890283799U,	// VFNMADD231SSZrb
    890414871U,	// VFNMADD231SSZrb_Int
    87189271U,	// VFNMADD231SSZrb_Intk
    89286423U,	// VFNMADD231SSZrb_Intkz
    1089677079U,	// VFNMADD231SSm
    1089677079U,	// VFNMADD231SSm_Int
    890283799U,	// VFNMADD231SSr
    890283799U,	// VFNMADD231SSr_Int
    393497423U,	// VFNMADDPD4Ymr
    890309455U,	// VFNMADDPD4Yrm
    890276687U,	// VFNMADDPD4Yrr
    890276687U,	// VFNMADDPD4Yrr_REV
    301222735U,	// VFNMADDPD4mr
    890178383U,	// VFNMADDPD4rm
    890276687U,	// VFNMADDPD4rr
    890276687U,	// VFNMADDPD4rr_REV
    393503843U,	// VFNMADDPS4Ymr
    890315875U,	// VFNMADDPS4Yrm
    890283107U,	// VFNMADDPS4Yrr
    890283107U,	// VFNMADDPS4Yrr_REV
    301229155U,	// VFNMADDPS4mr
    890184803U,	// VFNMADDPS4rm
    890283107U,	// VFNMADDPS4rr
    890283107U,	// VFNMADDPS4rr_REV
    852774644U,	// VFNMADDSD4mr
    852774644U,	// VFNMADDSD4mr_Int
    1089474292U,	// VFNMADDSD4rm
    1089474292U,	// VFNMADDSD4rm_Int
    890277620U,	// VFNMADDSD4rr
    890277620U,	// VFNMADDSD4rr_Int
    890277620U,	// VFNMADDSD4rr_Int_REV
    890277620U,	// VFNMADDSD4rr_REV
    856975366U,	// VFNMADDSS4mr
    856975366U,	// VFNMADDSS4mr_Int
    1089677318U,	// VFNMADDSS4rm
    1089677318U,	// VFNMADDSS4rm_Int
    890284038U,	// VFNMADDSS4rr
    890284038U,	// VFNMADDSS4rr_Int
    890284038U,	// VFNMADDSS4rr_Int_REV
    890284038U,	// VFNMADDSS4rr_REV
    890308985U,	// VFNMSUB132PDYm
    890276217U,	// VFNMSUB132PDYr
    890177913U,	// VFNMSUB132PDZ128m
    1164970361U,	// VFNMSUB132PDZ128mb
    1433389433U,	// VFNMSUB132PDZ128mbk
    1433389433U,	// VFNMSUB132PDZ128mbkz
    86985081U,	// VFNMSUB132PDZ128mk
    89082233U,	// VFNMSUB132PDZ128mkz
    890276217U,	// VFNMSUB132PDZ128r
    87050617U,	// VFNMSUB132PDZ128rk
    89147769U,	// VFNMSUB132PDZ128rkz
    890308985U,	// VFNMSUB132PDZ256m
    1167067513U,	// VFNMSUB132PDZ256mb
    1435486585U,	// VFNMSUB132PDZ256mbk
    1435486585U,	// VFNMSUB132PDZ256mbkz
    87083385U,	// VFNMSUB132PDZ256mk
    89180537U,	// VFNMSUB132PDZ256mkz
    890276217U,	// VFNMSUB132PDZ256r
    87050617U,	// VFNMSUB132PDZ256rk
    89147769U,	// VFNMSUB132PDZ256rkz
    890358137U,	// VFNMSUB132PDZm
    1169164665U,	// VFNMSUB132PDZmb
    1437583737U,	// VFNMSUB132PDZmbk
    1437583737U,	// VFNMSUB132PDZmbkz
    87132537U,	// VFNMSUB132PDZmk
    89229689U,	// VFNMSUB132PDZmkz
    890276217U,	// VFNMSUB132PDZr
    890407289U,	// VFNMSUB132PDZrb
    87181689U,	// VFNMSUB132PDZrbk
    89278841U,	// VFNMSUB132PDZrbkz
    87050617U,	// VFNMSUB132PDZrk
    89147769U,	// VFNMSUB132PDZrkz
    890177913U,	// VFNMSUB132PDm
    890276217U,	// VFNMSUB132PDr
    890315379U,	// VFNMSUB132PSYm
    890282611U,	// VFNMSUB132PSYr
    890184307U,	// VFNMSUB132PSZ128m
    1167270515U,	// VFNMSUB132PSZ128mb
    1435689587U,	// VFNMSUB132PSZ128mbk
    1435689587U,	// VFNMSUB132PSZ128mbkz
    86991475U,	// VFNMSUB132PSZ128mk
    89088627U,	// VFNMSUB132PSZ128mkz
    890282611U,	// VFNMSUB132PSZ128r
    87057011U,	// VFNMSUB132PSZ128rk
    89154163U,	// VFNMSUB132PSZ128rkz
    890315379U,	// VFNMSUB132PSZ256m
    1169367667U,	// VFNMSUB132PSZ256mb
    1437786739U,	// VFNMSUB132PSZ256mbk
    1437786739U,	// VFNMSUB132PSZ256mbkz
    87089779U,	// VFNMSUB132PSZ256mk
    89186931U,	// VFNMSUB132PSZ256mkz
    890282611U,	// VFNMSUB132PSZ256r
    87057011U,	// VFNMSUB132PSZ256rk
    89154163U,	// VFNMSUB132PSZ256rkz
    890364531U,	// VFNMSUB132PSZm
    1171464819U,	// VFNMSUB132PSZmb
    1439883891U,	// VFNMSUB132PSZmbk
    1439883891U,	// VFNMSUB132PSZmbkz
    87138931U,	// VFNMSUB132PSZmk
    89236083U,	// VFNMSUB132PSZmkz
    890282611U,	// VFNMSUB132PSZr
    890413683U,	// VFNMSUB132PSZrb
    87188083U,	// VFNMSUB132PSZrbk
    89285235U,	// VFNMSUB132PSZrbkz
    87057011U,	// VFNMSUB132PSZrk
    89154163U,	// VFNMSUB132PSZrkz
    890184307U,	// VFNMSUB132PSm
    890282611U,	// VFNMSUB132PSr
    1089474095U,	// VFNMSUB132SDZm
    1089474095U,	// VFNMSUB132SDZm_Int
    1357893167U,	// VFNMSUB132SDZm_Intk
    1357893167U,	// VFNMSUB132SDZm_Intkz
    890277423U,	// VFNMSUB132SDZr
    890277423U,	// VFNMSUB132SDZr_Int
    87051823U,	// VFNMSUB132SDZr_Intk
    89148975U,	// VFNMSUB132SDZr_Intkz
    890277423U,	// VFNMSUB132SDZrb
    890408495U,	// VFNMSUB132SDZrb_Int
    87182895U,	// VFNMSUB132SDZrb_Intk
    89280047U,	// VFNMSUB132SDZrb_Intkz
    1089474095U,	// VFNMSUB132SDm
    1089474095U,	// VFNMSUB132SDm_Int
    890277423U,	// VFNMSUB132SDr
    890277423U,	// VFNMSUB132SDr_Int
    1089677106U,	// VFNMSUB132SSZm
    1089677106U,	// VFNMSUB132SSZm_Int
    1358096178U,	// VFNMSUB132SSZm_Intk
    1358096178U,	// VFNMSUB132SSZm_Intkz
    890283826U,	// VFNMSUB132SSZr
    890283826U,	// VFNMSUB132SSZr_Int
    87058226U,	// VFNMSUB132SSZr_Intk
    89155378U,	// VFNMSUB132SSZr_Intkz
    890283826U,	// VFNMSUB132SSZrb
    890414898U,	// VFNMSUB132SSZrb_Int
    87189298U,	// VFNMSUB132SSZrb_Intk
    89286450U,	// VFNMSUB132SSZrb_Intkz
    1089677106U,	// VFNMSUB132SSm
    1089677106U,	// VFNMSUB132SSm_Int
    890283826U,	// VFNMSUB132SSr
    890283826U,	// VFNMSUB132SSr_Int
    890309181U,	// VFNMSUB213PDYm
    890276413U,	// VFNMSUB213PDYr
    890178109U,	// VFNMSUB213PDZ128m
    1164970557U,	// VFNMSUB213PDZ128mb
    1433389629U,	// VFNMSUB213PDZ128mbk
    1433389629U,	// VFNMSUB213PDZ128mbkz
    86985277U,	// VFNMSUB213PDZ128mk
    89082429U,	// VFNMSUB213PDZ128mkz
    890276413U,	// VFNMSUB213PDZ128r
    87050813U,	// VFNMSUB213PDZ128rk
    89147965U,	// VFNMSUB213PDZ128rkz
    890309181U,	// VFNMSUB213PDZ256m
    1167067709U,	// VFNMSUB213PDZ256mb
    1435486781U,	// VFNMSUB213PDZ256mbk
    1435486781U,	// VFNMSUB213PDZ256mbkz
    87083581U,	// VFNMSUB213PDZ256mk
    89180733U,	// VFNMSUB213PDZ256mkz
    890276413U,	// VFNMSUB213PDZ256r
    87050813U,	// VFNMSUB213PDZ256rk
    89147965U,	// VFNMSUB213PDZ256rkz
    890358333U,	// VFNMSUB213PDZm
    1169164861U,	// VFNMSUB213PDZmb
    1437583933U,	// VFNMSUB213PDZmbk
    1437583933U,	// VFNMSUB213PDZmbkz
    87132733U,	// VFNMSUB213PDZmk
    89229885U,	// VFNMSUB213PDZmkz
    890276413U,	// VFNMSUB213PDZr
    890407485U,	// VFNMSUB213PDZrb
    87181885U,	// VFNMSUB213PDZrbk
    89279037U,	// VFNMSUB213PDZrbkz
    87050813U,	// VFNMSUB213PDZrk
    89147965U,	// VFNMSUB213PDZrkz
    890178109U,	// VFNMSUB213PDm
    890276413U,	// VFNMSUB213PDr
    890315586U,	// VFNMSUB213PSYm
    890282818U,	// VFNMSUB213PSYr
    890184514U,	// VFNMSUB213PSZ128m
    1167270722U,	// VFNMSUB213PSZ128mb
    1435689794U,	// VFNMSUB213PSZ128mbk
    1435689794U,	// VFNMSUB213PSZ128mbkz
    86991682U,	// VFNMSUB213PSZ128mk
    89088834U,	// VFNMSUB213PSZ128mkz
    890282818U,	// VFNMSUB213PSZ128r
    87057218U,	// VFNMSUB213PSZ128rk
    89154370U,	// VFNMSUB213PSZ128rkz
    890315586U,	// VFNMSUB213PSZ256m
    1169367874U,	// VFNMSUB213PSZ256mb
    1437786946U,	// VFNMSUB213PSZ256mbk
    1437786946U,	// VFNMSUB213PSZ256mbkz
    87089986U,	// VFNMSUB213PSZ256mk
    89187138U,	// VFNMSUB213PSZ256mkz
    890282818U,	// VFNMSUB213PSZ256r
    87057218U,	// VFNMSUB213PSZ256rk
    89154370U,	// VFNMSUB213PSZ256rkz
    890364738U,	// VFNMSUB213PSZm
    1171465026U,	// VFNMSUB213PSZmb
    1439884098U,	// VFNMSUB213PSZmbk
    1439884098U,	// VFNMSUB213PSZmbkz
    87139138U,	// VFNMSUB213PSZmk
    89236290U,	// VFNMSUB213PSZmkz
    890282818U,	// VFNMSUB213PSZr
    890413890U,	// VFNMSUB213PSZrb
    87188290U,	// VFNMSUB213PSZrbk
    89285442U,	// VFNMSUB213PSZrbkz
    87057218U,	// VFNMSUB213PSZrk
    89154370U,	// VFNMSUB213PSZrkz
    890184514U,	// VFNMSUB213PSm
    890282818U,	// VFNMSUB213PSr
    1089474160U,	// VFNMSUB213SDZm
    1089474160U,	// VFNMSUB213SDZm_Int
    1357893232U,	// VFNMSUB213SDZm_Intk
    1357893232U,	// VFNMSUB213SDZm_Intkz
    890277488U,	// VFNMSUB213SDZr
    890277488U,	// VFNMSUB213SDZr_Int
    87051888U,	// VFNMSUB213SDZr_Intk
    89149040U,	// VFNMSUB213SDZr_Intkz
    890277488U,	// VFNMSUB213SDZrb
    890408560U,	// VFNMSUB213SDZrb_Int
    87182960U,	// VFNMSUB213SDZrb_Intk
    89280112U,	// VFNMSUB213SDZrb_Intkz
    1089474160U,	// VFNMSUB213SDm
    1089474160U,	// VFNMSUB213SDm_Int
    890277488U,	// VFNMSUB213SDr
    890277488U,	// VFNMSUB213SDr_Int
    1089677171U,	// VFNMSUB213SSZm
    1089677171U,	// VFNMSUB213SSZm_Int
    1358096243U,	// VFNMSUB213SSZm_Intk
    1358096243U,	// VFNMSUB213SSZm_Intkz
    890283891U,	// VFNMSUB213SSZr
    890283891U,	// VFNMSUB213SSZr_Int
    87058291U,	// VFNMSUB213SSZr_Intk
    89155443U,	// VFNMSUB213SSZr_Intkz
    890283891U,	// VFNMSUB213SSZrb
    890414963U,	// VFNMSUB213SSZrb_Int
    87189363U,	// VFNMSUB213SSZrb_Intk
    89286515U,	// VFNMSUB213SSZrb_Intkz
    1089677171U,	// VFNMSUB213SSm
    1089677171U,	// VFNMSUB213SSm_Int
    890283891U,	// VFNMSUB213SSr
    890283891U,	// VFNMSUB213SSr_Int
    890308899U,	// VFNMSUB231PDYm
    890276131U,	// VFNMSUB231PDYr
    890177827U,	// VFNMSUB231PDZ128m
    1164970275U,	// VFNMSUB231PDZ128mb
    1433389347U,	// VFNMSUB231PDZ128mbk
    1433389347U,	// VFNMSUB231PDZ128mbkz
    86984995U,	// VFNMSUB231PDZ128mk
    89082147U,	// VFNMSUB231PDZ128mkz
    890276131U,	// VFNMSUB231PDZ128r
    87050531U,	// VFNMSUB231PDZ128rk
    89147683U,	// VFNMSUB231PDZ128rkz
    890308899U,	// VFNMSUB231PDZ256m
    1167067427U,	// VFNMSUB231PDZ256mb
    1435486499U,	// VFNMSUB231PDZ256mbk
    1435486499U,	// VFNMSUB231PDZ256mbkz
    87083299U,	// VFNMSUB231PDZ256mk
    89180451U,	// VFNMSUB231PDZ256mkz
    890276131U,	// VFNMSUB231PDZ256r
    87050531U,	// VFNMSUB231PDZ256rk
    89147683U,	// VFNMSUB231PDZ256rkz
    890358051U,	// VFNMSUB231PDZm
    1169164579U,	// VFNMSUB231PDZmb
    1437583651U,	// VFNMSUB231PDZmbk
    1437583651U,	// VFNMSUB231PDZmbkz
    87132451U,	// VFNMSUB231PDZmk
    89229603U,	// VFNMSUB231PDZmkz
    890276131U,	// VFNMSUB231PDZr
    890407203U,	// VFNMSUB231PDZrb
    87181603U,	// VFNMSUB231PDZrbk
    89278755U,	// VFNMSUB231PDZrbkz
    87050531U,	// VFNMSUB231PDZrk
    89147683U,	// VFNMSUB231PDZrkz
    890177827U,	// VFNMSUB231PDm
    890276131U,	// VFNMSUB231PDr
    890315293U,	// VFNMSUB231PSYm
    890282525U,	// VFNMSUB231PSYr
    890184221U,	// VFNMSUB231PSZ128m
    1167270429U,	// VFNMSUB231PSZ128mb
    1435689501U,	// VFNMSUB231PSZ128mbk
    1435689501U,	// VFNMSUB231PSZ128mbkz
    86991389U,	// VFNMSUB231PSZ128mk
    89088541U,	// VFNMSUB231PSZ128mkz
    890282525U,	// VFNMSUB231PSZ128r
    87056925U,	// VFNMSUB231PSZ128rk
    89154077U,	// VFNMSUB231PSZ128rkz
    890315293U,	// VFNMSUB231PSZ256m
    1169367581U,	// VFNMSUB231PSZ256mb
    1437786653U,	// VFNMSUB231PSZ256mbk
    1437786653U,	// VFNMSUB231PSZ256mbkz
    87089693U,	// VFNMSUB231PSZ256mk
    89186845U,	// VFNMSUB231PSZ256mkz
    890282525U,	// VFNMSUB231PSZ256r
    87056925U,	// VFNMSUB231PSZ256rk
    89154077U,	// VFNMSUB231PSZ256rkz
    890364445U,	// VFNMSUB231PSZm
    1171464733U,	// VFNMSUB231PSZmb
    1439883805U,	// VFNMSUB231PSZmbk
    1439883805U,	// VFNMSUB231PSZmbkz
    87138845U,	// VFNMSUB231PSZmk
    89235997U,	// VFNMSUB231PSZmkz
    890282525U,	// VFNMSUB231PSZr
    890413597U,	// VFNMSUB231PSZrb
    87187997U,	// VFNMSUB231PSZrbk
    89285149U,	// VFNMSUB231PSZrbkz
    87056925U,	// VFNMSUB231PSZrk
    89154077U,	// VFNMSUB231PSZrkz
    890184221U,	// VFNMSUB231PSm
    890282525U,	// VFNMSUB231PSr
    1089474041U,	// VFNMSUB231SDZm
    1089474041U,	// VFNMSUB231SDZm_Int
    1357893113U,	// VFNMSUB231SDZm_Intk
    1357893113U,	// VFNMSUB231SDZm_Intkz
    890277369U,	// VFNMSUB231SDZr
    890277369U,	// VFNMSUB231SDZr_Int
    87051769U,	// VFNMSUB231SDZr_Intk
    89148921U,	// VFNMSUB231SDZr_Intkz
    890277369U,	// VFNMSUB231SDZrb
    890408441U,	// VFNMSUB231SDZrb_Int
    87182841U,	// VFNMSUB231SDZrb_Intk
    89279993U,	// VFNMSUB231SDZrb_Intkz
    1089474041U,	// VFNMSUB231SDm
    1089474041U,	// VFNMSUB231SDm_Int
    890277369U,	// VFNMSUB231SDr
    890277369U,	// VFNMSUB231SDr_Int
    1089677052U,	// VFNMSUB231SSZm
    1089677052U,	// VFNMSUB231SSZm_Int
    1358096124U,	// VFNMSUB231SSZm_Intk
    1358096124U,	// VFNMSUB231SSZm_Intkz
    890283772U,	// VFNMSUB231SSZr
    890283772U,	// VFNMSUB231SSZr_Int
    87058172U,	// VFNMSUB231SSZr_Intk
    89155324U,	// VFNMSUB231SSZr_Intkz
    890283772U,	// VFNMSUB231SSZrb
    890414844U,	// VFNMSUB231SSZrb_Int
    87189244U,	// VFNMSUB231SSZrb_Intk
    89286396U,	// VFNMSUB231SSZrb_Intkz
    1089677052U,	// VFNMSUB231SSm
    1089677052U,	// VFNMSUB231SSm_Int
    890283772U,	// VFNMSUB231SSr
    890283772U,	// VFNMSUB231SSr_Int
    393497310U,	// VFNMSUBPD4Ymr
    890309342U,	// VFNMSUBPD4Yrm
    890276574U,	// VFNMSUBPD4Yrr
    890276574U,	// VFNMSUBPD4Yrr_REV
    301222622U,	// VFNMSUBPD4mr
    890178270U,	// VFNMSUBPD4rm
    890276574U,	// VFNMSUBPD4rr
    890276574U,	// VFNMSUBPD4rr_REV
    393503707U,	// VFNMSUBPS4Ymr
    890315739U,	// VFNMSUBPS4Yrm
    890282971U,	// VFNMSUBPS4Yrr
    890282971U,	// VFNMSUBPS4Yrr_REV
    301229019U,	// VFNMSUBPS4mr
    890184667U,	// VFNMSUBPS4rm
    890282971U,	// VFNMSUBPS4rr
    890282971U,	// VFNMSUBPS4rr_REV
    852774615U,	// VFNMSUBSD4mr
    852774615U,	// VFNMSUBSD4mr_Int
    1089474263U,	// VFNMSUBSD4rm
    1089474263U,	// VFNMSUBSD4rm_Int
    890277591U,	// VFNMSUBSD4rr
    890277591U,	// VFNMSUBSD4rr_Int
    890277591U,	// VFNMSUBSD4rr_Int_REV
    890277591U,	// VFNMSUBSD4rr_REV
    856975314U,	// VFNMSUBSS4mr
    856975314U,	// VFNMSUBSS4mr_Int
    1089677266U,	// VFNMSUBSS4rm
    1089677266U,	// VFNMSUBSS4rm_Int
    890283986U,	// VFNMSUBSS4rr
    890283986U,	// VFNMSUBSS4rr_Int
    890283986U,	// VFNMSUBSS4rr_Int_REV
    890283986U,	// VFNMSUBSS4rr_REV
    77901811U,	// VFPCLASSPDZ128rm
    3032783586U,	// VFPCLASSPDZ128rmb
    2999311074U,	// VFPCLASSPDZ128rmbk
    568717299U,	// VFPCLASSPDZ128rmk
    283430104U,	// VFPCLASSPDZ128rr
    1088818392U,	// VFPCLASSPDZ128rrk
    168079470U,	// VFPCLASSPDZ256rm
    1690606306U,	// VFPCLASSPDZ256rmb
    1657133794U,	// VFPCLASSPDZ256rmbk
    660992110U,	// VFPCLASSPDZ256rmk
    283430104U,	// VFPCLASSPDZ256rr
    1088818392U,	// VFPCLASSPDZ256rrk
    170176747U,	// VFPCLASSPDZrm
    2495912674U,	// VFPCLASSPDZrmb
    2462440162U,	// VFPCLASSPDZrmbk
    669380843U,	// VFPCLASSPDZrmk
    283430104U,	// VFPCLASSPDZrr
    1088818392U,	// VFPCLASSPDZrrk
    77901913U,	// VFPCLASSPSZ128rm
    1692702429U,	// VFPCLASSPSZ128rmb
    1661327069U,	// VFPCLASSPSZ128rmbk
    568717401U,	// VFPCLASSPSZ128rmk
    283436561U,	// VFPCLASSPSZ128rr
    1088824849U,	// VFPCLASSPSZ128rrk
    168079582U,	// VFPCLASSPSZ256rm
    2498008797U,	// VFPCLASSPSZ256rmb
    2466633437U,	// VFPCLASSPSZ256rmbk
    660992222U,	// VFPCLASSPSZ256rmk
    283436561U,	// VFPCLASSPSZ256rr
    1088824849U,	// VFPCLASSPSZ256rrk
    170176760U,	// VFPCLASSPSZrm
    2766444253U,	// VFPCLASSPSZrmb
    2735068893U,	// VFPCLASSPSZrmbk
    669380856U,	// VFPCLASSPSZrmk
    283436561U,	// VFPCLASSPSZrr
    1088824849U,	// VFPCLASSPSZrrk
    885297054U,	// VFPCLASSSDZrm
    851824542U,	// VFPCLASSSDZrmk
    283430814U,	// VFPCLASSSDZrr
    1088819102U,	// VFPCLASSSDZrrk
    887400603U,	// VFPCLASSSSZrm
    856025243U,	// VFPCLASSSSZrmk
    283437211U,	// VFPCLASSSSZrr
    1088825499U,	// VFPCLASSSSZrrk
    1346906U,	// VFRCZPDYrm
    551832922U,	// VFRCZPDYrr
    658778U,	// VFRCZPDrm
    551832922U,	// VFRCZPDrr
    1353403U,	// VFRCZPSYrm
    551839419U,	// VFRCZPSYrr
    665275U,	// VFRCZPSrm
    551839419U,	// VFRCZPSrr
    552177694U,	// VFRCZSDrm
    551833630U,	// VFRCZSDrr
    552200437U,	// VFRCZSSrm
    551839989U,	// VFRCZSSrr
    649546633U,	// VGATHERDPDYrm
    3231157129U,	// VGATHERDPDZ128rm
    3231173513U,	// VGATHERDPDZ256rm
    3231189897U,	// VGATHERDPDZrm
    643255177U,	// VGATHERDPDrm
    649553053U,	// VGATHERDPSYrm
    3231163549U,	// VGATHERDPSZ128rm
    3231179933U,	// VGATHERDPSZ256rm
    3231196317U,	// VGATHERDPSZrm
    643261597U,	// VGATHERDPSrm
    172854001U,	// VGATHERPF0DPDm
    172860398U,	// VGATHERPF0DPSm
    172854386U,	// VGATHERPF0QPDm
    173368747U,	// VGATHERPF0QPSm
    172854032U,	// VGATHERPF1DPDm
    172860429U,	// VGATHERPF1DPSm
    172854417U,	// VGATHERPF1QPDm
    173368778U,	// VGATHERPF1QPSm
    649546928U,	// VGATHERQPDYrm
    3231157424U,	// VGATHERQPDZ128rm
    3231173808U,	// VGATHERQPDZ256rm
    3231190192U,	// VGATHERQPDZrm
    643255472U,	// VGATHERQPDrm
    643261929U,	// VGATHERQPSYrm
    553149929U,	// VGATHERQPSZ128rm
    3231163881U,	// VGATHERQPSZ256rm
    3231180265U,	// VGATHERQPSZrm
    928474601U,	// VGATHERQPSrm
    658535U,	// VGETEXPPDZ128m
    627674215U,	// VGETEXPPDZ128mb
    628100199U,	// VGETEXPPDZ128mbk
    627199079U,	// VGETEXPPDZ128mbkz
    3230600295U,	// VGETEXPPDZ128mk
    3229748327U,	// VGETEXPPDZ128mkz
    551832679U,	// VGETEXPPDZ128r
    3230698599U,	// VGETEXPPDZ128rk
    3229666407U,	// VGETEXPPDZ128rkz
    1346663U,	// VGETEXPPDZ256m
    629771367U,	// VGETEXPPDZ256mb
    630197351U,	// VGETEXPPDZ256mbk
    629296231U,	// VGETEXPPDZ256mbkz
    3230731367U,	// VGETEXPPDZ256mk
    3230633063U,	// VGETEXPPDZ256mkz
    551832679U,	// VGETEXPPDZ256r
    3230698599U,	// VGETEXPPDZ256rk
    3229666407U,	// VGETEXPPDZ256rkz
    1510503U,	// VGETEXPPDZm
    631868519U,	// VGETEXPPDZmb
    632294503U,	// VGETEXPPDZmbk
    631393383U,	// VGETEXPPDZmbkz
    3230780519U,	// VGETEXPPDZmk
    3230747751U,	// VGETEXPPDZmkz
    551832679U,	// VGETEXPPDZr
    551843335U,	// VGETEXPPDZrb
    3230709255U,	// VGETEXPPDZrbk
    3229677063U,	// VGETEXPPDZrbkz
    3230698599U,	// VGETEXPPDZrk
    3229666407U,	// VGETEXPPDZrkz
    664992U,	// VGETEXPPSZ128m
    629794208U,	// VGETEXPPSZ128mb
    630400416U,	// VGETEXPPSZ128mbk
    629319072U,	// VGETEXPPSZ128mbkz
    3230606752U,	// VGETEXPPSZ128mk
    3229754784U,	// VGETEXPPSZ128mkz
    551839136U,	// VGETEXPPSZ128r
    3230705056U,	// VGETEXPPSZ128rk
    3229672864U,	// VGETEXPPSZ128rkz
    1353120U,	// VGETEXPPSZ256m
    631891360U,	// VGETEXPPSZ256mb
    632497568U,	// VGETEXPPSZ256mbk
    631416224U,	// VGETEXPPSZ256mbkz
    3230737824U,	// VGETEXPPSZ256mk
    3230639520U,	// VGETEXPPSZ256mkz
    551839136U,	// VGETEXPPSZ256r
    3230705056U,	// VGETEXPPSZ256rk
    3229672864U,	// VGETEXPPSZ256rkz
    1516960U,	// VGETEXPPSZm
    633988512U,	// VGETEXPPSZmb
    634594720U,	// VGETEXPPSZmbk
    633513376U,	// VGETEXPPSZmbkz
    3230786976U,	// VGETEXPPSZmk
    3230754208U,	// VGETEXPPSZmkz
    551839136U,	// VGETEXPPSZr
    551843822U,	// VGETEXPPSZrb
    3230709742U,	// VGETEXPPSZrbk
    3229677550U,	// VGETEXPPSZrbkz
    3230705056U,	// VGETEXPPSZrk
    3229672864U,	// VGETEXPPSZrkz
    283266943U,	// VGETEXPSDZm
    1357893503U,	// VGETEXPSDZmk
    1089474431U,	// VGETEXPSDZmkz
    811650943U,	// VGETEXPSDZr
    811660942U,	// VGETEXPSDZrb
    87062158U,	// VGETEXPSDZrbk
    890287758U,	// VGETEXPSDZrbkz
    87052159U,	// VGETEXPSDZrk
    890277759U,	// VGETEXPSDZrkz
    283289744U,	// VGETEXPSSZm
    1358096528U,	// VGETEXPSSZmk
    1089677456U,	// VGETEXPSSZmkz
    811657360U,	// VGETEXPSSZr
    811661411U,	// VGETEXPSSZrb
    87062627U,	// VGETEXPSSZrbk
    890288227U,	// VGETEXPSSZrbkz
    87058576U,	// VGETEXPSSZrk
    890284176U,	// VGETEXPSSZrkz
    3032780034U,	// VGETMANTPDZ128rmbi
    3079933186U,	// VGETMANTPDZ128rmbik
    2999307522U,	// VGETMANTPDZ128rmbikz
    77892866U,	// VGETMANTPDZ128rmi
    666111234U,	// VGETMANTPDZ128rmik
    568708354U,	// VGETMANTPDZ128rmikz
    283430146U,	// VGETMANTPDZ128rri
    1357581570U,	// VGETMANTPDZ128rrik
    1088818434U,	// VGETMANTPDZ128rrikz
    1690602754U,	// VGETMANTPDZ256rmbi
    1737755906U,	// VGETMANTPDZ256rmbik
    1657130242U,	// VGETMANTPDZ256rmbikz
    168070402U,	// VGETMANTPDZ256rmi
    668208386U,	// VGETMANTPDZ256rmik
    660983042U,	// VGETMANTPDZ256rmikz
    283430146U,	// VGETMANTPDZ256rri
    1357581570U,	// VGETMANTPDZ256rrik
    1088818434U,	// VGETMANTPDZ256rrikz
    2495909122U,	// VGETMANTPDZrmbi
    2543062274U,	// VGETMANTPDZrmbik
    2462436610U,	// VGETMANTPDZrmbikz
    170167554U,	// VGETMANTPDZrmi
    672402690U,	// VGETMANTPDZrmik
    669371650U,	// VGETMANTPDZrmikz
    283430146U,	// VGETMANTPDZrri
    407162114U,	// VGETMANTPDZrrib
    1481313538U,	// VGETMANTPDZrribk
    1212550402U,	// VGETMANTPDZrribkz
    1357581570U,	// VGETMANTPDZrrik
    1088818434U,	// VGETMANTPDZrrikz
    1692706358U,	// VGETMANTPSZ128rmbi
    1752442422U,	// VGETMANTPSZ128rmbik
    1661330998U,	// VGETMANTPSZ128rmbikz
    77899318U,	// VGETMANTPSZ128rmi
    666117686U,	// VGETMANTPSZ128rmik
    568714806U,	// VGETMANTPSZ128rmikz
    283436598U,	// VGETMANTPSZ128rri
    1357588022U,	// VGETMANTPSZ128rrik
    1088824886U,	// VGETMANTPSZ128rrikz
    2498012726U,	// VGETMANTPSZ256rmbi
    2557748790U,	// VGETMANTPSZ256rmbik
    2466637366U,	// VGETMANTPSZ256rmbikz
    168076854U,	// VGETMANTPSZ256rmi
    668214838U,	// VGETMANTPSZ256rmik
    660989494U,	// VGETMANTPSZ256rmikz
    283436598U,	// VGETMANTPSZ256rri
    1357588022U,	// VGETMANTPSZ256rrik
    1088824886U,	// VGETMANTPSZ256rrikz
    2766448182U,	// VGETMANTPSZrmbi
    2826184246U,	// VGETMANTPSZrmbik
    2735072822U,	// VGETMANTPSZrmbikz
    170174006U,	// VGETMANTPSZrmi
    672409142U,	// VGETMANTPSZrmik
    669378102U,	// VGETMANTPSZrmikz
    283436598U,	// VGETMANTPSZrri
    407168566U,	// VGETMANTPSZrrib
    1481319990U,	// VGETMANTPSZrribk
    1212556854U,	// VGETMANTPSZrribkz
    1357588022U,	// VGETMANTPSZrrik
    1088824886U,	// VGETMANTPSZrrikz
    851824583U,	// VGETMANTSDZrmi
    963891143U,	// VGETMANTSDZrmik
    932450247U,	// VGETMANTSDZrmikz
    1088819143U,	// VGETMANTSDZrri
    1212551111U,	// VGETMANTSDZrrib
    2286866375U,	// VGETMANTSDZrribk
    1481314247U,	// VGETMANTSDZrribkz
    2163134407U,	// VGETMANTSDZrrik
    1357582279U,	// VGETMANTSDZrrikz
    856025255U,	// VGETMANTSSZrmi
    972286119U,	// VGETMANTSSZrmik
    947136679U,	// VGETMANTSSZrmikz
    1088825511U,	// VGETMANTSSZrri
    1212557479U,	// VGETMANTSSZrrib
    2286872743U,	// VGETMANTSSZrribk
    1481320615U,	// VGETMANTSSZrribkz
    2163140775U,	// VGETMANTSSZrrik
    1357588647U,	// VGETMANTSSZrrikz
    375768372U,	// VGF2P8AFFINEINVQBYrmi
    1088816436U,	// VGF2P8AFFINEINVQBYrri
    3026568500U,	// VGF2P8AFFINEINVQBZ128rmbi
    3128149300U,	// VGF2P8AFFINEINVQBZ128rmbik
    3130262836U,	// VGF2P8AFFINEINVQBZ128rmbikz
    325436724U,	// VGF2P8AFFINEINVQBZ128rmi
    1983104308U,	// VGF2P8AFFINEINVQBZ128rmik
    1179911476U,	// VGF2P8AFFINEINVQBZ128rmikz
    1088816436U,	// VGF2P8AFFINEINVQBZ128rri
    2163131700U,	// VGF2P8AFFINEINVQBZ128rrik
    1357579572U,	// VGF2P8AFFINEINVQBZ128rrikz
    1684391220U,	// VGF2P8AFFINEINVQBZ256rmbi
    1785972020U,	// VGF2P8AFFINEINVQBZ256rmbik
    1788085556U,	// VGF2P8AFFINEINVQBZ256rmbikz
    375768372U,	// VGF2P8AFFINEINVQBZ256rmi
    1989395764U,	// VGF2P8AFFINEINVQBZ256rmik
    1186202932U,	// VGF2P8AFFINEINVQBZ256rmikz
    1088816436U,	// VGF2P8AFFINEINVQBZ256rri
    2163131700U,	// VGF2P8AFFINEINVQBZ256rrik
    1357579572U,	// VGF2P8AFFINEINVQBZ256rrikz
    2489697588U,	// VGF2P8AFFINEINVQBZrmbi
    2591278388U,	// VGF2P8AFFINEINVQBZrmbik
    2593391924U,	// VGF2P8AFFINEINVQBZrmbikz
    382059828U,	// VGF2P8AFFINEINVQBZrmi
    1995687220U,	// VGF2P8AFFINEINVQBZrmik
    1192494388U,	// VGF2P8AFFINEINVQBZrmikz
    1088816436U,	// VGF2P8AFFINEINVQBZrri
    2163131700U,	// VGF2P8AFFINEINVQBZrrik
    1357579572U,	// VGF2P8AFFINEINVQBZrrikz
    325436724U,	// VGF2P8AFFINEINVQBrmi
    1088816436U,	// VGF2P8AFFINEINVQBrri
    375768309U,	// VGF2P8AFFINEQBYrmi
    1088816373U,	// VGF2P8AFFINEQBYrri
    3026568437U,	// VGF2P8AFFINEQBZ128rmbi
    3128149237U,	// VGF2P8AFFINEQBZ128rmbik
    3130262773U,	// VGF2P8AFFINEQBZ128rmbikz
    325436661U,	// VGF2P8AFFINEQBZ128rmi
    1983104245U,	// VGF2P8AFFINEQBZ128rmik
    1179911413U,	// VGF2P8AFFINEQBZ128rmikz
    1088816373U,	// VGF2P8AFFINEQBZ128rri
    2163131637U,	// VGF2P8AFFINEQBZ128rrik
    1357579509U,	// VGF2P8AFFINEQBZ128rrikz
    1684391157U,	// VGF2P8AFFINEQBZ256rmbi
    1785971957U,	// VGF2P8AFFINEQBZ256rmbik
    1788085493U,	// VGF2P8AFFINEQBZ256rmbikz
    375768309U,	// VGF2P8AFFINEQBZ256rmi
    1989395701U,	// VGF2P8AFFINEQBZ256rmik
    1186202869U,	// VGF2P8AFFINEQBZ256rmikz
    1088816373U,	// VGF2P8AFFINEQBZ256rri
    2163131637U,	// VGF2P8AFFINEQBZ256rrik
    1357579509U,	// VGF2P8AFFINEQBZ256rrikz
    2489697525U,	// VGF2P8AFFINEQBZrmbi
    2591278325U,	// VGF2P8AFFINEQBZrmbik
    2593391861U,	// VGF2P8AFFINEQBZrmbikz
    382059765U,	// VGF2P8AFFINEQBZrmi
    1995687157U,	// VGF2P8AFFINEQBZrmik
    1192494325U,	// VGF2P8AFFINEQBZrmikz
    1088816373U,	// VGF2P8AFFINEQBZrri
    2163131637U,	// VGF2P8AFFINEQBZrrik
    1357579509U,	// VGF2P8AFFINEQBZrrikz
    325436661U,	// VGF2P8AFFINEQBrmi
    1088816373U,	// VGF2P8AFFINEQBrri
    812860541U,	// VGF2P8MULBYrm
    811648125U,	// VGF2P8MULBYrr
    811844733U,	// VGF2P8MULBZ128rm
    985105533U,	// VGF2P8MULBZ128rmk
    890569853U,	// VGF2P8MULBZ128rmkz
    811648125U,	// VGF2P8MULBZ128rr
    87049341U,	// VGF2P8MULBZ128rrk
    890274941U,	// VGF2P8MULBZ128rrkz
    812860541U,	// VGF2P8MULBZ256rm
    985121917U,	// VGF2P8MULBZ256rmk
    890602621U,	// VGF2P8MULBZ256rmkz
    811648125U,	// VGF2P8MULBZ256rr
    87049341U,	// VGF2P8MULBZ256rrk
    890274941U,	// VGF2P8MULBZ256rrkz
    812876925U,	// VGF2P8MULBZrm
    985138301U,	// VGF2P8MULBZrmk
    890668157U,	// VGF2P8MULBZrmkz
    811648125U,	// VGF2P8MULBZrr
    87049341U,	// VGF2P8MULBZrrk
    890274941U,	// VGF2P8MULBZrrkz
    811844733U,	// VGF2P8MULBrm
    811648125U,	// VGF2P8MULBrr
    812616508U,	// VHADDPDYrm
    811649852U,	// VHADDPDYrr
    811731772U,	// VHADDPDrm
    811649852U,	// VHADDPDrr
    812622905U,	// VHADDPSYrm
    811656249U,	// VHADDPSYrr
    811738169U,	// VHADDPSrm
    811656249U,	// VHADDPSrr
    812616395U,	// VHSUBPDYrm
    811649739U,	// VHSUBPDYrr
    811731659U,	// VHSUBPDrm
    811649739U,	// VHSUBPDrr
    812622792U,	// VHSUBPSYrm
    811656136U,	// VHSUBPSYrr
    811738056U,	// VHSUBPSrm
    811656136U,	// VHSUBPSrr
    300270206U,	// VINSERTF128rm
    1088815742U,	// VINSERTF128rr
    300269988U,	// VINSERTF32x4Z256rm
    2039726500U,	// VINSERTF32x4Z256rmk
    1202979236U,	// VINSERTF32x4Z256rmkz
    1088815524U,	// VINSERTF32x4Z256rr
    2163130788U,	// VINSERTF32x4Z256rrk
    1357578660U,	// VINSERTF32x4Z256rrkz
    300269988U,	// VINSERTF32x4Zrm
    2039726500U,	// VINSERTF32x4Zrmk
    1202979236U,	// VINSERTF32x4Zrmkz
    1088815524U,	// VINSERTF32x4Zrr
    2163130788U,	// VINSERTF32x4Zrrk
    1357578660U,	// VINSERTF32x4Zrrkz
    392545003U,	// VINSERTF32x8Zrm
    2041823979U,	// VINSERTF32x8Zrmk
    1205076715U,	// VINSERTF32x8Zrmkz
    1088815851U,	// VINSERTF32x8Zrr
    2163131115U,	// VINSERTF32x8Zrrk
    1357578987U,	// VINSERTF32x8Zrrkz
    300269775U,	// VINSERTF64x2Z256rm
    2039726287U,	// VINSERTF64x2Z256rmk
    1202979023U,	// VINSERTF64x2Z256rmkz
    1088815311U,	// VINSERTF64x2Z256rr
    2163130575U,	// VINSERTF64x2Z256rrk
    1357578447U,	// VINSERTF64x2Z256rrkz
    300269775U,	// VINSERTF64x2Zrm
    2039726287U,	// VINSERTF64x2Zrmk
    1202979023U,	// VINSERTF64x2Zrmkz
    1088815311U,	// VINSERTF64x2Zrr
    2163130575U,	// VINSERTF64x2Zrrk
    1357578447U,	// VINSERTF64x2Zrrkz
    392544780U,	// VINSERTF64x4Zrm
    2041823756U,	// VINSERTF64x4Zrmk
    1205076492U,	// VINSERTF64x4Zrmkz
    1088815628U,	// VINSERTF64x4Zrr
    2163130892U,	// VINSERTF64x4Zrrk
    1357578764U,	// VINSERTF64x4Zrrkz
    325436085U,	// VINSERTI128rm
    1088815797U,	// VINSERTI128rr
    325435870U,	// VINSERTI32x4Z256rm
    1983103454U,	// VINSERTI32x4Z256rmk
    1179910622U,	// VINSERTI32x4Z256rmkz
    1088815582U,	// VINSERTI32x4Z256rr
    2163130846U,	// VINSERTI32x4Z256rrk
    1357578718U,	// VINSERTI32x4Z256rrkz
    325435870U,	// VINSERTI32x4Zrm
    1983103454U,	// VINSERTI32x4Zrmk
    1179910622U,	// VINSERTI32x4Zrmkz
    1088815582U,	// VINSERTI32x4Zrr
    2163130846U,	// VINSERTI32x4Zrrk
    1357578718U,	// VINSERTI32x4Zrrkz
    375767833U,	// VINSERTI32x8Zrm
    1989395225U,	// VINSERTI32x8Zrmk
    1186202393U,	// VINSERTI32x8Zrmkz
    1088815897U,	// VINSERTI32x8Zrr
    2163131161U,	// VINSERTI32x8Zrrk
    1357579033U,	// VINSERTI32x8Zrrkz
    325435657U,	// VINSERTI64x2Z256rm
    1983103241U,	// VINSERTI64x2Z256rmk
    1179910409U,	// VINSERTI64x2Z256rmkz
    1088815369U,	// VINSERTI64x2Z256rr
    2163130633U,	// VINSERTI64x2Z256rrk
    1357578505U,	// VINSERTI64x2Z256rrkz
    325435657U,	// VINSERTI64x2Zrm
    1983103241U,	// VINSERTI64x2Zrmk
    1179910409U,	// VINSERTI64x2Zrmkz
    1088815369U,	// VINSERTI64x2Zrr
    2163130633U,	// VINSERTI64x2Zrrk
    1357578505U,	// VINSERTI64x2Zrrkz
    375767610U,	// VINSERTI64x4Zrm
    1989395002U,	// VINSERTI64x4Zrmk
    1186202170U,	// VINSERTI64x4Zrmkz
    1088815674U,	// VINSERTI64x4Zrr
    2163130938U,	// VINSERTI64x4Zrrk
    1357578810U,	// VINSERTI64x4Zrrkz
    856024652U,	// VINSERTPSZrm
    1088824908U,	// VINSERTPSZrr
    856024652U,	// VINSERTPSrm
    1088824908U,	// VINSERTPSrr
    552954308U,	// VLDDQUYrm
    272836U,	// VLDDQUrm
    237909U,	// VLDMXCSR
    551840204U,	// VMASKMOVDQU
    551840204U,	// VMASKMOVDQU64
    1663372614U,	// VMASKMOVPDYmr
    812617030U,	// VMASKMOVPDYrm
    1126501702U,	// VMASKMOVPDmr
    811732294U,	// VMASKMOVPDrm
    1663379111U,	// VMASKMOVPSYmr
    812623527U,	// VMASKMOVPSYrm
    1126508199U,	// VMASKMOVPSmr
    811738791U,	// VMASKMOVPSrm
    812617042U,	// VMAXCPDYrm
    811650386U,	// VMAXCPDYrr
    811732306U,	// VMAXCPDZ128rm
    358763858U,	// VMAXCPDZ128rmb
    1433390418U,	// VMAXCPDZ128rmbk
    1164971346U,	// VMAXCPDZ128rmbkz
    86986066U,	// VMAXCPDZ128rmk
    890178898U,	// VMAXCPDZ128rmkz
    811650386U,	// VMAXCPDZ128rr
    87051602U,	// VMAXCPDZ128rrk
    890277202U,	// VMAXCPDZ128rrkz
    812617042U,	// VMAXCPDZ256rm
    360861010U,	// VMAXCPDZ256rmb
    1435487570U,	// VMAXCPDZ256rmbk
    1167068498U,	// VMAXCPDZ256rmbkz
    87084370U,	// VMAXCPDZ256rmk
    890309970U,	// VMAXCPDZ256rmkz
    811650386U,	// VMAXCPDZ256rr
    87051602U,	// VMAXCPDZ256rrk
    890277202U,	// VMAXCPDZ256rrkz
    812731730U,	// VMAXCPDZrm
    362958162U,	// VMAXCPDZrmb
    1437584722U,	// VMAXCPDZrmbk
    1169165650U,	// VMAXCPDZrmbkz
    87133522U,	// VMAXCPDZrmk
    890359122U,	// VMAXCPDZrmkz
    811650386U,	// VMAXCPDZrr
    87051602U,	// VMAXCPDZrrk
    890277202U,	// VMAXCPDZrrkz
    811732306U,	// VMAXCPDrm
    811650386U,	// VMAXCPDrr
    812623539U,	// VMAXCPSYrm
    811656883U,	// VMAXCPSYrr
    811738803U,	// VMAXCPSZ128rm
    360883891U,	// VMAXCPSZ128rmb
    1435690675U,	// VMAXCPSZ128rmbk
    1167271603U,	// VMAXCPSZ128rmbkz
    86992563U,	// VMAXCPSZ128rmk
    890185395U,	// VMAXCPSZ128rmkz
    811656883U,	// VMAXCPSZ128rr
    87058099U,	// VMAXCPSZ128rrk
    890283699U,	// VMAXCPSZ128rrkz
    812623539U,	// VMAXCPSZ256rm
    362981043U,	// VMAXCPSZ256rmb
    1437787827U,	// VMAXCPSZ256rmbk
    1169368755U,	// VMAXCPSZ256rmbkz
    87090867U,	// VMAXCPSZ256rmk
    890316467U,	// VMAXCPSZ256rmkz
    811656883U,	// VMAXCPSZ256rr
    87058099U,	// VMAXCPSZ256rrk
    890283699U,	// VMAXCPSZ256rrkz
    812738227U,	// VMAXCPSZrm
    365078195U,	// VMAXCPSZrmb
    1439884979U,	// VMAXCPSZrmbk
    1171465907U,	// VMAXCPSZrmbkz
    87140019U,	// VMAXCPSZrmk
    890365619U,	// VMAXCPSZrmkz
    811656883U,	// VMAXCPSZrr
    87058099U,	// VMAXCPSZrrk
    890283699U,	// VMAXCPSZrrkz
    811738803U,	// VMAXCPSrm
    811656883U,	// VMAXCPSrr
    283267094U,	// VMAXCSDZrm
    811651094U,	// VMAXCSDZrr
    283267094U,	// VMAXCSDrm
    811651094U,	// VMAXCSDrr
    283289837U,	// VMAXCSSZrm
    811657453U,	// VMAXCSSZrr
    283289837U,	// VMAXCSSrm
    811657453U,	// VMAXCSSrr
    812617042U,	// VMAXPDYrm
    811650386U,	// VMAXPDYrr
    811732306U,	// VMAXPDZ128rm
    358763858U,	// VMAXPDZ128rmb
    1433390418U,	// VMAXPDZ128rmbk
    1164971346U,	// VMAXPDZ128rmbkz
    86986066U,	// VMAXPDZ128rmk
    890178898U,	// VMAXPDZ128rmkz
    811650386U,	// VMAXPDZ128rr
    87051602U,	// VMAXPDZ128rrk
    890277202U,	// VMAXPDZ128rrkz
    812617042U,	// VMAXPDZ256rm
    360861010U,	// VMAXPDZ256rmb
    1435487570U,	// VMAXPDZ256rmbk
    1167068498U,	// VMAXPDZ256rmbkz
    87084370U,	// VMAXPDZ256rmk
    890309970U,	// VMAXPDZ256rmkz
    811650386U,	// VMAXPDZ256rr
    87051602U,	// VMAXPDZ256rrk
    890277202U,	// VMAXPDZ256rrkz
    812731730U,	// VMAXPDZrm
    362958162U,	// VMAXPDZrmb
    1437584722U,	// VMAXPDZrmbk
    1169165650U,	// VMAXPDZrmbkz
    87133522U,	// VMAXPDZrmk
    890359122U,	// VMAXPDZrmkz
    811650386U,	// VMAXPDZrr
    811660825U,	// VMAXPDZrrb
    87062041U,	// VMAXPDZrrbk
    890287641U,	// VMAXPDZrrbkz
    87051602U,	// VMAXPDZrrk
    890277202U,	// VMAXPDZrrkz
    811732306U,	// VMAXPDrm
    811650386U,	// VMAXPDrr
    812623539U,	// VMAXPSYrm
    811656883U,	// VMAXPSYrr
    811738803U,	// VMAXPSZ128rm
    360883891U,	// VMAXPSZ128rmb
    1435690675U,	// VMAXPSZ128rmbk
    1167271603U,	// VMAXPSZ128rmbkz
    86992563U,	// VMAXPSZ128rmk
    890185395U,	// VMAXPSZ128rmkz
    811656883U,	// VMAXPSZ128rr
    87058099U,	// VMAXPSZ128rrk
    890283699U,	// VMAXPSZ128rrkz
    812623539U,	// VMAXPSZ256rm
    362981043U,	// VMAXPSZ256rmb
    1437787827U,	// VMAXPSZ256rmbk
    1169368755U,	// VMAXPSZ256rmbkz
    87090867U,	// VMAXPSZ256rmk
    890316467U,	// VMAXPSZ256rmkz
    811656883U,	// VMAXPSZ256rr
    87058099U,	// VMAXPSZ256rrk
    890283699U,	// VMAXPSZ256rrkz
    812738227U,	// VMAXPSZrm
    365078195U,	// VMAXPSZrmb
    1439884979U,	// VMAXPSZrmbk
    1171465907U,	// VMAXPSZrmbkz
    87140019U,	// VMAXPSZrmk
    890365619U,	// VMAXPSZrmkz
    811656883U,	// VMAXPSZrr
    811661312U,	// VMAXPSZrrb
    87062528U,	// VMAXPSZrrbk
    890288128U,	// VMAXPSZrrbkz
    87058099U,	// VMAXPSZrrk
    890283699U,	// VMAXPSZrrkz
    811738803U,	// VMAXPSrm
    811656883U,	// VMAXPSrr
    283267094U,	// VMAXSDZrm
    283267094U,	// VMAXSDZrm_Int
    1357893654U,	// VMAXSDZrm_Intk
    1089474582U,	// VMAXSDZrm_Intkz
    811651094U,	// VMAXSDZrr
    811651094U,	// VMAXSDZrr_Int
    87052310U,	// VMAXSDZrr_Intk
    890277910U,	// VMAXSDZrr_Intkz
    811660960U,	// VMAXSDZrrb_Int
    87062176U,	// VMAXSDZrrb_Intk
    890287776U,	// VMAXSDZrrb_Intkz
    283267094U,	// VMAXSDrm
    283267094U,	// VMAXSDrm_Int
    811651094U,	// VMAXSDrr
    811651094U,	// VMAXSDrr_Int
    283289837U,	// VMAXSSZrm
    283289837U,	// VMAXSSZrm_Int
    1358096621U,	// VMAXSSZrm_Intk
    1089677549U,	// VMAXSSZrm_Intkz
    811657453U,	// VMAXSSZrr
    811657453U,	// VMAXSSZrr_Int
    87058669U,	// VMAXSSZrr_Intk
    890284269U,	// VMAXSSZrr_Intkz
    811661429U,	// VMAXSSZrrb_Int
    87062645U,	// VMAXSSZrrb_Intk
    890288245U,	// VMAXSSZrrb_Intkz
    283289837U,	// VMAXSSrm
    283289837U,	// VMAXSSrm_Int
    811657453U,	// VMAXSSrr
    811657453U,	// VMAXSSrr_Int
    15223U,	// VMCALL
    450821U,	// VMCLEARm
    14950U,	// VMFUNC
    812616784U,	// VMINCPDYrm
    811650128U,	// VMINCPDYrr
    811732048U,	// VMINCPDZ128rm
    358763600U,	// VMINCPDZ128rmb
    1433390160U,	// VMINCPDZ128rmbk
    1164971088U,	// VMINCPDZ128rmbkz
    86985808U,	// VMINCPDZ128rmk
    890178640U,	// VMINCPDZ128rmkz
    811650128U,	// VMINCPDZ128rr
    87051344U,	// VMINCPDZ128rrk
    890276944U,	// VMINCPDZ128rrkz
    812616784U,	// VMINCPDZ256rm
    360860752U,	// VMINCPDZ256rmb
    1435487312U,	// VMINCPDZ256rmbk
    1167068240U,	// VMINCPDZ256rmbkz
    87084112U,	// VMINCPDZ256rmk
    890309712U,	// VMINCPDZ256rmkz
    811650128U,	// VMINCPDZ256rr
    87051344U,	// VMINCPDZ256rrk
    890276944U,	// VMINCPDZ256rrkz
    812731472U,	// VMINCPDZrm
    362957904U,	// VMINCPDZrmb
    1437584464U,	// VMINCPDZrmbk
    1169165392U,	// VMINCPDZrmbkz
    87133264U,	// VMINCPDZrmk
    890358864U,	// VMINCPDZrmkz
    811650128U,	// VMINCPDZrr
    87051344U,	// VMINCPDZrrk
    890276944U,	// VMINCPDZrrkz
    811732048U,	// VMINCPDrm
    811650128U,	// VMINCPDrr
    812623233U,	// VMINCPSYrm
    811656577U,	// VMINCPSYrr
    811738497U,	// VMINCPSZ128rm
    360883585U,	// VMINCPSZ128rmb
    1435690369U,	// VMINCPSZ128rmbk
    1167271297U,	// VMINCPSZ128rmbkz
    86992257U,	// VMINCPSZ128rmk
    890185089U,	// VMINCPSZ128rmkz
    811656577U,	// VMINCPSZ128rr
    87057793U,	// VMINCPSZ128rrk
    890283393U,	// VMINCPSZ128rrkz
    812623233U,	// VMINCPSZ256rm
    362980737U,	// VMINCPSZ256rmb
    1437787521U,	// VMINCPSZ256rmbk
    1169368449U,	// VMINCPSZ256rmbkz
    87090561U,	// VMINCPSZ256rmk
    890316161U,	// VMINCPSZ256rmkz
    811656577U,	// VMINCPSZ256rr
    87057793U,	// VMINCPSZ256rrk
    890283393U,	// VMINCPSZ256rrkz
    812737921U,	// VMINCPSZrm
    365077889U,	// VMINCPSZrmb
    1439884673U,	// VMINCPSZrmbk
    1171465601U,	// VMINCPSZrmbkz
    87139713U,	// VMINCPSZrmk
    890365313U,	// VMINCPSZrmkz
    811656577U,	// VMINCPSZrr
    87057793U,	// VMINCPSZrrk
    890283393U,	// VMINCPSZrrkz
    811738497U,	// VMINCPSrm
    811656577U,	// VMINCPSrr
    283266927U,	// VMINCSDZrm
    811650927U,	// VMINCSDZrr
    283266927U,	// VMINCSDrm
    811650927U,	// VMINCSDrr
    283289720U,	// VMINCSSZrm
    811657336U,	// VMINCSSZrr
    283289720U,	// VMINCSSrm
    811657336U,	// VMINCSSrr
    812616784U,	// VMINPDYrm
    811650128U,	// VMINPDYrr
    811732048U,	// VMINPDZ128rm
    358763600U,	// VMINPDZ128rmb
    1433390160U,	// VMINPDZ128rmbk
    1164971088U,	// VMINPDZ128rmbkz
    86985808U,	// VMINPDZ128rmk
    890178640U,	// VMINPDZ128rmkz
    811650128U,	// VMINPDZ128rr
    87051344U,	// VMINPDZ128rrk
    890276944U,	// VMINPDZ128rrkz
    812616784U,	// VMINPDZ256rm
    360860752U,	// VMINPDZ256rmb
    1435487312U,	// VMINPDZ256rmbk
    1167068240U,	// VMINPDZ256rmbkz
    87084112U,	// VMINPDZ256rmk
    890309712U,	// VMINPDZ256rmkz
    811650128U,	// VMINPDZ256rr
    87051344U,	// VMINPDZ256rrk
    890276944U,	// VMINPDZ256rrkz
    812731472U,	// VMINPDZrm
    362957904U,	// VMINPDZrmb
    1437584464U,	// VMINPDZrmbk
    1169165392U,	// VMINPDZrmbkz
    87133264U,	// VMINPDZrmk
    890358864U,	// VMINPDZrmkz
    811650128U,	// VMINPDZrr
    811660792U,	// VMINPDZrrb
    87062008U,	// VMINPDZrrbk
    890287608U,	// VMINPDZrrbkz
    87051344U,	// VMINPDZrrk
    890276944U,	// VMINPDZrrkz
    811732048U,	// VMINPDrm
    811650128U,	// VMINPDrr
    812623233U,	// VMINPSYrm
    811656577U,	// VMINPSYrr
    811738497U,	// VMINPSZ128rm
    360883585U,	// VMINPSZ128rmb
    1435690369U,	// VMINPSZ128rmbk
    1167271297U,	// VMINPSZ128rmbkz
    86992257U,	// VMINPSZ128rmk
    890185089U,	// VMINPSZ128rmkz
    811656577U,	// VMINPSZ128rr
    87057793U,	// VMINPSZ128rrk
    890283393U,	// VMINPSZ128rrkz
    812623233U,	// VMINPSZ256rm
    362980737U,	// VMINPSZ256rmb
    1437787521U,	// VMINPSZ256rmbk
    1169368449U,	// VMINPSZ256rmbkz
    87090561U,	// VMINPSZ256rmk
    890316161U,	// VMINPSZ256rmkz
    811656577U,	// VMINPSZ256rr
    87057793U,	// VMINPSZ256rrk
    890283393U,	// VMINPSZ256rrkz
    812737921U,	// VMINPSZrm
    365077889U,	// VMINPSZrmb
    1439884673U,	// VMINPSZrmbk
    1171465601U,	// VMINPSZrmbkz
    87139713U,	// VMINPSZrmk
    890365313U,	// VMINPSZrmkz
    811656577U,	// VMINPSZrr
    811661279U,	// VMINPSZrrb
    87062495U,	// VMINPSZrrbk
    890288095U,	// VMINPSZrrbkz
    87057793U,	// VMINPSZrrk
    890283393U,	// VMINPSZrrkz
    811738497U,	// VMINPSrm
    811656577U,	// VMINPSrr
    283266927U,	// VMINSDZrm
    283266927U,	// VMINSDZrm_Int
    1357893487U,	// VMINSDZrm_Intk
    1089474415U,	// VMINSDZrm_Intkz
    811650927U,	// VMINSDZrr
    811650927U,	// VMINSDZrr_Int
    87052143U,	// VMINSDZrr_Intk
    890277743U,	// VMINSDZrr_Intkz
    811660927U,	// VMINSDZrrb_Int
    87062143U,	// VMINSDZrrb_Intk
    890287743U,	// VMINSDZrrb_Intkz
    283266927U,	// VMINSDrm
    283266927U,	// VMINSDrm_Int
    811650927U,	// VMINSDrr
    811650927U,	// VMINSDrr_Int
    283289720U,	// VMINSSZrm
    283289720U,	// VMINSSZrm_Int
    1358096504U,	// VMINSSZrm_Intk
    1089677432U,	// VMINSSZrm_Intkz
    811657336U,	// VMINSSZrr
    811657336U,	// VMINSSZrr_Int
    87058552U,	// VMINSSZrr_Intk
    890284152U,	// VMINSSZrr_Intkz
    811661396U,	// VMINSSZrrb_Int
    87062612U,	// VMINSSZrrb_Intk
    890288212U,	// VMINSSZrrb_Intkz
    283289720U,	// VMINSSrm
    283289720U,	// VMINSSrm_Int
    811657336U,	// VMINSSrr
    811657336U,	// VMINSSrr_Int
    15124U,	// VMLAUNCH
    16019U,	// VMLOAD32
    16080U,	// VMLOAD64
    15215U,	// VMMCALL
    551919746U,	// VMOV64toPQIZrm
    551837826U,	// VMOV64toPQIZrr
    551919746U,	// VMOV64toPQIrm
    551837826U,	// VMOV64toPQIrr
    551919746U,	// VMOV64toSDZrm
    551837826U,	// VMOV64toSDZrr
    551919746U,	// VMOV64toSDrm
    551837826U,	// VMOV64toSDrr
    148933282U,	// VMOVAPDYmr
    1346210U,	// VMOVAPDYrm
    551832226U,	// VMOVAPDYrr
    551832226U,	// VMOVAPDYrr_REV
    65047202U,	// VMOVAPDZ128mr
    3286567586U,	// VMOVAPDZ128mrk
    658082U,	// VMOVAPDZ128rm
    3230599842U,	// VMOVAPDZ128rmk
    3229747874U,	// VMOVAPDZ128rmkz
    551832226U,	// VMOVAPDZ128rr
    551832226U,	// VMOVAPDZ128rr_REV
    3230698146U,	// VMOVAPDZ128rrk
    3229665954U,	// VMOVAPDZ128rrk_REV
    3229665954U,	// VMOVAPDZ128rrkz
    3229665954U,	// VMOVAPDZ128rrkz_REV
    148933282U,	// VMOVAPDZ256mr
    3370453666U,	// VMOVAPDZ256mrk
    1346210U,	// VMOVAPDZ256rm
    3230730914U,	// VMOVAPDZ256rmk
    3230632610U,	// VMOVAPDZ256rmkz
    551832226U,	// VMOVAPDZ256rr
    551832226U,	// VMOVAPDZ256rr_REV
    3230698146U,	// VMOVAPDZ256rrk
    3229665954U,	// VMOVAPDZ256rrk_REV
    3229665954U,	// VMOVAPDZ256rrkz
    3229665954U,	// VMOVAPDZ256rrkz_REV
    151030434U,	// VMOVAPDZmr
    3372550818U,	// VMOVAPDZmrk
    1510050U,	// VMOVAPDZrm
    3230780066U,	// VMOVAPDZrmk
    3230747298U,	// VMOVAPDZrmkz
    551832226U,	// VMOVAPDZrr
    551832226U,	// VMOVAPDZrr_REV
    3230698146U,	// VMOVAPDZrrk
    3229665954U,	// VMOVAPDZrrk_REV
    3229665954U,	// VMOVAPDZrrkz
    3229665954U,	// VMOVAPDZrrkz_REV
    65047202U,	// VMOVAPDmr
    658082U,	// VMOVAPDrm
    551832226U,	// VMOVAPDrr
    551832226U,	// VMOVAPDrr_REV
    148939687U,	// VMOVAPSYmr
    1352615U,	// VMOVAPSYrm
    551838631U,	// VMOVAPSYrr
    551838631U,	// VMOVAPSYrr_REV
    65053607U,	// VMOVAPSZ128mr
    3286573991U,	// VMOVAPSZ128mrk
    664487U,	// VMOVAPSZ128rm
    3230606247U,	// VMOVAPSZ128rmk
    3229754279U,	// VMOVAPSZ128rmkz
    551838631U,	// VMOVAPSZ128rr
    551838631U,	// VMOVAPSZ128rr_REV
    3230704551U,	// VMOVAPSZ128rrk
    3229672359U,	// VMOVAPSZ128rrk_REV
    3229672359U,	// VMOVAPSZ128rrkz
    3229672359U,	// VMOVAPSZ128rrkz_REV
    148939687U,	// VMOVAPSZ256mr
    3370460071U,	// VMOVAPSZ256mrk
    1352615U,	// VMOVAPSZ256rm
    3230737319U,	// VMOVAPSZ256rmk
    3230639015U,	// VMOVAPSZ256rmkz
    551838631U,	// VMOVAPSZ256rr
    551838631U,	// VMOVAPSZ256rr_REV
    3230704551U,	// VMOVAPSZ256rrk
    3229672359U,	// VMOVAPSZ256rrk_REV
    3229672359U,	// VMOVAPSZ256rrkz
    3229672359U,	// VMOVAPSZ256rrkz_REV
    151036839U,	// VMOVAPSZmr
    3372557223U,	// VMOVAPSZmrk
    1516455U,	// VMOVAPSZrm
    3230786471U,	// VMOVAPSZrmk
    3230753703U,	// VMOVAPSZrmkz
    551838631U,	// VMOVAPSZrr
    551838631U,	// VMOVAPSZrr_REV
    3230704551U,	// VMOVAPSZrrk
    3229672359U,	// VMOVAPSZrrk_REV
    3229672359U,	// VMOVAPSZrrkz
    3229672359U,	// VMOVAPSZrrkz_REV
    65053607U,	// VMOVAPSmr
    664487U,	// VMOVAPSrm
    551838631U,	// VMOVAPSrr
    551838631U,	// VMOVAPSrr_REV
    1349887U,	// VMOVDDUPYrm
    551835903U,	// VMOVDDUPYrr
    552179967U,	// VMOVDDUPZ128rm
    552605951U,	// VMOVDDUPZ128rmk
    551704831U,	// VMOVDDUPZ128rmkz
    551835903U,	// VMOVDDUPZ128rr
    3230701823U,	// VMOVDDUPZ128rrk
    3229669631U,	// VMOVDDUPZ128rrkz
    1349887U,	// VMOVDDUPZ256rm
    3230734591U,	// VMOVDDUPZ256rmk
    3230636287U,	// VMOVDDUPZ256rmkz
    551835903U,	// VMOVDDUPZ256rr
    3230701823U,	// VMOVDDUPZ256rrk
    3229669631U,	// VMOVDDUPZ256rrkz
    1513727U,	// VMOVDDUPZrm
    3230783743U,	// VMOVDDUPZrmk
    3230750975U,	// VMOVDDUPZrmkz
    551835903U,	// VMOVDDUPZrr
    3230701823U,	// VMOVDDUPZrrk
    3229669631U,	// VMOVDDUPZrrkz
    552179967U,	// VMOVDDUPrm
    551835903U,	// VMOVDDUPrr
    551899369U,	// VMOVDI2PDIZrm
    551833833U,	// VMOVDI2PDIZrr
    551899369U,	// VMOVDI2PDIrm
    551833833U,	// VMOVDI2PDIrr
    551899369U,	// VMOVDI2SSZrm
    551833833U,	// VMOVDI2SSZrr
    551899369U,	// VMOVDI2SSrm
    551833833U,	// VMOVDI2SSrr
    33587280U,	// VMOVDQA32Z128mr
    3255107664U,	// VMOVDQA32Z128mrk
    262224U,	// VMOVDQA32Z128rm
    3230990416U,	// VMOVDQA32Z128rmk
    3229859920U,	// VMOVDQA32Z128rmkz
    551829584U,	// VMOVDQA32Z128rr
    551829584U,	// VMOVDQA32Z128rr_REV
    3230695504U,	// VMOVDQA32Z128rrk
    3229663312U,	// VMOVDQA32Z128rrk_REV
    3229663312U,	// VMOVDQA32Z128rrkz
    3229663312U,	// VMOVDQA32Z128rrkz_REV
    180387920U,	// VMOVDQA32Z256mr
    3401908304U,	// VMOVDQA32Z256mrk
    552943696U,	// VMOVDQA32Z256rm
    3231023184U,	// VMOVDQA32Z256rmk
    3230875728U,	// VMOVDQA32Z256rmkz
    551829584U,	// VMOVDQA32Z256rr
    551829584U,	// VMOVDQA32Z256rr_REV
    3230695504U,	// VMOVDQA32Z256rrk
    3229663312U,	// VMOVDQA32Z256rrk_REV
    3229663312U,	// VMOVDQA32Z256rrkz
    3229663312U,	// VMOVDQA32Z256rrkz_REV
    182485072U,	// VMOVDQA32Zmr
    3404005456U,	// VMOVDQA32Zmrk
    552435792U,	// VMOVDQA32Zrm
    3231088720U,	// VMOVDQA32Zrmk
    3230892112U,	// VMOVDQA32Zrmkz
    551829584U,	// VMOVDQA32Zrr
    551829584U,	// VMOVDQA32Zrr_REV
    3230695504U,	// VMOVDQA32Zrrk
    3229663312U,	// VMOVDQA32Zrrk_REV
    3229663312U,	// VMOVDQA32Zrrkz
    3229663312U,	// VMOVDQA32Zrrkz_REV
    33587496U,	// VMOVDQA64Z128mr
    3255107880U,	// VMOVDQA64Z128mrk
    262440U,	// VMOVDQA64Z128rm
    3230990632U,	// VMOVDQA64Z128rmk
    3229860136U,	// VMOVDQA64Z128rmkz
    551829800U,	// VMOVDQA64Z128rr
    551829800U,	// VMOVDQA64Z128rr_REV
    3230695720U,	// VMOVDQA64Z128rrk
    3229663528U,	// VMOVDQA64Z128rrk_REV
    3229663528U,	// VMOVDQA64Z128rrkz
    3229663528U,	// VMOVDQA64Z128rrkz_REV
    180388136U,	// VMOVDQA64Z256mr
    3401908520U,	// VMOVDQA64Z256mrk
    552943912U,	// VMOVDQA64Z256rm
    3231023400U,	// VMOVDQA64Z256rmk
    3230875944U,	// VMOVDQA64Z256rmkz
    551829800U,	// VMOVDQA64Z256rr
    551829800U,	// VMOVDQA64Z256rr_REV
    3230695720U,	// VMOVDQA64Z256rrk
    3229663528U,	// VMOVDQA64Z256rrk_REV
    3229663528U,	// VMOVDQA64Z256rrkz
    3229663528U,	// VMOVDQA64Z256rrkz_REV
    182485288U,	// VMOVDQA64Zmr
    3404005672U,	// VMOVDQA64Zmrk
    552436008U,	// VMOVDQA64Zrm
    3231088936U,	// VMOVDQA64Zrmk
    3230892328U,	// VMOVDQA64Zrmkz
    551829800U,	// VMOVDQA64Zrr
    551829800U,	// VMOVDQA64Zrr_REV
    3230695720U,	// VMOVDQA64Zrrk
    3229663528U,	// VMOVDQA64Zrrk_REV
    3229663528U,	// VMOVDQA64Zrrkz
    3229663528U,	// VMOVDQA64Zrrkz_REV
    180388679U,	// VMOVDQAYmr
    552944455U,	// VMOVDQAYrm
    551830343U,	// VMOVDQAYrr
    551830343U,	// VMOVDQAYrr_REV
    33588039U,	// VMOVDQAmr
    262983U,	// VMOVDQArm
    551830343U,	// VMOVDQArr
    551830343U,	// VMOVDQArr_REV
    33587801U,	// VMOVDQU16Z128mr
    3255108185U,	// VMOVDQU16Z128mrk
    262745U,	// VMOVDQU16Z128rm
    3230990937U,	// VMOVDQU16Z128rmk
    3229860441U,	// VMOVDQU16Z128rmkz
    551830105U,	// VMOVDQU16Z128rr
    551830105U,	// VMOVDQU16Z128rr_REV
    3230696025U,	// VMOVDQU16Z128rrk
    3229663833U,	// VMOVDQU16Z128rrk_REV
    3229663833U,	// VMOVDQU16Z128rrkz
    3229663833U,	// VMOVDQU16Z128rrkz_REV
    180388441U,	// VMOVDQU16Z256mr
    3401908825U,	// VMOVDQU16Z256mrk
    552944217U,	// VMOVDQU16Z256rm
    3231023705U,	// VMOVDQU16Z256rmk
    3230876249U,	// VMOVDQU16Z256rmkz
    551830105U,	// VMOVDQU16Z256rr
    551830105U,	// VMOVDQU16Z256rr_REV
    3230696025U,	// VMOVDQU16Z256rrk
    3229663833U,	// VMOVDQU16Z256rrk_REV
    3229663833U,	// VMOVDQU16Z256rrkz
    3229663833U,	// VMOVDQU16Z256rrkz_REV
    182485593U,	// VMOVDQU16Zmr
    3404005977U,	// VMOVDQU16Zmrk
    552436313U,	// VMOVDQU16Zrm
    3231089241U,	// VMOVDQU16Zrmk
    3230892633U,	// VMOVDQU16Zrmkz
    551830105U,	// VMOVDQU16Zrr
    551830105U,	// VMOVDQU16Zrr_REV
    3230696025U,	// VMOVDQU16Zrrk
    3229663833U,	// VMOVDQU16Zrrk_REV
    3229663833U,	// VMOVDQU16Zrrkz
    3229663833U,	// VMOVDQU16Zrrkz_REV
    33587291U,	// VMOVDQU32Z128mr
    3255107675U,	// VMOVDQU32Z128mrk
    262235U,	// VMOVDQU32Z128rm
    3230990427U,	// VMOVDQU32Z128rmk
    3229859931U,	// VMOVDQU32Z128rmkz
    551829595U,	// VMOVDQU32Z128rr
    551829595U,	// VMOVDQU32Z128rr_REV
    3230695515U,	// VMOVDQU32Z128rrk
    3229663323U,	// VMOVDQU32Z128rrk_REV
    3229663323U,	// VMOVDQU32Z128rrkz
    3229663323U,	// VMOVDQU32Z128rrkz_REV
    180387931U,	// VMOVDQU32Z256mr
    3401908315U,	// VMOVDQU32Z256mrk
    552943707U,	// VMOVDQU32Z256rm
    3231023195U,	// VMOVDQU32Z256rmk
    3230875739U,	// VMOVDQU32Z256rmkz
    551829595U,	// VMOVDQU32Z256rr
    551829595U,	// VMOVDQU32Z256rr_REV
    3230695515U,	// VMOVDQU32Z256rrk
    3229663323U,	// VMOVDQU32Z256rrk_REV
    3229663323U,	// VMOVDQU32Z256rrkz
    3229663323U,	// VMOVDQU32Z256rrkz_REV
    182485083U,	// VMOVDQU32Zmr
    3404005467U,	// VMOVDQU32Zmrk
    552435803U,	// VMOVDQU32Zrm
    3231088731U,	// VMOVDQU32Zrmk
    3230892123U,	// VMOVDQU32Zrmkz
    551829595U,	// VMOVDQU32Zrr
    551829595U,	// VMOVDQU32Zrr_REV
    3230695515U,	// VMOVDQU32Zrrk
    3229663323U,	// VMOVDQU32Zrrk_REV
    3229663323U,	// VMOVDQU32Zrrkz
    3229663323U,	// VMOVDQU32Zrrkz_REV
    33587571U,	// VMOVDQU64Z128mr
    3255107955U,	// VMOVDQU64Z128mrk
    262515U,	// VMOVDQU64Z128rm
    3230990707U,	// VMOVDQU64Z128rmk
    3229860211U,	// VMOVDQU64Z128rmkz
    551829875U,	// VMOVDQU64Z128rr
    551829875U,	// VMOVDQU64Z128rr_REV
    3230695795U,	// VMOVDQU64Z128rrk
    3229663603U,	// VMOVDQU64Z128rrk_REV
    3229663603U,	// VMOVDQU64Z128rrkz
    3229663603U,	// VMOVDQU64Z128rrkz_REV
    180388211U,	// VMOVDQU64Z256mr
    3401908595U,	// VMOVDQU64Z256mrk
    552943987U,	// VMOVDQU64Z256rm
    3231023475U,	// VMOVDQU64Z256rmk
    3230876019U,	// VMOVDQU64Z256rmkz
    551829875U,	// VMOVDQU64Z256rr
    551829875U,	// VMOVDQU64Z256rr_REV
    3230695795U,	// VMOVDQU64Z256rrk
    3229663603U,	// VMOVDQU64Z256rrk_REV
    3229663603U,	// VMOVDQU64Z256rrkz
    3229663603U,	// VMOVDQU64Z256rrkz_REV
    182485363U,	// VMOVDQU64Zmr
    3404005747U,	// VMOVDQU64Zmrk
    552436083U,	// VMOVDQU64Zrm
    3231089011U,	// VMOVDQU64Zrmk
    3230892403U,	// VMOVDQU64Zrmkz
    551829875U,	// VMOVDQU64Zrr
    551829875U,	// VMOVDQU64Zrr_REV
    3230695795U,	// VMOVDQU64Zrrk
    3229663603U,	// VMOVDQU64Zrrk_REV
    3229663603U,	// VMOVDQU64Zrrkz
    3229663603U,	// VMOVDQU64Zrrkz_REV
    33587922U,	// VMOVDQU8Z128mr
    3255108306U,	// VMOVDQU8Z128mrk
    262866U,	// VMOVDQU8Z128rm
    3230991058U,	// VMOVDQU8Z128rmk
    3229860562U,	// VMOVDQU8Z128rmkz
    551830226U,	// VMOVDQU8Z128rr
    551830226U,	// VMOVDQU8Z128rr_REV
    3230696146U,	// VMOVDQU8Z128rrk
    3229663954U,	// VMOVDQU8Z128rrk_REV
    3229663954U,	// VMOVDQU8Z128rrkz
    3229663954U,	// VMOVDQU8Z128rrkz_REV
    180388562U,	// VMOVDQU8Z256mr
    3401908946U,	// VMOVDQU8Z256mrk
    552944338U,	// VMOVDQU8Z256rm
    3231023826U,	// VMOVDQU8Z256rmk
    3230876370U,	// VMOVDQU8Z256rmkz
    551830226U,	// VMOVDQU8Z256rr
    551830226U,	// VMOVDQU8Z256rr_REV
    3230696146U,	// VMOVDQU8Z256rrk
    3229663954U,	// VMOVDQU8Z256rrk_REV
    3229663954U,	// VMOVDQU8Z256rrkz
    3229663954U,	// VMOVDQU8Z256rrkz_REV
    182485714U,	// VMOVDQU8Zmr
    3404006098U,	// VMOVDQU8Zmrk
    552436434U,	// VMOVDQU8Zrm
    3231089362U,	// VMOVDQU8Zrmk
    3230892754U,	// VMOVDQU8Zrmkz
    551830226U,	// VMOVDQU8Zrr
    551830226U,	// VMOVDQU8Zrr_REV
    3230696146U,	// VMOVDQU8Zrrk
    3229663954U,	// VMOVDQU8Zrrk_REV
    3229663954U,	// VMOVDQU8Zrrkz
    3229663954U,	// VMOVDQU8Zrrkz_REV
    180398553U,	// VMOVDQUYmr
    552954329U,	// VMOVDQUYrm
    551840217U,	// VMOVDQUYrr
    551840217U,	// VMOVDQUYrr_REV
    33597913U,	// VMOVDQUmr
    272857U,	// VMOVDQUrm
    551840217U,	// VMOVDQUrr
    551840217U,	// VMOVDQUrr_REV
    811656469U,	// VMOVHLPSZrr
    811656469U,	// VMOVHLPSrr
    67144675U,	// VMOVHPDZ128mr
    283266019U,	// VMOVHPDZ128rm
    67144675U,	// VMOVHPDmr
    283266019U,	// VMOVHPDrm
    67151105U,	// VMOVHPSZ128mr
    283272449U,	// VMOVHPSZ128rm
    67151105U,	// VMOVHPSmr
    283272449U,	// VMOVHPSrm
    811656439U,	// VMOVLHPSZrr
    811656439U,	// VMOVLHPSrr
    67144725U,	// VMOVLPDZ128mr
    283266069U,	// VMOVLPDZ128rm
    67144725U,	// VMOVLPDmr
    283266069U,	// VMOVLPDrm
    67151165U,	// VMOVLPSZ128mr
    283272509U,	// VMOVLPSZ128rm
    67151165U,	// VMOVLPSmr
    283272509U,	// VMOVLPSrm
    551832556U,	// VMOVMSKPDYrr
    551832556U,	// VMOVMSKPDrr
    551838986U,	// VMOVMSKPSYrr
    551838986U,	// VMOVMSKPSrr
    552944444U,	// VMOVNTDQAYrm
    262972U,	// VMOVNTDQAZ128rm
    552944444U,	// VMOVNTDQAZ256rm
    552436540U,	// VMOVNTDQAZrm
    262972U,	// VMOVNTDQArm
    180394832U,	// VMOVNTDQYmr
    33594192U,	// VMOVNTDQZ128mr
    180394832U,	// VMOVNTDQZ256mr
    182491984U,	// VMOVNTDQZmr
    33594192U,	// VMOVNTDQmr
    148933902U,	// VMOVNTPDYmr
    65047822U,	// VMOVNTPDZ128mr
    148933902U,	// VMOVNTPDZ256mr
    151031054U,	// VMOVNTPDZmr
    65047822U,	// VMOVNTPDmr
    148940354U,	// VMOVNTPSYmr
    65054274U,	// VMOVNTPSZ128mr
    148940354U,	// VMOVNTPSZ256mr
    151037506U,	// VMOVNTPSZmr
    65054274U,	// VMOVNTPSmr
    12620009U,	// VMOVPDI2DIZmr
    551833833U,	// VMOVPDI2DIZrr
    12620009U,	// VMOVPDI2DImr
    551833833U,	// VMOVPDI2DIrr
    18915458U,	// VMOVPQI2QIZmr
    551837826U,	// VMOVPQI2QIZrr
    18915458U,	// VMOVPQI2QImr
    551837826U,	// VMOVPQI2QIrr
    18915458U,	// VMOVPQIto64Zmr
    551837826U,	// VMOVPQIto64Zrr
    18915458U,	// VMOVPQIto64mr
    551837826U,	// VMOVPQIto64rr
    551919746U,	// VMOVQI2PQIZrm
    551919746U,	// VMOVQI2PQIrm
    67145733U,	// VMOVSDZmr
    3288666117U,	// VMOVSDZmrk
    552177669U,	// VMOVSDZrm
    552603653U,	// VMOVSDZrmk
    551702533U,	// VMOVSDZrmkz
    811651077U,	// VMOVSDZrr
    811651077U,	// VMOVSDZrr_REV
    87052293U,	// VMOVSDZrrk
    87052293U,	// VMOVSDZrrk_REV
    890277893U,	// VMOVSDZrrkz
    890277893U,	// VMOVSDZrrkz_REV
    67145733U,	// VMOVSDmr
    552177669U,	// VMOVSDrm
    811651077U,	// VMOVSDrr
    811651077U,	// VMOVSDrr_REV
    18915458U,	// VMOVSDto64Zmr
    551837826U,	// VMOVSDto64Zrr
    18915458U,	// VMOVSDto64mr
    551837826U,	// VMOVSDto64rr
    1349897U,	// VMOVSHDUPYrm
    551835913U,	// VMOVSHDUPYrr
    661769U,	// VMOVSHDUPZ128rm
    3230603529U,	// VMOVSHDUPZ128rmk
    3229751561U,	// VMOVSHDUPZ128rmkz
    551835913U,	// VMOVSHDUPZ128rr
    3230701833U,	// VMOVSHDUPZ128rrk
    3229669641U,	// VMOVSHDUPZ128rrkz
    1349897U,	// VMOVSHDUPZ256rm
    3230734601U,	// VMOVSHDUPZ256rmk
    3230636297U,	// VMOVSHDUPZ256rmkz
    551835913U,	// VMOVSHDUPZ256rr
    3230701833U,	// VMOVSHDUPZ256rrk
    3229669641U,	// VMOVSHDUPZ256rrkz
    1513737U,	// VMOVSHDUPZrm
    3230783753U,	// VMOVSHDUPZrmk
    3230750985U,	// VMOVSHDUPZrmkz
    551835913U,	// VMOVSHDUPZrr
    3230701833U,	// VMOVSHDUPZrrk
    3229669641U,	// VMOVSHDUPZrrkz
    661769U,	// VMOVSHDUPrm
    551835913U,	// VMOVSHDUPrr
    1349908U,	// VMOVSLDUPYrm
    551835924U,	// VMOVSLDUPYrr
    661780U,	// VMOVSLDUPZ128rm
    3230603540U,	// VMOVSLDUPZ128rmk
    3229751572U,	// VMOVSLDUPZ128rmkz
    551835924U,	// VMOVSLDUPZ128rr
    3230701844U,	// VMOVSLDUPZ128rrk
    3229669652U,	// VMOVSLDUPZ128rrkz
    1349908U,	// VMOVSLDUPZ256rm
    3230734612U,	// VMOVSLDUPZ256rmk
    3230636308U,	// VMOVSLDUPZ256rmkz
    551835924U,	// VMOVSLDUPZ256rr
    3230701844U,	// VMOVSLDUPZ256rrk
    3229669652U,	// VMOVSLDUPZ256rrkz
    1513748U,	// VMOVSLDUPZrm
    3230783764U,	// VMOVSLDUPZrmk
    3230750996U,	// VMOVSLDUPZrmkz
    551835924U,	// VMOVSLDUPZrr
    3230701844U,	// VMOVSLDUPZrrk
    3229669652U,	// VMOVSLDUPZrrkz
    661780U,	// VMOVSLDUPrm
    551835924U,	// VMOVSLDUPrr
    12620009U,	// VMOVSS2DIZmr
    551833833U,	// VMOVSS2DIZrr
    12620009U,	// VMOVSS2DImr
    551833833U,	// VMOVSS2DIrr
    69249253U,	// VMOVSSZmr
    3290769637U,	// VMOVSSZmrk
    552200421U,	// VMOVSSZrm
    552806629U,	// VMOVSSZrmk
    551725285U,	// VMOVSSZrmkz
    811657445U,	// VMOVSSZrr
    811657445U,	// VMOVSSZrr_REV
    87058661U,	// VMOVSSZrrk
    87058661U,	// VMOVSSZrrk_REV
    890284261U,	// VMOVSSZrrkz
    890284261U,	// VMOVSSZrrkz_REV
    69249253U,	// VMOVSSmr
    552200421U,	// VMOVSSrm
    811657445U,	// VMOVSSrr
    811657445U,	// VMOVSSrr_REV
    148933930U,	// VMOVUPDYmr
    1346858U,	// VMOVUPDYrm
    551832874U,	// VMOVUPDYrr
    551832874U,	// VMOVUPDYrr_REV
    65047850U,	// VMOVUPDZ128mr
    3286568234U,	// VMOVUPDZ128mrk
    658730U,	// VMOVUPDZ128rm
    3230600490U,	// VMOVUPDZ128rmk
    3229748522U,	// VMOVUPDZ128rmkz
    551832874U,	// VMOVUPDZ128rr
    551832874U,	// VMOVUPDZ128rr_REV
    3230698794U,	// VMOVUPDZ128rrk
    3229666602U,	// VMOVUPDZ128rrk_REV
    3229666602U,	// VMOVUPDZ128rrkz
    3229666602U,	// VMOVUPDZ128rrkz_REV
    148933930U,	// VMOVUPDZ256mr
    3370454314U,	// VMOVUPDZ256mrk
    1346858U,	// VMOVUPDZ256rm
    3230731562U,	// VMOVUPDZ256rmk
    3230633258U,	// VMOVUPDZ256rmkz
    551832874U,	// VMOVUPDZ256rr
    551832874U,	// VMOVUPDZ256rr_REV
    3230698794U,	// VMOVUPDZ256rrk
    3229666602U,	// VMOVUPDZ256rrk_REV
    3229666602U,	// VMOVUPDZ256rrkz
    3229666602U,	// VMOVUPDZ256rrkz_REV
    151031082U,	// VMOVUPDZmr
    3372551466U,	// VMOVUPDZmrk
    1510698U,	// VMOVUPDZrm
    3230780714U,	// VMOVUPDZrmk
    3230747946U,	// VMOVUPDZrmkz
    551832874U,	// VMOVUPDZrr
    551832874U,	// VMOVUPDZrr_REV
    3230698794U,	// VMOVUPDZrrk
    3229666602U,	// VMOVUPDZrrk_REV
    3229666602U,	// VMOVUPDZrrkz
    3229666602U,	// VMOVUPDZrrkz_REV
    65047850U,	// VMOVUPDmr
    658730U,	// VMOVUPDrm
    551832874U,	// VMOVUPDrr
    551832874U,	// VMOVUPDrr_REV
    148940427U,	// VMOVUPSYmr
    1353355U,	// VMOVUPSYrm
    551839371U,	// VMOVUPSYrr
    551839371U,	// VMOVUPSYrr_REV
    65054347U,	// VMOVUPSZ128mr
    3286574731U,	// VMOVUPSZ128mrk
    665227U,	// VMOVUPSZ128rm
    3230606987U,	// VMOVUPSZ128rmk
    3229755019U,	// VMOVUPSZ128rmkz
    551839371U,	// VMOVUPSZ128rr
    551839371U,	// VMOVUPSZ128rr_REV
    3230705291U,	// VMOVUPSZ128rrk
    3229673099U,	// VMOVUPSZ128rrk_REV
    3229673099U,	// VMOVUPSZ128rrkz
    3229673099U,	// VMOVUPSZ128rrkz_REV
    148940427U,	// VMOVUPSZ256mr
    3370460811U,	// VMOVUPSZ256mrk
    1353355U,	// VMOVUPSZ256rm
    3230738059U,	// VMOVUPSZ256rmk
    3230639755U,	// VMOVUPSZ256rmkz
    551839371U,	// VMOVUPSZ256rr
    551839371U,	// VMOVUPSZ256rr_REV
    3230705291U,	// VMOVUPSZ256rrk
    3229673099U,	// VMOVUPSZ256rrk_REV
    3229673099U,	// VMOVUPSZ256rrkz
    3229673099U,	// VMOVUPSZ256rrkz_REV
    151037579U,	// VMOVUPSZmr
    3372557963U,	// VMOVUPSZmrk
    1517195U,	// VMOVUPSZrm
    3230787211U,	// VMOVUPSZrmk
    3230754443U,	// VMOVUPSZrmkz
    551839371U,	// VMOVUPSZrr
    551839371U,	// VMOVUPSZrr_REV
    3230705291U,	// VMOVUPSZrrk
    3229673099U,	// VMOVUPSZrrk_REV
    3229673099U,	// VMOVUPSZrrkz
    3229673099U,	// VMOVUPSZrrkz_REV
    65054347U,	// VMOVUPSmr
    665227U,	// VMOVUPSrm
    551839371U,	// VMOVUPSrr
    551839371U,	// VMOVUPSrr_REV
    551837826U,	// VMOVZPQILo2PQIZrr
    551837826U,	// VMOVZPQILo2PQIrr
    375777904U,	// VMPSADBWYrmi
    1088825968U,	// VMPSADBWYrri
    325446256U,	// VMPSADBWrmi
    1088825968U,	// VMPSADBWrri
    444562U,	// VMPTRLDm
    453035U,	// VMPTRSTm
    12620766U,	// VMREAD32mr
    551834590U,	// VMREAD32rr
    18913853U,	// VMREAD64mr
    551836221U,	// VMREAD64rr
    15047U,	// VMRESUME
    16043U,	// VMRUN32
    16104U,	// VMRUN64
    16031U,	// VMSAVE32
    16092U,	// VMSAVE64
    812616717U,	// VMULPDYrm
    811650061U,	// VMULPDYrr
    811731981U,	// VMULPDZ128rm
    358763533U,	// VMULPDZ128rmb
    1433390093U,	// VMULPDZ128rmbk
    1164971021U,	// VMULPDZ128rmbkz
    86985741U,	// VMULPDZ128rmk
    890178573U,	// VMULPDZ128rmkz
    811650061U,	// VMULPDZ128rr
    87051277U,	// VMULPDZ128rrk
    890276877U,	// VMULPDZ128rrkz
    812616717U,	// VMULPDZ256rm
    360860685U,	// VMULPDZ256rmb
    1435487245U,	// VMULPDZ256rmbk
    1167068173U,	// VMULPDZ256rmbkz
    87084045U,	// VMULPDZ256rmk
    890309645U,	// VMULPDZ256rmkz
    811650061U,	// VMULPDZ256rr
    87051277U,	// VMULPDZ256rrk
    890276877U,	// VMULPDZ256rrkz
    812731405U,	// VMULPDZrm
    362957837U,	// VMULPDZrmb
    1437584397U,	// VMULPDZrmbk
    1169165325U,	// VMULPDZrmbkz
    87133197U,	// VMULPDZrmk
    890358797U,	// VMULPDZrmkz
    811650061U,	// VMULPDZrr
    812780557U,	// VMULPDZrrb
    87182349U,	// VMULPDZrrbk
    890407949U,	// VMULPDZrrbkz
    87051277U,	// VMULPDZrrk
    890276877U,	// VMULPDZrrkz
    811731981U,	// VMULPDrm
    811650061U,	// VMULPDrr
    812623157U,	// VMULPSYrm
    811656501U,	// VMULPSYrr
    811738421U,	// VMULPSZ128rm
    360883509U,	// VMULPSZ128rmb
    1435690293U,	// VMULPSZ128rmbk
    1167271221U,	// VMULPSZ128rmbkz
    86992181U,	// VMULPSZ128rmk
    890185013U,	// VMULPSZ128rmkz
    811656501U,	// VMULPSZ128rr
    87057717U,	// VMULPSZ128rrk
    890283317U,	// VMULPSZ128rrkz
    812623157U,	// VMULPSZ256rm
    362980661U,	// VMULPSZ256rmb
    1437787445U,	// VMULPSZ256rmbk
    1169368373U,	// VMULPSZ256rmbkz
    87090485U,	// VMULPSZ256rmk
    890316085U,	// VMULPSZ256rmkz
    811656501U,	// VMULPSZ256rr
    87057717U,	// VMULPSZ256rrk
    890283317U,	// VMULPSZ256rrkz
    812737845U,	// VMULPSZrm
    365077813U,	// VMULPSZrmb
    1439884597U,	// VMULPSZrmbk
    1171465525U,	// VMULPSZrmbkz
    87139637U,	// VMULPSZrmk
    890365237U,	// VMULPSZrmkz
    811656501U,	// VMULPSZrr
    812786997U,	// VMULPSZrrb
    87188789U,	// VMULPSZrrbk
    890414389U,	// VMULPSZrrbkz
    87057717U,	// VMULPSZrrk
    890283317U,	// VMULPSZrrkz
    811738421U,	// VMULPSrm
    811656501U,	// VMULPSrr
    283266897U,	// VMULSDZrm
    283266897U,	// VMULSDZrm_Int
    1357893457U,	// VMULSDZrm_Intk
    1089474385U,	// VMULSDZrm_Intkz
    811650897U,	// VMULSDZrr
    811650897U,	// VMULSDZrr_Int
    87052113U,	// VMULSDZrr_Intk
    890277713U,	// VMULSDZrr_Intkz
    812781393U,	// VMULSDZrrb_Int
    87183185U,	// VMULSDZrrb_Intk
    890408785U,	// VMULSDZrrb_Intkz
    283266897U,	// VMULSDrm
    283266897U,	// VMULSDrm_Int
    811650897U,	// VMULSDrr
    811650897U,	// VMULSDrr_Int
    283289699U,	// VMULSSZrm
    283289699U,	// VMULSSZrm_Int
    1358096483U,	// VMULSSZrm_Intk
    1089677411U,	// VMULSSZrm_Intkz
    811657315U,	// VMULSSZrr
    811657315U,	// VMULSSZrr_Int
    87058531U,	// VMULSSZrr_Intk
    890284131U,	// VMULSSZrr_Intkz
    812787811U,	// VMULSSZrrb_Int
    87189603U,	// VMULSSZrrb_Intk
    890415203U,	// VMULSSZrrb_Intkz
    283289699U,	// VMULSSrm
    283289699U,	// VMULSSrm_Int
    811657315U,	// VMULSSrr
    811657315U,	// VMULSSrr_Int
    551900316U,	// VMWRITE32rm
    551834780U,	// VMWRITE32rr
    551918617U,	// VMWRITE64rm
    551836697U,	// VMWRITE64rr
    15099U,	// VMXOFF
    448617U,	// VMXON
    812616905U,	// VORPDYrm
    811650249U,	// VORPDYrr
    811732169U,	// VORPDZ128rm
    358763721U,	// VORPDZ128rmb
    1433390281U,	// VORPDZ128rmbk
    1164971209U,	// VORPDZ128rmbkz
    86985929U,	// VORPDZ128rmk
    890178761U,	// VORPDZ128rmkz
    811650249U,	// VORPDZ128rr
    87051465U,	// VORPDZ128rrk
    890277065U,	// VORPDZ128rrkz
    812616905U,	// VORPDZ256rm
    360860873U,	// VORPDZ256rmb
    1435487433U,	// VORPDZ256rmbk
    1167068361U,	// VORPDZ256rmbkz
    87084233U,	// VORPDZ256rmk
    890309833U,	// VORPDZ256rmkz
    811650249U,	// VORPDZ256rr
    87051465U,	// VORPDZ256rrk
    890277065U,	// VORPDZ256rrkz
    812731593U,	// VORPDZrm
    362958025U,	// VORPDZrmb
    1437584585U,	// VORPDZrmbk
    1169165513U,	// VORPDZrmbkz
    87133385U,	// VORPDZrmk
    890358985U,	// VORPDZrmkz
    811650249U,	// VORPDZrr
    87051465U,	// VORPDZrrk
    890277065U,	// VORPDZrrkz
    811732169U,	// VORPDrm
    811650249U,	// VORPDrr
    812623362U,	// VORPSYrm
    811656706U,	// VORPSYrr
    811738626U,	// VORPSZ128rm
    360883714U,	// VORPSZ128rmb
    1435690498U,	// VORPSZ128rmbk
    1167271426U,	// VORPSZ128rmbkz
    86992386U,	// VORPSZ128rmk
    890185218U,	// VORPSZ128rmkz
    811656706U,	// VORPSZ128rr
    87057922U,	// VORPSZ128rrk
    890283522U,	// VORPSZ128rrkz
    812623362U,	// VORPSZ256rm
    362980866U,	// VORPSZ256rmb
    1437787650U,	// VORPSZ256rmbk
    1169368578U,	// VORPSZ256rmbkz
    87090690U,	// VORPSZ256rmk
    890316290U,	// VORPSZ256rmkz
    811656706U,	// VORPSZ256rr
    87057922U,	// VORPSZ256rrk
    890283522U,	// VORPSZ256rrkz
    812738050U,	// VORPSZrm
    365078018U,	// VORPSZrmb
    1439884802U,	// VORPSZrmbk
    1171465730U,	// VORPSZrmbkz
    87139842U,	// VORPSZrmk
    890365442U,	// VORPSZrmkz
    811656706U,	// VORPSZrr
    87057922U,	// VORPSZrrk
    890283522U,	// VORPSZrrkz
    811738626U,	// VORPSrm
    811656706U,	// VORPSrr
    890184091U,	// VP4DPWSSDSrm
    86991259U,	// VP4DPWSSDSrmk
    89088411U,	// VP4DPWSSDSrmkz
    890179506U,	// VP4DPWSSDrm
    86986674U,	// VP4DPWSSDrmk
    89083826U,	// VP4DPWSSDrmkz
    552945056U,	// VPABSBYrm
    551830944U,	// VPABSBYrr
    263584U,	// VPABSBZ128rm
    3230991776U,	// VPABSBZ128rmk
    3229861280U,	// VPABSBZ128rmkz
    551830944U,	// VPABSBZ128rr
    3230696864U,	// VPABSBZ128rrk
    3229664672U,	// VPABSBZ128rrkz
    552945056U,	// VPABSBZ256rm
    3231024544U,	// VPABSBZ256rmk
    3230877088U,	// VPABSBZ256rmkz
    551830944U,	// VPABSBZ256rr
    3230696864U,	// VPABSBZ256rrk
    3229664672U,	// VPABSBZ256rrkz
    552437152U,	// VPABSBZrm
    3231090080U,	// VPABSBZrmk
    3230893472U,	// VPABSBZrmkz
    551830944U,	// VPABSBZrr
    3230696864U,	// VPABSBZrrk
    3229664672U,	// VPABSBZrrkz
    263584U,	// VPABSBrm
    551830944U,	// VPABSBrr
    552947397U,	// VPABSDYrm
    551833285U,	// VPABSDYrr
    265925U,	// VPABSDZ128rm
    629493445U,	// VPABSDZ128rmb
    630607557U,	// VPABSDZ128rmbk
    629231301U,	// VPABSDZ128rmbkz
    3230994117U,	// VPABSDZ128rmk
    3229863621U,	// VPABSDZ128rmkz
    551833285U,	// VPABSDZ128rr
    3230699205U,	// VPABSDZ128rrk
    3229667013U,	// VPABSDZ128rrkz
    552947397U,	// VPABSDZ256rm
    631590597U,	// VPABSDZ256rmb
    632704709U,	// VPABSDZ256rmbk
    631328453U,	// VPABSDZ256rmbkz
    3231026885U,	// VPABSDZ256rmk
    3230879429U,	// VPABSDZ256rmkz
    551833285U,	// VPABSDZ256rr
    3230699205U,	// VPABSDZ256rrk
    3229667013U,	// VPABSDZ256rrkz
    552439493U,	// VPABSDZrm
    633687749U,	// VPABSDZrmb
    634801861U,	// VPABSDZrmbk
    633425605U,	// VPABSDZrmbkz
    3231092421U,	// VPABSDZrmk
    3230895813U,	// VPABSDZrmkz
    551833285U,	// VPABSDZrr
    3230699205U,	// VPABSDZrrk
    3229667013U,	// VPABSDZrrkz
    265925U,	// VPABSDrm
    551833285U,	// VPABSDrr
    270016U,	// VPABSQZ128rm
    627416768U,	// VPABSQZ128rmb
    628416192U,	// VPABSQZ128rmbk
    627154624U,	// VPABSQZ128rmbkz
    3230998208U,	// VPABSQZ128rmk
    3229867712U,	// VPABSQZ128rmkz
    551837376U,	// VPABSQZ128rr
    3230703296U,	// VPABSQZ128rrk
    3229671104U,	// VPABSQZ128rrkz
    552951488U,	// VPABSQZ256rm
    629513920U,	// VPABSQZ256rmb
    630513344U,	// VPABSQZ256rmbk
    629251776U,	// VPABSQZ256rmbkz
    3231030976U,	// VPABSQZ256rmk
    3230883520U,	// VPABSQZ256rmkz
    551837376U,	// VPABSQZ256rr
    3230703296U,	// VPABSQZ256rrk
    3229671104U,	// VPABSQZ256rrkz
    552443584U,	// VPABSQZrm
    631611072U,	// VPABSQZrmb
    632610496U,	// VPABSQZrmbk
    631348928U,	// VPABSQZrmbkz
    3231096512U,	// VPABSQZrmk
    3230899904U,	// VPABSQZrmkz
    551837376U,	// VPABSQZrr
    3230703296U,	// VPABSQZrrk
    3229671104U,	// VPABSQZrrkz
    552955357U,	// VPABSWYrm
    551841245U,	// VPABSWYrr
    273885U,	// VPABSWZ128rm
    3231002077U,	// VPABSWZ128rmk
    3229871581U,	// VPABSWZ128rmkz
    551841245U,	// VPABSWZ128rr
    3230707165U,	// VPABSWZ128rrk
    3229674973U,	// VPABSWZ128rrkz
    552955357U,	// VPABSWZ256rm
    3231034845U,	// VPABSWZ256rmk
    3230887389U,	// VPABSWZ256rmkz
    551841245U,	// VPABSWZ256rr
    3230707165U,	// VPABSWZ256rrk
    3229674973U,	// VPABSWZ256rrkz
    552447453U,	// VPABSWZrm
    3231100381U,	// VPABSWZrmk
    3230903773U,	// VPABSWZrmkz
    551841245U,	// VPABSWZrr
    3230707165U,	// VPABSWZrrk
    3229674973U,	// VPABSWZrrkz
    273885U,	// VPABSWrm
    551841245U,	// VPABSWrr
    812870527U,	// VPACKSSDWYrm
    811658111U,	// VPACKSSDWYrr
    811854719U,	// VPACKSSDWZ128rm
    360803199U,	// VPACKSSDWZ128rmb
    1436068735U,	// VPACKSSDWZ128rmbk
    1167485823U,	// VPACKSSDWZ128rmbkz
    985115519U,	// VPACKSSDWZ128rmk
    890579839U,	// VPACKSSDWZ128rmkz
    811658111U,	// VPACKSSDWZ128rr
    87059327U,	// VPACKSSDWZ128rrk
    890284927U,	// VPACKSSDWZ128rrkz
    812870527U,	// VPACKSSDWZ256rm
    362900351U,	// VPACKSSDWZ256rmb
    1438165887U,	// VPACKSSDWZ256rmbk
    1169582975U,	// VPACKSSDWZ256rmbkz
    985131903U,	// VPACKSSDWZ256rmk
    890612607U,	// VPACKSSDWZ256rmkz
    811658111U,	// VPACKSSDWZ256rr
    87059327U,	// VPACKSSDWZ256rrk
    890284927U,	// VPACKSSDWZ256rrkz
    812886911U,	// VPACKSSDWZrm
    364997503U,	// VPACKSSDWZrmb
    1440263039U,	// VPACKSSDWZrmbk
    1171680127U,	// VPACKSSDWZrmbkz
    985148287U,	// VPACKSSDWZrmk
    890678143U,	// VPACKSSDWZrmkz
    811658111U,	// VPACKSSDWZrr
    87059327U,	// VPACKSSDWZrrk
    890284927U,	// VPACKSSDWZrrkz
    811854719U,	// VPACKSSDWrm
    811658111U,	// VPACKSSDWrr
    812861110U,	// VPACKSSWBYrm
    811648694U,	// VPACKSSWBYrr
    811845302U,	// VPACKSSWBZ128rm
    985106102U,	// VPACKSSWBZ128rmk
    890570422U,	// VPACKSSWBZ128rmkz
    811648694U,	// VPACKSSWBZ128rr
    87049910U,	// VPACKSSWBZ128rrk
    890275510U,	// VPACKSSWBZ128rrkz
    812861110U,	// VPACKSSWBZ256rm
    985122486U,	// VPACKSSWBZ256rmk
    890603190U,	// VPACKSSWBZ256rmkz
    811648694U,	// VPACKSSWBZ256rr
    87049910U,	// VPACKSSWBZ256rrk
    890275510U,	// VPACKSSWBZ256rrkz
    812877494U,	// VPACKSSWBZrm
    985138870U,	// VPACKSSWBZrmk
    890668726U,	// VPACKSSWBZrmkz
    811648694U,	// VPACKSSWBZrr
    87049910U,	// VPACKSSWBZrrk
    890275510U,	// VPACKSSWBZrrkz
    811845302U,	// VPACKSSWBrm
    811648694U,	// VPACKSSWBrr
    812870538U,	// VPACKUSDWYrm
    811658122U,	// VPACKUSDWYrr
    811854730U,	// VPACKUSDWZ128rm
    360803210U,	// VPACKUSDWZ128rmb
    1436068746U,	// VPACKUSDWZ128rmbk
    1167485834U,	// VPACKUSDWZ128rmbkz
    985115530U,	// VPACKUSDWZ128rmk
    890579850U,	// VPACKUSDWZ128rmkz
    811658122U,	// VPACKUSDWZ128rr
    87059338U,	// VPACKUSDWZ128rrk
    890284938U,	// VPACKUSDWZ128rrkz
    812870538U,	// VPACKUSDWZ256rm
    362900362U,	// VPACKUSDWZ256rmb
    1438165898U,	// VPACKUSDWZ256rmbk
    1169582986U,	// VPACKUSDWZ256rmbkz
    985131914U,	// VPACKUSDWZ256rmk
    890612618U,	// VPACKUSDWZ256rmkz
    811658122U,	// VPACKUSDWZ256rr
    87059338U,	// VPACKUSDWZ256rrk
    890284938U,	// VPACKUSDWZ256rrkz
    812886922U,	// VPACKUSDWZrm
    364997514U,	// VPACKUSDWZrmb
    1440263050U,	// VPACKUSDWZrmbk
    1171680138U,	// VPACKUSDWZrmbkz
    985148298U,	// VPACKUSDWZrmk
    890678154U,	// VPACKUSDWZrmkz
    811658122U,	// VPACKUSDWZrr
    87059338U,	// VPACKUSDWZrrk
    890284938U,	// VPACKUSDWZrrkz
    811854730U,	// VPACKUSDWrm
    811658122U,	// VPACKUSDWrr
    812861121U,	// VPACKUSWBYrm
    811648705U,	// VPACKUSWBYrr
    811845313U,	// VPACKUSWBZ128rm
    985106113U,	// VPACKUSWBZ128rmk
    890570433U,	// VPACKUSWBZ128rmkz
    811648705U,	// VPACKUSWBZ128rr
    87049921U,	// VPACKUSWBZ128rrk
    890275521U,	// VPACKUSWBZ128rrkz
    812861121U,	// VPACKUSWBZ256rm
    985122497U,	// VPACKUSWBZ256rmk
    890603201U,	// VPACKUSWBZ256rmkz
    811648705U,	// VPACKUSWBZ256rr
    87049921U,	// VPACKUSWBZ256rrk
    890275521U,	// VPACKUSWBZ256rrkz
    812877505U,	// VPACKUSWBZrm
    985138881U,	// VPACKUSWBZrmk
    890668737U,	// VPACKUSWBZrmkz
    811648705U,	// VPACKUSWBZrr
    87049921U,	// VPACKUSWBZrrk
    890275521U,	// VPACKUSWBZrrkz
    811845313U,	// VPACKUSWBrm
    811648705U,	// VPACKUSWBrr
    812860394U,	// VPADDBYrm
    811647978U,	// VPADDBYrr
    811844586U,	// VPADDBZ128rm
    985105386U,	// VPADDBZ128rmk
    890569706U,	// VPADDBZ128rmkz
    811647978U,	// VPADDBZ128rr
    87049194U,	// VPADDBZ128rrk
    890274794U,	// VPADDBZ128rrkz
    812860394U,	// VPADDBZ256rm
    985121770U,	// VPADDBZ256rmk
    890602474U,	// VPADDBZ256rmkz
    811647978U,	// VPADDBZ256rr
    87049194U,	// VPADDBZ256rrk
    890274794U,	// VPADDBZ256rrkz
    812876778U,	// VPADDBZrm
    985138154U,	// VPADDBZrmk
    890668010U,	// VPADDBZrmkz
    811647978U,	// VPADDBZrr
    87049194U,	// VPADDBZrrk
    890274794U,	// VPADDBZrrkz
    811844586U,	// VPADDBrm
    811647978U,	// VPADDBrr
    812861372U,	// VPADDDYrm
    811648956U,	// VPADDDYrr
    811845564U,	// VPADDDZ128rm
    360794044U,	// VPADDDZ128rmb
    1436059580U,	// VPADDDZ128rmbk
    1167476668U,	// VPADDDZ128rmbkz
    985106364U,	// VPADDDZ128rmk
    890570684U,	// VPADDDZ128rmkz
    811648956U,	// VPADDDZ128rr
    87050172U,	// VPADDDZ128rrk
    890275772U,	// VPADDDZ128rrkz
    812861372U,	// VPADDDZ256rm
    362891196U,	// VPADDDZ256rmb
    1438156732U,	// VPADDDZ256rmbk
    1169573820U,	// VPADDDZ256rmbkz
    985122748U,	// VPADDDZ256rmk
    890603452U,	// VPADDDZ256rmkz
    811648956U,	// VPADDDZ256rr
    87050172U,	// VPADDDZ256rrk
    890275772U,	// VPADDDZ256rrkz
    812877756U,	// VPADDDZrm
    364988348U,	// VPADDDZrmb
    1440253884U,	// VPADDDZrmbk
    1171670972U,	// VPADDDZrmbkz
    985139132U,	// VPADDDZrmk
    890668988U,	// VPADDDZrmkz
    811648956U,	// VPADDDZrr
    87050172U,	// VPADDDZrrk
    890275772U,	// VPADDDZrrkz
    811845564U,	// VPADDDrm
    811648956U,	// VPADDDrr
    812866135U,	// VPADDQYrm
    811653719U,	// VPADDQYrr
    811850327U,	// VPADDQZ128rm
    358718039U,	// VPADDQZ128rmb
    1433950807U,	// VPADDQZ128rmbk
    1165285975U,	// VPADDQZ128rmbkz
    985111127U,	// VPADDQZ128rmk
    890575447U,	// VPADDQZ128rmkz
    811653719U,	// VPADDQZ128rr
    87054935U,	// VPADDQZ128rrk
    890280535U,	// VPADDQZ128rrkz
    812866135U,	// VPADDQZ256rm
    360815191U,	// VPADDQZ256rmb
    1436047959U,	// VPADDQZ256rmbk
    1167383127U,	// VPADDQZ256rmbkz
    985127511U,	// VPADDQZ256rmk
    890608215U,	// VPADDQZ256rmkz
    811653719U,	// VPADDQZ256rr
    87054935U,	// VPADDQZ256rrk
    890280535U,	// VPADDQZ256rrkz
    812882519U,	// VPADDQZrm
    362912343U,	// VPADDQZrmb
    1438145111U,	// VPADDQZrmbk
    1169480279U,	// VPADDQZrmbkz
    985143895U,	// VPADDQZrmk
    890673751U,	// VPADDQZrmkz
    811653719U,	// VPADDQZrr
    87054935U,	// VPADDQZrrk
    890280535U,	// VPADDQZrrkz
    811850327U,	// VPADDQrm
    811653719U,	// VPADDQrr
    812860858U,	// VPADDSBYrm
    811648442U,	// VPADDSBYrr
    811845050U,	// VPADDSBZ128rm
    985105850U,	// VPADDSBZ128rmk
    890570170U,	// VPADDSBZ128rmkz
    811648442U,	// VPADDSBZ128rr
    87049658U,	// VPADDSBZ128rrk
    890275258U,	// VPADDSBZ128rrkz
    812860858U,	// VPADDSBZ256rm
    985122234U,	// VPADDSBZ256rmk
    890602938U,	// VPADDSBZ256rmkz
    811648442U,	// VPADDSBZ256rr
    87049658U,	// VPADDSBZ256rrk
    890275258U,	// VPADDSBZ256rrkz
    812877242U,	// VPADDSBZrm
    985138618U,	// VPADDSBZrmk
    890668474U,	// VPADDSBZrmkz
    811648442U,	// VPADDSBZrr
    87049658U,	// VPADDSBZrrk
    890275258U,	// VPADDSBZrrkz
    811845050U,	// VPADDSBrm
    811648442U,	// VPADDSBrr
    812871191U,	// VPADDSWYrm
    811658775U,	// VPADDSWYrr
    811855383U,	// VPADDSWZ128rm
    985116183U,	// VPADDSWZ128rmk
    890580503U,	// VPADDSWZ128rmkz
    811658775U,	// VPADDSWZ128rr
    87059991U,	// VPADDSWZ128rrk
    890285591U,	// VPADDSWZ128rrkz
    812871191U,	// VPADDSWZ256rm
    985132567U,	// VPADDSWZ256rmk
    890613271U,	// VPADDSWZ256rmkz
    811658775U,	// VPADDSWZ256rr
    87059991U,	// VPADDSWZ256rrk
    890285591U,	// VPADDSWZ256rrkz
    812887575U,	// VPADDSWZrm
    985148951U,	// VPADDSWZrmk
    890678807U,	// VPADDSWZrmkz
    811658775U,	// VPADDSWZrr
    87059991U,	// VPADDSWZrrk
    890285591U,	// VPADDSWZrrkz
    811855383U,	// VPADDSWrm
    811658775U,	// VPADDSWrr
    812860920U,	// VPADDUSBYrm
    811648504U,	// VPADDUSBYrr
    811845112U,	// VPADDUSBZ128rm
    985105912U,	// VPADDUSBZ128rmk
    890570232U,	// VPADDUSBZ128rmkz
    811648504U,	// VPADDUSBZ128rr
    87049720U,	// VPADDUSBZ128rrk
    890275320U,	// VPADDUSBZ128rrkz
    812860920U,	// VPADDUSBZ256rm
    985122296U,	// VPADDUSBZ256rmk
    890603000U,	// VPADDUSBZ256rmkz
    811648504U,	// VPADDUSBZ256rr
    87049720U,	// VPADDUSBZ256rrk
    890275320U,	// VPADDUSBZ256rrkz
    812877304U,	// VPADDUSBZrm
    985138680U,	// VPADDUSBZrmk
    890668536U,	// VPADDUSBZrmkz
    811648504U,	// VPADDUSBZrr
    87049720U,	// VPADDUSBZrrk
    890275320U,	// VPADDUSBZrrkz
    811845112U,	// VPADDUSBrm
    811648504U,	// VPADDUSBrr
    812871317U,	// VPADDUSWYrm
    811658901U,	// VPADDUSWYrr
    811855509U,	// VPADDUSWZ128rm
    985116309U,	// VPADDUSWZ128rmk
    890580629U,	// VPADDUSWZ128rmkz
    811658901U,	// VPADDUSWZ128rr
    87060117U,	// VPADDUSWZ128rrk
    890285717U,	// VPADDUSWZ128rrkz
    812871317U,	// VPADDUSWZ256rm
    985132693U,	// VPADDUSWZ256rmk
    890613397U,	// VPADDUSWZ256rmkz
    811658901U,	// VPADDUSWZ256rr
    87060117U,	// VPADDUSWZ256rrk
    890285717U,	// VPADDUSWZ256rrkz
    812887701U,	// VPADDUSWZrm
    985149077U,	// VPADDUSWZrmk
    890678933U,	// VPADDUSWZrmkz
    811658901U,	// VPADDUSWZrr
    87060117U,	// VPADDUSWZrrk
    890285717U,	// VPADDUSWZrrkz
    811855509U,	// VPADDUSWrm
    811658901U,	// VPADDUSWrr
    812870448U,	// VPADDWYrm
    811658032U,	// VPADDWYrr
    811854640U,	// VPADDWZ128rm
    985115440U,	// VPADDWZ128rmk
    890579760U,	// VPADDWZ128rmkz
    811658032U,	// VPADDWZ128rr
    87059248U,	// VPADDWZ128rrk
    890284848U,	// VPADDWZ128rrkz
    812870448U,	// VPADDWZ256rm
    985131824U,	// VPADDWZ256rmk
    890612528U,	// VPADDWZ256rmkz
    811658032U,	// VPADDWZ256rr
    87059248U,	// VPADDWZ256rrk
    890284848U,	// VPADDWZ256rrkz
    812886832U,	// VPADDWZrm
    985148208U,	// VPADDWZrmk
    890678064U,	// VPADDWZrmkz
    811658032U,	// VPADDWZrr
    87059248U,	// VPADDWZrrk
    890284848U,	// VPADDWZrrkz
    811854640U,	// VPADDWrm
    811658032U,	// VPADDWrr
    375775517U,	// VPALIGNRYrmi
    1088823581U,	// VPALIGNRYrri
    325443869U,	// VPALIGNRZ128rmi
    1983111453U,	// VPALIGNRZ128rmik
    1179918621U,	// VPALIGNRZ128rmikz
    1088823581U,	// VPALIGNRZ128rri
    2163138845U,	// VPALIGNRZ128rrik
    1357586717U,	// VPALIGNRZ128rrikz
    375775517U,	// VPALIGNRZ256rmi
    1989402909U,	// VPALIGNRZ256rmik
    1186210077U,	// VPALIGNRZ256rmikz
    1088823581U,	// VPALIGNRZ256rri
    2163138845U,	// VPALIGNRZ256rrik
    1357586717U,	// VPALIGNRZ256rrikz
    382066973U,	// VPALIGNRZrmi
    1995694365U,	// VPALIGNRZrmik
    1192501533U,	// VPALIGNRZrmikz
    1088823581U,	// VPALIGNRZrri
    2163138845U,	// VPALIGNRZrrik
    1357586717U,	// VPALIGNRZrrikz
    325443869U,	// VPALIGNRrmi
    1088823581U,	// VPALIGNRrri
    811845588U,	// VPANDDZ128rm
    360794068U,	// VPANDDZ128rmb
    1436059604U,	// VPANDDZ128rmbk
    1167476692U,	// VPANDDZ128rmbkz
    985106388U,	// VPANDDZ128rmk
    890570708U,	// VPANDDZ128rmkz
    811648980U,	// VPANDDZ128rr
    87050196U,	// VPANDDZ128rrk
    890275796U,	// VPANDDZ128rrkz
    812861396U,	// VPANDDZ256rm
    362891220U,	// VPANDDZ256rmb
    1438156756U,	// VPANDDZ256rmbk
    1169573844U,	// VPANDDZ256rmbkz
    985122772U,	// VPANDDZ256rmk
    890603476U,	// VPANDDZ256rmkz
    811648980U,	// VPANDDZ256rr
    87050196U,	// VPANDDZ256rrk
    890275796U,	// VPANDDZ256rrkz
    812877780U,	// VPANDDZrm
    364988372U,	// VPANDDZrmb
    1440253908U,	// VPANDDZrmbk
    1171670996U,	// VPANDDZrmbkz
    985139156U,	// VPANDDZrmk
    890669012U,	// VPANDDZrmkz
    811648980U,	// VPANDDZrr
    87050196U,	// VPANDDZrrk
    890275796U,	// VPANDDZrrkz
    811845860U,	// VPANDNDZ128rm
    360794340U,	// VPANDNDZ128rmb
    1436059876U,	// VPANDNDZ128rmbk
    1167476964U,	// VPANDNDZ128rmbkz
    985106660U,	// VPANDNDZ128rmk
    890570980U,	// VPANDNDZ128rmkz
    811649252U,	// VPANDNDZ128rr
    87050468U,	// VPANDNDZ128rrk
    890276068U,	// VPANDNDZ128rrkz
    812861668U,	// VPANDNDZ256rm
    362891492U,	// VPANDNDZ256rmb
    1438157028U,	// VPANDNDZ256rmbk
    1169574116U,	// VPANDNDZ256rmbkz
    985123044U,	// VPANDNDZ256rmk
    890603748U,	// VPANDNDZ256rmkz
    811649252U,	// VPANDNDZ256rr
    87050468U,	// VPANDNDZ256rrk
    890276068U,	// VPANDNDZ256rrkz
    812878052U,	// VPANDNDZrm
    364988644U,	// VPANDNDZrmb
    1440254180U,	// VPANDNDZrmbk
    1171671268U,	// VPANDNDZrmbkz
    985139428U,	// VPANDNDZrmk
    890669284U,	// VPANDNDZrmkz
    811649252U,	// VPANDNDZrr
    87050468U,	// VPANDNDZrrk
    890276068U,	// VPANDNDZrrkz
    811851085U,	// VPANDNQZ128rm
    358718797U,	// VPANDNQZ128rmb
    1433951565U,	// VPANDNQZ128rmbk
    1165286733U,	// VPANDNQZ128rmbkz
    985111885U,	// VPANDNQZ128rmk
    890576205U,	// VPANDNQZ128rmkz
    811654477U,	// VPANDNQZ128rr
    87055693U,	// VPANDNQZ128rrk
    890281293U,	// VPANDNQZ128rrkz
    812866893U,	// VPANDNQZ256rm
    360815949U,	// VPANDNQZ256rmb
    1436048717U,	// VPANDNQZ256rmbk
    1167383885U,	// VPANDNQZ256rmbkz
    985128269U,	// VPANDNQZ256rmk
    890608973U,	// VPANDNQZ256rmkz
    811654477U,	// VPANDNQZ256rr
    87055693U,	// VPANDNQZ256rrk
    890281293U,	// VPANDNQZ256rrkz
    812883277U,	// VPANDNQZrm
    362913101U,	// VPANDNQZrmb
    1438145869U,	// VPANDNQZrmbk
    1169481037U,	// VPANDNQZrmbkz
    985144653U,	// VPANDNQZrmk
    890674509U,	// VPANDNQZrmkz
    811654477U,	// VPANDNQZrr
    87055693U,	// VPANDNQZrrk
    890281293U,	// VPANDNQZrrkz
    812865618U,	// VPANDNYrm
    811653202U,	// VPANDNYrr
    811849810U,	// VPANDNrm
    811653202U,	// VPANDNrr
    811850438U,	// VPANDQZ128rm
    358718150U,	// VPANDQZ128rmb
    1433950918U,	// VPANDQZ128rmbk
    1165286086U,	// VPANDQZ128rmbkz
    985111238U,	// VPANDQZ128rmk
    890575558U,	// VPANDQZ128rmkz
    811653830U,	// VPANDQZ128rr
    87055046U,	// VPANDQZ128rrk
    890280646U,	// VPANDQZ128rrkz
    812866246U,	// VPANDQZ256rm
    360815302U,	// VPANDQZ256rmb
    1436048070U,	// VPANDQZ256rmbk
    1167383238U,	// VPANDQZ256rmbkz
    985127622U,	// VPANDQZ256rmk
    890608326U,	// VPANDQZ256rmkz
    811653830U,	// VPANDQZ256rr
    87055046U,	// VPANDQZ256rrk
    890280646U,	// VPANDQZ256rrkz
    812882630U,	// VPANDQZrm
    362912454U,	// VPANDQZrmb
    1438145222U,	// VPANDQZrmbk
    1169480390U,	// VPANDQZrmbkz
    985144006U,	// VPANDQZrmk
    890673862U,	// VPANDQZrmkz
    811653830U,	// VPANDQZrr
    87055046U,	// VPANDQZrrk
    890280646U,	// VPANDQZrrkz
    812861653U,	// VPANDYrm
    811649237U,	// VPANDYrr
    811845845U,	// VPANDrm
    811649237U,	// VPANDrr
    812860482U,	// VPAVGBYrm
    811648066U,	// VPAVGBYrr
    811844674U,	// VPAVGBZ128rm
    985105474U,	// VPAVGBZ128rmk
    890569794U,	// VPAVGBZ128rmkz
    811648066U,	// VPAVGBZ128rr
    87049282U,	// VPAVGBZ128rrk
    890274882U,	// VPAVGBZ128rrkz
    812860482U,	// VPAVGBZ256rm
    985121858U,	// VPAVGBZ256rmk
    890602562U,	// VPAVGBZ256rmkz
    811648066U,	// VPAVGBZ256rr
    87049282U,	// VPAVGBZ256rrk
    890274882U,	// VPAVGBZ256rrkz
    812876866U,	// VPAVGBZrm
    985138242U,	// VPAVGBZrmk
    890668098U,	// VPAVGBZrmkz
    811648066U,	// VPAVGBZrr
    87049282U,	// VPAVGBZrrk
    890274882U,	// VPAVGBZrrkz
    811844674U,	// VPAVGBrm
    811648066U,	// VPAVGBrr
    812870669U,	// VPAVGWYrm
    811658253U,	// VPAVGWYrr
    811854861U,	// VPAVGWZ128rm
    985115661U,	// VPAVGWZ128rmk
    890579981U,	// VPAVGWZ128rmkz
    811658253U,	// VPAVGWZ128rr
    87059469U,	// VPAVGWZ128rrk
    890285069U,	// VPAVGWZ128rrkz
    812870669U,	// VPAVGWZ256rm
    985132045U,	// VPAVGWZ256rmk
    890612749U,	// VPAVGWZ256rmkz
    811658253U,	// VPAVGWZ256rr
    87059469U,	// VPAVGWZ256rrk
    890285069U,	// VPAVGWZ256rrkz
    812887053U,	// VPAVGWZrm
    985148429U,	// VPAVGWZrmk
    890678285U,	// VPAVGWZrmkz
    811658253U,	// VPAVGWZrr
    87059469U,	// VPAVGWZrrk
    890285069U,	// VPAVGWZrrkz
    811854861U,	// VPAVGWrm
    811658253U,	// VPAVGWrr
    375769063U,	// VPBLENDDYrmi
    1088817127U,	// VPBLENDDYrri
    325437415U,	// VPBLENDDrmi
    1088817127U,	// VPBLENDDrri
    811844752U,	// VPBLENDMBZ128rm
    890569872U,	// VPBLENDMBZ128rmk
    890569872U,	// VPBLENDMBZ128rmkz
    811648144U,	// VPBLENDMBZ128rr
    890274960U,	// VPBLENDMBZ128rrk
    890274960U,	// VPBLENDMBZ128rrkz
    812860560U,	// VPBLENDMBZ256rm
    890602640U,	// VPBLENDMBZ256rmk
    890602640U,	// VPBLENDMBZ256rmkz
    811648144U,	// VPBLENDMBZ256rr
    890274960U,	// VPBLENDMBZ256rrk
    890274960U,	// VPBLENDMBZ256rrkz
    812876944U,	// VPBLENDMBZrm
    890668176U,	// VPBLENDMBZrmk
    890668176U,	// VPBLENDMBZrmkz
    811648144U,	// VPBLENDMBZrr
    890274960U,	// VPBLENDMBZrrk
    890274960U,	// VPBLENDMBZrrkz
    811845797U,	// VPBLENDMDZ128rm
    360794277U,	// VPBLENDMDZ128rmb
    1167476901U,	// VPBLENDMDZ128rmbk
    1167476901U,	// VPBLENDMDZ128rmbkz
    890570917U,	// VPBLENDMDZ128rmk
    890570917U,	// VPBLENDMDZ128rmkz
    811649189U,	// VPBLENDMDZ128rr
    890276005U,	// VPBLENDMDZ128rrk
    890276005U,	// VPBLENDMDZ128rrkz
    812861605U,	// VPBLENDMDZ256rm
    362891429U,	// VPBLENDMDZ256rmb
    1169574053U,	// VPBLENDMDZ256rmbk
    1169574053U,	// VPBLENDMDZ256rmbkz
    890603685U,	// VPBLENDMDZ256rmk
    890603685U,	// VPBLENDMDZ256rmkz
    811649189U,	// VPBLENDMDZ256rr
    890276005U,	// VPBLENDMDZ256rrk
    890276005U,	// VPBLENDMDZ256rrkz
    812877989U,	// VPBLENDMDZrm
    364988581U,	// VPBLENDMDZrmb
    1171671205U,	// VPBLENDMDZrmbk
    1171671205U,	// VPBLENDMDZrmbkz
    890669221U,	// VPBLENDMDZrmk
    890669221U,	// VPBLENDMDZrmkz
    811649189U,	// VPBLENDMDZrr
    890276005U,	// VPBLENDMDZrrk
    890276005U,	// VPBLENDMDZrrkz
    811851029U,	// VPBLENDMQZ128rm
    358718741U,	// VPBLENDMQZ128rmb
    1165286677U,	// VPBLENDMQZ128rmbk
    1165286677U,	// VPBLENDMQZ128rmbkz
    890576149U,	// VPBLENDMQZ128rmk
    890576149U,	// VPBLENDMQZ128rmkz
    811654421U,	// VPBLENDMQZ128rr
    890281237U,	// VPBLENDMQZ128rrk
    890281237U,	// VPBLENDMQZ128rrkz
    812866837U,	// VPBLENDMQZ256rm
    360815893U,	// VPBLENDMQZ256rmb
    1167383829U,	// VPBLENDMQZ256rmbk
    1167383829U,	// VPBLENDMQZ256rmbkz
    890608917U,	// VPBLENDMQZ256rmk
    890608917U,	// VPBLENDMQZ256rmkz
    811654421U,	// VPBLENDMQZ256rr
    890281237U,	// VPBLENDMQZ256rrk
    890281237U,	// VPBLENDMQZ256rrkz
    812883221U,	// VPBLENDMQZrm
    362913045U,	// VPBLENDMQZrmb
    1169480981U,	// VPBLENDMQZrmbk
    1169480981U,	// VPBLENDMQZrmbkz
    890674453U,	// VPBLENDMQZrmk
    890674453U,	// VPBLENDMQZrmkz
    811654421U,	// VPBLENDMQZrr
    890281237U,	// VPBLENDMQZrrk
    890281237U,	// VPBLENDMQZrrkz
    811855021U,	// VPBLENDMWZ128rm
    890580141U,	// VPBLENDMWZ128rmk
    890580141U,	// VPBLENDMWZ128rmkz
    811658413U,	// VPBLENDMWZ128rr
    890285229U,	// VPBLENDMWZ128rrk
    890285229U,	// VPBLENDMWZ128rrkz
    812870829U,	// VPBLENDMWZ256rm
    890612909U,	// VPBLENDMWZ256rmk
    890612909U,	// VPBLENDMWZ256rmkz
    811658413U,	// VPBLENDMWZ256rr
    890285229U,	// VPBLENDMWZ256rrk
    890285229U,	// VPBLENDMWZ256rrkz
    812887213U,	// VPBLENDMWZrm
    890678445U,	// VPBLENDMWZrmk
    890678445U,	// VPBLENDMWZrmkz
    811658413U,	// VPBLENDMWZrr
    890285229U,	// VPBLENDMWZrrk
    890285229U,	// VPBLENDMWZrrkz
    376718991U,	// VPBLENDVBYrm
    890275471U,	// VPBLENDVBYrr
    326387343U,	// VPBLENDVBrm
    890275471U,	// VPBLENDVBrr
    375778156U,	// VPBLENDWYrmi
    1088826220U,	// VPBLENDWYrri
    325446508U,	// VPBLENDWrmi
    1088826220U,	// VPBLENDWrri
    493124U,	// VPBROADCASTBYrm
    551831108U,	// VPBROADCASTBYrr
    493124U,	// VPBROADCASTBZ128m
    1623620U,	// VPBROADCASTBZ128mk
    3229730372U,	// VPBROADCASTBZ128mkz
    551831108U,	// VPBROADCASTBZ128r
    3230697028U,	// VPBROADCASTBZ128rk
    3229664836U,	// VPBROADCASTBZ128rkz
    493124U,	// VPBROADCASTBZ256m
    1623620U,	// VPBROADCASTBZ256mk
    3229730372U,	// VPBROADCASTBZ256mkz
    551831108U,	// VPBROADCASTBZ256r
    3230697028U,	// VPBROADCASTBZ256rk
    3229664836U,	// VPBROADCASTBZ256rkz
    493124U,	// VPBROADCASTBZm
    1623620U,	// VPBROADCASTBZmk
    3229730372U,	// VPBROADCASTBZmkz
    551831108U,	// VPBROADCASTBZr
    3230697028U,	// VPBROADCASTBZrk
    3229664836U,	// VPBROADCASTBZrkz
    551831108U,	// VPBROADCASTBrZ128r
    3230697028U,	// VPBROADCASTBrZ128rk
    3229664836U,	// VPBROADCASTBrZ128rkz
    551831108U,	// VPBROADCASTBrZ256r
    3230697028U,	// VPBROADCASTBrZ256rk
    3229664836U,	// VPBROADCASTBrZ256rkz
    551831108U,	// VPBROADCASTBrZr
    3230697028U,	// VPBROADCASTBrZrk
    3229664836U,	// VPBROADCASTBrZrkz
    493124U,	// VPBROADCASTBrm
    551831108U,	// VPBROADCASTBrr
    551899233U,	// VPBROADCASTDYrm
    551833697U,	// VPBROADCASTDYrr
    551899233U,	// VPBROADCASTDZ128m
    553013345U,	// VPBROADCASTDZ128mk
    551637089U,	// VPBROADCASTDZ128mkz
    551833697U,	// VPBROADCASTDZ128r
    3230699617U,	// VPBROADCASTDZ128rk
    3229667425U,	// VPBROADCASTDZ128rkz
    551899233U,	// VPBROADCASTDZ256m
    553013345U,	// VPBROADCASTDZ256mk
    551637089U,	// VPBROADCASTDZ256mkz
    551833697U,	// VPBROADCASTDZ256r
    3230699617U,	// VPBROADCASTDZ256rk
    3229667425U,	// VPBROADCASTDZ256rkz
    551899233U,	// VPBROADCASTDZm
    553013345U,	// VPBROADCASTDZmk
    551637089U,	// VPBROADCASTDZmkz
    551833697U,	// VPBROADCASTDZr
    3230699617U,	// VPBROADCASTDZrk
    3229667425U,	// VPBROADCASTDZrkz
    551833697U,	// VPBROADCASTDrZ128r
    3230699617U,	// VPBROADCASTDrZ128rk
    3229667425U,	// VPBROADCASTDrZ128rkz
    551833697U,	// VPBROADCASTDrZ256r
    3230699617U,	// VPBROADCASTDrZ256rk
    3229667425U,	// VPBROADCASTDrZ256rkz
    551833697U,	// VPBROADCASTDrZr
    3230699617U,	// VPBROADCASTDrZrk
    3229667425U,	// VPBROADCASTDrZrkz
    551899233U,	// VPBROADCASTDrm
    551833697U,	// VPBROADCASTDrr
    551835950U,	// VPBROADCASTMB2QZ128rr
    551835950U,	// VPBROADCASTMB2QZ256rr
    551835950U,	// VPBROADCASTMB2QZrr
    551831363U,	// VPBROADCASTMW2DZ128rr
    551831363U,	// VPBROADCASTMW2DZ256rr
    551831363U,	// VPBROADCASTMW2DZrr
    551919570U,	// VPBROADCASTQYrm
    551837650U,	// VPBROADCASTQYrr
    551919570U,	// VPBROADCASTQZ128m
    552918994U,	// VPBROADCASTQZ128mk
    551657426U,	// VPBROADCASTQZ128mkz
    551837650U,	// VPBROADCASTQZ128r
    3230703570U,	// VPBROADCASTQZ128rk
    3229671378U,	// VPBROADCASTQZ128rkz
    551919570U,	// VPBROADCASTQZ256m
    552918994U,	// VPBROADCASTQZ256mk
    551657426U,	// VPBROADCASTQZ256mkz
    551837650U,	// VPBROADCASTQZ256r
    3230703570U,	// VPBROADCASTQZ256rk
    3229671378U,	// VPBROADCASTQZ256rkz
    551919570U,	// VPBROADCASTQZm
    552918994U,	// VPBROADCASTQZmk
    551657426U,	// VPBROADCASTQZmkz
    551837650U,	// VPBROADCASTQZr
    3230703570U,	// VPBROADCASTQZrk
    3229671378U,	// VPBROADCASTQZrkz
    551837650U,	// VPBROADCASTQrZ128r
    3230703570U,	// VPBROADCASTQrZ128rk
    3229671378U,	// VPBROADCASTQrZ128rkz
    551837650U,	// VPBROADCASTQrZ256r
    3230703570U,	// VPBROADCASTQrZ256rk
    3229671378U,	// VPBROADCASTQrZ256rkz
    551837650U,	// VPBROADCASTQrZr
    3230703570U,	// VPBROADCASTQrZrk
    3229671378U,	// VPBROADCASTQrZrkz
    551919570U,	// VPBROADCASTQrm
    551837650U,	// VPBROADCASTQrr
    438041U,	// VPBROADCASTWYrm
    551841561U,	// VPBROADCASTWYrr
    438041U,	// VPBROADCASTWZ128m
    1650457U,	// VPBROADCASTWZ128mk
    3229691673U,	// VPBROADCASTWZ128mkz
    551841561U,	// VPBROADCASTWZ128r
    3230707481U,	// VPBROADCASTWZ128rk
    3229675289U,	// VPBROADCASTWZ128rkz
    438041U,	// VPBROADCASTWZ256m
    1650457U,	// VPBROADCASTWZ256mk
    3229691673U,	// VPBROADCASTWZ256mkz
    551841561U,	// VPBROADCASTWZ256r
    3230707481U,	// VPBROADCASTWZ256rk
    3229675289U,	// VPBROADCASTWZ256rkz
    438041U,	// VPBROADCASTWZm
    1650457U,	// VPBROADCASTWZmk
    3229691673U,	// VPBROADCASTWZmkz
    551841561U,	// VPBROADCASTWZr
    3230707481U,	// VPBROADCASTWZrk
    3229675289U,	// VPBROADCASTWZrkz
    551841561U,	// VPBROADCASTWrZ128r
    3230707481U,	// VPBROADCASTWrZ128rk
    3229675289U,	// VPBROADCASTWrZ128rkz
    551841561U,	// VPBROADCASTWrZ256r
    3230707481U,	// VPBROADCASTWrZ256rk
    3229675289U,	// VPBROADCASTWrZ256rkz
    551841561U,	// VPBROADCASTWrZr
    3230707481U,	// VPBROADCASTWrZrk
    3229675289U,	// VPBROADCASTWrZrkz
    438041U,	// VPBROADCASTWrm
    551841561U,	// VPBROADCASTWrr
    375773961U,	// VPCLMULQDQYrm
    1088822025U,	// VPCLMULQDQYrr
    325442313U,	// VPCLMULQDQZ128rm
    1088822025U,	// VPCLMULQDQZ128rr
    375773961U,	// VPCLMULQDQZ256rm
    1088822025U,	// VPCLMULQDQZ256rr
    382065417U,	// VPCLMULQDQZrm
    1088822025U,	// VPCLMULQDQZrr
    325442313U,	// VPCLMULQDQrm
    1088822025U,	// VPCLMULQDQrr
    376728065U,	// VPCMOVYrmr
    890612225U,	// VPCMOVYrrm
    890284545U,	// VPCMOVYrrr
    890284545U,	// VPCMOVYrrr_REV
    326396417U,	// VPCMOVrmr
    890579457U,	// VPCMOVrrm
    890284545U,	// VPCMOVrrr
    890284545U,	// VPCMOVrrr_REV
    2869427203U,	// VPCMPBZ128rmi
    325436653U,	// VPCMPBZ128rmi_alt
    3138780163U,	// VPCMPBZ128rmik
    1179911405U,	// VPCMPBZ128rmik_alt
    1258830851U,	// VPCMPBZ128rri
    1088816365U,	// VPCMPBZ128rri_alt
    1528183811U,	// VPCMPBZ128rrik
    1357579501U,	// VPCMPBZ128rrik_alt
    3406298115U,	// VPCMPBZ256rmi
    375768301U,	// VPCMPBZ256rmi_alt
    3675651075U,	// VPCMPBZ256rmik
    1186202861U,	// VPCMPBZ256rmik_alt
    1258830851U,	// VPCMPBZ256rri
    1088816365U,	// VPCMPBZ256rri_alt
    1528183811U,	// VPCMPBZ256rrik
    1357579501U,	// VPCMPBZ256rrik_alt
    3943169027U,	// VPCMPBZrmi
    382059757U,	// VPCMPBZrmi_alt
    4212521987U,	// VPCMPBZrmik
    1192494317U,	// VPCMPBZrmik_alt
    1258830851U,	// VPCMPBZrri
    1088816365U,	// VPCMPBZrri_alt
    1528183811U,	// VPCMPBZrrik
    1357579501U,	// VPCMPBZrrik_alt
    2871524355U,	// VPCMPDZ128rmi
    325438494U,	// VPCMPDZ128rmi_alt
    187169795U,	// VPCMPDZ128rmib
    1686490142U,	// VPCMPDZ128rmib_alt
    456522755U,	// VPCMPDZ128rmibk
    1712589854U,	// VPCMPDZ128rmibk_alt
    3140877315U,	// VPCMPDZ128rmik
    1179913246U,	// VPCMPDZ128rmik_alt
    1260928003U,	// VPCMPDZ128rri
    1088818206U,	// VPCMPDZ128rri_alt
    1530280963U,	// VPCMPDZ128rrik
    1357581342U,	// VPCMPDZ128rrik_alt
    3408395267U,	// VPCMPDZ256rmi
    375770142U,	// VPCMPDZ256rmi_alt
    187169795U,	// VPCMPDZ256rmib
    2491796510U,	// VPCMPDZ256rmib_alt
    456522755U,	// VPCMPDZ256rmibk
    2517896222U,	// VPCMPDZ256rmibk_alt
    3677748227U,	// VPCMPDZ256rmik
    1186204702U,	// VPCMPDZ256rmik_alt
    1260928003U,	// VPCMPDZ256rri
    1088818206U,	// VPCMPDZ256rri_alt
    1530280963U,	// VPCMPDZ256rrik
    1357581342U,	// VPCMPDZ256rrik_alt
    3945266179U,	// VPCMPDZrmi
    382061598U,	// VPCMPDZrmi_alt
    187169795U,	// VPCMPDZrmib
    2760231966U,	// VPCMPDZrmib_alt
    456522755U,	// VPCMPDZrmibk
    2786331678U,	// VPCMPDZrmibk_alt
    4214619139U,	// VPCMPDZrmik
    1192496158U,	// VPCMPDZrmik_alt
    1260928003U,	// VPCMPDZrri
    1088818206U,	// VPCMPDZrri_alt
    1530280963U,	// VPCMPDZrrik
    1357581342U,	// VPCMPDZrrik_alt
    812860677U,	// VPCMPEQBYrm
    811648261U,	// VPCMPEQBYrr
    811844869U,	// VPCMPEQBZ128rm
    890569989U,	// VPCMPEQBZ128rmk
    811648261U,	// VPCMPEQBZ128rr
    890275077U,	// VPCMPEQBZ128rrk
    812860677U,	// VPCMPEQBZ256rm
    890602757U,	// VPCMPEQBZ256rmk
    811648261U,	// VPCMPEQBZ256rr
    890275077U,	// VPCMPEQBZ256rrk
    812877061U,	// VPCMPEQBZrm
    890668293U,	// VPCMPEQBZrmk
    811648261U,	// VPCMPEQBZrr
    890275077U,	// VPCMPEQBZrrk
    811844869U,	// VPCMPEQBrm
    811648261U,	// VPCMPEQBrr
    812862819U,	// VPCMPEQDYrm
    811650403U,	// VPCMPEQDYrr
    811847011U,	// VPCMPEQDZ128rm
    360795491U,	// VPCMPEQDZ128rmb
    1167478115U,	// VPCMPEQDZ128rmbk
    890572131U,	// VPCMPEQDZ128rmk
    811650403U,	// VPCMPEQDZ128rr
    890277219U,	// VPCMPEQDZ128rrk
    812862819U,	// VPCMPEQDZ256rm
    362892643U,	// VPCMPEQDZ256rmb
    1169575267U,	// VPCMPEQDZ256rmbk
    890604899U,	// VPCMPEQDZ256rmk
    811650403U,	// VPCMPEQDZ256rr
    890277219U,	// VPCMPEQDZ256rrk
    812879203U,	// VPCMPEQDZrm
    364989795U,	// VPCMPEQDZrmb
    1171672419U,	// VPCMPEQDZrmbk
    890670435U,	// VPCMPEQDZrmk
    811650403U,	// VPCMPEQDZrr
    890277219U,	// VPCMPEQDZrrk
    811847011U,	// VPCMPEQDrm
    811650403U,	// VPCMPEQDrr
    812867043U,	// VPCMPEQQYrm
    811654627U,	// VPCMPEQQYrr
    811851235U,	// VPCMPEQQZ128rm
    358718947U,	// VPCMPEQQZ128rmb
    1165286883U,	// VPCMPEQQZ128rmbk
    890576355U,	// VPCMPEQQZ128rmk
    811654627U,	// VPCMPEQQZ128rr
    890281443U,	// VPCMPEQQZ128rrk
    812867043U,	// VPCMPEQQZ256rm
    360816099U,	// VPCMPEQQZ256rmb
    1167384035U,	// VPCMPEQQZ256rmbk
    890609123U,	// VPCMPEQQZ256rmk
    811654627U,	// VPCMPEQQZ256rr
    890281443U,	// VPCMPEQQZ256rrk
    812883427U,	// VPCMPEQQZrm
    362913251U,	// VPCMPEQQZrmb
    1169481187U,	// VPCMPEQQZrmbk
    890674659U,	// VPCMPEQQZrmk
    811654627U,	// VPCMPEQQZrr
    890281443U,	// VPCMPEQQZrrk
    811851235U,	// VPCMPEQQrm
    811654627U,	// VPCMPEQQrr
    812870968U,	// VPCMPEQWYrm
    811658552U,	// VPCMPEQWYrr
    811855160U,	// VPCMPEQWZ128rm
    890580280U,	// VPCMPEQWZ128rmk
    811658552U,	// VPCMPEQWZ128rr
    890285368U,	// VPCMPEQWZ128rrk
    812870968U,	// VPCMPEQWZ256rm
    890613048U,	// VPCMPEQWZ256rmk
    811658552U,	// VPCMPEQWZ256rr
    890285368U,	// VPCMPEQWZ256rrk
    812887352U,	// VPCMPEQWZrm
    890678584U,	// VPCMPEQWZrmk
    811658552U,	// VPCMPEQWZrr
    890285368U,	// VPCMPEQWZrrk
    811855160U,	// VPCMPEQWrm
    811658552U,	// VPCMPEQWrr
    830771932U,	// VPCMPESTRIrm
    283431644U,	// VPCMPESTRIrr
    830773299U,	// VPCMPESTRMrm
    283433011U,	// VPCMPESTRMrr
    812860961U,	// VPCMPGTBYrm
    811648545U,	// VPCMPGTBYrr
    811845153U,	// VPCMPGTBZ128rm
    890570273U,	// VPCMPGTBZ128rmk
    811648545U,	// VPCMPGTBZ128rr
    890275361U,	// VPCMPGTBZ128rrk
    812860961U,	// VPCMPGTBZ256rm
    890603041U,	// VPCMPGTBZ256rmk
    811648545U,	// VPCMPGTBZ256rr
    890275361U,	// VPCMPGTBZ256rrk
    812877345U,	// VPCMPGTBZrm
    890668577U,	// VPCMPGTBZrmk
    811648545U,	// VPCMPGTBZrr
    890275361U,	// VPCMPGTBZrrk
    811845153U,	// VPCMPGTBrm
    811648545U,	// VPCMPGTBrr
    812863540U,	// VPCMPGTDYrm
    811651124U,	// VPCMPGTDYrr
    811847732U,	// VPCMPGTDZ128rm
    360796212U,	// VPCMPGTDZ128rmb
    1167478836U,	// VPCMPGTDZ128rmbk
    890572852U,	// VPCMPGTDZ128rmk
    811651124U,	// VPCMPGTDZ128rr
    890277940U,	// VPCMPGTDZ128rrk
    812863540U,	// VPCMPGTDZ256rm
    362893364U,	// VPCMPGTDZ256rmb
    1169575988U,	// VPCMPGTDZ256rmbk
    890605620U,	// VPCMPGTDZ256rmk
    811651124U,	// VPCMPGTDZ256rr
    890277940U,	// VPCMPGTDZ256rrk
    812879924U,	// VPCMPGTDZrm
    364990516U,	// VPCMPGTDZrmb
    1171673140U,	// VPCMPGTDZrmbk
    890671156U,	// VPCMPGTDZrmk
    811651124U,	// VPCMPGTDZrr
    890277940U,	// VPCMPGTDZrrk
    811847732U,	// VPCMPGTDrm
    811651124U,	// VPCMPGTDrr
    812867468U,	// VPCMPGTQYrm
    811655052U,	// VPCMPGTQYrr
    811851660U,	// VPCMPGTQZ128rm
    358719372U,	// VPCMPGTQZ128rmb
    1165287308U,	// VPCMPGTQZ128rmbk
    890576780U,	// VPCMPGTQZ128rmk
    811655052U,	// VPCMPGTQZ128rr
    890281868U,	// VPCMPGTQZ128rrk
    812867468U,	// VPCMPGTQZ256rm
    360816524U,	// VPCMPGTQZ256rmb
    1167384460U,	// VPCMPGTQZ256rmbk
    890609548U,	// VPCMPGTQZ256rmk
    811655052U,	// VPCMPGTQZ256rr
    890281868U,	// VPCMPGTQZ256rrk
    812883852U,	// VPCMPGTQZrm
    362913676U,	// VPCMPGTQZrmb
    1169481612U,	// VPCMPGTQZrmbk
    890675084U,	// VPCMPGTQZrmk
    811655052U,	// VPCMPGTQZrr
    890281868U,	// VPCMPGTQZrrk
    811851660U,	// VPCMPGTQrm
    811655052U,	// VPCMPGTQrr
    812871398U,	// VPCMPGTWYrm
    811658982U,	// VPCMPGTWYrr
    811855590U,	// VPCMPGTWZ128rm
    890580710U,	// VPCMPGTWZ128rmk
    811658982U,	// VPCMPGTWZ128rr
    890285798U,	// VPCMPGTWZ128rrk
    812871398U,	// VPCMPGTWZ256rm
    890613478U,	// VPCMPGTWZ256rmk
    811658982U,	// VPCMPGTWZ256rr
    890285798U,	// VPCMPGTWZ256rrk
    812887782U,	// VPCMPGTWZrm
    890679014U,	// VPCMPGTWZrmk
    811658982U,	// VPCMPGTWZrr
    890285798U,	// VPCMPGTWZrrk
    811855590U,	// VPCMPGTWrm
    811658982U,	// VPCMPGTWrr
    830771944U,	// VPCMPISTRIrm
    283431656U,	// VPCMPISTRIrr
    830773311U,	// VPCMPISTRMrm
    283433023U,	// VPCMPISTRMrr
    2873621507U,	// VPCMPQZ128rmi
    325442943U,	// VPCMPQZ128rmi_alt
    726137859U,	// VPCMPQZ128rmib
    3013991807U,	// VPCMPQZ128rmib_alt
    995490819U,	// VPCMPQZ128rmibk
    3075743103U,	// VPCMPQZ128rmibk_alt
    3142974467U,	// VPCMPQZ128rmik
    1179917695U,	// VPCMPQZ128rmik_alt
    1263025155U,	// VPCMPQZ128rri
    1088822655U,	// VPCMPQZ128rri_alt
    1532378115U,	// VPCMPQZ128rrik
    1357585791U,	// VPCMPQZ128rrik_alt
    3410492419U,	// VPCMPQZ256rmi
    375774591U,	// VPCMPQZ256rmi_alt
    726137859U,	// VPCMPQZ256rmib
    1671814527U,	// VPCMPQZ256rmib_alt
    995490819U,	// VPCMPQZ256rmibk
    1733565823U,	// VPCMPQZ256rmibk_alt
    3679845379U,	// VPCMPQZ256rmik
    1186209151U,	// VPCMPQZ256rmik_alt
    1263025155U,	// VPCMPQZ256rri
    1088822655U,	// VPCMPQZ256rri_alt
    1532378115U,	// VPCMPQZ256rrik
    1357585791U,	// VPCMPQZ256rrik_alt
    3947363331U,	// VPCMPQZrmi
    382066047U,	// VPCMPQZrmi_alt
    726137859U,	// VPCMPQZrmib
    2477120895U,	// VPCMPQZrmib_alt
    995490819U,	// VPCMPQZrmibk
    2538872191U,	// VPCMPQZrmibk_alt
    4216716291U,	// VPCMPQZrmik
    1192500607U,	// VPCMPQZrmik_alt
    1263025155U,	// VPCMPQZrri
    1088822655U,	// VPCMPQZrri_alt
    1532378115U,	// VPCMPQZrrik
    1357585791U,	// VPCMPQZrrik_alt
    2875718659U,	// VPCMPUBZ128rmi
    325437046U,	// VPCMPUBZ128rmi_alt
    3145071619U,	// VPCMPUBZ128rmik
    1179911798U,	// VPCMPUBZ128rmik_alt
    1265122307U,	// VPCMPUBZ128rri
    1088816758U,	// VPCMPUBZ128rri_alt
    1534475267U,	// VPCMPUBZ128rrik
    1357579894U,	// VPCMPUBZ128rrik_alt
    3412589571U,	// VPCMPUBZ256rmi
    375768694U,	// VPCMPUBZ256rmi_alt
    3681942531U,	// VPCMPUBZ256rmik
    1186203254U,	// VPCMPUBZ256rmik_alt
    1265122307U,	// VPCMPUBZ256rri
    1088816758U,	// VPCMPUBZ256rri_alt
    1534475267U,	// VPCMPUBZ256rrik
    1357579894U,	// VPCMPUBZ256rrik_alt
    3949460483U,	// VPCMPUBZrmi
    382060150U,	// VPCMPUBZrmi_alt
    4218813443U,	// VPCMPUBZrmik
    1192494710U,	// VPCMPUBZrmik_alt
    1265122307U,	// VPCMPUBZrri
    1088816758U,	// VPCMPUBZrri_alt
    1534475267U,	// VPCMPUBZrrik
    1357579894U,	// VPCMPUBZrrik_alt
    2877815811U,	// VPCMPUDZ128rmi
    325439635U,	// VPCMPUDZ128rmi_alt
    193461251U,	// VPCMPUDZ128rmib
    1686491283U,	// VPCMPUDZ128rmib_alt
    462814211U,	// VPCMPUDZ128rmibk
    1712590995U,	// VPCMPUDZ128rmibk_alt
    3147168771U,	// VPCMPUDZ128rmik
    1179914387U,	// VPCMPUDZ128rmik_alt
    1267219459U,	// VPCMPUDZ128rri
    1088819347U,	// VPCMPUDZ128rri_alt
    1536572419U,	// VPCMPUDZ128rrik
    1357582483U,	// VPCMPUDZ128rrik_alt
    3414686723U,	// VPCMPUDZ256rmi
    375771283U,	// VPCMPUDZ256rmi_alt
    193461251U,	// VPCMPUDZ256rmib
    2491797651U,	// VPCMPUDZ256rmib_alt
    462814211U,	// VPCMPUDZ256rmibk
    2517897363U,	// VPCMPUDZ256rmibk_alt
    3684039683U,	// VPCMPUDZ256rmik
    1186205843U,	// VPCMPUDZ256rmik_alt
    1267219459U,	// VPCMPUDZ256rri
    1088819347U,	// VPCMPUDZ256rri_alt
    1536572419U,	// VPCMPUDZ256rrik
    1357582483U,	// VPCMPUDZ256rrik_alt
    3951557635U,	// VPCMPUDZrmi
    382062739U,	// VPCMPUDZrmi_alt
    193461251U,	// VPCMPUDZrmib
    2760233107U,	// VPCMPUDZrmib_alt
    462814211U,	// VPCMPUDZrmibk
    2786332819U,	// VPCMPUDZrmibk_alt
    4220910595U,	// VPCMPUDZrmik
    1192497299U,	// VPCMPUDZrmik_alt
    1267219459U,	// VPCMPUDZrri
    1088819347U,	// VPCMPUDZrri_alt
    1536572419U,	// VPCMPUDZrrik
    1357582483U,	// VPCMPUDZrrik_alt
    2879912963U,	// VPCMPUQZ128rmi
    325443621U,	// VPCMPUQZ128rmi_alt
    732429315U,	// VPCMPUQZ128rmib
    3013992485U,	// VPCMPUQZ128rmib_alt
    1001782275U,	// VPCMPUQZ128rmibk
    3075743781U,	// VPCMPUQZ128rmibk_alt
    3149265923U,	// VPCMPUQZ128rmik
    1179918373U,	// VPCMPUQZ128rmik_alt
    1269316611U,	// VPCMPUQZ128rri
    1088823333U,	// VPCMPUQZ128rri_alt
    1538669571U,	// VPCMPUQZ128rrik
    1357586469U,	// VPCMPUQZ128rrik_alt
    3416783875U,	// VPCMPUQZ256rmi
    375775269U,	// VPCMPUQZ256rmi_alt
    732429315U,	// VPCMPUQZ256rmib
    1671815205U,	// VPCMPUQZ256rmib_alt
    1001782275U,	// VPCMPUQZ256rmibk
    1733566501U,	// VPCMPUQZ256rmibk_alt
    3686136835U,	// VPCMPUQZ256rmik
    1186209829U,	// VPCMPUQZ256rmik_alt
    1269316611U,	// VPCMPUQZ256rri
    1088823333U,	// VPCMPUQZ256rri_alt
    1538669571U,	// VPCMPUQZ256rrik
    1357586469U,	// VPCMPUQZ256rrik_alt
    3953654787U,	// VPCMPUQZrmi
    382066725U,	// VPCMPUQZrmi_alt
    732429315U,	// VPCMPUQZrmib
    2477121573U,	// VPCMPUQZrmib_alt
    1001782275U,	// VPCMPUQZrmibk
    2538872869U,	// VPCMPUQZrmibk_alt
    4223007747U,	// VPCMPUQZrmik
    1192501285U,	// VPCMPUQZrmik_alt
    1269316611U,	// VPCMPUQZrri
    1088823333U,	// VPCMPUQZrri_alt
    1538669571U,	// VPCMPUQZrrik
    1357586469U,	// VPCMPUQZrrik_alt
    2882010115U,	// VPCMPUWZ128rmi
    325447509U,	// VPCMPUWZ128rmi_alt
    3151363075U,	// VPCMPUWZ128rmik
    1179922261U,	// VPCMPUWZ128rmik_alt
    1271413763U,	// VPCMPUWZ128rri
    1088827221U,	// VPCMPUWZ128rri_alt
    1540766723U,	// VPCMPUWZ128rrik
    1357590357U,	// VPCMPUWZ128rrik_alt
    3418881027U,	// VPCMPUWZ256rmi
    375779157U,	// VPCMPUWZ256rmi_alt
    3688233987U,	// VPCMPUWZ256rmik
    1186213717U,	// VPCMPUWZ256rmik_alt
    1271413763U,	// VPCMPUWZ256rri
    1088827221U,	// VPCMPUWZ256rri_alt
    1540766723U,	// VPCMPUWZ256rrik
    1357590357U,	// VPCMPUWZ256rrik_alt
    3955751939U,	// VPCMPUWZrmi
    382070613U,	// VPCMPUWZrmi_alt
    4225104899U,	// VPCMPUWZrmik
    1192505173U,	// VPCMPUWZrmik_alt
    1271413763U,	// VPCMPUWZrri
    1088827221U,	// VPCMPUWZrri_alt
    1540766723U,	// VPCMPUWZrrik
    1357590357U,	// VPCMPUWZrrik_alt
    2884107267U,	// VPCMPWZ128rmi
    325446924U,	// VPCMPWZ128rmi_alt
    3153460227U,	// VPCMPWZ128rmik
    1179921676U,	// VPCMPWZ128rmik_alt
    1273510915U,	// VPCMPWZ128rri
    1088826636U,	// VPCMPWZ128rri_alt
    1542863875U,	// VPCMPWZ128rrik
    1357589772U,	// VPCMPWZ128rrik_alt
    3420978179U,	// VPCMPWZ256rmi
    375778572U,	// VPCMPWZ256rmi_alt
    3690331139U,	// VPCMPWZ256rmik
    1186213132U,	// VPCMPWZ256rmik_alt
    1273510915U,	// VPCMPWZ256rri
    1088826636U,	// VPCMPWZ256rri_alt
    1542863875U,	// VPCMPWZ256rrik
    1357589772U,	// VPCMPWZ256rrik_alt
    3957849091U,	// VPCMPWZrmi
    382070028U,	// VPCMPWZrmi_alt
    4227202051U,	// VPCMPWZrmik
    1192504588U,	// VPCMPWZrmik_alt
    1273510915U,	// VPCMPWZrri
    1088826636U,	// VPCMPWZrri_alt
    1542863875U,	// VPCMPWZrrik
    1357589772U,	// VPCMPWZrrik_alt
    2870574020U,	// VPCOMBmi
    325436582U,	// VPCOMBmi_alt
    1259977668U,	// VPCOMBri
    1088816294U,	// VPCOMBri_alt
    2872671172U,	// VPCOMDmi
    325437627U,	// VPCOMDmi_alt
    1262074820U,	// VPCOMDri
    1088817339U,	// VPCOMDri_alt
    33588698U,	// VPCOMPRESSBZ128mr
    3255109082U,	// VPCOMPRESSBZ128mrk
    551831002U,	// VPCOMPRESSBZ128rr
    3230696922U,	// VPCOMPRESSBZ128rrk
    3229664730U,	// VPCOMPRESSBZ128rrkz
    180389338U,	// VPCOMPRESSBZ256mr
    3401909722U,	// VPCOMPRESSBZ256mrk
    551831002U,	// VPCOMPRESSBZ256rr
    3230696922U,	// VPCOMPRESSBZ256rrk
    3229664730U,	// VPCOMPRESSBZ256rrkz
    182486490U,	// VPCOMPRESSBZmr
    3404006874U,	// VPCOMPRESSBZmrk
    551831002U,	// VPCOMPRESSBZrr
    3230696922U,	// VPCOMPRESSBZrrk
    3229664730U,	// VPCOMPRESSBZrrkz
    33591178U,	// VPCOMPRESSDZ128mr
    3255111562U,	// VPCOMPRESSDZ128mrk
    551833482U,	// VPCOMPRESSDZ128rr
    3230699402U,	// VPCOMPRESSDZ128rrk
    3229667210U,	// VPCOMPRESSDZ128rrkz
    180391818U,	// VPCOMPRESSDZ256mr
    3401912202U,	// VPCOMPRESSDZ256mrk
    551833482U,	// VPCOMPRESSDZ256rr
    3230699402U,	// VPCOMPRESSDZ256rrk
    3229667210U,	// VPCOMPRESSDZ256rrkz
    182488970U,	// VPCOMPRESSDZmr
    3404009354U,	// VPCOMPRESSDZmrk
    551833482U,	// VPCOMPRESSDZrr
    3230699402U,	// VPCOMPRESSDZrrk
    3229667210U,	// VPCOMPRESSDZrrkz
    33595159U,	// VPCOMPRESSQZ128mr
    3255115543U,	// VPCOMPRESSQZ128mrk
    551837463U,	// VPCOMPRESSQZ128rr
    3230703383U,	// VPCOMPRESSQZ128rrk
    3229671191U,	// VPCOMPRESSQZ128rrkz
    180395799U,	// VPCOMPRESSQZ256mr
    3401916183U,	// VPCOMPRESSQZ256mrk
    551837463U,	// VPCOMPRESSQZ256rr
    3230703383U,	// VPCOMPRESSQZ256rrk
    3229671191U,	// VPCOMPRESSQZ256rrkz
    182492951U,	// VPCOMPRESSQZmr
    3404013335U,	// VPCOMPRESSQZmrk
    551837463U,	// VPCOMPRESSQZrr
    3230703383U,	// VPCOMPRESSQZrrk
    3229671191U,	// VPCOMPRESSQZrrkz
    33599075U,	// VPCOMPRESSWZ128mr
    3255119459U,	// VPCOMPRESSWZ128mrk
    551841379U,	// VPCOMPRESSWZ128rr
    3230707299U,	// VPCOMPRESSWZ128rrk
    3229675107U,	// VPCOMPRESSWZ128rrkz
    180399715U,	// VPCOMPRESSWZ256mr
    3401920099U,	// VPCOMPRESSWZ256mrk
    551841379U,	// VPCOMPRESSWZ256rr
    3230707299U,	// VPCOMPRESSWZ256rrk
    3229675107U,	// VPCOMPRESSWZ256rrkz
    182496867U,	// VPCOMPRESSWZmr
    3404017251U,	// VPCOMPRESSWZmrk
    551841379U,	// VPCOMPRESSWZrr
    3230707299U,	// VPCOMPRESSWZrrk
    3229675107U,	// VPCOMPRESSWZrrkz
    2874768324U,	// VPCOMQmi
    325442859U,	// VPCOMQmi_alt
    1264171972U,	// VPCOMQri
    1088822571U,	// VPCOMQri_alt
    2876865476U,	// VPCOMUBmi
    325437028U,	// VPCOMUBmi_alt
    1266269124U,	// VPCOMUBri
    1088816740U,	// VPCOMUBri_alt
    2878962628U,	// VPCOMUDmi
    325439617U,	// VPCOMUDmi_alt
    1268366276U,	// VPCOMUDri
    1088819329U,	// VPCOMUDri_alt
    2881059780U,	// VPCOMUQmi
    325443603U,	// VPCOMUQmi_alt
    1270463428U,	// VPCOMUQri
    1088823315U,	// VPCOMUQri_alt
    2883156932U,	// VPCOMUWmi
    325447491U,	// VPCOMUWmi_alt
    1272560580U,	// VPCOMUWri
    1088827203U,	// VPCOMUWri_alt
    2885254084U,	// VPCOMWmi
    325446851U,	// VPCOMWmi_alt
    1274657732U,	// VPCOMWri
    1088826563U,	// VPCOMWri_alt
    266279U,	// VPCONFLICTDZ128rm
    629493799U,	// VPCONFLICTDZ128rmb
    630607911U,	// VPCONFLICTDZ128rmbk
    629231655U,	// VPCONFLICTDZ128rmbkz
    3230994471U,	// VPCONFLICTDZ128rmk
    3229863975U,	// VPCONFLICTDZ128rmkz
    551833639U,	// VPCONFLICTDZ128rr
    3230699559U,	// VPCONFLICTDZ128rrk
    3229667367U,	// VPCONFLICTDZ128rrkz
    552947751U,	// VPCONFLICTDZ256rm
    631590951U,	// VPCONFLICTDZ256rmb
    632705063U,	// VPCONFLICTDZ256rmbk
    631328807U,	// VPCONFLICTDZ256rmbkz
    3231027239U,	// VPCONFLICTDZ256rmk
    3230879783U,	// VPCONFLICTDZ256rmkz
    551833639U,	// VPCONFLICTDZ256rr
    3230699559U,	// VPCONFLICTDZ256rrk
    3229667367U,	// VPCONFLICTDZ256rrkz
    552439847U,	// VPCONFLICTDZrm
    633688103U,	// VPCONFLICTDZrmb
    634802215U,	// VPCONFLICTDZrmbk
    633425959U,	// VPCONFLICTDZrmbkz
    3231092775U,	// VPCONFLICTDZrmk
    3230896167U,	// VPCONFLICTDZrmkz
    551833639U,	// VPCONFLICTDZrr
    3230699559U,	// VPCONFLICTDZrrk
    3229667367U,	// VPCONFLICTDZrrkz
    270165U,	// VPCONFLICTQZ128rm
    627416917U,	// VPCONFLICTQZ128rmb
    628416341U,	// VPCONFLICTQZ128rmbk
    627154773U,	// VPCONFLICTQZ128rmbkz
    3230998357U,	// VPCONFLICTQZ128rmk
    3229867861U,	// VPCONFLICTQZ128rmkz
    551837525U,	// VPCONFLICTQZ128rr
    3230703445U,	// VPCONFLICTQZ128rrk
    3229671253U,	// VPCONFLICTQZ128rrkz
    552951637U,	// VPCONFLICTQZ256rm
    629514069U,	// VPCONFLICTQZ256rmb
    630513493U,	// VPCONFLICTQZ256rmbk
    629251925U,	// VPCONFLICTQZ256rmbkz
    3231031125U,	// VPCONFLICTQZ256rmk
    3230883669U,	// VPCONFLICTQZ256rmkz
    551837525U,	// VPCONFLICTQZ256rr
    3230703445U,	// VPCONFLICTQZ256rrk
    3229671253U,	// VPCONFLICTQZ256rrkz
    552443733U,	// VPCONFLICTQZrm
    631611221U,	// VPCONFLICTQZrmb
    632610645U,	// VPCONFLICTQZrmbk
    631349077U,	// VPCONFLICTQZrmbkz
    3231096661U,	// VPCONFLICTQZrmk
    3230900053U,	// VPCONFLICTQZrmkz
    551837525U,	// VPCONFLICTQZrr
    3230703445U,	// VPCONFLICTQZrrk
    3229671253U,	// VPCONFLICTQZrrkz
    890577330U,	// VPDPBUSDSZ128m
    1167483314U,	// VPDPBUSDSZ128mb
    1436066226U,	// VPDPBUSDSZ128mbk
    1436066226U,	// VPDPBUSDSZ128mbkz
    985113010U,	// VPDPBUSDSZ128mk
    985113010U,	// VPDPBUSDSZ128mkz
    890282418U,	// VPDPBUSDSZ128r
    87056818U,	// VPDPBUSDSZ128rk
    89153970U,	// VPDPBUSDSZ128rkz
    890610098U,	// VPDPBUSDSZ256m
    1169580466U,	// VPDPBUSDSZ256mb
    1438163378U,	// VPDPBUSDSZ256mbk
    1438163378U,	// VPDPBUSDSZ256mbkz
    985129394U,	// VPDPBUSDSZ256mk
    985129394U,	// VPDPBUSDSZ256mkz
    890282418U,	// VPDPBUSDSZ256r
    87056818U,	// VPDPBUSDSZ256rk
    89153970U,	// VPDPBUSDSZ256rkz
    890675634U,	// VPDPBUSDSZm
    1171677618U,	// VPDPBUSDSZmb
    1440260530U,	// VPDPBUSDSZmbk
    1440260530U,	// VPDPBUSDSZmbkz
    985145778U,	// VPDPBUSDSZmk
    985145778U,	// VPDPBUSDSZmkz
    890282418U,	// VPDPBUSDSZr
    87056818U,	// VPDPBUSDSZrk
    89153970U,	// VPDPBUSDSZrkz
    890572787U,	// VPDPBUSDZ128m
    1167478771U,	// VPDPBUSDZ128mb
    1436061683U,	// VPDPBUSDZ128mbk
    1436061683U,	// VPDPBUSDZ128mbkz
    985108467U,	// VPDPBUSDZ128mk
    985108467U,	// VPDPBUSDZ128mkz
    890277875U,	// VPDPBUSDZ128r
    87052275U,	// VPDPBUSDZ128rk
    89149427U,	// VPDPBUSDZ128rkz
    890605555U,	// VPDPBUSDZ256m
    1169575923U,	// VPDPBUSDZ256mb
    1438158835U,	// VPDPBUSDZ256mbk
    1438158835U,	// VPDPBUSDZ256mbkz
    985124851U,	// VPDPBUSDZ256mk
    985124851U,	// VPDPBUSDZ256mkz
    890277875U,	// VPDPBUSDZ256r
    87052275U,	// VPDPBUSDZ256rk
    89149427U,	// VPDPBUSDZ256rkz
    890671091U,	// VPDPBUSDZm
    1171673075U,	// VPDPBUSDZmb
    1440255987U,	// VPDPBUSDZmbk
    1440255987U,	// VPDPBUSDZmbkz
    985141235U,	// VPDPBUSDZmk
    985141235U,	// VPDPBUSDZmkz
    890277875U,	// VPDPBUSDZr
    87052275U,	// VPDPBUSDZrk
    89149427U,	// VPDPBUSDZrkz
    890577319U,	// VPDPWSSDSZ128m
    1167483303U,	// VPDPWSSDSZ128mb
    1436066215U,	// VPDPWSSDSZ128mbk
    1436066215U,	// VPDPWSSDSZ128mbkz
    985112999U,	// VPDPWSSDSZ128mk
    985112999U,	// VPDPWSSDSZ128mkz
    890282407U,	// VPDPWSSDSZ128r
    87056807U,	// VPDPWSSDSZ128rk
    89153959U,	// VPDPWSSDSZ128rkz
    890610087U,	// VPDPWSSDSZ256m
    1169580455U,	// VPDPWSSDSZ256mb
    1438163367U,	// VPDPWSSDSZ256mbk
    1438163367U,	// VPDPWSSDSZ256mbkz
    985129383U,	// VPDPWSSDSZ256mk
    985129383U,	// VPDPWSSDSZ256mkz
    890282407U,	// VPDPWSSDSZ256r
    87056807U,	// VPDPWSSDSZ256rk
    89153959U,	// VPDPWSSDSZ256rkz
    890675623U,	// VPDPWSSDSZm
    1171677607U,	// VPDPWSSDSZmb
    1440260519U,	// VPDPWSSDSZmbk
    1440260519U,	// VPDPWSSDSZmbkz
    985145767U,	// VPDPWSSDSZmk
    985145767U,	// VPDPWSSDSZmkz
    890282407U,	// VPDPWSSDSZr
    87056807U,	// VPDPWSSDSZrk
    89153959U,	// VPDPWSSDSZrkz
    890572733U,	// VPDPWSSDZ128m
    1167478717U,	// VPDPWSSDZ128mb
    1436061629U,	// VPDPWSSDZ128mbk
    1436061629U,	// VPDPWSSDZ128mbkz
    985108413U,	// VPDPWSSDZ128mk
    985108413U,	// VPDPWSSDZ128mkz
    890277821U,	// VPDPWSSDZ128r
    87052221U,	// VPDPWSSDZ128rk
    89149373U,	// VPDPWSSDZ128rkz
    890605501U,	// VPDPWSSDZ256m
    1169575869U,	// VPDPWSSDZ256mb
    1438158781U,	// VPDPWSSDZ256mbk
    1438158781U,	// VPDPWSSDZ256mbkz
    985124797U,	// VPDPWSSDZ256mk
    985124797U,	// VPDPWSSDZ256mkz
    890277821U,	// VPDPWSSDZ256r
    87052221U,	// VPDPWSSDZ256rk
    89149373U,	// VPDPWSSDZ256rkz
    890671037U,	// VPDPWSSDZm
    1171673021U,	// VPDPWSSDZmb
    1440255933U,	// VPDPWSSDZmbk
    1440255933U,	// VPDPWSSDZmbkz
    985141181U,	// VPDPWSSDZmk
    985141181U,	// VPDPWSSDZmkz
    890277821U,	// VPDPWSSDZr
    87052221U,	// VPDPWSSDZrk
    89149373U,	// VPDPWSSDZrkz
    392544868U,	// VPERM2F128rm
    1088815716U,	// VPERM2F128rr
    392544923U,	// VPERM2I128rm
    1088815771U,	// VPERM2I128rr
    811844796U,	// VPERMBZ128rm
    985105596U,	// VPERMBZ128rmk
    890569916U,	// VPERMBZ128rmkz
    811648188U,	// VPERMBZ128rr
    87049404U,	// VPERMBZ128rrk
    890275004U,	// VPERMBZ128rrkz
    812860604U,	// VPERMBZ256rm
    985121980U,	// VPERMBZ256rmk
    890602684U,	// VPERMBZ256rmkz
    811648188U,	// VPERMBZ256rr
    87049404U,	// VPERMBZ256rrk
    890275004U,	// VPERMBZ256rrkz
    812876988U,	// VPERMBZrm
    985138364U,	// VPERMBZrmk
    890668220U,	// VPERMBZrmkz
    811648188U,	// VPERMBZrr
    87049404U,	// VPERMBZrrk
    890275004U,	// VPERMBZrrkz
    812861635U,	// VPERMDYrm
    811649219U,	// VPERMDYrr
    812861635U,	// VPERMDZ256rm
    362891459U,	// VPERMDZ256rmb
    1438156995U,	// VPERMDZ256rmbk
    1169574083U,	// VPERMDZ256rmbkz
    985123011U,	// VPERMDZ256rmk
    890603715U,	// VPERMDZ256rmkz
    811649219U,	// VPERMDZ256rr
    87050435U,	// VPERMDZ256rrk
    890276035U,	// VPERMDZ256rrkz
    812878019U,	// VPERMDZrm
    364988611U,	// VPERMDZrmb
    1440254147U,	// VPERMDZrmbk
    1171671235U,	// VPERMDZrmbkz
    985139395U,	// VPERMDZrmk
    890669251U,	// VPERMDZrmkz
    811649219U,	// VPERMDZrr
    87050435U,	// VPERMDZrrk
    890276035U,	// VPERMDZrrkz
    890569579U,	// VPERMI2B128rm
    985105259U,	// VPERMI2B128rmk
    985105259U,	// VPERMI2B128rmkz
    890274667U,	// VPERMI2B128rr
    87049067U,	// VPERMI2B128rrk
    89146219U,	// VPERMI2B128rrkz
    890602347U,	// VPERMI2B256rm
    985121643U,	// VPERMI2B256rmk
    985121643U,	// VPERMI2B256rmkz
    890274667U,	// VPERMI2B256rr
    87049067U,	// VPERMI2B256rrk
    89146219U,	// VPERMI2B256rrkz
    890667883U,	// VPERMI2Brm
    985138027U,	// VPERMI2Brmk
    985138027U,	// VPERMI2Brmkz
    890274667U,	// VPERMI2Brr
    87049067U,	// VPERMI2Brrk
    89146219U,	// VPERMI2Brrkz
    890570533U,	// VPERMI2D128rm
    1167476517U,	// VPERMI2D128rmb
    1436059429U,	// VPERMI2D128rmbk
    1436059429U,	// VPERMI2D128rmbkz
    985106213U,	// VPERMI2D128rmk
    985106213U,	// VPERMI2D128rmkz
    890275621U,	// VPERMI2D128rr
    87050021U,	// VPERMI2D128rrk
    89147173U,	// VPERMI2D128rrkz
    890603301U,	// VPERMI2D256rm
    1169573669U,	// VPERMI2D256rmb
    1438156581U,	// VPERMI2D256rmbk
    1438156581U,	// VPERMI2D256rmbkz
    985122597U,	// VPERMI2D256rmk
    985122597U,	// VPERMI2D256rmkz
    890275621U,	// VPERMI2D256rr
    87050021U,	// VPERMI2D256rrk
    89147173U,	// VPERMI2D256rrkz
    890668837U,	// VPERMI2Drm
    1171670821U,	// VPERMI2Drmb
    1440253733U,	// VPERMI2Drmbk
    1440253733U,	// VPERMI2Drmbkz
    985138981U,	// VPERMI2Drmk
    985138981U,	// VPERMI2Drmkz
    890275621U,	// VPERMI2Drr
    87050021U,	// VPERMI2Drrk
    89147173U,	// VPERMI2Drrkz
    890177970U,	// VPERMI2PD128rm
    1164970418U,	// VPERMI2PD128rmb
    1433389490U,	// VPERMI2PD128rmbk
    1433389490U,	// VPERMI2PD128rmbkz
    86985138U,	// VPERMI2PD128rmk
    89082290U,	// VPERMI2PD128rmkz
    890276274U,	// VPERMI2PD128rr
    87050674U,	// VPERMI2PD128rrk
    89147826U,	// VPERMI2PD128rrkz
    890309042U,	// VPERMI2PD256rm
    1167067570U,	// VPERMI2PD256rmb
    1435486642U,	// VPERMI2PD256rmbk
    1435486642U,	// VPERMI2PD256rmbkz
    87083442U,	// VPERMI2PD256rmk
    89180594U,	// VPERMI2PD256rmkz
    890276274U,	// VPERMI2PD256rr
    87050674U,	// VPERMI2PD256rrk
    89147826U,	// VPERMI2PD256rrkz
    890358194U,	// VPERMI2PDrm
    1169164722U,	// VPERMI2PDrmb
    1437583794U,	// VPERMI2PDrmbk
    1437583794U,	// VPERMI2PDrmbkz
    87132594U,	// VPERMI2PDrmk
    89229746U,	// VPERMI2PDrmkz
    890276274U,	// VPERMI2PDrr
    87050674U,	// VPERMI2PDrrk
    89147826U,	// VPERMI2PDrrkz
    890184386U,	// VPERMI2PS128rm
    1167270594U,	// VPERMI2PS128rmb
    1435689666U,	// VPERMI2PS128rmbk
    1435689666U,	// VPERMI2PS128rmbkz
    86991554U,	// VPERMI2PS128rmk
    89088706U,	// VPERMI2PS128rmkz
    890282690U,	// VPERMI2PS128rr
    87057090U,	// VPERMI2PS128rrk
    89154242U,	// VPERMI2PS128rrkz
    890315458U,	// VPERMI2PS256rm
    1169367746U,	// VPERMI2PS256rmb
    1437786818U,	// VPERMI2PS256rmbk
    1437786818U,	// VPERMI2PS256rmbkz
    87089858U,	// VPERMI2PS256rmk
    89187010U,	// VPERMI2PS256rmkz
    890282690U,	// VPERMI2PS256rr
    87057090U,	// VPERMI2PS256rrk
    89154242U,	// VPERMI2PS256rrkz
    890364610U,	// VPERMI2PSrm
    1171464898U,	// VPERMI2PSrmb
    1439883970U,	// VPERMI2PSrmbk
    1439883970U,	// VPERMI2PSrmbkz
    87139010U,	// VPERMI2PSrmk
    89236162U,	// VPERMI2PSrmkz
    890282690U,	// VPERMI2PSrr
    87057090U,	// VPERMI2PSrrk
    89154242U,	// VPERMI2PSrrkz
    890575167U,	// VPERMI2Q128rm
    1165285695U,	// VPERMI2Q128rmb
    1433950527U,	// VPERMI2Q128rmbk
    1433950527U,	// VPERMI2Q128rmbkz
    985110847U,	// VPERMI2Q128rmk
    985110847U,	// VPERMI2Q128rmkz
    890280255U,	// VPERMI2Q128rr
    87054655U,	// VPERMI2Q128rrk
    89151807U,	// VPERMI2Q128rrkz
    890607935U,	// VPERMI2Q256rm
    1167382847U,	// VPERMI2Q256rmb
    1436047679U,	// VPERMI2Q256rmbk
    1436047679U,	// VPERMI2Q256rmbkz
    985127231U,	// VPERMI2Q256rmk
    985127231U,	// VPERMI2Q256rmkz
    890280255U,	// VPERMI2Q256rr
    87054655U,	// VPERMI2Q256rrk
    89151807U,	// VPERMI2Q256rrkz
    890673471U,	// VPERMI2Qrm
    1169479999U,	// VPERMI2Qrmb
    1438144831U,	// VPERMI2Qrmbk
    1438144831U,	// VPERMI2Qrmbkz
    985143615U,	// VPERMI2Qrmk
    985143615U,	// VPERMI2Qrmkz
    890280255U,	// VPERMI2Qrr
    87054655U,	// VPERMI2Qrrk
    89151807U,	// VPERMI2Qrrkz
    890579481U,	// VPERMI2W128rm
    985115161U,	// VPERMI2W128rmk
    985115161U,	// VPERMI2W128rmkz
    890284569U,	// VPERMI2W128rr
    87058969U,	// VPERMI2W128rrk
    89156121U,	// VPERMI2W128rrkz
    890612249U,	// VPERMI2W256rm
    985131545U,	// VPERMI2W256rmk
    985131545U,	// VPERMI2W256rmkz
    890284569U,	// VPERMI2W256rr
    87058969U,	// VPERMI2W256rrk
    89156121U,	// VPERMI2W256rrkz
    890677785U,	// VPERMI2Wrm
    985147929U,	// VPERMI2Wrmk
    985147929U,	// VPERMI2Wrmkz
    890284569U,	// VPERMI2Wrr
    87058969U,	// VPERMI2Wrrk
    89156121U,	// VPERMI2Wrrkz
    3692300743U,	// VPERMIL2PDYmr
    1186204103U,	// VPERMIL2PDYrm
    1357580743U,	// VPERMIL2PDYrr
    1357580743U,	// VPERMIL2PDYrr_REV
    2081688007U,	// VPERMIL2PDmr
    1179912647U,	// VPERMIL2PDrm
    1357580743U,	// VPERMIL2PDrr
    1357580743U,	// VPERMIL2PDrr_REV
    3692307159U,	// VPERMIL2PSYmr
    1186210519U,	// VPERMIL2PSYrm
    1357587159U,	// VPERMIL2PSYrr
    1357587159U,	// VPERMIL2PSYrr_REV
    2081694423U,	// VPERMIL2PSmr
    1179919063U,	// VPERMIL2PSrm
    1357587159U,	// VPERMIL2PSrr
    1357587159U,	// VPERMIL2PSrr_REV
    168070135U,	// VPERMILPDYmi
    283429879U,	// VPERMILPDYri
    812862455U,	// VPERMILPDYrm
    811650039U,	// VPERMILPDYrr
    3032779767U,	// VPERMILPDZ128mbi
    3079932919U,	// VPERMILPDZ128mbik
    2999307255U,	// VPERMILPDZ128mbikz
    77892599U,	// VPERMILPDZ128mi
    666110967U,	// VPERMILPDZ128mik
    568708087U,	// VPERMILPDZ128mikz
    283429879U,	// VPERMILPDZ128ri
    1357581303U,	// VPERMILPDZ128rik
    1088818167U,	// VPERMILPDZ128rikz
    811846647U,	// VPERMILPDZ128rm
    358763511U,	// VPERMILPDZ128rmb
    1433390071U,	// VPERMILPDZ128rmbk
    1164970999U,	// VPERMILPDZ128rmbkz
    985107447U,	// VPERMILPDZ128rmk
    890571767U,	// VPERMILPDZ128rmkz
    811650039U,	// VPERMILPDZ128rr
    87051255U,	// VPERMILPDZ128rrk
    890276855U,	// VPERMILPDZ128rrkz
    1690602487U,	// VPERMILPDZ256mbi
    1737755639U,	// VPERMILPDZ256mbik
    1657129975U,	// VPERMILPDZ256mbikz
    168070135U,	// VPERMILPDZ256mi
    668208119U,	// VPERMILPDZ256mik
    660982775U,	// VPERMILPDZ256mikz
    283429879U,	// VPERMILPDZ256ri
    1357581303U,	// VPERMILPDZ256rik
    1088818167U,	// VPERMILPDZ256rikz
    812862455U,	// VPERMILPDZ256rm
    360860663U,	// VPERMILPDZ256rmb
    1435487223U,	// VPERMILPDZ256rmbk
    1167068151U,	// VPERMILPDZ256rmbkz
    985123831U,	// VPERMILPDZ256rmk
    890604535U,	// VPERMILPDZ256rmkz
    811650039U,	// VPERMILPDZ256rr
    87051255U,	// VPERMILPDZ256rrk
    890276855U,	// VPERMILPDZ256rrkz
    2495908855U,	// VPERMILPDZmbi
    2543062007U,	// VPERMILPDZmbik
    2462436343U,	// VPERMILPDZmbikz
    170167287U,	// VPERMILPDZmi
    672402423U,	// VPERMILPDZmik
    669371383U,	// VPERMILPDZmikz
    283429879U,	// VPERMILPDZri
    1357581303U,	// VPERMILPDZrik
    1088818167U,	// VPERMILPDZrikz
    812878839U,	// VPERMILPDZrm
    362957815U,	// VPERMILPDZrmb
    1437584375U,	// VPERMILPDZrmbk
    1169165303U,	// VPERMILPDZrmbkz
    985140215U,	// VPERMILPDZrmk
    890670071U,	// VPERMILPDZrmkz
    811650039U,	// VPERMILPDZrr
    87051255U,	// VPERMILPDZrrk
    890276855U,	// VPERMILPDZrrkz
    77892599U,	// VPERMILPDmi
    283429879U,	// VPERMILPDri
    811846647U,	// VPERMILPDrm
    811650039U,	// VPERMILPDrr
    168076575U,	// VPERMILPSYmi
    283436319U,	// VPERMILPSYri
    812868895U,	// VPERMILPSYrm
    811656479U,	// VPERMILPSYrr
    1692706079U,	// VPERMILPSZ128mbi
    1752442143U,	// VPERMILPSZ128mbik
    1661330719U,	// VPERMILPSZ128mbikz
    77899039U,	// VPERMILPSZ128mi
    666117407U,	// VPERMILPSZ128mik
    568714527U,	// VPERMILPSZ128mikz
    283436319U,	// VPERMILPSZ128ri
    1357587743U,	// VPERMILPSZ128rik
    1088824607U,	// VPERMILPSZ128rikz
    811853087U,	// VPERMILPSZ128rm
    360883487U,	// VPERMILPSZ128rmb
    1435690271U,	// VPERMILPSZ128rmbk
    1167271199U,	// VPERMILPSZ128rmbkz
    985113887U,	// VPERMILPSZ128rmk
    890578207U,	// VPERMILPSZ128rmkz
    811656479U,	// VPERMILPSZ128rr
    87057695U,	// VPERMILPSZ128rrk
    890283295U,	// VPERMILPSZ128rrkz
    2498012447U,	// VPERMILPSZ256mbi
    2557748511U,	// VPERMILPSZ256mbik
    2466637087U,	// VPERMILPSZ256mbikz
    168076575U,	// VPERMILPSZ256mi
    668214559U,	// VPERMILPSZ256mik
    660989215U,	// VPERMILPSZ256mikz
    283436319U,	// VPERMILPSZ256ri
    1357587743U,	// VPERMILPSZ256rik
    1088824607U,	// VPERMILPSZ256rikz
    812868895U,	// VPERMILPSZ256rm
    362980639U,	// VPERMILPSZ256rmb
    1437787423U,	// VPERMILPSZ256rmbk
    1169368351U,	// VPERMILPSZ256rmbkz
    985130271U,	// VPERMILPSZ256rmk
    890610975U,	// VPERMILPSZ256rmkz
    811656479U,	// VPERMILPSZ256rr
    87057695U,	// VPERMILPSZ256rrk
    890283295U,	// VPERMILPSZ256rrkz
    2766447903U,	// VPERMILPSZmbi
    2826183967U,	// VPERMILPSZmbik
    2735072543U,	// VPERMILPSZmbikz
    170173727U,	// VPERMILPSZmi
    672408863U,	// VPERMILPSZmik
    669377823U,	// VPERMILPSZmikz
    283436319U,	// VPERMILPSZri
    1357587743U,	// VPERMILPSZrik
    1088824607U,	// VPERMILPSZrikz
    812885279U,	// VPERMILPSZrm
    365077791U,	// VPERMILPSZrmb
    1439884575U,	// VPERMILPSZrmbk
    1171465503U,	// VPERMILPSZrmbkz
    985146655U,	// VPERMILPSZrmk
    890676511U,	// VPERMILPSZrmkz
    811656479U,	// VPERMILPSZrr
    87057695U,	// VPERMILPSZrrk
    890283295U,	// VPERMILPSZrrkz
    77899039U,	// VPERMILPSmi
    283436319U,	// VPERMILPSri
    811853087U,	// VPERMILPSrm
    811656479U,	// VPERMILPSrr
    168070206U,	// VPERMPDYmi
    283429950U,	// VPERMPDYri
    1690602558U,	// VPERMPDZ256mbi
    1737755710U,	// VPERMPDZ256mbik
    1657130046U,	// VPERMPDZ256mbikz
    168070206U,	// VPERMPDZ256mi
    668208190U,	// VPERMPDZ256mik
    660982846U,	// VPERMPDZ256mikz
    283429950U,	// VPERMPDZ256ri
    1357581374U,	// VPERMPDZ256rik
    1088818238U,	// VPERMPDZ256rikz
    812616766U,	// VPERMPDZ256rm
    360860734U,	// VPERMPDZ256rmb
    1435487294U,	// VPERMPDZ256rmbk
    1167068222U,	// VPERMPDZ256rmbkz
    87084094U,	// VPERMPDZ256rmk
    890309694U,	// VPERMPDZ256rmkz
    811650110U,	// VPERMPDZ256rr
    87051326U,	// VPERMPDZ256rrk
    890276926U,	// VPERMPDZ256rrkz
    2495908926U,	// VPERMPDZmbi
    2543062078U,	// VPERMPDZmbik
    2462436414U,	// VPERMPDZmbikz
    170167358U,	// VPERMPDZmi
    672402494U,	// VPERMPDZmik
    669371454U,	// VPERMPDZmikz
    283429950U,	// VPERMPDZri
    1357581374U,	// VPERMPDZrik
    1088818238U,	// VPERMPDZrikz
    812731454U,	// VPERMPDZrm
    362957886U,	// VPERMPDZrmb
    1437584446U,	// VPERMPDZrmbk
    1169165374U,	// VPERMPDZrmbkz
    87133246U,	// VPERMPDZrmk
    890358846U,	// VPERMPDZrmkz
    811650110U,	// VPERMPDZrr
    87051326U,	// VPERMPDZrrk
    890276926U,	// VPERMPDZrrkz
    812623215U,	// VPERMPSYrm
    811656559U,	// VPERMPSYrr
    812623215U,	// VPERMPSZ256rm
    362980719U,	// VPERMPSZ256rmb
    1437787503U,	// VPERMPSZ256rmbk
    1169368431U,	// VPERMPSZ256rmbkz
    87090543U,	// VPERMPSZ256rmk
    890316143U,	// VPERMPSZ256rmkz
    811656559U,	// VPERMPSZ256rr
    87057775U,	// VPERMPSZ256rrk
    890283375U,	// VPERMPSZ256rrkz
    812737903U,	// VPERMPSZrm
    365077871U,	// VPERMPSZrmb
    1439884655U,	// VPERMPSZrmbk
    1171465583U,	// VPERMPSZrmbkz
    87139695U,	// VPERMPSZrmk
    890365295U,	// VPERMPSZrmkz
    811656559U,	// VPERMPSZrr
    87057775U,	// VPERMPSZrrk
    890283375U,	// VPERMPSZrrkz
    1009032499U,	// VPERMQYmi
    283434291U,	// VPERMQYri
    1640275251U,	// VPERMQZ256mbi
    1733565747U,	// VPERMQZ256mbik
    1671814451U,	// VPERMQZ256mbikz
    1009032499U,	// VPERMQZ256mi
    649338163U,	// VPERMQZ256mik
    644209971U,	// VPERMQZ256mikz
    283434291U,	// VPERMQZ256ri
    1357585715U,	// VPERMQZ256rik
    1088822579U,	// VPERMQZ256rikz
    812866867U,	// VPERMQZ256rm
    360815923U,	// VPERMQZ256rmb
    1436048691U,	// VPERMQZ256rmbk
    1167383859U,	// VPERMQZ256rmbkz
    985128243U,	// VPERMQZ256rmk
    890608947U,	// VPERMQZ256rmkz
    811654451U,	// VPERMQZ256rr
    87055667U,	// VPERMQZ256rrk
    890281267U,	// VPERMQZ256rrkz
    2445581619U,	// VPERMQZmbi
    2538872115U,	// VPERMQZmbik
    2477120819U,	// VPERMQZmbikz
    1011129651U,	// VPERMQZmi
    655629619U,	// VPERMQZmik
    650501427U,	// VPERMQZmikz
    283434291U,	// VPERMQZri
    1357585715U,	// VPERMQZrik
    1088822579U,	// VPERMQZrikz
    812883251U,	// VPERMQZrm
    362913075U,	// VPERMQZrmb
    1438145843U,	// VPERMQZrmbk
    1169481011U,	// VPERMQZrmbkz
    985144627U,	// VPERMQZrmk
    890674483U,	// VPERMQZrmkz
    811654451U,	// VPERMQZrr
    87055667U,	// VPERMQZrrk
    890281267U,	// VPERMQZrrkz
    890569599U,	// VPERMT2B128rm
    985105279U,	// VPERMT2B128rmk
    985105279U,	// VPERMT2B128rmkz
    890274687U,	// VPERMT2B128rr
    87049087U,	// VPERMT2B128rrk
    89146239U,	// VPERMT2B128rrkz
    890602367U,	// VPERMT2B256rm
    985121663U,	// VPERMT2B256rmk
    985121663U,	// VPERMT2B256rmkz
    890274687U,	// VPERMT2B256rr
    87049087U,	// VPERMT2B256rrk
    89146239U,	// VPERMT2B256rrkz
    890667903U,	// VPERMT2Brm
    985138047U,	// VPERMT2Brmk
    985138047U,	// VPERMT2Brmkz
    890274687U,	// VPERMT2Brr
    87049087U,	// VPERMT2Brrk
    89146239U,	// VPERMT2Brrkz
    890570553U,	// VPERMT2D128rm
    1167476537U,	// VPERMT2D128rmb
    1436059449U,	// VPERMT2D128rmbk
    1436059449U,	// VPERMT2D128rmbkz
    985106233U,	// VPERMT2D128rmk
    985106233U,	// VPERMT2D128rmkz
    890275641U,	// VPERMT2D128rr
    87050041U,	// VPERMT2D128rrk
    89147193U,	// VPERMT2D128rrkz
    890603321U,	// VPERMT2D256rm
    1169573689U,	// VPERMT2D256rmb
    1438156601U,	// VPERMT2D256rmbk
    1438156601U,	// VPERMT2D256rmbkz
    985122617U,	// VPERMT2D256rmk
    985122617U,	// VPERMT2D256rmkz
    890275641U,	// VPERMT2D256rr
    87050041U,	// VPERMT2D256rrk
    89147193U,	// VPERMT2D256rrkz
    890668857U,	// VPERMT2Drm
    1171670841U,	// VPERMT2Drmb
    1440253753U,	// VPERMT2Drmbk
    1440253753U,	// VPERMT2Drmbkz
    985139001U,	// VPERMT2Drmk
    985139001U,	// VPERMT2Drmkz
    890275641U,	// VPERMT2Drr
    87050041U,	// VPERMT2Drrk
    89147193U,	// VPERMT2Drrkz
    890178069U,	// VPERMT2PD128rm
    1164970517U,	// VPERMT2PD128rmb
    1433389589U,	// VPERMT2PD128rmbk
    1433389589U,	// VPERMT2PD128rmbkz
    86985237U,	// VPERMT2PD128rmk
    89082389U,	// VPERMT2PD128rmkz
    890276373U,	// VPERMT2PD128rr
    87050773U,	// VPERMT2PD128rrk
    89147925U,	// VPERMT2PD128rrkz
    890309141U,	// VPERMT2PD256rm
    1167067669U,	// VPERMT2PD256rmb
    1435486741U,	// VPERMT2PD256rmbk
    1435486741U,	// VPERMT2PD256rmbkz
    87083541U,	// VPERMT2PD256rmk
    89180693U,	// VPERMT2PD256rmkz
    890276373U,	// VPERMT2PD256rr
    87050773U,	// VPERMT2PD256rrk
    89147925U,	// VPERMT2PD256rrkz
    890358293U,	// VPERMT2PDrm
    1169164821U,	// VPERMT2PDrmb
    1437583893U,	// VPERMT2PDrmbk
    1437583893U,	// VPERMT2PDrmbkz
    87132693U,	// VPERMT2PDrmk
    89229845U,	// VPERMT2PDrmkz
    890276373U,	// VPERMT2PDrr
    87050773U,	// VPERMT2PDrrk
    89147925U,	// VPERMT2PDrrkz
    890184474U,	// VPERMT2PS128rm
    1167270682U,	// VPERMT2PS128rmb
    1435689754U,	// VPERMT2PS128rmbk
    1435689754U,	// VPERMT2PS128rmbkz
    86991642U,	// VPERMT2PS128rmk
    89088794U,	// VPERMT2PS128rmkz
    890282778U,	// VPERMT2PS128rr
    87057178U,	// VPERMT2PS128rrk
    89154330U,	// VPERMT2PS128rrkz
    890315546U,	// VPERMT2PS256rm
    1169367834U,	// VPERMT2PS256rmb
    1437786906U,	// VPERMT2PS256rmbk
    1437786906U,	// VPERMT2PS256rmbkz
    87089946U,	// VPERMT2PS256rmk
    89187098U,	// VPERMT2PS256rmkz
    890282778U,	// VPERMT2PS256rr
    87057178U,	// VPERMT2PS256rrk
    89154330U,	// VPERMT2PS256rrkz
    890364698U,	// VPERMT2PSrm
    1171464986U,	// VPERMT2PSrmb
    1439884058U,	// VPERMT2PSrmbk
    1439884058U,	// VPERMT2PSrmbkz
    87139098U,	// VPERMT2PSrmk
    89236250U,	// VPERMT2PSrmkz
    890282778U,	// VPERMT2PSrr
    87057178U,	// VPERMT2PSrrk
    89154330U,	// VPERMT2PSrrkz
    890575196U,	// VPERMT2Q128rm
    1165285724U,	// VPERMT2Q128rmb
    1433950556U,	// VPERMT2Q128rmbk
    1433950556U,	// VPERMT2Q128rmbkz
    985110876U,	// VPERMT2Q128rmk
    985110876U,	// VPERMT2Q128rmkz
    890280284U,	// VPERMT2Q128rr
    87054684U,	// VPERMT2Q128rrk
    89151836U,	// VPERMT2Q128rrkz
    890607964U,	// VPERMT2Q256rm
    1167382876U,	// VPERMT2Q256rmb
    1436047708U,	// VPERMT2Q256rmbk
    1436047708U,	// VPERMT2Q256rmbkz
    985127260U,	// VPERMT2Q256rmk
    985127260U,	// VPERMT2Q256rmkz
    890280284U,	// VPERMT2Q256rr
    87054684U,	// VPERMT2Q256rrk
    89151836U,	// VPERMT2Q256rrkz
    890673500U,	// VPERMT2Qrm
    1169480028U,	// VPERMT2Qrmb
    1438144860U,	// VPERMT2Qrmbk
    1438144860U,	// VPERMT2Qrmbkz
    985143644U,	// VPERMT2Qrmk
    985143644U,	// VPERMT2Qrmkz
    890280284U,	// VPERMT2Qrr
    87054684U,	// VPERMT2Qrrk
    89151836U,	// VPERMT2Qrrkz
    890579501U,	// VPERMT2W128rm
    985115181U,	// VPERMT2W128rmk
    985115181U,	// VPERMT2W128rmkz
    890284589U,	// VPERMT2W128rr
    87058989U,	// VPERMT2W128rrk
    89156141U,	// VPERMT2W128rrkz
    890612269U,	// VPERMT2W256rm
    985131565U,	// VPERMT2W256rmk
    985131565U,	// VPERMT2W256rmkz
    890284589U,	// VPERMT2W256rr
    87058989U,	// VPERMT2W256rrk
    89156141U,	// VPERMT2W256rrkz
    890677805U,	// VPERMT2Wrm
    985147949U,	// VPERMT2Wrmk
    985147949U,	// VPERMT2Wrmkz
    890284589U,	// VPERMT2Wrr
    87058989U,	// VPERMT2Wrrk
    89156141U,	// VPERMT2Wrrkz
    811855051U,	// VPERMWZ128rm
    985115851U,	// VPERMWZ128rmk
    890580171U,	// VPERMWZ128rmkz
    811658443U,	// VPERMWZ128rr
    87059659U,	// VPERMWZ128rrk
    890285259U,	// VPERMWZ128rrkz
    812870859U,	// VPERMWZ256rm
    985132235U,	// VPERMWZ256rmk
    890612939U,	// VPERMWZ256rmkz
    811658443U,	// VPERMWZ256rr
    87059659U,	// VPERMWZ256rrk
    890285259U,	// VPERMWZ256rrkz
    812887243U,	// VPERMWZrm
    985148619U,	// VPERMWZrmk
    890678475U,	// VPERMWZrmkz
    811658443U,	// VPERMWZrr
    87059659U,	// VPERMWZrrk
    890285259U,	// VPERMWZrrkz
    263168U,	// VPEXPANDBZ128rm
    3230991360U,	// VPEXPANDBZ128rmk
    3229860864U,	// VPEXPANDBZ128rmkz
    551830528U,	// VPEXPANDBZ128rr
    3230696448U,	// VPEXPANDBZ128rrk
    3229664256U,	// VPEXPANDBZ128rrkz
    552944640U,	// VPEXPANDBZ256rm
    3231024128U,	// VPEXPANDBZ256rmk
    3230876672U,	// VPEXPANDBZ256rmkz
    551830528U,	// VPEXPANDBZ256rr
    3230696448U,	// VPEXPANDBZ256rrk
    3229664256U,	// VPEXPANDBZ256rrkz
    552436736U,	// VPEXPANDBZrm
    3231089664U,	// VPEXPANDBZrmk
    3230893056U,	// VPEXPANDBZrmkz
    551830528U,	// VPEXPANDBZrr
    3230696448U,	// VPEXPANDBZrrk
    3229664256U,	// VPEXPANDBZrrkz
    264156U,	// VPEXPANDDZ128rm
    3230992348U,	// VPEXPANDDZ128rmk
    3229861852U,	// VPEXPANDDZ128rmkz
    551831516U,	// VPEXPANDDZ128rr
    3230697436U,	// VPEXPANDDZ128rrk
    3229665244U,	// VPEXPANDDZ128rrkz
    552945628U,	// VPEXPANDDZ256rm
    3231025116U,	// VPEXPANDDZ256rmk
    3230877660U,	// VPEXPANDDZ256rmkz
    551831516U,	// VPEXPANDDZ256rr
    3230697436U,	// VPEXPANDDZ256rrk
    3229665244U,	// VPEXPANDDZ256rrkz
    552437724U,	// VPEXPANDDZrm
    3231090652U,	// VPEXPANDDZrmk
    3230894044U,	// VPEXPANDDZrmkz
    551831516U,	// VPEXPANDDZrr
    3230697436U,	// VPEXPANDDZrrk
    3229665244U,	// VPEXPANDDZrrkz
    269006U,	// VPEXPANDQZ128rm
    3230997198U,	// VPEXPANDQZ128rmk
    3229866702U,	// VPEXPANDQZ128rmkz
    551836366U,	// VPEXPANDQZ128rr
    3230702286U,	// VPEXPANDQZ128rrk
    3229670094U,	// VPEXPANDQZ128rrkz
    552950478U,	// VPEXPANDQZ256rm
    3231029966U,	// VPEXPANDQZ256rmk
    3230882510U,	// VPEXPANDQZ256rmkz
    551836366U,	// VPEXPANDQZ256rr
    3230702286U,	// VPEXPANDQZ256rrk
    3229670094U,	// VPEXPANDQZ256rrkz
    552442574U,	// VPEXPANDQZrm
    3231095502U,	// VPEXPANDQZrmk
    3230898894U,	// VPEXPANDQZrmkz
    551836366U,	// VPEXPANDQZrr
    3230702286U,	// VPEXPANDQZrrk
    3229670094U,	// VPEXPANDQZrrkz
    273240U,	// VPEXPANDWZ128rm
    3231001432U,	// VPEXPANDWZ128rmk
    3229870936U,	// VPEXPANDWZ128rmkz
    551840600U,	// VPEXPANDWZ128rr
    3230706520U,	// VPEXPANDWZ128rrk
    3229674328U,	// VPEXPANDWZ128rrkz
    552954712U,	// VPEXPANDWZ256rm
    3231034200U,	// VPEXPANDWZ256rmk
    3230886744U,	// VPEXPANDWZ256rmkz
    551840600U,	// VPEXPANDWZ256rr
    3230706520U,	// VPEXPANDWZ256rrk
    3229674328U,	// VPEXPANDWZ256rrkz
    552446808U,	// VPEXPANDWZrm
    3231099736U,	// VPEXPANDWZrmk
    3230903128U,	// VPEXPANDWZrmkz
    551840600U,	// VPEXPANDWZrr
    3230706520U,	// VPEXPANDWZrrk
    3229674328U,	// VPEXPANDWZrrkz
    321160592U,	// VPEXTRBZmr
    283428240U,	// VPEXTRBZrr
    321160592U,	// VPEXTRBmr
    283428240U,	// VPEXTRBrr
    589598179U,	// VPEXTRDZmr
    283430371U,	// VPEXTRDZrr
    589598179U,	// VPEXTRDmr
    283430371U,	// VPEXTRDrr
    858037936U,	// VPEXTRQZmr
    283434672U,	// VPEXTRQZrr
    858037936U,	// VPEXTRQmr
    283434672U,	// VPEXTRQrr
    1126477261U,	// VPEXTRWZmr
    283438541U,	// VPEXTRWZrr
    283438541U,	// VPEXTRWZrr_REV
    1126477261U,	// VPEXTRWmr
    283438541U,	// VPEXTRWrr
    283438541U,	// VPEXTRWrr_REV
    649545713U,	// VPGATHERDDYrm
    3231156209U,	// VPGATHERDDZ128rm
    3231172593U,	// VPGATHERDDZ256rm
    3231188977U,	// VPGATHERDDZrm
    643254257U,	// VPGATHERDDrm
    649550613U,	// VPGATHERDQYrm
    3231161109U,	// VPGATHERDQZ128rm
    3231177493U,	// VPGATHERDQZ256rm
    3231193877U,	// VPGATHERDQZrm
    643259157U,	// VPGATHERDQrm
    643255661U,	// VPGATHERQDYrm
    553143661U,	// VPGATHERQDZ128rm
    3231157613U,	// VPGATHERQDZ256rm
    3231173997U,	// VPGATHERQDZrm
    928468333U,	// VPGATHERQDrm
    649551341U,	// VPGATHERQQYrm
    3231161837U,	// VPGATHERQQZ128rm
    3231178221U,	// VPGATHERQQZ256rm
    3231194605U,	// VPGATHERQQZrm
    643259885U,	// VPGATHERQQrm
    264041U,	// VPHADDBDrm
    551831401U,	// VPHADDBDrr
    268682U,	// VPHADDBQrm
    551836042U,	// VPHADDBQrr
    273027U,	// VPHADDBWrm
    551840387U,	// VPHADDBWrr
    268902U,	// VPHADDDQrm
    551836262U,	// VPHADDDQrr
    812861356U,	// VPHADDDYrm
    811648940U,	// VPHADDDYrr
    811845548U,	// VPHADDDrm
    811648940U,	// VPHADDDrr
    812871181U,	// VPHADDSWYrm
    811658765U,	// VPHADDSWYrr
    811855373U,	// VPHADDSWrm
    811658765U,	// VPHADDSWrr
    264051U,	// VPHADDUBDrm
    551831411U,	// VPHADDUBDrr
    268700U,	// VPHADDUBQrm
    551836060U,	// VPHADDUBQrr
    273079U,	// VPHADDUBWrm
    551840439U,	// VPHADDUBWrr
    269196U,	// VPHADDUDQrm
    551836556U,	// VPHADDUDQrr
    266597U,	// VPHADDUWDrm
    551833957U,	// VPHADDUWDrr
    270507U,	// VPHADDUWQrm
    551837867U,	// VPHADDUWQrr
    266499U,	// VPHADDWDrm
    551833859U,	// VPHADDWDrr
    270482U,	// VPHADDWQrm
    551837842U,	// VPHADDWQrr
    812870432U,	// VPHADDWYrm
    811658016U,	// VPHADDWYrr
    811854624U,	// VPHADDWrm
    811658016U,	// VPHADDWrr
    274270U,	// VPHMINPOSUWrm
    551841630U,	// VPHMINPOSUWrr
    272987U,	// VPHSUBBWrm
    551840347U,	// VPHSUBBWrr
    268870U,	// VPHSUBDQrm
    551836230U,	// VPHSUBDQrr
    812861310U,	// VPHSUBDYrm
    811648894U,	// VPHSUBDYrr
    811845502U,	// VPHSUBDrm
    811648894U,	// VPHSUBDrr
    812871162U,	// VPHSUBSWYrm
    811658746U,	// VPHSUBSWYrr
    811855354U,	// VPHSUBSWrm
    811658746U,	// VPHSUBSWrr
    266489U,	// VPHSUBWDrm
    551833849U,	// VPHSUBWDrr
    812870338U,	// VPHSUBWYrm
    811657922U,	// VPHSUBWYrr
    811854530U,	// VPHSUBWrm
    811657922U,	// VPHSUBWrr
    879084925U,	// VPINSRBZrm
    1088816509U,	// VPINSRBZrr
    879084925U,	// VPINSRBrm
    1088816509U,	// VPINSRBrr
    881184208U,	// VPINSRDZrm
    1088818640U,	// VPINSRDZrr
    881184208U,	// VPINSRDrm
    1088818640U,	// VPINSRDrr
    866508425U,	// VPINSRQZrm
    1088822921U,	// VPINSRQZrr
    866508425U,	// VPINSRQrm
    1088822921U,	// VPINSRQrr
    331738536U,	// VPINSRWZrm
    1088826792U,	// VPINSRWZrr
    331738536U,	// VPINSRWrm
    1088826792U,	// VPINSRWrr
    266312U,	// VPLZCNTDZ128rm
    629493832U,	// VPLZCNTDZ128rmb
    630607944U,	// VPLZCNTDZ128rmbk
    629231688U,	// VPLZCNTDZ128rmbkz
    3230994504U,	// VPLZCNTDZ128rmk
    3229864008U,	// VPLZCNTDZ128rmkz
    551833672U,	// VPLZCNTDZ128rr
    3230699592U,	// VPLZCNTDZ128rrk
    3229667400U,	// VPLZCNTDZ128rrkz
    552947784U,	// VPLZCNTDZ256rm
    631590984U,	// VPLZCNTDZ256rmb
    632705096U,	// VPLZCNTDZ256rmbk
    631328840U,	// VPLZCNTDZ256rmbkz
    3231027272U,	// VPLZCNTDZ256rmk
    3230879816U,	// VPLZCNTDZ256rmkz
    551833672U,	// VPLZCNTDZ256rr
    3230699592U,	// VPLZCNTDZ256rrk
    3229667400U,	// VPLZCNTDZ256rrkz
    552439880U,	// VPLZCNTDZrm
    633688136U,	// VPLZCNTDZrmb
    634802248U,	// VPLZCNTDZrmbk
    633425992U,	// VPLZCNTDZrmbkz
    3231092808U,	// VPLZCNTDZrmk
    3230896200U,	// VPLZCNTDZrmkz
    551833672U,	// VPLZCNTDZrr
    3230699592U,	// VPLZCNTDZrrk
    3229667400U,	// VPLZCNTDZrrkz
    270240U,	// VPLZCNTQZ128rm
    627416992U,	// VPLZCNTQZ128rmb
    628416416U,	// VPLZCNTQZ128rmbk
    627154848U,	// VPLZCNTQZ128rmbkz
    3230998432U,	// VPLZCNTQZ128rmk
    3229867936U,	// VPLZCNTQZ128rmkz
    551837600U,	// VPLZCNTQZ128rr
    3230703520U,	// VPLZCNTQZ128rrk
    3229671328U,	// VPLZCNTQZ128rrkz
    552951712U,	// VPLZCNTQZ256rm
    629514144U,	// VPLZCNTQZ256rmb
    630513568U,	// VPLZCNTQZ256rmbk
    629252000U,	// VPLZCNTQZ256rmbkz
    3231031200U,	// VPLZCNTQZ256rmk
    3230883744U,	// VPLZCNTQZ256rmkz
    551837600U,	// VPLZCNTQZ256rr
    3230703520U,	// VPLZCNTQZ256rrk
    3229671328U,	// VPLZCNTQZ256rrkz
    552443808U,	// VPLZCNTQZrm
    631611296U,	// VPLZCNTQZrmb
    632610720U,	// VPLZCNTQZrmbk
    631349152U,	// VPLZCNTQZrmbkz
    3231096736U,	// VPLZCNTQZrmk
    3230900128U,	// VPLZCNTQZrmkz
    551837600U,	// VPLZCNTQZrr
    3230703520U,	// VPLZCNTQZrrk
    3229671328U,	// VPLZCNTQZrrkz
    326387731U,	// VPMACSDDrm
    890275859U,	// VPMACSDDrr
    326390377U,	// VPMACSDQHrm
    890278505U,	// VPMACSDQHrr
    326391321U,	// VPMACSDQLrm
    890279449U,	// VPMACSDQLrr
    326387741U,	// VPMACSSDDrm
    890275869U,	// VPMACSSDDrr
    326390388U,	// VPMACSSDQHrm
    890278516U,	// VPMACSSDQHrr
    326391332U,	// VPMACSSDQLrm
    890279460U,	// VPMACSSDQLrr
    326390094U,	// VPMACSSWDrm
    890278222U,	// VPMACSSWDrr
    326397897U,	// VPMACSSWWrm
    890286025U,	// VPMACSSWWrr
    326390073U,	// VPMACSWDrm
    890278201U,	// VPMACSWDrr
    326397873U,	// VPMACSWWrm
    890286001U,	// VPMACSWWrr
    326390105U,	// VPMADCSSWDrm
    890278233U,	// VPMADCSSWDrr
    326390083U,	// VPMADCSWDrm
    890278211U,	// VPMADCSWDrr
    890576889U,	// VPMADD52HUQZ128m
    1165287417U,	// VPMADD52HUQZ128mb
    1433952249U,	// VPMADD52HUQZ128mbk
    1433952249U,	// VPMADD52HUQZ128mbkz
    985112569U,	// VPMADD52HUQZ128mk
    985112569U,	// VPMADD52HUQZ128mkz
    890281977U,	// VPMADD52HUQZ128r
    87056377U,	// VPMADD52HUQZ128rk
    89153529U,	// VPMADD52HUQZ128rkz
    890609657U,	// VPMADD52HUQZ256m
    1167384569U,	// VPMADD52HUQZ256mb
    1436049401U,	// VPMADD52HUQZ256mbk
    1436049401U,	// VPMADD52HUQZ256mbkz
    985128953U,	// VPMADD52HUQZ256mk
    985128953U,	// VPMADD52HUQZ256mkz
    890281977U,	// VPMADD52HUQZ256r
    87056377U,	// VPMADD52HUQZ256rk
    89153529U,	// VPMADD52HUQZ256rkz
    890675193U,	// VPMADD52HUQZm
    1169481721U,	// VPMADD52HUQZmb
    1438146553U,	// VPMADD52HUQZmbk
    1438146553U,	// VPMADD52HUQZmbkz
    985145337U,	// VPMADD52HUQZmk
    985145337U,	// VPMADD52HUQZmkz
    890281977U,	// VPMADD52HUQZr
    87056377U,	// VPMADD52HUQZrk
    89153529U,	// VPMADD52HUQZrkz
    890576902U,	// VPMADD52LUQZ128m
    1165287430U,	// VPMADD52LUQZ128mb
    1433952262U,	// VPMADD52LUQZ128mbk
    1433952262U,	// VPMADD52LUQZ128mbkz
    985112582U,	// VPMADD52LUQZ128mk
    985112582U,	// VPMADD52LUQZ128mkz
    890281990U,	// VPMADD52LUQZ128r
    87056390U,	// VPMADD52LUQZ128rk
    89153542U,	// VPMADD52LUQZ128rkz
    890609670U,	// VPMADD52LUQZ256m
    1167384582U,	// VPMADD52LUQZ256mb
    1436049414U,	// VPMADD52LUQZ256mbk
    1436049414U,	// VPMADD52LUQZ256mbkz
    985128966U,	// VPMADD52LUQZ256mk
    985128966U,	// VPMADD52LUQZ256mkz
    890281990U,	// VPMADD52LUQZ256r
    87056390U,	// VPMADD52LUQZ256rk
    89153542U,	// VPMADD52LUQZ256rkz
    890675206U,	// VPMADD52LUQZm
    1169481734U,	// VPMADD52LUQZmb
    1438146566U,	// VPMADD52LUQZmbk
    1438146566U,	// VPMADD52LUQZmbkz
    985145350U,	// VPMADD52LUQZmk
    985145350U,	// VPMADD52LUQZmkz
    890281990U,	// VPMADD52LUQZr
    87056390U,	// VPMADD52LUQZrk
    89153542U,	// VPMADD52LUQZrkz
    812871150U,	// VPMADDUBSWYrm
    811658734U,	// VPMADDUBSWYrr
    811855342U,	// VPMADDUBSWZ128rm
    985116142U,	// VPMADDUBSWZ128rmk
    890580462U,	// VPMADDUBSWZ128rmkz
    811658734U,	// VPMADDUBSWZ128rr
    87059950U,	// VPMADDUBSWZ128rrk
    890285550U,	// VPMADDUBSWZ128rrkz
    812871150U,	// VPMADDUBSWZ256rm
    985132526U,	// VPMADDUBSWZ256rmk
    890613230U,	// VPMADDUBSWZ256rmkz
    811658734U,	// VPMADDUBSWZ256rr
    87059950U,	// VPMADDUBSWZ256rrk
    890285550U,	// VPMADDUBSWZ256rrkz
    812887534U,	// VPMADDUBSWZrm
    985148910U,	// VPMADDUBSWZrmk
    890678766U,	// VPMADDUBSWZrmkz
    811658734U,	// VPMADDUBSWZrr
    87059950U,	// VPMADDUBSWZrrk
    890285550U,	// VPMADDUBSWZrrkz
    811855342U,	// VPMADDUBSWrm
    811658734U,	// VPMADDUBSWrr
    812863757U,	// VPMADDWDYrm
    811651341U,	// VPMADDWDYrr
    811847949U,	// VPMADDWDZ128rm
    985108749U,	// VPMADDWDZ128rmk
    890573069U,	// VPMADDWDZ128rmkz
    811651341U,	// VPMADDWDZ128rr
    87052557U,	// VPMADDWDZ128rrk
    890278157U,	// VPMADDWDZ128rrkz
    812863757U,	// VPMADDWDZ256rm
    985125133U,	// VPMADDWDZ256rmk
    890605837U,	// VPMADDWDZ256rmkz
    811651341U,	// VPMADDWDZ256rr
    87052557U,	// VPMADDWDZ256rrk
    890278157U,	// VPMADDWDZ256rrkz
    812880141U,	// VPMADDWDZrm
    985141517U,	// VPMADDWDZrmk
    890671373U,	// VPMADDWDZrmkz
    811651341U,	// VPMADDWDZrr
    87052557U,	// VPMADDWDZrrk
    890278157U,	// VPMADDWDZrrkz
    811847949U,	// VPMADDWDrm
    811651341U,	// VPMADDWDrr
    2200244445U,	// VPMASKMOVDYmr
    812863709U,	// VPMASKMOVDYrm
    1931808989U,	// VPMASKMOVDmr
    811847901U,	// VPMASKMOVDrm
    2200248438U,	// VPMASKMOVQYmr
    812867702U,	// VPMASKMOVQYrm
    1931812982U,	// VPMASKMOVQmr
    811851894U,	// VPMASKMOVQrm
    812860946U,	// VPMAXSBYrm
    811648530U,	// VPMAXSBYrr
    811845138U,	// VPMAXSBZ128rm
    985105938U,	// VPMAXSBZ128rmk
    890570258U,	// VPMAXSBZ128rmkz
    811648530U,	// VPMAXSBZ128rr
    87049746U,	// VPMAXSBZ128rrk
    890275346U,	// VPMAXSBZ128rrkz
    812860946U,	// VPMAXSBZ256rm
    985122322U,	// VPMAXSBZ256rmk
    890603026U,	// VPMAXSBZ256rmkz
    811648530U,	// VPMAXSBZ256rr
    87049746U,	// VPMAXSBZ256rrk
    890275346U,	// VPMAXSBZ256rrkz
    812877330U,	// VPMAXSBZrm
    985138706U,	// VPMAXSBZrmk
    890668562U,	// VPMAXSBZrmkz
    811648530U,	// VPMAXSBZrr
    87049746U,	// VPMAXSBZrrk
    890275346U,	// VPMAXSBZrrkz
    811845138U,	// VPMAXSBrm
    811648530U,	// VPMAXSBrr
    812863501U,	// VPMAXSDYrm
    811651085U,	// VPMAXSDYrr
    811847693U,	// VPMAXSDZ128rm
    360796173U,	// VPMAXSDZ128rmb
    1436061709U,	// VPMAXSDZ128rmbk
    1167478797U,	// VPMAXSDZ128rmbkz
    985108493U,	// VPMAXSDZ128rmk
    890572813U,	// VPMAXSDZ128rmkz
    811651085U,	// VPMAXSDZ128rr
    87052301U,	// VPMAXSDZ128rrk
    890277901U,	// VPMAXSDZ128rrkz
    812863501U,	// VPMAXSDZ256rm
    362893325U,	// VPMAXSDZ256rmb
    1438158861U,	// VPMAXSDZ256rmbk
    1169575949U,	// VPMAXSDZ256rmbkz
    985124877U,	// VPMAXSDZ256rmk
    890605581U,	// VPMAXSDZ256rmkz
    811651085U,	// VPMAXSDZ256rr
    87052301U,	// VPMAXSDZ256rrk
    890277901U,	// VPMAXSDZ256rrkz
    812879885U,	// VPMAXSDZrm
    364990477U,	// VPMAXSDZrmb
    1440256013U,	// VPMAXSDZrmbk
    1171673101U,	// VPMAXSDZrmbkz
    985141261U,	// VPMAXSDZrmk
    890671117U,	// VPMAXSDZrmkz
    811651085U,	// VPMAXSDZrr
    87052301U,	// VPMAXSDZrrk
    890277901U,	// VPMAXSDZrrkz
    811847693U,	// VPMAXSDrm
    811651085U,	// VPMAXSDrr
    811851591U,	// VPMAXSQZ128rm
    358719303U,	// VPMAXSQZ128rmb
    1433952071U,	// VPMAXSQZ128rmbk
    1165287239U,	// VPMAXSQZ128rmbkz
    985112391U,	// VPMAXSQZ128rmk
    890576711U,	// VPMAXSQZ128rmkz
    811654983U,	// VPMAXSQZ128rr
    87056199U,	// VPMAXSQZ128rrk
    890281799U,	// VPMAXSQZ128rrkz
    812867399U,	// VPMAXSQZ256rm
    360816455U,	// VPMAXSQZ256rmb
    1436049223U,	// VPMAXSQZ256rmbk
    1167384391U,	// VPMAXSQZ256rmbkz
    985128775U,	// VPMAXSQZ256rmk
    890609479U,	// VPMAXSQZ256rmkz
    811654983U,	// VPMAXSQZ256rr
    87056199U,	// VPMAXSQZ256rrk
    890281799U,	// VPMAXSQZ256rrkz
    812883783U,	// VPMAXSQZrm
    362913607U,	// VPMAXSQZrmb
    1438146375U,	// VPMAXSQZrmbk
    1169481543U,	// VPMAXSQZrmbkz
    985145159U,	// VPMAXSQZrmk
    890675015U,	// VPMAXSQZrmkz
    811654983U,	// VPMAXSQZrr
    87056199U,	// VPMAXSQZrrk
    890281799U,	// VPMAXSQZrrkz
    812871335U,	// VPMAXSWYrm
    811658919U,	// VPMAXSWYrr
    811855527U,	// VPMAXSWZ128rm
    985116327U,	// VPMAXSWZ128rmk
    890580647U,	// VPMAXSWZ128rmkz
    811658919U,	// VPMAXSWZ128rr
    87060135U,	// VPMAXSWZ128rrk
    890285735U,	// VPMAXSWZ128rrkz
    812871335U,	// VPMAXSWZ256rm
    985132711U,	// VPMAXSWZ256rmk
    890613415U,	// VPMAXSWZ256rmkz
    811658919U,	// VPMAXSWZ256rr
    87060135U,	// VPMAXSWZ256rrk
    890285735U,	// VPMAXSWZ256rrkz
    812887719U,	// VPMAXSWZrm
    985149095U,	// VPMAXSWZrmk
    890678951U,	// VPMAXSWZrmkz
    811658919U,	// VPMAXSWZrr
    87060135U,	// VPMAXSWZrrk
    890285735U,	// VPMAXSWZrrkz
    811855527U,	// VPMAXSWrm
    811658919U,	// VPMAXSWrr
    812861062U,	// VPMAXUBYrm
    811648646U,	// VPMAXUBYrr
    811845254U,	// VPMAXUBZ128rm
    985106054U,	// VPMAXUBZ128rmk
    890570374U,	// VPMAXUBZ128rmkz
    811648646U,	// VPMAXUBZ128rr
    87049862U,	// VPMAXUBZ128rrk
    890275462U,	// VPMAXUBZ128rrkz
    812861062U,	// VPMAXUBZ256rm
    985122438U,	// VPMAXUBZ256rmk
    890603142U,	// VPMAXUBZ256rmkz
    811648646U,	// VPMAXUBZ256rr
    87049862U,	// VPMAXUBZ256rrk
    890275462U,	// VPMAXUBZ256rrkz
    812877446U,	// VPMAXUBZrm
    985138822U,	// VPMAXUBZrmk
    890668678U,	// VPMAXUBZrmkz
    811648646U,	// VPMAXUBZrr
    87049862U,	// VPMAXUBZrrk
    890275462U,	// VPMAXUBZrrkz
    811845254U,	// VPMAXUBrm
    811648646U,	// VPMAXUBrr
    812863644U,	// VPMAXUDYrm
    811651228U,	// VPMAXUDYrr
    811847836U,	// VPMAXUDZ128rm
    360796316U,	// VPMAXUDZ128rmb
    1436061852U,	// VPMAXUDZ128rmbk
    1167478940U,	// VPMAXUDZ128rmbkz
    985108636U,	// VPMAXUDZ128rmk
    890572956U,	// VPMAXUDZ128rmkz
    811651228U,	// VPMAXUDZ128rr
    87052444U,	// VPMAXUDZ128rrk
    890278044U,	// VPMAXUDZ128rrkz
    812863644U,	// VPMAXUDZ256rm
    362893468U,	// VPMAXUDZ256rmb
    1438159004U,	// VPMAXUDZ256rmbk
    1169576092U,	// VPMAXUDZ256rmbkz
    985125020U,	// VPMAXUDZ256rmk
    890605724U,	// VPMAXUDZ256rmkz
    811651228U,	// VPMAXUDZ256rr
    87052444U,	// VPMAXUDZ256rrk
    890278044U,	// VPMAXUDZ256rrkz
    812880028U,	// VPMAXUDZrm
    364990620U,	// VPMAXUDZrmb
    1440256156U,	// VPMAXUDZrmbk
    1171673244U,	// VPMAXUDZrmbkz
    985141404U,	// VPMAXUDZrmk
    890671260U,	// VPMAXUDZrmkz
    811651228U,	// VPMAXUDZrr
    87052444U,	// VPMAXUDZrrk
    890278044U,	// VPMAXUDZrrkz
    811847836U,	// VPMAXUDrm
    811651228U,	// VPMAXUDrr
    811851822U,	// VPMAXUQZ128rm
    358719534U,	// VPMAXUQZ128rmb
    1433952302U,	// VPMAXUQZ128rmbk
    1165287470U,	// VPMAXUQZ128rmbkz
    985112622U,	// VPMAXUQZ128rmk
    890576942U,	// VPMAXUQZ128rmkz
    811655214U,	// VPMAXUQZ128rr
    87056430U,	// VPMAXUQZ128rrk
    890282030U,	// VPMAXUQZ128rrkz
    812867630U,	// VPMAXUQZ256rm
    360816686U,	// VPMAXUQZ256rmb
    1436049454U,	// VPMAXUQZ256rmbk
    1167384622U,	// VPMAXUQZ256rmbkz
    985129006U,	// VPMAXUQZ256rmk
    890609710U,	// VPMAXUQZ256rmkz
    811655214U,	// VPMAXUQZ256rr
    87056430U,	// VPMAXUQZ256rrk
    890282030U,	// VPMAXUQZ256rrkz
    812884014U,	// VPMAXUQZrm
    362913838U,	// VPMAXUQZrmb
    1438146606U,	// VPMAXUQZrmbk
    1169481774U,	// VPMAXUQZrmbkz
    985145390U,	// VPMAXUQZrmk
    890675246U,	// VPMAXUQZrmkz
    811655214U,	// VPMAXUQZrr
    87056430U,	// VPMAXUQZrrk
    890282030U,	// VPMAXUQZrrkz
    812871531U,	// VPMAXUWYrm
    811659115U,	// VPMAXUWYrr
    811855723U,	// VPMAXUWZ128rm
    985116523U,	// VPMAXUWZ128rmk
    890580843U,	// VPMAXUWZ128rmkz
    811659115U,	// VPMAXUWZ128rr
    87060331U,	// VPMAXUWZ128rrk
    890285931U,	// VPMAXUWZ128rrkz
    812871531U,	// VPMAXUWZ256rm
    985132907U,	// VPMAXUWZ256rmk
    890613611U,	// VPMAXUWZ256rmkz
    811659115U,	// VPMAXUWZ256rr
    87060331U,	// VPMAXUWZ256rrk
    890285931U,	// VPMAXUWZ256rrkz
    812887915U,	// VPMAXUWZrm
    985149291U,	// VPMAXUWZrmk
    890679147U,	// VPMAXUWZrmkz
    811659115U,	// VPMAXUWZrr
    87060331U,	// VPMAXUWZrrk
    890285931U,	// VPMAXUWZrrkz
    811855723U,	// VPMAXUWrm
    811659115U,	// VPMAXUWrr
    812860874U,	// VPMINSBYrm
    811648458U,	// VPMINSBYrr
    811845066U,	// VPMINSBZ128rm
    985105866U,	// VPMINSBZ128rmk
    890570186U,	// VPMINSBZ128rmkz
    811648458U,	// VPMINSBZ128rr
    87049674U,	// VPMINSBZ128rrk
    890275274U,	// VPMINSBZ128rrkz
    812860874U,	// VPMINSBZ256rm
    985122250U,	// VPMINSBZ256rmk
    890602954U,	// VPMINSBZ256rmkz
    811648458U,	// VPMINSBZ256rr
    87049674U,	// VPMINSBZ256rrk
    890275274U,	// VPMINSBZ256rrkz
    812877258U,	// VPMINSBZrm
    985138634U,	// VPMINSBZrmk
    890668490U,	// VPMINSBZrmkz
    811648458U,	// VPMINSBZrr
    87049674U,	// VPMINSBZrrk
    890275274U,	// VPMINSBZrrkz
    811845066U,	// VPMINSBrm
    811648458U,	// VPMINSBrr
    812863334U,	// VPMINSDYrm
    811650918U,	// VPMINSDYrr
    811847526U,	// VPMINSDZ128rm
    360796006U,	// VPMINSDZ128rmb
    1436061542U,	// VPMINSDZ128rmbk
    1167478630U,	// VPMINSDZ128rmbkz
    985108326U,	// VPMINSDZ128rmk
    890572646U,	// VPMINSDZ128rmkz
    811650918U,	// VPMINSDZ128rr
    87052134U,	// VPMINSDZ128rrk
    890277734U,	// VPMINSDZ128rrkz
    812863334U,	// VPMINSDZ256rm
    362893158U,	// VPMINSDZ256rmb
    1438158694U,	// VPMINSDZ256rmbk
    1169575782U,	// VPMINSDZ256rmbkz
    985124710U,	// VPMINSDZ256rmk
    890605414U,	// VPMINSDZ256rmkz
    811650918U,	// VPMINSDZ256rr
    87052134U,	// VPMINSDZ256rrk
    890277734U,	// VPMINSDZ256rrkz
    812879718U,	// VPMINSDZrm
    364990310U,	// VPMINSDZrmb
    1440255846U,	// VPMINSDZrmbk
    1171672934U,	// VPMINSDZrmbkz
    985141094U,	// VPMINSDZrmk
    890670950U,	// VPMINSDZrmkz
    811650918U,	// VPMINSDZrr
    87052134U,	// VPMINSDZrrk
    890277734U,	// VPMINSDZrrkz
    811847526U,	// VPMINSDrm
    811650918U,	// VPMINSDrr
    811851493U,	// VPMINSQZ128rm
    358719205U,	// VPMINSQZ128rmb
    1433951973U,	// VPMINSQZ128rmbk
    1165287141U,	// VPMINSQZ128rmbkz
    985112293U,	// VPMINSQZ128rmk
    890576613U,	// VPMINSQZ128rmkz
    811654885U,	// VPMINSQZ128rr
    87056101U,	// VPMINSQZ128rrk
    890281701U,	// VPMINSQZ128rrkz
    812867301U,	// VPMINSQZ256rm
    360816357U,	// VPMINSQZ256rmb
    1436049125U,	// VPMINSQZ256rmbk
    1167384293U,	// VPMINSQZ256rmbkz
    985128677U,	// VPMINSQZ256rmk
    890609381U,	// VPMINSQZ256rmkz
    811654885U,	// VPMINSQZ256rr
    87056101U,	// VPMINSQZ256rrk
    890281701U,	// VPMINSQZ256rrkz
    812883685U,	// VPMINSQZrm
    362913509U,	// VPMINSQZrmb
    1438146277U,	// VPMINSQZrmbk
    1169481445U,	// VPMINSQZrmbkz
    985145061U,	// VPMINSQZrmk
    890674917U,	// VPMINSQZrmkz
    811654885U,	// VPMINSQZrr
    87056101U,	// VPMINSQZrrk
    890281701U,	// VPMINSQZrrkz
    812871231U,	// VPMINSWYrm
    811658815U,	// VPMINSWYrr
    811855423U,	// VPMINSWZ128rm
    985116223U,	// VPMINSWZ128rmk
    890580543U,	// VPMINSWZ128rmkz
    811658815U,	// VPMINSWZ128rr
    87060031U,	// VPMINSWZ128rrk
    890285631U,	// VPMINSWZ128rrkz
    812871231U,	// VPMINSWZ256rm
    985132607U,	// VPMINSWZ256rmk
    890613311U,	// VPMINSWZ256rmkz
    811658815U,	// VPMINSWZ256rr
    87060031U,	// VPMINSWZ256rrk
    890285631U,	// VPMINSWZ256rrkz
    812887615U,	// VPMINSWZrm
    985148991U,	// VPMINSWZrmk
    890678847U,	// VPMINSWZrmkz
    811658815U,	// VPMINSWZrr
    87060031U,	// VPMINSWZrrk
    890285631U,	// VPMINSWZrrkz
    811855423U,	// VPMINSWrm
    811658815U,	// VPMINSWrr
    812861037U,	// VPMINUBYrm
    811648621U,	// VPMINUBYrr
    811845229U,	// VPMINUBZ128rm
    985106029U,	// VPMINUBZ128rmk
    890570349U,	// VPMINUBZ128rmkz
    811648621U,	// VPMINUBZ128rr
    87049837U,	// VPMINUBZ128rrk
    890275437U,	// VPMINUBZ128rrkz
    812861037U,	// VPMINUBZ256rm
    985122413U,	// VPMINUBZ256rmk
    890603117U,	// VPMINUBZ256rmkz
    811648621U,	// VPMINUBZ256rr
    87049837U,	// VPMINUBZ256rrk
    890275437U,	// VPMINUBZ256rrkz
    812877421U,	// VPMINUBZrm
    985138797U,	// VPMINUBZrmk
    890668653U,	// VPMINUBZrmkz
    811648621U,	// VPMINUBZrr
    87049837U,	// VPMINUBZrrk
    890275437U,	// VPMINUBZrrkz
    811845229U,	// VPMINUBrm
    811648621U,	// VPMINUBrr
    812863626U,	// VPMINUDYrm
    811651210U,	// VPMINUDYrr
    811847818U,	// VPMINUDZ128rm
    360796298U,	// VPMINUDZ128rmb
    1436061834U,	// VPMINUDZ128rmbk
    1167478922U,	// VPMINUDZ128rmbkz
    985108618U,	// VPMINUDZ128rmk
    890572938U,	// VPMINUDZ128rmkz
    811651210U,	// VPMINUDZ128rr
    87052426U,	// VPMINUDZ128rrk
    890278026U,	// VPMINUDZ128rrkz
    812863626U,	// VPMINUDZ256rm
    362893450U,	// VPMINUDZ256rmb
    1438158986U,	// VPMINUDZ256rmbk
    1169576074U,	// VPMINUDZ256rmbkz
    985125002U,	// VPMINUDZ256rmk
    890605706U,	// VPMINUDZ256rmkz
    811651210U,	// VPMINUDZ256rr
    87052426U,	// VPMINUDZ256rrk
    890278026U,	// VPMINUDZ256rrkz
    812880010U,	// VPMINUDZrm
    364990602U,	// VPMINUDZrmb
    1440256138U,	// VPMINUDZrmbk
    1171673226U,	// VPMINUDZrmbkz
    985141386U,	// VPMINUDZrmk
    890671242U,	// VPMINUDZrmkz
    811651210U,	// VPMINUDZrr
    87052426U,	// VPMINUDZrrk
    890278026U,	// VPMINUDZrrkz
    811847818U,	// VPMINUDrm
    811651210U,	// VPMINUDrr
    811851804U,	// VPMINUQZ128rm
    358719516U,	// VPMINUQZ128rmb
    1433952284U,	// VPMINUQZ128rmbk
    1165287452U,	// VPMINUQZ128rmbkz
    985112604U,	// VPMINUQZ128rmk
    890576924U,	// VPMINUQZ128rmkz
    811655196U,	// VPMINUQZ128rr
    87056412U,	// VPMINUQZ128rrk
    890282012U,	// VPMINUQZ128rrkz
    812867612U,	// VPMINUQZ256rm
    360816668U,	// VPMINUQZ256rmb
    1436049436U,	// VPMINUQZ256rmbk
    1167384604U,	// VPMINUQZ256rmbkz
    985128988U,	// VPMINUQZ256rmk
    890609692U,	// VPMINUQZ256rmkz
    811655196U,	// VPMINUQZ256rr
    87056412U,	// VPMINUQZ256rrk
    890282012U,	// VPMINUQZ256rrkz
    812883996U,	// VPMINUQZrm
    362913820U,	// VPMINUQZrmb
    1438146588U,	// VPMINUQZrmbk
    1169481756U,	// VPMINUQZrmbkz
    985145372U,	// VPMINUQZrmk
    890675228U,	// VPMINUQZrmkz
    811655196U,	// VPMINUQZrr
    87056412U,	// VPMINUQZrrk
    890282012U,	// VPMINUQZrrkz
    812871500U,	// VPMINUWYrm
    811659084U,	// VPMINUWYrr
    811855692U,	// VPMINUWZ128rm
    985116492U,	// VPMINUWZ128rmk
    890580812U,	// VPMINUWZ128rmkz
    811659084U,	// VPMINUWZ128rr
    87060300U,	// VPMINUWZ128rrk
    890285900U,	// VPMINUWZ128rrkz
    812871500U,	// VPMINUWZ256rm
    985132876U,	// VPMINUWZ256rmk
    890613580U,	// VPMINUWZ256rmkz
    811659084U,	// VPMINUWZ256rr
    87060300U,	// VPMINUWZ256rrk
    890285900U,	// VPMINUWZ256rrkz
    812887884U,	// VPMINUWZrm
    985149260U,	// VPMINUWZrmk
    890679116U,	// VPMINUWZrmkz
    811659084U,	// VPMINUWZrr
    87060300U,	// VPMINUWZrrk
    890285900U,	// VPMINUWZrrkz
    811855692U,	// VPMINUWrm
    811659084U,	// VPMINUWrr
    551835633U,	// VPMOVB2MZ128rr
    551835633U,	// VPMOVB2MZ256rr
    551835633U,	// VPMOVB2MZrr
    551835643U,	// VPMOVD2MZ128rr
    551835643U,	// VPMOVD2MZ256rr
    551835643U,	// VPMOVD2MZrr
    12616736U,	// VPMOVDBZ128mr
    3234137120U,	// VPMOVDBZ128mrk
    551830560U,	// VPMOVDBZ128rr
    3230696480U,	// VPMOVDBZ128rrk
    3229664288U,	// VPMOVDBZ128rrkz
    18908192U,	// VPMOVDBZ256mr
    3240428576U,	// VPMOVDBZ256mrk
    551830560U,	// VPMOVDBZ256rr
    3230696480U,	// VPMOVDBZ256rrk
    3229664288U,	// VPMOVDBZ256rrkz
    33588256U,	// VPMOVDBZmr
    3255108640U,	// VPMOVDBZmrk
    551830560U,	// VPMOVDBZrr
    3230696480U,	// VPMOVDBZrrk
    3229664288U,	// VPMOVDBZrrkz
    18918314U,	// VPMOVDWZ128mr
    3240438698U,	// VPMOVDWZ128mrk
    551840682U,	// VPMOVDWZ128rr
    3230706602U,	// VPMOVDWZ128rrk
    3229674410U,	// VPMOVDWZ128rrkz
    33598378U,	// VPMOVDWZ256mr
    3255118762U,	// VPMOVDWZ256mrk
    551840682U,	// VPMOVDWZ256rr
    3230706602U,	// VPMOVDWZ256rrk
    3229674410U,	// VPMOVDWZ256rrkz
    180399018U,	// VPMOVDWZmr
    3401919402U,	// VPMOVDWZmrk
    551840682U,	// VPMOVDWZrr
    3230706602U,	// VPMOVDWZrrk
    3229674410U,	// VPMOVDWZrrkz
    551830389U,	// VPMOVM2BZ128rr
    551830389U,	// VPMOVM2BZ256rr
    551830389U,	// VPMOVM2BZrr
    551831343U,	// VPMOVM2DZ128rr
    551831343U,	// VPMOVM2DZ256rr
    551831343U,	// VPMOVM2DZrr
    551835977U,	// VPMOVM2QZ128rr
    551835977U,	// VPMOVM2QZ256rr
    551835977U,	// VPMOVM2QZrr
    551840291U,	// VPMOVM2WZ128rr
    551840291U,	// VPMOVM2WZ256rr
    551840291U,	// VPMOVM2WZrr
    551830606U,	// VPMOVMSKBYrr
    551830606U,	// VPMOVMSKBrr
    551835653U,	// VPMOVQ2MZ128rr
    551835653U,	// VPMOVQ2MZ256rr
    551835653U,	// VPMOVQ2MZrr
    4228423U,	// VPMOVQBZ128mr
    3225748807U,	// VPMOVQBZ128mrk
    551830855U,	// VPMOVQBZ128rr
    3230696775U,	// VPMOVQBZ128rrk
    3229664583U,	// VPMOVQBZ128rrkz
    12617031U,	// VPMOVQBZ256mr
    3234137415U,	// VPMOVQBZ256mrk
    551830855U,	// VPMOVQBZ256rr
    3230696775U,	// VPMOVQBZ256rrk
    3229664583U,	// VPMOVQBZ256rrkz
    18908487U,	// VPMOVQBZmr
    3240428871U,	// VPMOVQBZmrk
    551830855U,	// VPMOVQBZrr
    3230696775U,	// VPMOVQBZrrk
    3229664583U,	// VPMOVQBZrrkz
    18910619U,	// VPMOVQDZ128mr
    3240431003U,	// VPMOVQDZ128mrk
    551832987U,	// VPMOVQDZ128rr
    3230698907U,	// VPMOVQDZ128rrk
    3229666715U,	// VPMOVQDZ128rrkz
    33590683U,	// VPMOVQDZ256mr
    3255111067U,	// VPMOVQDZ256mrk
    551832987U,	// VPMOVQDZ256rr
    3230698907U,	// VPMOVQDZ256rrk
    3229666715U,	// VPMOVQDZ256rrkz
    180391323U,	// VPMOVQDZmr
    3401911707U,	// VPMOVQDZmrk
    551832987U,	// VPMOVQDZrr
    3230698907U,	// VPMOVQDZrrk
    3229666715U,	// VPMOVQDZrrkz
    12627287U,	// VPMOVQWZ128mr
    3234147671U,	// VPMOVQWZ128mrk
    551841111U,	// VPMOVQWZ128rr
    3230707031U,	// VPMOVQWZ128rrk
    3229674839U,	// VPMOVQWZ128rrkz
    18918743U,	// VPMOVQWZ256mr
    3240439127U,	// VPMOVQWZ256mrk
    551841111U,	// VPMOVQWZ256rr
    3230707031U,	// VPMOVQWZ256rrk
    3229674839U,	// VPMOVQWZ256rrkz
    33598807U,	// VPMOVQWZmr
    3255119191U,	// VPMOVQWZmrk
    551841111U,	// VPMOVQWZrr
    3230707031U,	// VPMOVQWZrrk
    3229674839U,	// VPMOVQWZrrkz
    12616726U,	// VPMOVSDBZ128mr
    3234137110U,	// VPMOVSDBZ128mrk
    551830550U,	// VPMOVSDBZ128rr
    3230696470U,	// VPMOVSDBZ128rrk
    3229664278U,	// VPMOVSDBZ128rrkz
    18908182U,	// VPMOVSDBZ256mr
    3240428566U,	// VPMOVSDBZ256mrk
    551830550U,	// VPMOVSDBZ256rr
    3230696470U,	// VPMOVSDBZ256rrk
    3229664278U,	// VPMOVSDBZ256rrkz
    33588246U,	// VPMOVSDBZmr
    3255108630U,	// VPMOVSDBZmrk
    551830550U,	// VPMOVSDBZrr
    3230696470U,	// VPMOVSDBZrrk
    3229664278U,	// VPMOVSDBZrrkz
    18918304U,	// VPMOVSDWZ128mr
    3240438688U,	// VPMOVSDWZ128mrk
    551840672U,	// VPMOVSDWZ128rr
    3230706592U,	// VPMOVSDWZ128rrk
    3229674400U,	// VPMOVSDWZ128rrkz
    33598368U,	// VPMOVSDWZ256mr
    3255118752U,	// VPMOVSDWZ256mrk
    551840672U,	// VPMOVSDWZ256rr
    3230706592U,	// VPMOVSDWZ256rrk
    3229674400U,	// VPMOVSDWZ256rrkz
    180399008U,	// VPMOVSDWZmr
    3401919392U,	// VPMOVSDWZmrk
    551840672U,	// VPMOVSDWZrr
    3230706592U,	// VPMOVSDWZrrk
    3229674400U,	// VPMOVSDWZrrkz
    4228378U,	// VPMOVSQBZ128mr
    3225748762U,	// VPMOVSQBZ128mrk
    551830810U,	// VPMOVSQBZ128rr
    3230696730U,	// VPMOVSQBZ128rrk
    3229664538U,	// VPMOVSQBZ128rrkz
    12616986U,	// VPMOVSQBZ256mr
    3234137370U,	// VPMOVSQBZ256mrk
    551830810U,	// VPMOVSQBZ256rr
    3230696730U,	// VPMOVSQBZ256rrk
    3229664538U,	// VPMOVSQBZ256rrkz
    18908442U,	// VPMOVSQBZmr
    3240428826U,	// VPMOVSQBZmrk
    551830810U,	// VPMOVSQBZrr
    3230696730U,	// VPMOVSQBZrrk
    3229664538U,	// VPMOVSQBZrrkz
    18910609U,	// VPMOVSQDZ128mr
    3240430993U,	// VPMOVSQDZ128mrk
    551832977U,	// VPMOVSQDZ128rr
    3230698897U,	// VPMOVSQDZ128rrk
    3229666705U,	// VPMOVSQDZ128rrkz
    33590673U,	// VPMOVSQDZ256mr
    3255111057U,	// VPMOVSQDZ256mrk
    551832977U,	// VPMOVSQDZ256rr
    3230698897U,	// VPMOVSQDZ256rrk
    3229666705U,	// VPMOVSQDZ256rrkz
    180391313U,	// VPMOVSQDZmr
    3401911697U,	// VPMOVSQDZmrk
    551832977U,	// VPMOVSQDZrr
    3230698897U,	// VPMOVSQDZrrk
    3229666705U,	// VPMOVSQDZrrkz
    12627277U,	// VPMOVSQWZ128mr
    3234147661U,	// VPMOVSQWZ128mrk
    551841101U,	// VPMOVSQWZ128rr
    3230707021U,	// VPMOVSQWZ128rrk
    3229674829U,	// VPMOVSQWZ128rrkz
    18918733U,	// VPMOVSQWZ256mr
    3240439117U,	// VPMOVSQWZ256mrk
    551841101U,	// VPMOVSQWZ256rr
    3230707021U,	// VPMOVSQWZ256rrk
    3229674829U,	// VPMOVSQWZ256rrkz
    33598797U,	// VPMOVSQWZmr
    3255119181U,	// VPMOVSQWZmrk
    551841101U,	// VPMOVSQWZrr
    3230707021U,	// VPMOVSQWZrrk
    3229674829U,	// VPMOVSQWZrrkz
    18908887U,	// VPMOVSWBZ128mr
    3240429271U,	// VPMOVSWBZ128mrk
    551831255U,	// VPMOVSWBZ128rr
    3230697175U,	// VPMOVSWBZ128rrk
    3229664983U,	// VPMOVSWBZ128rrkz
    33588951U,	// VPMOVSWBZ256mr
    3255109335U,	// VPMOVSWBZ256mrk
    551831255U,	// VPMOVSWBZ256rr
    3230697175U,	// VPMOVSWBZ256rrk
    3229664983U,	// VPMOVSWBZ256rrkz
    180389591U,	// VPMOVSWBZmr
    3401909975U,	// VPMOVSWBZmrk
    551831255U,	// VPMOVSWBZrr
    3230697175U,	// VPMOVSWBZrrk
    3229664983U,	// VPMOVSWBZrrkz
    551913359U,	// VPMOVSXBDYrm
    551831439U,	// VPMOVSXBDYrr
    551896975U,	// VPMOVSXBDZ128rm
    553011087U,	// VPMOVSXBDZ128rmk
    551634831U,	// VPMOVSXBDZ128rmkz
    551831439U,	// VPMOVSXBDZ128rr
    3230697359U,	// VPMOVSXBDZ128rrk
    3229665167U,	// VPMOVSXBDZ128rrkz
    551913359U,	// VPMOVSXBDZ256rm
    552912783U,	// VPMOVSXBDZ256rmk
    551651215U,	// VPMOVSXBDZ256rmkz
    551831439U,	// VPMOVSXBDZ256rr
    3230697359U,	// VPMOVSXBDZ256rrk
    3229665167U,	// VPMOVSXBDZ256rrkz
    264079U,	// VPMOVSXBDZrm
    3230992271U,	// VPMOVSXBDZrmk
    3229861775U,	// VPMOVSXBDZrmkz
    551831439U,	// VPMOVSXBDZrr
    3230697359U,	// VPMOVSXBDZrrk
    3229665167U,	// VPMOVSXBDZrrkz
    551896975U,	// VPMOVSXBDrm
    551831439U,	// VPMOVSXBDrr
    551901623U,	// VPMOVSXBQYrm
    551836087U,	// VPMOVSXBQYrr
    432567U,	// VPMOVSXBQZ128rm
    1644983U,	// VPMOVSXBQZ128rmk
    3229686199U,	// VPMOVSXBQZ128rmkz
    551836087U,	// VPMOVSXBQZ128rr
    3230702007U,	// VPMOVSXBQZ128rrk
    3229669815U,	// VPMOVSXBQZ128rrkz
    551901623U,	// VPMOVSXBQZ256rm
    553015735U,	// VPMOVSXBQZ256rmk
    551639479U,	// VPMOVSXBQZ256rmkz
    551836087U,	// VPMOVSXBQZ256rr
    3230702007U,	// VPMOVSXBQZ256rrk
    3229669815U,	// VPMOVSXBQZ256rrkz
    551918007U,	// VPMOVSXBQZrm
    552917431U,	// VPMOVSXBQZrmk
    551655863U,	// VPMOVSXBQZrmkz
    551836087U,	// VPMOVSXBQZrr
    3230702007U,	// VPMOVSXBQZrrk
    3229669815U,	// VPMOVSXBQZrrkz
    432567U,	// VPMOVSXBQrm
    551836087U,	// VPMOVSXBQrr
    273115U,	// VPMOVSXBWYrm
    551840475U,	// VPMOVSXBWYrr
    551922395U,	// VPMOVSXBWZ128rm
    552921819U,	// VPMOVSXBWZ128rmk
    551660251U,	// VPMOVSXBWZ128rmkz
    551840475U,	// VPMOVSXBWZ128rr
    3230706395U,	// VPMOVSXBWZ128rrk
    3229674203U,	// VPMOVSXBWZ128rrkz
    273115U,	// VPMOVSXBWZ256rm
    3231001307U,	// VPMOVSXBWZ256rmk
    3229870811U,	// VPMOVSXBWZ256rmkz
    551840475U,	// VPMOVSXBWZ256rr
    3230706395U,	// VPMOVSXBWZ256rrk
    3229674203U,	// VPMOVSXBWZ256rrkz
    552954587U,	// VPMOVSXBWZrm
    3231034075U,	// VPMOVSXBWZrmk
    3230886619U,	// VPMOVSXBWZrmkz
    551840475U,	// VPMOVSXBWZrr
    3230706395U,	// VPMOVSXBWZrrk
    3229674203U,	// VPMOVSXBWZrrkz
    551922395U,	// VPMOVSXBWrm
    551840475U,	// VPMOVSXBWrr
    269217U,	// VPMOVSXDQYrm
    551836577U,	// VPMOVSXDQYrr
    551918497U,	// VPMOVSXDQZ128rm
    552917921U,	// VPMOVSXDQZ128rmk
    551656353U,	// VPMOVSXDQZ128rmkz
    551836577U,	// VPMOVSXDQZ128rr
    3230702497U,	// VPMOVSXDQZ128rrk
    3229670305U,	// VPMOVSXDQZ128rrkz
    269217U,	// VPMOVSXDQZ256rm
    3230997409U,	// VPMOVSXDQZ256rmk
    3229866913U,	// VPMOVSXDQZ256rmkz
    551836577U,	// VPMOVSXDQZ256rr
    3230702497U,	// VPMOVSXDQZ256rrk
    3229670305U,	// VPMOVSXDQZ256rrkz
    552950689U,	// VPMOVSXDQZrm
    3231030177U,	// VPMOVSXDQZrmk
    3230882721U,	// VPMOVSXDQZrmkz
    551836577U,	// VPMOVSXDQZrr
    3230702497U,	// VPMOVSXDQZrrk
    3229670305U,	// VPMOVSXDQZrrkz
    551918497U,	// VPMOVSXDQrm
    551836577U,	// VPMOVSXDQrr
    266608U,	// VPMOVSXWDYrm
    551833968U,	// VPMOVSXWDYrr
    551915888U,	// VPMOVSXWDZ128rm
    552915312U,	// VPMOVSXWDZ128rmk
    551653744U,	// VPMOVSXWDZ128rmkz
    551833968U,	// VPMOVSXWDZ128rr
    3230699888U,	// VPMOVSXWDZ128rrk
    3229667696U,	// VPMOVSXWDZ128rrkz
    266608U,	// VPMOVSXWDZ256rm
    3230994800U,	// VPMOVSXWDZ256rmk
    3229864304U,	// VPMOVSXWDZ256rmkz
    551833968U,	// VPMOVSXWDZ256rr
    3230699888U,	// VPMOVSXWDZ256rrk
    3229667696U,	// VPMOVSXWDZ256rrkz
    552948080U,	// VPMOVSXWDZrm
    3231027568U,	// VPMOVSXWDZrmk
    3230880112U,	// VPMOVSXWDZrmkz
    551833968U,	// VPMOVSXWDZrr
    3230699888U,	// VPMOVSXWDZrrk
    3229667696U,	// VPMOVSXWDZrrkz
    551915888U,	// VPMOVSXWDrm
    551833968U,	// VPMOVSXWDrr
    551919798U,	// VPMOVSXWQYrm
    551837878U,	// VPMOVSXWQYrr
    551903414U,	// VPMOVSXWQZ128rm
    553017526U,	// VPMOVSXWQZ128rmk
    551641270U,	// VPMOVSXWQZ128rmkz
    551837878U,	// VPMOVSXWQZ128rr
    3230703798U,	// VPMOVSXWQZ128rrk
    3229671606U,	// VPMOVSXWQZ128rrkz
    551919798U,	// VPMOVSXWQZ256rm
    552919222U,	// VPMOVSXWQZ256rmk
    551657654U,	// VPMOVSXWQZ256rmkz
    551837878U,	// VPMOVSXWQZ256rr
    3230703798U,	// VPMOVSXWQZ256rrk
    3229671606U,	// VPMOVSXWQZ256rrkz
    270518U,	// VPMOVSXWQZrm
    3230998710U,	// VPMOVSXWQZrmk
    3229868214U,	// VPMOVSXWQZrmkz
    551837878U,	// VPMOVSXWQZrr
    3230703798U,	// VPMOVSXWQZrrk
    3229671606U,	// VPMOVSXWQZrrkz
    551903414U,	// VPMOVSXWQrm
    551837878U,	// VPMOVSXWQrr
    12616715U,	// VPMOVUSDBZ128mr
    3234137099U,	// VPMOVUSDBZ128mrk
    551830539U,	// VPMOVUSDBZ128rr
    3230696459U,	// VPMOVUSDBZ128rrk
    3229664267U,	// VPMOVUSDBZ128rrkz
    18908171U,	// VPMOVUSDBZ256mr
    3240428555U,	// VPMOVUSDBZ256mrk
    551830539U,	// VPMOVUSDBZ256rr
    3230696459U,	// VPMOVUSDBZ256rrk
    3229664267U,	// VPMOVUSDBZ256rrkz
    33588235U,	// VPMOVUSDBZmr
    3255108619U,	// VPMOVUSDBZmrk
    551830539U,	// VPMOVUSDBZrr
    3230696459U,	// VPMOVUSDBZrrk
    3229664267U,	// VPMOVUSDBZrrkz
    18918293U,	// VPMOVUSDWZ128mr
    3240438677U,	// VPMOVUSDWZ128mrk
    551840661U,	// VPMOVUSDWZ128rr
    3230706581U,	// VPMOVUSDWZ128rrk
    3229674389U,	// VPMOVUSDWZ128rrkz
    33598357U,	// VPMOVUSDWZ256mr
    3255118741U,	// VPMOVUSDWZ256mrk
    551840661U,	// VPMOVUSDWZ256rr
    3230706581U,	// VPMOVUSDWZ256rrk
    3229674389U,	// VPMOVUSDWZ256rrkz
    180398997U,	// VPMOVUSDWZmr
    3401919381U,	// VPMOVUSDWZmrk
    551840661U,	// VPMOVUSDWZrr
    3230706581U,	// VPMOVUSDWZrrk
    3229674389U,	// VPMOVUSDWZrrkz
    4228367U,	// VPMOVUSQBZ128mr
    3225748751U,	// VPMOVUSQBZ128mrk
    551830799U,	// VPMOVUSQBZ128rr
    3230696719U,	// VPMOVUSQBZ128rrk
    3229664527U,	// VPMOVUSQBZ128rrkz
    12616975U,	// VPMOVUSQBZ256mr
    3234137359U,	// VPMOVUSQBZ256mrk
    551830799U,	// VPMOVUSQBZ256rr
    3230696719U,	// VPMOVUSQBZ256rrk
    3229664527U,	// VPMOVUSQBZ256rrkz
    18908431U,	// VPMOVUSQBZmr
    3240428815U,	// VPMOVUSQBZmrk
    551830799U,	// VPMOVUSQBZrr
    3230696719U,	// VPMOVUSQBZrrk
    3229664527U,	// VPMOVUSQBZrrkz
    18910598U,	// VPMOVUSQDZ128mr
    3240430982U,	// VPMOVUSQDZ128mrk
    551832966U,	// VPMOVUSQDZ128rr
    3230698886U,	// VPMOVUSQDZ128rrk
    3229666694U,	// VPMOVUSQDZ128rrkz
    33590662U,	// VPMOVUSQDZ256mr
    3255111046U,	// VPMOVUSQDZ256mrk
    551832966U,	// VPMOVUSQDZ256rr
    3230698886U,	// VPMOVUSQDZ256rrk
    3229666694U,	// VPMOVUSQDZ256rrkz
    180391302U,	// VPMOVUSQDZmr
    3401911686U,	// VPMOVUSQDZmrk
    551832966U,	// VPMOVUSQDZrr
    3230698886U,	// VPMOVUSQDZrrk
    3229666694U,	// VPMOVUSQDZrrkz
    12627266U,	// VPMOVUSQWZ128mr
    3234147650U,	// VPMOVUSQWZ128mrk
    551841090U,	// VPMOVUSQWZ128rr
    3230707010U,	// VPMOVUSQWZ128rrk
    3229674818U,	// VPMOVUSQWZ128rrkz
    18918722U,	// VPMOVUSQWZ256mr
    3240439106U,	// VPMOVUSQWZ256mrk
    551841090U,	// VPMOVUSQWZ256rr
    3230707010U,	// VPMOVUSQWZ256rrk
    3229674818U,	// VPMOVUSQWZ256rrkz
    33598786U,	// VPMOVUSQWZmr
    3255119170U,	// VPMOVUSQWZmrk
    551841090U,	// VPMOVUSQWZrr
    3230707010U,	// VPMOVUSQWZrrk
    3229674818U,	// VPMOVUSQWZrrkz
    18908876U,	// VPMOVUSWBZ128mr
    3240429260U,	// VPMOVUSWBZ128mrk
    551831244U,	// VPMOVUSWBZ128rr
    3230697164U,	// VPMOVUSWBZ128rrk
    3229664972U,	// VPMOVUSWBZ128rrkz
    33588940U,	// VPMOVUSWBZ256mr
    3255109324U,	// VPMOVUSWBZ256mrk
    551831244U,	// VPMOVUSWBZ256rr
    3230697164U,	// VPMOVUSWBZ256rrk
    3229664972U,	// VPMOVUSWBZ256rrkz
    180389580U,	// VPMOVUSWBZmr
    3401909964U,	// VPMOVUSWBZmrk
    551831244U,	// VPMOVUSWBZrr
    3230697164U,	// VPMOVUSWBZrrk
    3229664972U,	// VPMOVUSWBZrrkz
    551835663U,	// VPMOVW2MZ128rr
    551835663U,	// VPMOVW2MZ256rr
    551835663U,	// VPMOVW2MZrr
    18908897U,	// VPMOVWBZ128mr
    3240429281U,	// VPMOVWBZ128mrk
    551831265U,	// VPMOVWBZ128rr
    3230697185U,	// VPMOVWBZ128rrk
    3229664993U,	// VPMOVWBZ128rrkz
    33588961U,	// VPMOVWBZ256mr
    3255109345U,	// VPMOVWBZ256mrk
    551831265U,	// VPMOVWBZ256rr
    3230697185U,	// VPMOVWBZ256rrk
    3229664993U,	// VPMOVWBZ256rrkz
    180389601U,	// VPMOVWBZmr
    3401909985U,	// VPMOVWBZmrk
    551831265U,	// VPMOVWBZrr
    3230697185U,	// VPMOVWBZrrk
    3229664993U,	// VPMOVWBZrrkz
    551913370U,	// VPMOVZXBDYrm
    551831450U,	// VPMOVZXBDYrr
    551896986U,	// VPMOVZXBDZ128rm
    553011098U,	// VPMOVZXBDZ128rmk
    551634842U,	// VPMOVZXBDZ128rmkz
    551831450U,	// VPMOVZXBDZ128rr
    3230697370U,	// VPMOVZXBDZ128rrk
    3229665178U,	// VPMOVZXBDZ128rrkz
    551913370U,	// VPMOVZXBDZ256rm
    552912794U,	// VPMOVZXBDZ256rmk
    551651226U,	// VPMOVZXBDZ256rmkz
    551831450U,	// VPMOVZXBDZ256rr
    3230697370U,	// VPMOVZXBDZ256rrk
    3229665178U,	// VPMOVZXBDZ256rrkz
    264090U,	// VPMOVZXBDZrm
    3230992282U,	// VPMOVZXBDZrmk
    3229861786U,	// VPMOVZXBDZrmkz
    551831450U,	// VPMOVZXBDZrr
    3230697370U,	// VPMOVZXBDZrrk
    3229665178U,	// VPMOVZXBDZrrkz
    551896986U,	// VPMOVZXBDrm
    551831450U,	// VPMOVZXBDrr
    551901634U,	// VPMOVZXBQYrm
    551836098U,	// VPMOVZXBQYrr
    432578U,	// VPMOVZXBQZ128rm
    1644994U,	// VPMOVZXBQZ128rmk
    3229686210U,	// VPMOVZXBQZ128rmkz
    551836098U,	// VPMOVZXBQZ128rr
    3230702018U,	// VPMOVZXBQZ128rrk
    3229669826U,	// VPMOVZXBQZ128rrkz
    551901634U,	// VPMOVZXBQZ256rm
    553015746U,	// VPMOVZXBQZ256rmk
    551639490U,	// VPMOVZXBQZ256rmkz
    551836098U,	// VPMOVZXBQZ256rr
    3230702018U,	// VPMOVZXBQZ256rrk
    3229669826U,	// VPMOVZXBQZ256rrkz
    551918018U,	// VPMOVZXBQZrm
    552917442U,	// VPMOVZXBQZrmk
    551655874U,	// VPMOVZXBQZrmkz
    551836098U,	// VPMOVZXBQZrr
    3230702018U,	// VPMOVZXBQZrrk
    3229669826U,	// VPMOVZXBQZrrkz
    432578U,	// VPMOVZXBQrm
    551836098U,	// VPMOVZXBQrr
    273126U,	// VPMOVZXBWYrm
    551840486U,	// VPMOVZXBWYrr
    551922406U,	// VPMOVZXBWZ128rm
    552921830U,	// VPMOVZXBWZ128rmk
    551660262U,	// VPMOVZXBWZ128rmkz
    551840486U,	// VPMOVZXBWZ128rr
    3230706406U,	// VPMOVZXBWZ128rrk
    3229674214U,	// VPMOVZXBWZ128rrkz
    273126U,	// VPMOVZXBWZ256rm
    3231001318U,	// VPMOVZXBWZ256rmk
    3229870822U,	// VPMOVZXBWZ256rmkz
    551840486U,	// VPMOVZXBWZ256rr
    3230706406U,	// VPMOVZXBWZ256rrk
    3229674214U,	// VPMOVZXBWZ256rrkz
    552954598U,	// VPMOVZXBWZrm
    3231034086U,	// VPMOVZXBWZrmk
    3230886630U,	// VPMOVZXBWZrmkz
    551840486U,	// VPMOVZXBWZrr
    3230706406U,	// VPMOVZXBWZrrk
    3229674214U,	// VPMOVZXBWZrrkz
    551922406U,	// VPMOVZXBWrm
    551840486U,	// VPMOVZXBWrr
    269228U,	// VPMOVZXDQYrm
    551836588U,	// VPMOVZXDQYrr
    551918508U,	// VPMOVZXDQZ128rm
    552917932U,	// VPMOVZXDQZ128rmk
    551656364U,	// VPMOVZXDQZ128rmkz
    551836588U,	// VPMOVZXDQZ128rr
    3230702508U,	// VPMOVZXDQZ128rrk
    3229670316U,	// VPMOVZXDQZ128rrkz
    269228U,	// VPMOVZXDQZ256rm
    3230997420U,	// VPMOVZXDQZ256rmk
    3229866924U,	// VPMOVZXDQZ256rmkz
    551836588U,	// VPMOVZXDQZ256rr
    3230702508U,	// VPMOVZXDQZ256rrk
    3229670316U,	// VPMOVZXDQZ256rrkz
    552950700U,	// VPMOVZXDQZrm
    3231030188U,	// VPMOVZXDQZrmk
    3230882732U,	// VPMOVZXDQZrmkz
    551836588U,	// VPMOVZXDQZrr
    3230702508U,	// VPMOVZXDQZrrk
    3229670316U,	// VPMOVZXDQZrrkz
    551918508U,	// VPMOVZXDQrm
    551836588U,	// VPMOVZXDQrr
    266619U,	// VPMOVZXWDYrm
    551833979U,	// VPMOVZXWDYrr
    551915899U,	// VPMOVZXWDZ128rm
    552915323U,	// VPMOVZXWDZ128rmk
    551653755U,	// VPMOVZXWDZ128rmkz
    551833979U,	// VPMOVZXWDZ128rr
    3230699899U,	// VPMOVZXWDZ128rrk
    3229667707U,	// VPMOVZXWDZ128rrkz
    266619U,	// VPMOVZXWDZ256rm
    3230994811U,	// VPMOVZXWDZ256rmk
    3229864315U,	// VPMOVZXWDZ256rmkz
    551833979U,	// VPMOVZXWDZ256rr
    3230699899U,	// VPMOVZXWDZ256rrk
    3229667707U,	// VPMOVZXWDZ256rrkz
    552948091U,	// VPMOVZXWDZrm
    3231027579U,	// VPMOVZXWDZrmk
    3230880123U,	// VPMOVZXWDZrmkz
    551833979U,	// VPMOVZXWDZrr
    3230699899U,	// VPMOVZXWDZrrk
    3229667707U,	// VPMOVZXWDZrrkz
    551915899U,	// VPMOVZXWDrm
    551833979U,	// VPMOVZXWDrr
    551919809U,	// VPMOVZXWQYrm
    551837889U,	// VPMOVZXWQYrr
    551903425U,	// VPMOVZXWQZ128rm
    553017537U,	// VPMOVZXWQZ128rmk
    551641281U,	// VPMOVZXWQZ128rmkz
    551837889U,	// VPMOVZXWQZ128rr
    3230703809U,	// VPMOVZXWQZ128rrk
    3229671617U,	// VPMOVZXWQZ128rrkz
    551919809U,	// VPMOVZXWQZ256rm
    552919233U,	// VPMOVZXWQZ256rmk
    551657665U,	// VPMOVZXWQZ256rmkz
    551837889U,	// VPMOVZXWQZ256rr
    3230703809U,	// VPMOVZXWQZ256rrk
    3229671617U,	// VPMOVZXWQZ256rrkz
    270529U,	// VPMOVZXWQZrm
    3230998721U,	// VPMOVZXWQZrmk
    3229868225U,	// VPMOVZXWQZrmkz
    551837889U,	// VPMOVZXWQZrr
    3230703809U,	// VPMOVZXWQZrrk
    3229671617U,	// VPMOVZXWQZrrkz
    551903425U,	// VPMOVZXWQrm
    551837889U,	// VPMOVZXWQrr
    812866230U,	// VPMULDQYrm
    811653814U,	// VPMULDQYrr
    811850422U,	// VPMULDQZ128rm
    358718134U,	// VPMULDQZ128rmb
    1433950902U,	// VPMULDQZ128rmbk
    1165286070U,	// VPMULDQZ128rmbkz
    985111222U,	// VPMULDQZ128rmk
    890575542U,	// VPMULDQZ128rmkz
    811653814U,	// VPMULDQZ128rr
    87055030U,	// VPMULDQZ128rrk
    890280630U,	// VPMULDQZ128rrkz
    812866230U,	// VPMULDQZ256rm
    360815286U,	// VPMULDQZ256rmb
    1436048054U,	// VPMULDQZ256rmbk
    1167383222U,	// VPMULDQZ256rmbkz
    985127606U,	// VPMULDQZ256rmk
    890608310U,	// VPMULDQZ256rmkz
    811653814U,	// VPMULDQZ256rr
    87055030U,	// VPMULDQZ256rrk
    890280630U,	// VPMULDQZ256rrkz
    812882614U,	// VPMULDQZrm
    362912438U,	// VPMULDQZrmb
    1438145206U,	// VPMULDQZrmbk
    1169480374U,	// VPMULDQZrmbkz
    985143990U,	// VPMULDQZrmk
    890673846U,	// VPMULDQZrmkz
    811653814U,	// VPMULDQZrr
    87055030U,	// VPMULDQZrrk
    890280630U,	// VPMULDQZrrkz
    811850422U,	// VPMULDQrm
    811653814U,	// VPMULDQrr
    812871256U,	// VPMULHRSWYrm
    811658840U,	// VPMULHRSWYrr
    811855448U,	// VPMULHRSWZ128rm
    985116248U,	// VPMULHRSWZ128rmk
    890580568U,	// VPMULHRSWZ128rmkz
    811658840U,	// VPMULHRSWZ128rr
    87060056U,	// VPMULHRSWZ128rrk
    890285656U,	// VPMULHRSWZ128rrkz
    812871256U,	// VPMULHRSWZ256rm
    985132632U,	// VPMULHRSWZ256rmk
    890613336U,	// VPMULHRSWZ256rmkz
    811658840U,	// VPMULHRSWZ256rr
    87060056U,	// VPMULHRSWZ256rrk
    890285656U,	// VPMULHRSWZ256rrkz
    812887640U,	// VPMULHRSWZrm
    985149016U,	// VPMULHRSWZrmk
    890678872U,	// VPMULHRSWZrmkz
    811658840U,	// VPMULHRSWZrr
    87060056U,	// VPMULHRSWZrrk
    890285656U,	// VPMULHRSWZrrkz
    811855448U,	// VPMULHRSWrm
    811658840U,	// VPMULHRSWrr
    812871481U,	// VPMULHUWYrm
    811659065U,	// VPMULHUWYrr
    811855673U,	// VPMULHUWZ128rm
    985116473U,	// VPMULHUWZ128rmk
    890580793U,	// VPMULHUWZ128rmkz
    811659065U,	// VPMULHUWZ128rr
    87060281U,	// VPMULHUWZ128rrk
    890285881U,	// VPMULHUWZ128rrkz
    812871481U,	// VPMULHUWZ256rm
    985132857U,	// VPMULHUWZ256rmk
    890613561U,	// VPMULHUWZ256rmkz
    811659065U,	// VPMULHUWZ256rr
    87060281U,	// VPMULHUWZ256rrk
    890285881U,	// VPMULHUWZ256rrkz
    812887865U,	// VPMULHUWZrm
    985149241U,	// VPMULHUWZrmk
    890679097U,	// VPMULHUWZrmkz
    811659065U,	// VPMULHUWZrr
    87060281U,	// VPMULHUWZrrk
    890285881U,	// VPMULHUWZrrkz
    811855673U,	// VPMULHUWrm
    811659065U,	// VPMULHUWrr
    812870706U,	// VPMULHWYrm
    811658290U,	// VPMULHWYrr
    811854898U,	// VPMULHWZ128rm
    985115698U,	// VPMULHWZ128rmk
    890580018U,	// VPMULHWZ128rmkz
    811658290U,	// VPMULHWZ128rr
    87059506U,	// VPMULHWZ128rrk
    890285106U,	// VPMULHWZ128rrkz
    812870706U,	// VPMULHWZ256rm
    985132082U,	// VPMULHWZ256rmk
    890612786U,	// VPMULHWZ256rmkz
    811658290U,	// VPMULHWZ256rr
    87059506U,	// VPMULHWZ256rrk
    890285106U,	// VPMULHWZ256rrkz
    812887090U,	// VPMULHWZrm
    985148466U,	// VPMULHWZrmk
    890678322U,	// VPMULHWZrmkz
    811658290U,	// VPMULHWZrr
    87059506U,	// VPMULHWZrrk
    890285106U,	// VPMULHWZrrkz
    811854898U,	// VPMULHWrm
    811658290U,	// VPMULHWrr
    812861561U,	// VPMULLDYrm
    811649145U,	// VPMULLDYrr
    811845753U,	// VPMULLDZ128rm
    360794233U,	// VPMULLDZ128rmb
    1436059769U,	// VPMULLDZ128rmbk
    1167476857U,	// VPMULLDZ128rmbkz
    985106553U,	// VPMULLDZ128rmk
    890570873U,	// VPMULLDZ128rmkz
    811649145U,	// VPMULLDZ128rr
    87050361U,	// VPMULLDZ128rrk
    890275961U,	// VPMULLDZ128rrkz
    812861561U,	// VPMULLDZ256rm
    362891385U,	// VPMULLDZ256rmb
    1438156921U,	// VPMULLDZ256rmbk
    1169574009U,	// VPMULLDZ256rmbkz
    985122937U,	// VPMULLDZ256rmk
    890603641U,	// VPMULLDZ256rmkz
    811649145U,	// VPMULLDZ256rr
    87050361U,	// VPMULLDZ256rrk
    890275961U,	// VPMULLDZ256rrkz
    812877945U,	// VPMULLDZrm
    364988537U,	// VPMULLDZrmb
    1440254073U,	// VPMULLDZrmbk
    1171671161U,	// VPMULLDZrmbkz
    985139321U,	// VPMULLDZrmk
    890669177U,	// VPMULLDZrmkz
    811649145U,	// VPMULLDZrr
    87050361U,	// VPMULLDZrrk
    890275961U,	// VPMULLDZrrkz
    811845753U,	// VPMULLDrm
    811649145U,	// VPMULLDrr
    811850965U,	// VPMULLQZ128rm
    358718677U,	// VPMULLQZ128rmb
    1433951445U,	// VPMULLQZ128rmbk
    1165286613U,	// VPMULLQZ128rmbkz
    985111765U,	// VPMULLQZ128rmk
    890576085U,	// VPMULLQZ128rmkz
    811654357U,	// VPMULLQZ128rr
    87055573U,	// VPMULLQZ128rrk
    890281173U,	// VPMULLQZ128rrkz
    812866773U,	// VPMULLQZ256rm
    360815829U,	// VPMULLQZ256rmb
    1436048597U,	// VPMULLQZ256rmbk
    1167383765U,	// VPMULLQZ256rmbkz
    985128149U,	// VPMULLQZ256rmk
    890608853U,	// VPMULLQZ256rmkz
    811654357U,	// VPMULLQZ256rr
    87055573U,	// VPMULLQZ256rrk
    890281173U,	// VPMULLQZ256rrkz
    812883157U,	// VPMULLQZrm
    362912981U,	// VPMULLQZrmb
    1438145749U,	// VPMULLQZrmbk
    1169480917U,	// VPMULLQZrmbkz
    985144533U,	// VPMULLQZrmk
    890674389U,	// VPMULLQZrmkz
    811654357U,	// VPMULLQZrr
    87055573U,	// VPMULLQZrrk
    890281173U,	// VPMULLQZrrkz
    812870775U,	// VPMULLWYrm
    811658359U,	// VPMULLWYrr
    811854967U,	// VPMULLWZ128rm
    985115767U,	// VPMULLWZ128rmk
    890580087U,	// VPMULLWZ128rmkz
    811658359U,	// VPMULLWZ128rr
    87059575U,	// VPMULLWZ128rrk
    890285175U,	// VPMULLWZ128rrkz
    812870775U,	// VPMULLWZ256rm
    985132151U,	// VPMULLWZ256rmk
    890612855U,	// VPMULLWZ256rmkz
    811658359U,	// VPMULLWZ256rr
    87059575U,	// VPMULLWZ256rrk
    890285175U,	// VPMULLWZ256rrkz
    812887159U,	// VPMULLWZrm
    985148535U,	// VPMULLWZrmk
    890678391U,	// VPMULLWZrmkz
    811658359U,	// VPMULLWZrr
    87059575U,	// VPMULLWZrrk
    890285175U,	// VPMULLWZrrkz
    811854967U,	// VPMULLWrm
    811658359U,	// VPMULLWrr
    811844900U,	// VPMULTISHIFTQBZ128rm
    358712612U,	// VPMULTISHIFTQBZ128rmb
    1433945380U,	// VPMULTISHIFTQBZ128rmbk
    1165280548U,	// VPMULTISHIFTQBZ128rmbkz
    985105700U,	// VPMULTISHIFTQBZ128rmk
    890570020U,	// VPMULTISHIFTQBZ128rmkz
    811648292U,	// VPMULTISHIFTQBZ128rr
    87049508U,	// VPMULTISHIFTQBZ128rrk
    890275108U,	// VPMULTISHIFTQBZ128rrkz
    812860708U,	// VPMULTISHIFTQBZ256rm
    360809764U,	// VPMULTISHIFTQBZ256rmb
    1436042532U,	// VPMULTISHIFTQBZ256rmbk
    1167377700U,	// VPMULTISHIFTQBZ256rmbkz
    985122084U,	// VPMULTISHIFTQBZ256rmk
    890602788U,	// VPMULTISHIFTQBZ256rmkz
    811648292U,	// VPMULTISHIFTQBZ256rr
    87049508U,	// VPMULTISHIFTQBZ256rrk
    890275108U,	// VPMULTISHIFTQBZ256rrkz
    812877092U,	// VPMULTISHIFTQBZrm
    362906916U,	// VPMULTISHIFTQBZrmb
    1438139684U,	// VPMULTISHIFTQBZrmbk
    1169474852U,	// VPMULTISHIFTQBZrmbkz
    985138468U,	// VPMULTISHIFTQBZrmk
    890668324U,	// VPMULTISHIFTQBZrmkz
    811648292U,	// VPMULTISHIFTQBZrr
    87049508U,	// VPMULTISHIFTQBZrrk
    890275108U,	// VPMULTISHIFTQBZrrkz
    812866455U,	// VPMULUDQYrm
    811654039U,	// VPMULUDQYrr
    811850647U,	// VPMULUDQZ128rm
    358718359U,	// VPMULUDQZ128rmb
    1433951127U,	// VPMULUDQZ128rmbk
    1165286295U,	// VPMULUDQZ128rmbkz
    985111447U,	// VPMULUDQZ128rmk
    890575767U,	// VPMULUDQZ128rmkz
    811654039U,	// VPMULUDQZ128rr
    87055255U,	// VPMULUDQZ128rrk
    890280855U,	// VPMULUDQZ128rrkz
    812866455U,	// VPMULUDQZ256rm
    360815511U,	// VPMULUDQZ256rmb
    1436048279U,	// VPMULUDQZ256rmbk
    1167383447U,	// VPMULUDQZ256rmbkz
    985127831U,	// VPMULUDQZ256rmk
    890608535U,	// VPMULUDQZ256rmkz
    811654039U,	// VPMULUDQZ256rr
    87055255U,	// VPMULUDQZ256rrk
    890280855U,	// VPMULUDQZ256rrkz
    812882839U,	// VPMULUDQZrm
    362912663U,	// VPMULUDQZrmb
    1438145431U,	// VPMULUDQZrmbk
    1169480599U,	// VPMULUDQZrmbkz
    985144215U,	// VPMULUDQZrmk
    890674071U,	// VPMULUDQZrmkz
    811654039U,	// VPMULUDQZrr
    87055255U,	// VPMULUDQZrrk
    890280855U,	// VPMULUDQZrrkz
    811850647U,	// VPMULUDQrm
    811654039U,	// VPMULUDQrr
    263723U,	// VPOPCNTBZ128rm
    3230991915U,	// VPOPCNTBZ128rmk
    3229861419U,	// VPOPCNTBZ128rmkz
    551831083U,	// VPOPCNTBZ128rr
    3230697003U,	// VPOPCNTBZ128rrk
    3229664811U,	// VPOPCNTBZ128rrkz
    552945195U,	// VPOPCNTBZ256rm
    3231024683U,	// VPOPCNTBZ256rmk
    3230877227U,	// VPOPCNTBZ256rmkz
    551831083U,	// VPOPCNTBZ256rr
    3230697003U,	// VPOPCNTBZ256rrk
    3229664811U,	// VPOPCNTBZ256rrkz
    552437291U,	// VPOPCNTBZrm
    3231090219U,	// VPOPCNTBZrmk
    3230893611U,	// VPOPCNTBZrmkz
    551831083U,	// VPOPCNTBZrr
    3230697003U,	// VPOPCNTBZrrk
    3229664811U,	// VPOPCNTBZrrkz
    266302U,	// VPOPCNTDZ128rm
    629493822U,	// VPOPCNTDZ128rmb
    630607934U,	// VPOPCNTDZ128rmbk
    629231678U,	// VPOPCNTDZ128rmbkz
    3230994494U,	// VPOPCNTDZ128rmk
    3229863998U,	// VPOPCNTDZ128rmkz
    551833662U,	// VPOPCNTDZ128rr
    3230699582U,	// VPOPCNTDZ128rrk
    3229667390U,	// VPOPCNTDZ128rrkz
    552947774U,	// VPOPCNTDZ256rm
    631590974U,	// VPOPCNTDZ256rmb
    632705086U,	// VPOPCNTDZ256rmbk
    631328830U,	// VPOPCNTDZ256rmbkz
    3231027262U,	// VPOPCNTDZ256rmk
    3230879806U,	// VPOPCNTDZ256rmkz
    551833662U,	// VPOPCNTDZ256rr
    3230699582U,	// VPOPCNTDZ256rrk
    3229667390U,	// VPOPCNTDZ256rrkz
    552439870U,	// VPOPCNTDZrm
    633688126U,	// VPOPCNTDZrmb
    634802238U,	// VPOPCNTDZrmbk
    633425982U,	// VPOPCNTDZrmbkz
    3231092798U,	// VPOPCNTDZrmk
    3230896190U,	// VPOPCNTDZrmkz
    551833662U,	// VPOPCNTDZrr
    3230699582U,	// VPOPCNTDZrrk
    3229667390U,	// VPOPCNTDZrrkz
    270230U,	// VPOPCNTQZ128rm
    627416982U,	// VPOPCNTQZ128rmb
    628416406U,	// VPOPCNTQZ128rmbk
    627154838U,	// VPOPCNTQZ128rmbkz
    3230998422U,	// VPOPCNTQZ128rmk
    3229867926U,	// VPOPCNTQZ128rmkz
    551837590U,	// VPOPCNTQZ128rr
    3230703510U,	// VPOPCNTQZ128rrk
    3229671318U,	// VPOPCNTQZ128rrkz
    552951702U,	// VPOPCNTQZ256rm
    629514134U,	// VPOPCNTQZ256rmb
    630513558U,	// VPOPCNTQZ256rmbk
    629251990U,	// VPOPCNTQZ256rmbkz
    3231031190U,	// VPOPCNTQZ256rmk
    3230883734U,	// VPOPCNTQZ256rmkz
    551837590U,	// VPOPCNTQZ256rr
    3230703510U,	// VPOPCNTQZ256rrk
    3229671318U,	// VPOPCNTQZ256rrkz
    552443798U,	// VPOPCNTQZrm
    631611286U,	// VPOPCNTQZrmb
    632610710U,	// VPOPCNTQZrmbk
    631349142U,	// VPOPCNTQZrmbkz
    3231096726U,	// VPOPCNTQZrmk
    3230900118U,	// VPOPCNTQZrmkz
    551837590U,	// VPOPCNTQZrr
    3230703510U,	// VPOPCNTQZrrk
    3229671318U,	// VPOPCNTQZrrkz
    274160U,	// VPOPCNTWZ128rm
    3231002352U,	// VPOPCNTWZ128rmk
    3229871856U,	// VPOPCNTWZ128rmkz
    551841520U,	// VPOPCNTWZ128rr
    3230707440U,	// VPOPCNTWZ128rrk
    3229675248U,	// VPOPCNTWZ128rrkz
    552955632U,	// VPOPCNTWZ256rm
    3231035120U,	// VPOPCNTWZ256rmk
    3230887664U,	// VPOPCNTWZ256rmkz
    551841520U,	// VPOPCNTWZ256rr
    3230707440U,	// VPOPCNTWZ256rrk
    3229675248U,	// VPOPCNTWZ256rrkz
    552447728U,	// VPOPCNTWZrm
    3231100656U,	// VPOPCNTWZrmk
    3230904048U,	// VPOPCNTWZrmkz
    551841520U,	// VPOPCNTWZrr
    3230707440U,	// VPOPCNTWZrrk
    3229675248U,	// VPOPCNTWZrrkz
    811847090U,	// VPORDZ128rm
    360795570U,	// VPORDZ128rmb
    1436061106U,	// VPORDZ128rmbk
    1167478194U,	// VPORDZ128rmbkz
    985107890U,	// VPORDZ128rmk
    890572210U,	// VPORDZ128rmkz
    811650482U,	// VPORDZ128rr
    87051698U,	// VPORDZ128rrk
    890277298U,	// VPORDZ128rrkz
    812862898U,	// VPORDZ256rm
    362892722U,	// VPORDZ256rmb
    1438158258U,	// VPORDZ256rmbk
    1169575346U,	// VPORDZ256rmbkz
    985124274U,	// VPORDZ256rmk
    890604978U,	// VPORDZ256rmkz
    811650482U,	// VPORDZ256rr
    87051698U,	// VPORDZ256rrk
    890277298U,	// VPORDZ256rrkz
    812879282U,	// VPORDZrm
    364989874U,	// VPORDZrmb
    1440255410U,	// VPORDZrmbk
    1171672498U,	// VPORDZrmbkz
    985140658U,	// VPORDZrmk
    890670514U,	// VPORDZrmkz
    811650482U,	// VPORDZrr
    87051698U,	// VPORDZrrk
    890277298U,	// VPORDZrrkz
    811851358U,	// VPORQZ128rm
    358719070U,	// VPORQZ128rmb
    1433951838U,	// VPORQZ128rmbk
    1165287006U,	// VPORQZ128rmbkz
    985112158U,	// VPORQZ128rmk
    890576478U,	// VPORQZ128rmkz
    811654750U,	// VPORQZ128rr
    87055966U,	// VPORQZ128rrk
    890281566U,	// VPORQZ128rrkz
    812867166U,	// VPORQZ256rm
    360816222U,	// VPORQZ256rmb
    1436048990U,	// VPORQZ256rmbk
    1167384158U,	// VPORQZ256rmbkz
    985128542U,	// VPORQZ256rmk
    890609246U,	// VPORQZ256rmkz
    811654750U,	// VPORQZ256rr
    87055966U,	// VPORQZ256rrk
    890281566U,	// VPORQZ256rrkz
    812883550U,	// VPORQZrm
    362913374U,	// VPORQZrmb
    1438146142U,	// VPORQZrmbk
    1169481310U,	// VPORQZrmbkz
    985144926U,	// VPORQZrmk
    890674782U,	// VPORQZrmkz
    811654750U,	// VPORQZrr
    87055966U,	// VPORQZrrk
    890281566U,	// VPORQZrrkz
    812867879U,	// VPORYrm
    811655463U,	// VPORYrr
    811852071U,	// VPORrm
    811655463U,	// VPORrr
    326391851U,	// VPPERMrmr
    890574891U,	// VPPERMrrm
    890279979U,	// VPPERMrrr
    890279979U,	// VPPERMrrr_REV
    1638172802U,	// VPROLDZ128mbi
    1712588930U,	// VPROLDZ128mbik
    1686489218U,	// VPROLDZ128mbikz
    830769282U,	// VPROLDZ128mi
    643041410U,	// VPROLDZ128mik
    593873026U,	// VPROLDZ128mikz
    283428994U,	// VPROLDZ128ri
    1357580418U,	// VPROLDZ128rik
    1088817282U,	// VPROLDZ128rikz
    2443479170U,	// VPROLDZ256mbi
    2517895298U,	// VPROLDZ256mbik
    2491795586U,	// VPROLDZ256mbikz
    1009027202U,	// VPROLDZ256mi
    649332866U,	// VPROLDZ256mik
    644204674U,	// VPROLDZ256mikz
    283428994U,	// VPROLDZ256ri
    1357580418U,	// VPROLDZ256rik
    1088817282U,	// VPROLDZ256rikz
    2711914626U,	// VPROLDZmbi
    2786330754U,	// VPROLDZmbik
    2760231042U,	// VPROLDZmbikz
    1011124354U,	// VPROLDZmi
    655624322U,	// VPROLDZmik
    650496130U,	// VPROLDZmikz
    283428994U,	// VPROLDZri
    1357580418U,	// VPROLDZrik
    1088817282U,	// VPROLDZrikz
    2982452446U,	// VPROLQZ128mbi
    3075742942U,	// VPROLQZ128mbik
    3013991646U,	// VPROLQZ128mbikz
    830774494U,	// VPROLQZ128mi
    643046622U,	// VPROLQZ128mik
    593878238U,	// VPROLQZ128mikz
    283434206U,	// VPROLQZ128ri
    1357585630U,	// VPROLQZ128rik
    1088822494U,	// VPROLQZ128rikz
    1640275166U,	// VPROLQZ256mbi
    1733565662U,	// VPROLQZ256mbik
    1671814366U,	// VPROLQZ256mbikz
    1009032414U,	// VPROLQZ256mi
    649338078U,	// VPROLQZ256mik
    644209886U,	// VPROLQZ256mikz
    283434206U,	// VPROLQZ256ri
    1357585630U,	// VPROLQZ256rik
    1088822494U,	// VPROLQZ256rikz
    2445581534U,	// VPROLQZmbi
    2538872030U,	// VPROLQZmbik
    2477120734U,	// VPROLQZmbikz
    1011129566U,	// VPROLQZmi
    655629534U,	// VPROLQZmik
    650501342U,	// VPROLQZmikz
    283434206U,	// VPROLQZri
    1357585630U,	// VPROLQZrik
    1088822494U,	// VPROLQZrikz
    811847883U,	// VPROLVDZ128rm
    360796363U,	// VPROLVDZ128rmb
    1436061899U,	// VPROLVDZ128rmbk
    1167478987U,	// VPROLVDZ128rmbkz
    985108683U,	// VPROLVDZ128rmk
    890573003U,	// VPROLVDZ128rmkz
    811651275U,	// VPROLVDZ128rr
    87052491U,	// VPROLVDZ128rrk
    890278091U,	// VPROLVDZ128rrkz
    812863691U,	// VPROLVDZ256rm
    362893515U,	// VPROLVDZ256rmb
    1438159051U,	// VPROLVDZ256rmbk
    1169576139U,	// VPROLVDZ256rmbkz
    985125067U,	// VPROLVDZ256rmk
    890605771U,	// VPROLVDZ256rmkz
    811651275U,	// VPROLVDZ256rr
    87052491U,	// VPROLVDZ256rrk
    890278091U,	// VPROLVDZ256rrkz
    812880075U,	// VPROLVDZrm
    364990667U,	// VPROLVDZrmb
    1440256203U,	// VPROLVDZrmbk
    1171673291U,	// VPROLVDZrmbkz
    985141451U,	// VPROLVDZrmk
    890671307U,	// VPROLVDZrmkz
    811651275U,	// VPROLVDZrr
    87052491U,	// VPROLVDZrrk
    890278091U,	// VPROLVDZrrkz
    811851876U,	// VPROLVQZ128rm
    358719588U,	// VPROLVQZ128rmb
    1433952356U,	// VPROLVQZ128rmbk
    1165287524U,	// VPROLVQZ128rmbkz
    985112676U,	// VPROLVQZ128rmk
    890576996U,	// VPROLVQZ128rmkz
    811655268U,	// VPROLVQZ128rr
    87056484U,	// VPROLVQZ128rrk
    890282084U,	// VPROLVQZ128rrkz
    812867684U,	// VPROLVQZ256rm
    360816740U,	// VPROLVQZ256rmb
    1436049508U,	// VPROLVQZ256rmbk
    1167384676U,	// VPROLVQZ256rmbkz
    985129060U,	// VPROLVQZ256rmk
    890609764U,	// VPROLVQZ256rmkz
    811655268U,	// VPROLVQZ256rr
    87056484U,	// VPROLVQZ256rrk
    890282084U,	// VPROLVQZ256rrkz
    812884068U,	// VPROLVQZrm
    362913892U,	// VPROLVQZrmb
    1438146660U,	// VPROLVQZrmbk
    1169481828U,	// VPROLVQZrmbkz
    985145444U,	// VPROLVQZrmk
    890675300U,	// VPROLVQZrmkz
    811655268U,	// VPROLVQZrr
    87056484U,	// VPROLVQZrrk
    890282084U,	// VPROLVQZrrkz
    1638174137U,	// VPRORDZ128mbi
    1712590265U,	// VPRORDZ128mbik
    1686490553U,	// VPRORDZ128mbikz
    830770617U,	// VPRORDZ128mi
    643042745U,	// VPRORDZ128mik
    593874361U,	// VPRORDZ128mikz
    283430329U,	// VPRORDZ128ri
    1357581753U,	// VPRORDZ128rik
    1088818617U,	// VPRORDZ128rikz
    2443480505U,	// VPRORDZ256mbi
    2517896633U,	// VPRORDZ256mbik
    2491796921U,	// VPRORDZ256mbikz
    1009028537U,	// VPRORDZ256mi
    649334201U,	// VPRORDZ256mik
    644206009U,	// VPRORDZ256mikz
    283430329U,	// VPRORDZ256ri
    1357581753U,	// VPRORDZ256rik
    1088818617U,	// VPRORDZ256rikz
    2711915961U,	// VPRORDZmbi
    2786332089U,	// VPRORDZmbik
    2760232377U,	// VPRORDZmbikz
    1011125689U,	// VPRORDZmi
    655625657U,	// VPRORDZmik
    650497465U,	// VPRORDZmikz
    283430329U,	// VPRORDZri
    1357581753U,	// VPRORDZrik
    1088818617U,	// VPRORDZrikz
    2982452837U,	// VPRORQZ128mbi
    3075743333U,	// VPRORQZ128mbik
    3013992037U,	// VPRORQZ128mbikz
    830774885U,	// VPRORQZ128mi
    643047013U,	// VPRORQZ128mik
    593878629U,	// VPRORQZ128mikz
    283434597U,	// VPRORQZ128ri
    1357586021U,	// VPRORQZ128rik
    1088822885U,	// VPRORQZ128rikz
    1640275557U,	// VPRORQZ256mbi
    1733566053U,	// VPRORQZ256mbik
    1671814757U,	// VPRORQZ256mbikz
    1009032805U,	// VPRORQZ256mi
    649338469U,	// VPRORQZ256mik
    644210277U,	// VPRORQZ256mikz
    283434597U,	// VPRORQZ256ri
    1357586021U,	// VPRORQZ256rik
    1088822885U,	// VPRORQZ256rikz
    2445581925U,	// VPRORQZmbi
    2538872421U,	// VPRORQZmbik
    2477121125U,	// VPRORQZmbikz
    1011129957U,	// VPRORQZmi
    655629925U,	// VPRORQZmik
    650501733U,	// VPRORQZmikz
    283434597U,	// VPRORQZri
    1357586021U,	// VPRORQZrik
    1088822885U,	// VPRORQZrikz
    811847920U,	// VPRORVDZ128rm
    360796400U,	// VPRORVDZ128rmb
    1436061936U,	// VPRORVDZ128rmbk
    1167479024U,	// VPRORVDZ128rmbkz
    985108720U,	// VPRORVDZ128rmk
    890573040U,	// VPRORVDZ128rmkz
    811651312U,	// VPRORVDZ128rr
    87052528U,	// VPRORVDZ128rrk
    890278128U,	// VPRORVDZ128rrkz
    812863728U,	// VPRORVDZ256rm
    362893552U,	// VPRORVDZ256rmb
    1438159088U,	// VPRORVDZ256rmbk
    1169576176U,	// VPRORVDZ256rmbkz
    985125104U,	// VPRORVDZ256rmk
    890605808U,	// VPRORVDZ256rmkz
    811651312U,	// VPRORVDZ256rr
    87052528U,	// VPRORVDZ256rrk
    890278128U,	// VPRORVDZ256rrkz
    812880112U,	// VPRORVDZrm
    364990704U,	// VPRORVDZrmb
    1440256240U,	// VPRORVDZrmbk
    1171673328U,	// VPRORVDZrmbkz
    985141488U,	// VPRORVDZrmk
    890671344U,	// VPRORVDZrmkz
    811651312U,	// VPRORVDZrr
    87052528U,	// VPRORVDZrrk
    890278128U,	// VPRORVDZrrkz
    811851913U,	// VPRORVQZ128rm
    358719625U,	// VPRORVQZ128rmb
    1433952393U,	// VPRORVQZ128rmbk
    1165287561U,	// VPRORVQZ128rmbkz
    985112713U,	// VPRORVQZ128rmk
    890577033U,	// VPRORVQZ128rmkz
    811655305U,	// VPRORVQZ128rr
    87056521U,	// VPRORVQZ128rrk
    890282121U,	// VPRORVQZ128rrkz
    812867721U,	// VPRORVQZ256rm
    360816777U,	// VPRORVQZ256rmb
    1436049545U,	// VPRORVQZ256rmbk
    1167384713U,	// VPRORVQZ256rmbkz
    985129097U,	// VPRORVQZ256rmk
    890609801U,	// VPRORVQZ256rmkz
    811655305U,	// VPRORVQZ256rr
    87056521U,	// VPRORVQZ256rrk
    890282121U,	// VPRORVQZ256rrkz
    812884105U,	// VPRORVQZrm
    362913929U,	// VPRORVQZrmb
    1438146697U,	// VPRORVQZrmbk
    1169481865U,	// VPRORVQZrmbkz
    985145481U,	// VPRORVQZrmk
    890675337U,	// VPRORVQZrmkz
    811655305U,	// VPRORVQZrr
    87056521U,	// VPRORVQZrrk
    890282121U,	// VPRORVQZrrkz
    830768700U,	// VPROTBmi
    830801468U,	// VPROTBmr
    283428412U,	// VPROTBri
    811845180U,	// VPROTBrm
    811648572U,	// VPROTBrr
    811648572U,	// VPROTBrr_REV
    830771289U,	// VPROTDmi
    830804057U,	// VPROTDmr
    283431001U,	// VPROTDri
    811847769U,	// VPROTDrm
    811651161U,	// VPROTDrr
    811651161U,	// VPROTDrr_REV
    830775233U,	// VPROTQmi
    830808001U,	// VPROTQmr
    283434945U,	// VPROTQri
    811851713U,	// VPROTQrm
    811655105U,	// VPROTQrr
    811655105U,	// VPROTQrr_REV
    830779153U,	// VPROTWmi
    830811921U,	// VPROTWmr
    283438865U,	// VPROTWri
    811855633U,	// VPROTWrm
    811659025U,	// VPROTWrr
    811659025U,	// VPROTWrr_REV
    812870266U,	// VPSADBWYrm
    811657850U,	// VPSADBWYrr
    811854458U,	// VPSADBWZ128rm
    811657850U,	// VPSADBWZ128rr
    812870266U,	// VPSADBWZ256rm
    811657850U,	// VPSADBWZ256rr
    812886650U,	// VPSADBWZrm
    811657850U,	// VPSADBWZrr
    811854458U,	// VPSADBWrm
    811657850U,	// VPSADBWrr
    3247720445U,	// VPSCATTERDDZ128mr
    3425978365U,	// VPSCATTERDDZ256mr
    3428075517U,	// VPSCATTERDDZmr
    3247725345U,	// VPSCATTERDQZ128mr
    3425983265U,	// VPSCATTERDQZ256mr
    3428080417U,	// VPSCATTERDQZmr
    3251916153U,	// VPSCATTERQDZ128mr
    3247721849U,	// VPSCATTERQDZ256mr
    3425979769U,	// VPSCATTERQDZmr
    3247726073U,	// VPSCATTERQQZ128mr
    3425983993U,	// VPSCATTERQQZ256mr
    3428081145U,	// VPSCATTERQQZmr
    830800811U,	// VPSHABmr
    811844523U,	// VPSHABrm
    811647915U,	// VPSHABrr
    811647915U,	// VPSHABrr_REV
    830801753U,	// VPSHADmr
    811845465U,	// VPSHADrm
    811648857U,	// VPSHADrr
    811648857U,	// VPSHADrr_REV
    830806380U,	// VPSHAQmr
    811850092U,	// VPSHAQrm
    811653484U,	// VPSHAQrr
    811653484U,	// VPSHAQrr_REV
    830810685U,	// VPSHAWmr
    811854397U,	// VPSHAWrm
    811657789U,	// VPSHAWrr
    811657789U,	// VPSHAWrr_REV
    830800997U,	// VPSHLBmr
    811844709U,	// VPSHLBrm
    811648101U,	// VPSHLBrr
    811648101U,	// VPSHLBrr_REV
    1686489028U,	// VPSHLDDZ128rmbi
    1710475204U,	// VPSHLDDZ128rmbik
    1712588740U,	// VPSHLDDZ128rmbikz
    325437380U,	// VPSHLDDZ128rmi
    1983104964U,	// VPSHLDDZ128rmik
    1179912132U,	// VPSHLDDZ128rmikz
    1088817092U,	// VPSHLDDZ128rri
    2163132356U,	// VPSHLDDZ128rrik
    1357580228U,	// VPSHLDDZ128rrikz
    2491795396U,	// VPSHLDDZ256rmbi
    2515781572U,	// VPSHLDDZ256rmbik
    2517895108U,	// VPSHLDDZ256rmbikz
    375769028U,	// VPSHLDDZ256rmi
    1989396420U,	// VPSHLDDZ256rmik
    1186203588U,	// VPSHLDDZ256rmikz
    1088817092U,	// VPSHLDDZ256rri
    2163132356U,	// VPSHLDDZ256rrik
    1357580228U,	// VPSHLDDZ256rrikz
    2760230852U,	// VPSHLDDZrmbi
    2784217028U,	// VPSHLDDZrmbik
    2786330564U,	// VPSHLDDZrmbikz
    382060484U,	// VPSHLDDZrmi
    1995687876U,	// VPSHLDDZrmik
    1192495044U,	// VPSHLDDZrmikz
    1088817092U,	// VPSHLDDZrri
    2163132356U,	// VPSHLDDZrrik
    1357580228U,	// VPSHLDDZrrikz
    3013991055U,	// VPSHLDQZ128rmbi
    3073628815U,	// VPSHLDQZ128rmbik
    3075742351U,	// VPSHLDQZ128rmbikz
    325442191U,	// VPSHLDQZ128rmi
    1983109775U,	// VPSHLDQZ128rmik
    1179916943U,	// VPSHLDQZ128rmikz
    1088821903U,	// VPSHLDQZ128rri
    2163137167U,	// VPSHLDQZ128rrik
    1357585039U,	// VPSHLDQZ128rrikz
    1671813775U,	// VPSHLDQZ256rmbi
    1731451535U,	// VPSHLDQZ256rmbik
    1733565071U,	// VPSHLDQZ256rmbikz
    375773839U,	// VPSHLDQZ256rmi
    1989401231U,	// VPSHLDQZ256rmik
    1186208399U,	// VPSHLDQZ256rmikz
    1088821903U,	// VPSHLDQZ256rri
    2163137167U,	// VPSHLDQZ256rrik
    1357585039U,	// VPSHLDQZ256rrikz
    2477120143U,	// VPSHLDQZrmbi
    2536757903U,	// VPSHLDQZrmbik
    2538871439U,	// VPSHLDQZrmbikz
    382065295U,	// VPSHLDQZrmi
    1995692687U,	// VPSHLDQZrmik
    1192499855U,	// VPSHLDQZrmikz
    1088821903U,	// VPSHLDQZrri
    2163137167U,	// VPSHLDQZrrik
    1357585039U,	// VPSHLDQZrrikz
    890572974U,	// VPSHLDVDZ128m
    1167478958U,	// VPSHLDVDZ128mb
    1436061870U,	// VPSHLDVDZ128mbk
    1436061870U,	// VPSHLDVDZ128mbkz
    985108654U,	// VPSHLDVDZ128mk
    985108654U,	// VPSHLDVDZ128mkz
    890278062U,	// VPSHLDVDZ128r
    87052462U,	// VPSHLDVDZ128rk
    89149614U,	// VPSHLDVDZ128rkz
    890605742U,	// VPSHLDVDZ256m
    1169576110U,	// VPSHLDVDZ256mb
    1438159022U,	// VPSHLDVDZ256mbk
    1438159022U,	// VPSHLDVDZ256mbkz
    985125038U,	// VPSHLDVDZ256mk
    985125038U,	// VPSHLDVDZ256mkz
    890278062U,	// VPSHLDVDZ256r
    87052462U,	// VPSHLDVDZ256rk
    89149614U,	// VPSHLDVDZ256rkz
    890671278U,	// VPSHLDVDZm
    1171673262U,	// VPSHLDVDZmb
    1440256174U,	// VPSHLDVDZmbk
    1440256174U,	// VPSHLDVDZmbkz
    985141422U,	// VPSHLDVDZmk
    985141422U,	// VPSHLDVDZmkz
    890278062U,	// VPSHLDVDZr
    87052462U,	// VPSHLDVDZrk
    89149614U,	// VPSHLDVDZrkz
    890576960U,	// VPSHLDVQZ128m
    1165287488U,	// VPSHLDVQZ128mb
    1433952320U,	// VPSHLDVQZ128mbk
    1433952320U,	// VPSHLDVQZ128mbkz
    985112640U,	// VPSHLDVQZ128mk
    985112640U,	// VPSHLDVQZ128mkz
    890282048U,	// VPSHLDVQZ128r
    87056448U,	// VPSHLDVQZ128rk
    89153600U,	// VPSHLDVQZ128rkz
    890609728U,	// VPSHLDVQZ256m
    1167384640U,	// VPSHLDVQZ256mb
    1436049472U,	// VPSHLDVQZ256mbk
    1436049472U,	// VPSHLDVQZ256mbkz
    985129024U,	// VPSHLDVQZ256mk
    985129024U,	// VPSHLDVQZ256mkz
    890282048U,	// VPSHLDVQZ256r
    87056448U,	// VPSHLDVQZ256rk
    89153600U,	// VPSHLDVQZ256rkz
    890675264U,	// VPSHLDVQZm
    1169481792U,	// VPSHLDVQZmb
    1438146624U,	// VPSHLDVQZmbk
    1438146624U,	// VPSHLDVQZmbkz
    985145408U,	// VPSHLDVQZmk
    985145408U,	// VPSHLDVQZmkz
    890282048U,	// VPSHLDVQZr
    87056448U,	// VPSHLDVQZrk
    89153600U,	// VPSHLDVQZrkz
    890580861U,	// VPSHLDVWZ128m
    985116541U,	// VPSHLDVWZ128mk
    985116541U,	// VPSHLDVWZ128mkz
    890285949U,	// VPSHLDVWZ128r
    87060349U,	// VPSHLDVWZ128rk
    89157501U,	// VPSHLDVWZ128rkz
    890613629U,	// VPSHLDVWZ256m
    985132925U,	// VPSHLDVWZ256mk
    985132925U,	// VPSHLDVWZ256mkz
    890285949U,	// VPSHLDVWZ256r
    87060349U,	// VPSHLDVWZ256rk
    89157501U,	// VPSHLDVWZ256rkz
    890679165U,	// VPSHLDVWZm
    985149309U,	// VPSHLDVWZmk
    985149309U,	// VPSHLDVWZmkz
    890285949U,	// VPSHLDVWZr
    87060349U,	// VPSHLDVWZrk
    89157501U,	// VPSHLDVWZrkz
    325446472U,	// VPSHLDWZ128rmi
    1983114056U,	// VPSHLDWZ128rmik
    1179921224U,	// VPSHLDWZ128rmikz
    1088826184U,	// VPSHLDWZ128rri
    2163141448U,	// VPSHLDWZ128rrik
    1357589320U,	// VPSHLDWZ128rrikz
    375778120U,	// VPSHLDWZ256rmi
    1989405512U,	// VPSHLDWZ256rmik
    1186212680U,	// VPSHLDWZ256rmikz
    1088826184U,	// VPSHLDWZ256rri
    2163141448U,	// VPSHLDWZ256rrik
    1357589320U,	// VPSHLDWZ256rrikz
    382069576U,	// VPSHLDWZrmi
    1995696968U,	// VPSHLDWZrmik
    1192504136U,	// VPSHLDWZrmikz
    1088826184U,	// VPSHLDWZrri
    2163141448U,	// VPSHLDWZrrik
    1357589320U,	// VPSHLDWZrrikz
    830802025U,	// VPSHLDmr
    811845737U,	// VPSHLDrm
    811649129U,	// VPSHLDrr
    811649129U,	// VPSHLDrr_REV
    830807210U,	// VPSHLQmr
    811850922U,	// VPSHLQrm
    811654314U,	// VPSHLQrr
    811654314U,	// VPSHLQrr_REV
    830811231U,	// VPSHLWmr
    811854943U,	// VPSHLWrm
    811658335U,	// VPSHLWrr
    811658335U,	// VPSHLWrr_REV
    1686489098U,	// VPSHRDDZ128rmbi
    1710475274U,	// VPSHRDDZ128rmbik
    1712588810U,	// VPSHRDDZ128rmbikz
    325437450U,	// VPSHRDDZ128rmi
    1983105034U,	// VPSHRDDZ128rmik
    1179912202U,	// VPSHRDDZ128rmikz
    1088817162U,	// VPSHRDDZ128rri
    2163132426U,	// VPSHRDDZ128rrik
    1357580298U,	// VPSHRDDZ128rrikz
    2491795466U,	// VPSHRDDZ256rmbi
    2515781642U,	// VPSHRDDZ256rmbik
    2517895178U,	// VPSHRDDZ256rmbikz
    375769098U,	// VPSHRDDZ256rmi
    1989396490U,	// VPSHRDDZ256rmik
    1186203658U,	// VPSHRDDZ256rmikz
    1088817162U,	// VPSHRDDZ256rri
    2163132426U,	// VPSHRDDZ256rrik
    1357580298U,	// VPSHRDDZ256rrikz
    2760230922U,	// VPSHRDDZrmbi
    2784217098U,	// VPSHRDDZrmbik
    2786330634U,	// VPSHRDDZrmbikz
    382060554U,	// VPSHRDDZrmi
    1995687946U,	// VPSHRDDZrmik
    1192495114U,	// VPSHRDDZrmikz
    1088817162U,	// VPSHRDDZrri
    2163132426U,	// VPSHRDDZrrik
    1357580298U,	// VPSHRDDZrrikz
    3013991214U,	// VPSHRDQZ128rmbi
    3073628974U,	// VPSHRDQZ128rmbik
    3075742510U,	// VPSHRDQZ128rmbikz
    325442350U,	// VPSHRDQZ128rmi
    1983109934U,	// VPSHRDQZ128rmik
    1179917102U,	// VPSHRDQZ128rmikz
    1088822062U,	// VPSHRDQZ128rri
    2163137326U,	// VPSHRDQZ128rrik
    1357585198U,	// VPSHRDQZ128rrikz
    1671813934U,	// VPSHRDQZ256rmbi
    1731451694U,	// VPSHRDQZ256rmbik
    1733565230U,	// VPSHRDQZ256rmbikz
    375773998U,	// VPSHRDQZ256rmi
    1989401390U,	// VPSHRDQZ256rmik
    1186208558U,	// VPSHRDQZ256rmikz
    1088822062U,	// VPSHRDQZ256rri
    2163137326U,	// VPSHRDQZ256rrik
    1357585198U,	// VPSHRDQZ256rrikz
    2477120302U,	// VPSHRDQZrmbi
    2536758062U,	// VPSHRDQZrmbik
    2538871598U,	// VPSHRDQZrmbikz
    382065454U,	// VPSHRDQZrmi
    1995692846U,	// VPSHRDQZrmik
    1192500014U,	// VPSHRDQZrmikz
    1088822062U,	// VPSHRDQZrri
    2163137326U,	// VPSHRDQZrrik
    1357585198U,	// VPSHRDQZrrikz
    890572984U,	// VPSHRDVDZ128m
    1167478968U,	// VPSHRDVDZ128mb
    1436061880U,	// VPSHRDVDZ128mbk
    1436061880U,	// VPSHRDVDZ128mbkz
    985108664U,	// VPSHRDVDZ128mk
    985108664U,	// VPSHRDVDZ128mkz
    890278072U,	// VPSHRDVDZ128r
    87052472U,	// VPSHRDVDZ128rk
    89149624U,	// VPSHRDVDZ128rkz
    890605752U,	// VPSHRDVDZ256m
    1169576120U,	// VPSHRDVDZ256mb
    1438159032U,	// VPSHRDVDZ256mbk
    1438159032U,	// VPSHRDVDZ256mbkz
    985125048U,	// VPSHRDVDZ256mk
    985125048U,	// VPSHRDVDZ256mkz
    890278072U,	// VPSHRDVDZ256r
    87052472U,	// VPSHRDVDZ256rk
    89149624U,	// VPSHRDVDZ256rkz
    890671288U,	// VPSHRDVDZm
    1171673272U,	// VPSHRDVDZmb
    1440256184U,	// VPSHRDVDZmbk
    1440256184U,	// VPSHRDVDZmbkz
    985141432U,	// VPSHRDVDZmk
    985141432U,	// VPSHRDVDZmkz
    890278072U,	// VPSHRDVDZr
    87052472U,	// VPSHRDVDZrk
    89149624U,	// VPSHRDVDZrkz
    890576970U,	// VPSHRDVQZ128m
    1165287498U,	// VPSHRDVQZ128mb
    1433952330U,	// VPSHRDVQZ128mbk
    1433952330U,	// VPSHRDVQZ128mbkz
    985112650U,	// VPSHRDVQZ128mk
    985112650U,	// VPSHRDVQZ128mkz
    890282058U,	// VPSHRDVQZ128r
    87056458U,	// VPSHRDVQZ128rk
    89153610U,	// VPSHRDVQZ128rkz
    890609738U,	// VPSHRDVQZ256m
    1167384650U,	// VPSHRDVQZ256mb
    1436049482U,	// VPSHRDVQZ256mbk
    1436049482U,	// VPSHRDVQZ256mbkz
    985129034U,	// VPSHRDVQZ256mk
    985129034U,	// VPSHRDVQZ256mkz
    890282058U,	// VPSHRDVQZ256r
    87056458U,	// VPSHRDVQZ256rk
    89153610U,	// VPSHRDVQZ256rkz
    890675274U,	// VPSHRDVQZm
    1169481802U,	// VPSHRDVQZmb
    1438146634U,	// VPSHRDVQZmbk
    1438146634U,	// VPSHRDVQZmbkz
    985145418U,	// VPSHRDVQZmk
    985145418U,	// VPSHRDVQZmkz
    890282058U,	// VPSHRDVQZr
    87056458U,	// VPSHRDVQZrk
    89153610U,	// VPSHRDVQZrkz
    890580871U,	// VPSHRDVWZ128m
    985116551U,	// VPSHRDVWZ128mk
    985116551U,	// VPSHRDVWZ128mkz
    890285959U,	// VPSHRDVWZ128r
    87060359U,	// VPSHRDVWZ128rk
    89157511U,	// VPSHRDVWZ128rkz
    890613639U,	// VPSHRDVWZ256m
    985132935U,	// VPSHRDVWZ256mk
    985132935U,	// VPSHRDVWZ256mkz
    890285959U,	// VPSHRDVWZ256r
    87060359U,	// VPSHRDVWZ256rk
    89157511U,	// VPSHRDVWZ256rkz
    890679175U,	// VPSHRDVWZm
    985149319U,	// VPSHRDVWZmk
    985149319U,	// VPSHRDVWZmkz
    890285959U,	// VPSHRDVWZr
    87060359U,	// VPSHRDVWZrk
    89157511U,	// VPSHRDVWZrkz
    325446518U,	// VPSHRDWZ128rmi
    1983114102U,	// VPSHRDWZ128rmik
    1179921270U,	// VPSHRDWZ128rmikz
    1088826230U,	// VPSHRDWZ128rri
    2163141494U,	// VPSHRDWZ128rrik
    1357589366U,	// VPSHRDWZ128rrikz
    375778166U,	// VPSHRDWZ256rmi
    1989405558U,	// VPSHRDWZ256rmik
    1186212726U,	// VPSHRDWZ256rmikz
    1088826230U,	// VPSHRDWZ256rri
    2163141494U,	// VPSHRDWZ256rrik
    1357589366U,	// VPSHRDWZ256rrikz
    382069622U,	// VPSHRDWZrmi
    1995697014U,	// VPSHRDWZrmik
    1192504182U,	// VPSHRDWZrmikz
    1088826230U,	// VPSHRDWZrri
    2163141494U,	// VPSHRDWZrrik
    1357589366U,	// VPSHRDWZrrikz
    811844782U,	// VPSHUFBITQMBZ128rm
    890569902U,	// VPSHUFBITQMBZ128rmk
    811648174U,	// VPSHUFBITQMBZ128rr
    890274990U,	// VPSHUFBITQMBZ128rrk
    812860590U,	// VPSHUFBITQMBZ256rm
    890602670U,	// VPSHUFBITQMBZ256rmk
    811648174U,	// VPSHUFBITQMBZ256rr
    890274990U,	// VPSHUFBITQMBZ256rrk
    812876974U,	// VPSHUFBITQMBZrm
    890668206U,	// VPSHUFBITQMBZrmk
    811648174U,	// VPSHUFBITQMBZrr
    890274990U,	// VPSHUFBITQMBZrrk
    812860457U,	// VPSHUFBYrm
    811648041U,	// VPSHUFBYrr
    811844649U,	// VPSHUFBZ128rm
    985105449U,	// VPSHUFBZ128rmk
    890569769U,	// VPSHUFBZ128rmkz
    811648041U,	// VPSHUFBZ128rr
    87049257U,	// VPSHUFBZ128rrk
    890274857U,	// VPSHUFBZ128rrkz
    812860457U,	// VPSHUFBZ256rm
    985121833U,	// VPSHUFBZ256rmk
    890602537U,	// VPSHUFBZ256rmkz
    811648041U,	// VPSHUFBZ256rr
    87049257U,	// VPSHUFBZ256rrk
    890274857U,	// VPSHUFBZ256rrkz
    812876841U,	// VPSHUFBZrm
    985138217U,	// VPSHUFBZrmk
    890668073U,	// VPSHUFBZrmkz
    811648041U,	// VPSHUFBZrr
    87049257U,	// VPSHUFBZrrk
    890274857U,	// VPSHUFBZrrkz
    811844649U,	// VPSHUFBrm
    811648041U,	// VPSHUFBrr
    1009027119U,	// VPSHUFDYmi
    283428911U,	// VPSHUFDYri
    1638172719U,	// VPSHUFDZ128mbi
    1712588847U,	// VPSHUFDZ128mbik
    1686489135U,	// VPSHUFDZ128mbikz
    830769199U,	// VPSHUFDZ128mi
    643041327U,	// VPSHUFDZ128mik
    593872943U,	// VPSHUFDZ128mikz
    283428911U,	// VPSHUFDZ128ri
    1357580335U,	// VPSHUFDZ128rik
    1088817199U,	// VPSHUFDZ128rikz
    2443479087U,	// VPSHUFDZ256mbi
    2517895215U,	// VPSHUFDZ256mbik
    2491795503U,	// VPSHUFDZ256mbikz
    1009027119U,	// VPSHUFDZ256mi
    649332783U,	// VPSHUFDZ256mik
    644204591U,	// VPSHUFDZ256mikz
    283428911U,	// VPSHUFDZ256ri
    1357580335U,	// VPSHUFDZ256rik
    1088817199U,	// VPSHUFDZ256rikz
    2711914543U,	// VPSHUFDZmbi
    2786330671U,	// VPSHUFDZmbik
    2760230959U,	// VPSHUFDZmbikz
    1011124271U,	// VPSHUFDZmi
    655624239U,	// VPSHUFDZmik
    650496047U,	// VPSHUFDZmikz
    283428911U,	// VPSHUFDZri
    1357580335U,	// VPSHUFDZrik
    1088817199U,	// VPSHUFDZrikz
    830769199U,	// VPSHUFDmi
    283428911U,	// VPSHUFDri
    1009036328U,	// VPSHUFHWYmi
    283438120U,	// VPSHUFHWYri
    830778408U,	// VPSHUFHWZ128mi
    643050536U,	// VPSHUFHWZ128mik
    593882152U,	// VPSHUFHWZ128mikz
    283438120U,	// VPSHUFHWZ128ri
    1357589544U,	// VPSHUFHWZ128rik
    1088826408U,	// VPSHUFHWZ128rikz
    1009036328U,	// VPSHUFHWZ256mi
    649341992U,	// VPSHUFHWZ256mik
    644213800U,	// VPSHUFHWZ256mikz
    283438120U,	// VPSHUFHWZ256ri
    1357589544U,	// VPSHUFHWZ256rik
    1088826408U,	// VPSHUFHWZ256rikz
    1011133480U,	// VPSHUFHWZmi
    655633448U,	// VPSHUFHWZmik
    650505256U,	// VPSHUFHWZmikz
    283438120U,	// VPSHUFHWZri
    1357589544U,	// VPSHUFHWZrik
    1088826408U,	// VPSHUFHWZrikz
    830778408U,	// VPSHUFHWmi
    283438120U,	// VPSHUFHWri
    1009036373U,	// VPSHUFLWYmi
    283438165U,	// VPSHUFLWYri
    830778453U,	// VPSHUFLWZ128mi
    643050581U,	// VPSHUFLWZ128mik
    593882197U,	// VPSHUFLWZ128mikz
    283438165U,	// VPSHUFLWZ128ri
    1357589589U,	// VPSHUFLWZ128rik
    1088826453U,	// VPSHUFLWZ128rikz
    1009036373U,	// VPSHUFLWZ256mi
    649342037U,	// VPSHUFLWZ256mik
    644213845U,	// VPSHUFLWZ256mikz
    283438165U,	// VPSHUFLWZ256ri
    1357589589U,	// VPSHUFLWZ256rik
    1088826453U,	// VPSHUFLWZ256rikz
    1011133525U,	// VPSHUFLWZmi
    655633493U,	// VPSHUFLWZmik
    650505301U,	// VPSHUFLWZmikz
    283438165U,	// VPSHUFLWZri
    1357589589U,	// VPSHUFLWZrik
    1088826453U,	// VPSHUFLWZrikz
    830778453U,	// VPSHUFLWmi
    283438165U,	// VPSHUFLWri
    812860630U,	// VPSIGNBYrm
    811648214U,	// VPSIGNBYrr
    811844822U,	// VPSIGNBrm
    811648214U,	// VPSIGNBrr
    812861686U,	// VPSIGNDYrm
    811649270U,	// VPSIGNDYrr
    811845878U,	// VPSIGNDrm
    811649270U,	// VPSIGNDrr
    812870885U,	// VPSIGNWYrm
    811658469U,	// VPSIGNWYrr
    811855077U,	// VPSIGNWrm
    811658469U,	// VPSIGNWrr
    283433636U,	// VPSLLDQYri
    830773924U,	// VPSLLDQZ128rm
    283433636U,	// VPSLLDQZ128rr
    1009031844U,	// VPSLLDQZ256rm
    283433636U,	// VPSLLDQZ256rr
    1011128996U,	// VPSLLDQZrm
    283433636U,	// VPSLLDQZrr
    283433636U,	// VPSLLDQri
    283428977U,	// VPSLLDYri
    811845745U,	// VPSLLDYrm
    811649137U,	// VPSLLDYrr
    1638172785U,	// VPSLLDZ128mbi
    1712588913U,	// VPSLLDZ128mbik
    1686489201U,	// VPSLLDZ128mbikz
    830769265U,	// VPSLLDZ128mi
    643041393U,	// VPSLLDZ128mik
    593873009U,	// VPSLLDZ128mikz
    283428977U,	// VPSLLDZ128ri
    1357580401U,	// VPSLLDZ128rik
    1088817265U,	// VPSLLDZ128rikz
    811845745U,	// VPSLLDZ128rm
    985106545U,	// VPSLLDZ128rmk
    890570865U,	// VPSLLDZ128rmkz
    811649137U,	// VPSLLDZ128rr
    87050353U,	// VPSLLDZ128rrk
    890275953U,	// VPSLLDZ128rrkz
    2443479153U,	// VPSLLDZ256mbi
    2517895281U,	// VPSLLDZ256mbik
    2491795569U,	// VPSLLDZ256mbikz
    1009027185U,	// VPSLLDZ256mi
    649332849U,	// VPSLLDZ256mik
    644204657U,	// VPSLLDZ256mikz
    283428977U,	// VPSLLDZ256ri
    1357580401U,	// VPSLLDZ256rik
    1088817265U,	// VPSLLDZ256rikz
    811845745U,	// VPSLLDZ256rm
    985106545U,	// VPSLLDZ256rmk
    890570865U,	// VPSLLDZ256rmkz
    811649137U,	// VPSLLDZ256rr
    87050353U,	// VPSLLDZ256rrk
    890275953U,	// VPSLLDZ256rrkz
    2711914609U,	// VPSLLDZmbi
    2786330737U,	// VPSLLDZmbik
    2760231025U,	// VPSLLDZmbikz
    1011124337U,	// VPSLLDZmi
    655624305U,	// VPSLLDZmik
    650496113U,	// VPSLLDZmikz
    283428977U,	// VPSLLDZri
    1357580401U,	// VPSLLDZrik
    1088817265U,	// VPSLLDZrikz
    811845745U,	// VPSLLDZrm
    985106545U,	// VPSLLDZrmk
    890570865U,	// VPSLLDZrmkz
    811649137U,	// VPSLLDZrr
    87050353U,	// VPSLLDZrrk
    890275953U,	// VPSLLDZrrkz
    283428977U,	// VPSLLDri
    811845745U,	// VPSLLDrm
    811649137U,	// VPSLLDrr
    283434189U,	// VPSLLQYri
    811850957U,	// VPSLLQYrm
    811654349U,	// VPSLLQYrr
    2982452429U,	// VPSLLQZ128mbi
    3075742925U,	// VPSLLQZ128mbik
    3013991629U,	// VPSLLQZ128mbikz
    830774477U,	// VPSLLQZ128mi
    643046605U,	// VPSLLQZ128mik
    593878221U,	// VPSLLQZ128mikz
    283434189U,	// VPSLLQZ128ri
    1357585613U,	// VPSLLQZ128rik
    1088822477U,	// VPSLLQZ128rikz
    811850957U,	// VPSLLQZ128rm
    985111757U,	// VPSLLQZ128rmk
    890576077U,	// VPSLLQZ128rmkz
    811654349U,	// VPSLLQZ128rr
    87055565U,	// VPSLLQZ128rrk
    890281165U,	// VPSLLQZ128rrkz
    1640275149U,	// VPSLLQZ256mbi
    1733565645U,	// VPSLLQZ256mbik
    1671814349U,	// VPSLLQZ256mbikz
    1009032397U,	// VPSLLQZ256mi
    649338061U,	// VPSLLQZ256mik
    644209869U,	// VPSLLQZ256mikz
    283434189U,	// VPSLLQZ256ri
    1357585613U,	// VPSLLQZ256rik
    1088822477U,	// VPSLLQZ256rikz
    811850957U,	// VPSLLQZ256rm
    985111757U,	// VPSLLQZ256rmk
    890576077U,	// VPSLLQZ256rmkz
    811654349U,	// VPSLLQZ256rr
    87055565U,	// VPSLLQZ256rrk
    890281165U,	// VPSLLQZ256rrkz
    2445581517U,	// VPSLLQZmbi
    2538872013U,	// VPSLLQZmbik
    2477120717U,	// VPSLLQZmbikz
    1011129549U,	// VPSLLQZmi
    655629517U,	// VPSLLQZmik
    650501325U,	// VPSLLQZmikz
    283434189U,	// VPSLLQZri
    1357585613U,	// VPSLLQZrik
    1088822477U,	// VPSLLQZrikz
    811850957U,	// VPSLLQZrm
    985111757U,	// VPSLLQZrmk
    890576077U,	// VPSLLQZrmkz
    811654349U,	// VPSLLQZrr
    87055565U,	// VPSLLQZrrk
    890281165U,	// VPSLLQZrrkz
    283434189U,	// VPSLLQri
    811850957U,	// VPSLLQrm
    811654349U,	// VPSLLQrr
    812863682U,	// VPSLLVDYrm
    811651266U,	// VPSLLVDYrr
    811847874U,	// VPSLLVDZ128rm
    360796354U,	// VPSLLVDZ128rmb
    1436061890U,	// VPSLLVDZ128rmbk
    1167478978U,	// VPSLLVDZ128rmbkz
    985108674U,	// VPSLLVDZ128rmk
    890572994U,	// VPSLLVDZ128rmkz
    811651266U,	// VPSLLVDZ128rr
    87052482U,	// VPSLLVDZ128rrk
    890278082U,	// VPSLLVDZ128rrkz
    812863682U,	// VPSLLVDZ256rm
    362893506U,	// VPSLLVDZ256rmb
    1438159042U,	// VPSLLVDZ256rmbk
    1169576130U,	// VPSLLVDZ256rmbkz
    985125058U,	// VPSLLVDZ256rmk
    890605762U,	// VPSLLVDZ256rmkz
    811651266U,	// VPSLLVDZ256rr
    87052482U,	// VPSLLVDZ256rrk
    890278082U,	// VPSLLVDZ256rrkz
    812880066U,	// VPSLLVDZrm
    364990658U,	// VPSLLVDZrmb
    1440256194U,	// VPSLLVDZrmbk
    1171673282U,	// VPSLLVDZrmbkz
    985141442U,	// VPSLLVDZrmk
    890671298U,	// VPSLLVDZrmkz
    811651266U,	// VPSLLVDZrr
    87052482U,	// VPSLLVDZrrk
    890278082U,	// VPSLLVDZrrkz
    811847874U,	// VPSLLVDrm
    811651266U,	// VPSLLVDrr
    812867675U,	// VPSLLVQYrm
    811655259U,	// VPSLLVQYrr
    811851867U,	// VPSLLVQZ128rm
    358719579U,	// VPSLLVQZ128rmb
    1433952347U,	// VPSLLVQZ128rmbk
    1165287515U,	// VPSLLVQZ128rmbkz
    985112667U,	// VPSLLVQZ128rmk
    890576987U,	// VPSLLVQZ128rmkz
    811655259U,	// VPSLLVQZ128rr
    87056475U,	// VPSLLVQZ128rrk
    890282075U,	// VPSLLVQZ128rrkz
    812867675U,	// VPSLLVQZ256rm
    360816731U,	// VPSLLVQZ256rmb
    1436049499U,	// VPSLLVQZ256rmbk
    1167384667U,	// VPSLLVQZ256rmbkz
    985129051U,	// VPSLLVQZ256rmk
    890609755U,	// VPSLLVQZ256rmkz
    811655259U,	// VPSLLVQZ256rr
    87056475U,	// VPSLLVQZ256rrk
    890282075U,	// VPSLLVQZ256rrkz
    812884059U,	// VPSLLVQZrm
    362913883U,	// VPSLLVQZrmb
    1438146651U,	// VPSLLVQZrmbk
    1169481819U,	// VPSLLVQZrmbkz
    985145435U,	// VPSLLVQZrmk
    890675291U,	// VPSLLVQZrmkz
    811655259U,	// VPSLLVQZrr
    87056475U,	// VPSLLVQZrrk
    890282075U,	// VPSLLVQZrrkz
    811851867U,	// VPSLLVQrm
    811655259U,	// VPSLLVQrr
    811855768U,	// VPSLLVWZ128rm
    985116568U,	// VPSLLVWZ128rmk
    890580888U,	// VPSLLVWZ128rmkz
    811659160U,	// VPSLLVWZ128rr
    87060376U,	// VPSLLVWZ128rrk
    890285976U,	// VPSLLVWZ128rrkz
    812871576U,	// VPSLLVWZ256rm
    985132952U,	// VPSLLVWZ256rmk
    890613656U,	// VPSLLVWZ256rmkz
    811659160U,	// VPSLLVWZ256rr
    87060376U,	// VPSLLVWZ256rrk
    890285976U,	// VPSLLVWZ256rrkz
    812887960U,	// VPSLLVWZrm
    985149336U,	// VPSLLVWZrmk
    890679192U,	// VPSLLVWZrmkz
    811659160U,	// VPSLLVWZrr
    87060376U,	// VPSLLVWZrrk
    890285976U,	// VPSLLVWZrrkz
    283438191U,	// VPSLLWYri
    811854959U,	// VPSLLWYrm
    811658351U,	// VPSLLWYrr
    830778479U,	// VPSLLWZ128mi
    643050607U,	// VPSLLWZ128mik
    593882223U,	// VPSLLWZ128mikz
    283438191U,	// VPSLLWZ128ri
    1357589615U,	// VPSLLWZ128rik
    1088826479U,	// VPSLLWZ128rikz
    811854959U,	// VPSLLWZ128rm
    985115759U,	// VPSLLWZ128rmk
    890580079U,	// VPSLLWZ128rmkz
    811658351U,	// VPSLLWZ128rr
    87059567U,	// VPSLLWZ128rrk
    890285167U,	// VPSLLWZ128rrkz
    1009036399U,	// VPSLLWZ256mi
    649342063U,	// VPSLLWZ256mik
    644213871U,	// VPSLLWZ256mikz
    283438191U,	// VPSLLWZ256ri
    1357589615U,	// VPSLLWZ256rik
    1088826479U,	// VPSLLWZ256rikz
    811854959U,	// VPSLLWZ256rm
    985115759U,	// VPSLLWZ256rmk
    890580079U,	// VPSLLWZ256rmkz
    811658351U,	// VPSLLWZ256rr
    87059567U,	// VPSLLWZ256rrk
    890285167U,	// VPSLLWZ256rrkz
    1011133551U,	// VPSLLWZmi
    655633519U,	// VPSLLWZmik
    650505327U,	// VPSLLWZmikz
    283438191U,	// VPSLLWZri
    1357589615U,	// VPSLLWZrik
    1088826479U,	// VPSLLWZrikz
    811854959U,	// VPSLLWZrm
    985115759U,	// VPSLLWZrmk
    890580079U,	// VPSLLWZrmkz
    811658351U,	// VPSLLWZrr
    87059567U,	// VPSLLWZrrk
    890285167U,	// VPSLLWZrrkz
    283438191U,	// VPSLLWri
    811854959U,	// VPSLLWrm
    811658351U,	// VPSLLWrr
    283428705U,	// VPSRADYri
    811845473U,	// VPSRADYrm
    811648865U,	// VPSRADYrr
    1638172513U,	// VPSRADZ128mbi
    1712588641U,	// VPSRADZ128mbik
    1686488929U,	// VPSRADZ128mbikz
    830768993U,	// VPSRADZ128mi
    643041121U,	// VPSRADZ128mik
    593872737U,	// VPSRADZ128mikz
    283428705U,	// VPSRADZ128ri
    1357580129U,	// VPSRADZ128rik
    1088816993U,	// VPSRADZ128rikz
    811845473U,	// VPSRADZ128rm
    985106273U,	// VPSRADZ128rmk
    890570593U,	// VPSRADZ128rmkz
    811648865U,	// VPSRADZ128rr
    87050081U,	// VPSRADZ128rrk
    890275681U,	// VPSRADZ128rrkz
    2443478881U,	// VPSRADZ256mbi
    2517895009U,	// VPSRADZ256mbik
    2491795297U,	// VPSRADZ256mbikz
    1009026913U,	// VPSRADZ256mi
    649332577U,	// VPSRADZ256mik
    644204385U,	// VPSRADZ256mikz
    283428705U,	// VPSRADZ256ri
    1357580129U,	// VPSRADZ256rik
    1088816993U,	// VPSRADZ256rikz
    811845473U,	// VPSRADZ256rm
    985106273U,	// VPSRADZ256rmk
    890570593U,	// VPSRADZ256rmkz
    811648865U,	// VPSRADZ256rr
    87050081U,	// VPSRADZ256rrk
    890275681U,	// VPSRADZ256rrkz
    2711914337U,	// VPSRADZmbi
    2786330465U,	// VPSRADZmbik
    2760230753U,	// VPSRADZmbikz
    1011124065U,	// VPSRADZmi
    655624033U,	// VPSRADZmik
    650495841U,	// VPSRADZmikz
    283428705U,	// VPSRADZri
    1357580129U,	// VPSRADZrik
    1088816993U,	// VPSRADZrikz
    811845473U,	// VPSRADZrm
    985106273U,	// VPSRADZrmk
    890570593U,	// VPSRADZrmkz
    811648865U,	// VPSRADZrr
    87050081U,	// VPSRADZrrk
    890275681U,	// VPSRADZrrkz
    283428705U,	// VPSRADri
    811845473U,	// VPSRADrm
    811648865U,	// VPSRADrr
    2982451572U,	// VPSRAQZ128mbi
    3075742068U,	// VPSRAQZ128mbik
    3013990772U,	// VPSRAQZ128mbikz
    830773620U,	// VPSRAQZ128mi
    643045748U,	// VPSRAQZ128mik
    593877364U,	// VPSRAQZ128mikz
    283433332U,	// VPSRAQZ128ri
    1357584756U,	// VPSRAQZ128rik
    1088821620U,	// VPSRAQZ128rikz
    811850100U,	// VPSRAQZ128rm
    985110900U,	// VPSRAQZ128rmk
    890575220U,	// VPSRAQZ128rmkz
    811653492U,	// VPSRAQZ128rr
    87054708U,	// VPSRAQZ128rrk
    890280308U,	// VPSRAQZ128rrkz
    1640274292U,	// VPSRAQZ256mbi
    1733564788U,	// VPSRAQZ256mbik
    1671813492U,	// VPSRAQZ256mbikz
    1009031540U,	// VPSRAQZ256mi
    649337204U,	// VPSRAQZ256mik
    644209012U,	// VPSRAQZ256mikz
    283433332U,	// VPSRAQZ256ri
    1357584756U,	// VPSRAQZ256rik
    1088821620U,	// VPSRAQZ256rikz
    811850100U,	// VPSRAQZ256rm
    985110900U,	// VPSRAQZ256rmk
    890575220U,	// VPSRAQZ256rmkz
    811653492U,	// VPSRAQZ256rr
    87054708U,	// VPSRAQZ256rrk
    890280308U,	// VPSRAQZ256rrkz
    2445580660U,	// VPSRAQZmbi
    2538871156U,	// VPSRAQZmbik
    2477119860U,	// VPSRAQZmbikz
    1011128692U,	// VPSRAQZmi
    655628660U,	// VPSRAQZmik
    650500468U,	// VPSRAQZmikz
    283433332U,	// VPSRAQZri
    1357584756U,	// VPSRAQZrik
    1088821620U,	// VPSRAQZrikz
    811850100U,	// VPSRAQZrm
    985110900U,	// VPSRAQZrmk
    890575220U,	// VPSRAQZrmkz
    811653492U,	// VPSRAQZrr
    87054708U,	// VPSRAQZrrk
    890280308U,	// VPSRAQZrrkz
    812863653U,	// VPSRAVDYrm
    811651237U,	// VPSRAVDYrr
    811847845U,	// VPSRAVDZ128rm
    360796325U,	// VPSRAVDZ128rmb
    1436061861U,	// VPSRAVDZ128rmbk
    1167478949U,	// VPSRAVDZ128rmbkz
    985108645U,	// VPSRAVDZ128rmk
    890572965U,	// VPSRAVDZ128rmkz
    811651237U,	// VPSRAVDZ128rr
    87052453U,	// VPSRAVDZ128rrk
    890278053U,	// VPSRAVDZ128rrkz
    812863653U,	// VPSRAVDZ256rm
    362893477U,	// VPSRAVDZ256rmb
    1438159013U,	// VPSRAVDZ256rmbk
    1169576101U,	// VPSRAVDZ256rmbkz
    985125029U,	// VPSRAVDZ256rmk
    890605733U,	// VPSRAVDZ256rmkz
    811651237U,	// VPSRAVDZ256rr
    87052453U,	// VPSRAVDZ256rrk
    890278053U,	// VPSRAVDZ256rrkz
    812880037U,	// VPSRAVDZrm
    364990629U,	// VPSRAVDZrmb
    1440256165U,	// VPSRAVDZrmbk
    1171673253U,	// VPSRAVDZrmbkz
    985141413U,	// VPSRAVDZrmk
    890671269U,	// VPSRAVDZrmkz
    811651237U,	// VPSRAVDZrr
    87052453U,	// VPSRAVDZrrk
    890278053U,	// VPSRAVDZrrkz
    811847845U,	// VPSRAVDrm
    811651237U,	// VPSRAVDrr
    811851831U,	// VPSRAVQZ128rm
    358719543U,	// VPSRAVQZ128rmb
    1433952311U,	// VPSRAVQZ128rmbk
    1165287479U,	// VPSRAVQZ128rmbkz
    985112631U,	// VPSRAVQZ128rmk
    890576951U,	// VPSRAVQZ128rmkz
    811655223U,	// VPSRAVQZ128rr
    87056439U,	// VPSRAVQZ128rrk
    890282039U,	// VPSRAVQZ128rrkz
    812867639U,	// VPSRAVQZ256rm
    360816695U,	// VPSRAVQZ256rmb
    1436049463U,	// VPSRAVQZ256rmbk
    1167384631U,	// VPSRAVQZ256rmbkz
    985129015U,	// VPSRAVQZ256rmk
    890609719U,	// VPSRAVQZ256rmkz
    811655223U,	// VPSRAVQZ256rr
    87056439U,	// VPSRAVQZ256rrk
    890282039U,	// VPSRAVQZ256rrkz
    812884023U,	// VPSRAVQZrm
    362913847U,	// VPSRAVQZrmb
    1438146615U,	// VPSRAVQZrmbk
    1169481783U,	// VPSRAVQZrmbkz
    985145399U,	// VPSRAVQZrmk
    890675255U,	// VPSRAVQZrmkz
    811655223U,	// VPSRAVQZrr
    87056439U,	// VPSRAVQZrrk
    890282039U,	// VPSRAVQZrrkz
    811855732U,	// VPSRAVWZ128rm
    985116532U,	// VPSRAVWZ128rmk
    890580852U,	// VPSRAVWZ128rmkz
    811659124U,	// VPSRAVWZ128rr
    87060340U,	// VPSRAVWZ128rrk
    890285940U,	// VPSRAVWZ128rrkz
    812871540U,	// VPSRAVWZ256rm
    985132916U,	// VPSRAVWZ256rmk
    890613620U,	// VPSRAVWZ256rmkz
    811659124U,	// VPSRAVWZ256rr
    87060340U,	// VPSRAVWZ256rrk
    890285940U,	// VPSRAVWZ256rrkz
    812887924U,	// VPSRAVWZrm
    985149300U,	// VPSRAVWZrmk
    890679156U,	// VPSRAVWZrmkz
    811659124U,	// VPSRAVWZrr
    87060340U,	// VPSRAVWZrrk
    890285940U,	// VPSRAVWZrrkz
    283437637U,	// VPSRAWYri
    811854405U,	// VPSRAWYrm
    811657797U,	// VPSRAWYrr
    830777925U,	// VPSRAWZ128mi
    643050053U,	// VPSRAWZ128mik
    593881669U,	// VPSRAWZ128mikz
    283437637U,	// VPSRAWZ128ri
    1357589061U,	// VPSRAWZ128rik
    1088825925U,	// VPSRAWZ128rikz
    811854405U,	// VPSRAWZ128rm
    985115205U,	// VPSRAWZ128rmk
    890579525U,	// VPSRAWZ128rmkz
    811657797U,	// VPSRAWZ128rr
    87059013U,	// VPSRAWZ128rrk
    890284613U,	// VPSRAWZ128rrkz
    1009035845U,	// VPSRAWZ256mi
    649341509U,	// VPSRAWZ256mik
    644213317U,	// VPSRAWZ256mikz
    283437637U,	// VPSRAWZ256ri
    1357589061U,	// VPSRAWZ256rik
    1088825925U,	// VPSRAWZ256rikz
    811854405U,	// VPSRAWZ256rm
    985115205U,	// VPSRAWZ256rmk
    890579525U,	// VPSRAWZ256rmkz
    811657797U,	// VPSRAWZ256rr
    87059013U,	// VPSRAWZ256rrk
    890284613U,	// VPSRAWZ256rrkz
    1011132997U,	// VPSRAWZmi
    655632965U,	// VPSRAWZmik
    650504773U,	// VPSRAWZmikz
    283437637U,	// VPSRAWZri
    1357589061U,	// VPSRAWZrik
    1088825925U,	// VPSRAWZrikz
    811854405U,	// VPSRAWZrm
    985115205U,	// VPSRAWZrmk
    890579525U,	// VPSRAWZrmkz
    811657797U,	// VPSRAWZrr
    87059013U,	// VPSRAWZrrk
    890284613U,	// VPSRAWZrrkz
    283437637U,	// VPSRAWri
    811854405U,	// VPSRAWrm
    811657797U,	// VPSRAWrr
    283433645U,	// VPSRLDQYri
    830773933U,	// VPSRLDQZ128rm
    283433645U,	// VPSRLDQZ128rr
    1009031853U,	// VPSRLDQZ256rm
    283433645U,	// VPSRLDQZ256rr
    1011129005U,	// VPSRLDQZrm
    283433645U,	// VPSRLDQZrr
    283433645U,	// VPSRLDQri
    283429002U,	// VPSRLDYri
    811845770U,	// VPSRLDYrm
    811649162U,	// VPSRLDYrr
    1638172810U,	// VPSRLDZ128mbi
    1712588938U,	// VPSRLDZ128mbik
    1686489226U,	// VPSRLDZ128mbikz
    830769290U,	// VPSRLDZ128mi
    643041418U,	// VPSRLDZ128mik
    593873034U,	// VPSRLDZ128mikz
    283429002U,	// VPSRLDZ128ri
    1357580426U,	// VPSRLDZ128rik
    1088817290U,	// VPSRLDZ128rikz
    811845770U,	// VPSRLDZ128rm
    985106570U,	// VPSRLDZ128rmk
    890570890U,	// VPSRLDZ128rmkz
    811649162U,	// VPSRLDZ128rr
    87050378U,	// VPSRLDZ128rrk
    890275978U,	// VPSRLDZ128rrkz
    2443479178U,	// VPSRLDZ256mbi
    2517895306U,	// VPSRLDZ256mbik
    2491795594U,	// VPSRLDZ256mbikz
    1009027210U,	// VPSRLDZ256mi
    649332874U,	// VPSRLDZ256mik
    644204682U,	// VPSRLDZ256mikz
    283429002U,	// VPSRLDZ256ri
    1357580426U,	// VPSRLDZ256rik
    1088817290U,	// VPSRLDZ256rikz
    811845770U,	// VPSRLDZ256rm
    985106570U,	// VPSRLDZ256rmk
    890570890U,	// VPSRLDZ256rmkz
    811649162U,	// VPSRLDZ256rr
    87050378U,	// VPSRLDZ256rrk
    890275978U,	// VPSRLDZ256rrkz
    2711914634U,	// VPSRLDZmbi
    2786330762U,	// VPSRLDZmbik
    2760231050U,	// VPSRLDZmbikz
    1011124362U,	// VPSRLDZmi
    655624330U,	// VPSRLDZmik
    650496138U,	// VPSRLDZmikz
    283429002U,	// VPSRLDZri
    1357580426U,	// VPSRLDZrik
    1088817290U,	// VPSRLDZrikz
    811845770U,	// VPSRLDZrm
    985106570U,	// VPSRLDZrmk
    890570890U,	// VPSRLDZrmkz
    811649162U,	// VPSRLDZrr
    87050378U,	// VPSRLDZrrk
    890275978U,	// VPSRLDZrrkz
    283429002U,	// VPSRLDri
    811845770U,	// VPSRLDrm
    811649162U,	// VPSRLDrr
    283434214U,	// VPSRLQYri
    811850982U,	// VPSRLQYrm
    811654374U,	// VPSRLQYrr
    2982452454U,	// VPSRLQZ128mbi
    3075742950U,	// VPSRLQZ128mbik
    3013991654U,	// VPSRLQZ128mbikz
    830774502U,	// VPSRLQZ128mi
    643046630U,	// VPSRLQZ128mik
    593878246U,	// VPSRLQZ128mikz
    283434214U,	// VPSRLQZ128ri
    1357585638U,	// VPSRLQZ128rik
    1088822502U,	// VPSRLQZ128rikz
    811850982U,	// VPSRLQZ128rm
    985111782U,	// VPSRLQZ128rmk
    890576102U,	// VPSRLQZ128rmkz
    811654374U,	// VPSRLQZ128rr
    87055590U,	// VPSRLQZ128rrk
    890281190U,	// VPSRLQZ128rrkz
    1640275174U,	// VPSRLQZ256mbi
    1733565670U,	// VPSRLQZ256mbik
    1671814374U,	// VPSRLQZ256mbikz
    1009032422U,	// VPSRLQZ256mi
    649338086U,	// VPSRLQZ256mik
    644209894U,	// VPSRLQZ256mikz
    283434214U,	// VPSRLQZ256ri
    1357585638U,	// VPSRLQZ256rik
    1088822502U,	// VPSRLQZ256rikz
    811850982U,	// VPSRLQZ256rm
    985111782U,	// VPSRLQZ256rmk
    890576102U,	// VPSRLQZ256rmkz
    811654374U,	// VPSRLQZ256rr
    87055590U,	// VPSRLQZ256rrk
    890281190U,	// VPSRLQZ256rrkz
    2445581542U,	// VPSRLQZmbi
    2538872038U,	// VPSRLQZmbik
    2477120742U,	// VPSRLQZmbikz
    1011129574U,	// VPSRLQZmi
    655629542U,	// VPSRLQZmik
    650501350U,	// VPSRLQZmikz
    283434214U,	// VPSRLQZri
    1357585638U,	// VPSRLQZrik
    1088822502U,	// VPSRLQZrikz
    811850982U,	// VPSRLQZrm
    985111782U,	// VPSRLQZrmk
    890576102U,	// VPSRLQZrmkz
    811654374U,	// VPSRLQZrr
    87055590U,	// VPSRLQZrrk
    890281190U,	// VPSRLQZrrkz
    283434214U,	// VPSRLQri
    811850982U,	// VPSRLQrm
    811654374U,	// VPSRLQrr
    812863700U,	// VPSRLVDYrm
    811651284U,	// VPSRLVDYrr
    811847892U,	// VPSRLVDZ128rm
    360796372U,	// VPSRLVDZ128rmb
    1436061908U,	// VPSRLVDZ128rmbk
    1167478996U,	// VPSRLVDZ128rmbkz
    985108692U,	// VPSRLVDZ128rmk
    890573012U,	// VPSRLVDZ128rmkz
    811651284U,	// VPSRLVDZ128rr
    87052500U,	// VPSRLVDZ128rrk
    890278100U,	// VPSRLVDZ128rrkz
    812863700U,	// VPSRLVDZ256rm
    362893524U,	// VPSRLVDZ256rmb
    1438159060U,	// VPSRLVDZ256rmbk
    1169576148U,	// VPSRLVDZ256rmbkz
    985125076U,	// VPSRLVDZ256rmk
    890605780U,	// VPSRLVDZ256rmkz
    811651284U,	// VPSRLVDZ256rr
    87052500U,	// VPSRLVDZ256rrk
    890278100U,	// VPSRLVDZ256rrkz
    812880084U,	// VPSRLVDZrm
    364990676U,	// VPSRLVDZrmb
    1440256212U,	// VPSRLVDZrmbk
    1171673300U,	// VPSRLVDZrmbkz
    985141460U,	// VPSRLVDZrmk
    890671316U,	// VPSRLVDZrmkz
    811651284U,	// VPSRLVDZrr
    87052500U,	// VPSRLVDZrrk
    890278100U,	// VPSRLVDZrrkz
    811847892U,	// VPSRLVDrm
    811651284U,	// VPSRLVDrr
    812867693U,	// VPSRLVQYrm
    811655277U,	// VPSRLVQYrr
    811851885U,	// VPSRLVQZ128rm
    358719597U,	// VPSRLVQZ128rmb
    1433952365U,	// VPSRLVQZ128rmbk
    1165287533U,	// VPSRLVQZ128rmbkz
    985112685U,	// VPSRLVQZ128rmk
    890577005U,	// VPSRLVQZ128rmkz
    811655277U,	// VPSRLVQZ128rr
    87056493U,	// VPSRLVQZ128rrk
    890282093U,	// VPSRLVQZ128rrkz
    812867693U,	// VPSRLVQZ256rm
    360816749U,	// VPSRLVQZ256rmb
    1436049517U,	// VPSRLVQZ256rmbk
    1167384685U,	// VPSRLVQZ256rmbkz
    985129069U,	// VPSRLVQZ256rmk
    890609773U,	// VPSRLVQZ256rmkz
    811655277U,	// VPSRLVQZ256rr
    87056493U,	// VPSRLVQZ256rrk
    890282093U,	// VPSRLVQZ256rrkz
    812884077U,	// VPSRLVQZrm
    362913901U,	// VPSRLVQZrmb
    1438146669U,	// VPSRLVQZrmbk
    1169481837U,	// VPSRLVQZrmbkz
    985145453U,	// VPSRLVQZrmk
    890675309U,	// VPSRLVQZrmkz
    811655277U,	// VPSRLVQZrr
    87056493U,	// VPSRLVQZrrk
    890282093U,	// VPSRLVQZrrkz
    811851885U,	// VPSRLVQrm
    811655277U,	// VPSRLVQrr
    811855777U,	// VPSRLVWZ128rm
    985116577U,	// VPSRLVWZ128rmk
    890580897U,	// VPSRLVWZ128rmkz
    811659169U,	// VPSRLVWZ128rr
    87060385U,	// VPSRLVWZ128rrk
    890285985U,	// VPSRLVWZ128rrkz
    812871585U,	// VPSRLVWZ256rm
    985132961U,	// VPSRLVWZ256rmk
    890613665U,	// VPSRLVWZ256rmkz
    811659169U,	// VPSRLVWZ256rr
    87060385U,	// VPSRLVWZ256rrk
    890285985U,	// VPSRLVWZ256rrkz
    812887969U,	// VPSRLVWZrm
    985149345U,	// VPSRLVWZrmk
    890679201U,	// VPSRLVWZrmkz
    811659169U,	// VPSRLVWZrr
    87060385U,	// VPSRLVWZrrk
    890285985U,	// VPSRLVWZrrkz
    283438214U,	// VPSRLWYri
    811854982U,	// VPSRLWYrm
    811658374U,	// VPSRLWYrr
    830778502U,	// VPSRLWZ128mi
    643050630U,	// VPSRLWZ128mik
    593882246U,	// VPSRLWZ128mikz
    283438214U,	// VPSRLWZ128ri
    1357589638U,	// VPSRLWZ128rik
    1088826502U,	// VPSRLWZ128rikz
    811854982U,	// VPSRLWZ128rm
    985115782U,	// VPSRLWZ128rmk
    890580102U,	// VPSRLWZ128rmkz
    811658374U,	// VPSRLWZ128rr
    87059590U,	// VPSRLWZ128rrk
    890285190U,	// VPSRLWZ128rrkz
    1009036422U,	// VPSRLWZ256mi
    649342086U,	// VPSRLWZ256mik
    644213894U,	// VPSRLWZ256mikz
    283438214U,	// VPSRLWZ256ri
    1357589638U,	// VPSRLWZ256rik
    1088826502U,	// VPSRLWZ256rikz
    811854982U,	// VPSRLWZ256rm
    985115782U,	// VPSRLWZ256rmk
    890580102U,	// VPSRLWZ256rmkz
    811658374U,	// VPSRLWZ256rr
    87059590U,	// VPSRLWZ256rrk
    890285190U,	// VPSRLWZ256rrkz
    1011133574U,	// VPSRLWZmi
    655633542U,	// VPSRLWZmik
    650505350U,	// VPSRLWZmikz
    283438214U,	// VPSRLWZri
    1357589638U,	// VPSRLWZrik
    1088826502U,	// VPSRLWZrikz
    811854982U,	// VPSRLWZrm
    985115782U,	// VPSRLWZrmk
    890580102U,	// VPSRLWZrmkz
    811658374U,	// VPSRLWZrr
    87059590U,	// VPSRLWZrrk
    890285190U,	// VPSRLWZrrkz
    283438214U,	// VPSRLWri
    811854982U,	// VPSRLWrm
    811658374U,	// VPSRLWrr
    812860345U,	// VPSUBBYrm
    811647929U,	// VPSUBBYrr
    811844537U,	// VPSUBBZ128rm
    985105337U,	// VPSUBBZ128rmk
    890569657U,	// VPSUBBZ128rmkz
    811647929U,	// VPSUBBZ128rr
    87049145U,	// VPSUBBZ128rrk
    890274745U,	// VPSUBBZ128rrkz
    812860345U,	// VPSUBBZ256rm
    985121721U,	// VPSUBBZ256rmk
    890602425U,	// VPSUBBZ256rmkz
    811647929U,	// VPSUBBZ256rr
    87049145U,	// VPSUBBZ256rrk
    890274745U,	// VPSUBBZ256rrkz
    812876729U,	// VPSUBBZrm
    985138105U,	// VPSUBBZrmk
    890667961U,	// VPSUBBZrmkz
    811647929U,	// VPSUBBZrr
    87049145U,	// VPSUBBZrrk
    890274745U,	// VPSUBBZrrkz
    811844537U,	// VPSUBBrm
    811647929U,	// VPSUBBrr
    812861319U,	// VPSUBDYrm
    811648903U,	// VPSUBDYrr
    811845511U,	// VPSUBDZ128rm
    360793991U,	// VPSUBDZ128rmb
    1436059527U,	// VPSUBDZ128rmbk
    1167476615U,	// VPSUBDZ128rmbkz
    985106311U,	// VPSUBDZ128rmk
    890570631U,	// VPSUBDZ128rmkz
    811648903U,	// VPSUBDZ128rr
    87050119U,	// VPSUBDZ128rrk
    890275719U,	// VPSUBDZ128rrkz
    812861319U,	// VPSUBDZ256rm
    362891143U,	// VPSUBDZ256rmb
    1438156679U,	// VPSUBDZ256rmbk
    1169573767U,	// VPSUBDZ256rmbkz
    985122695U,	// VPSUBDZ256rmk
    890603399U,	// VPSUBDZ256rmkz
    811648903U,	// VPSUBDZ256rr
    87050119U,	// VPSUBDZ256rrk
    890275719U,	// VPSUBDZ256rrkz
    812877703U,	// VPSUBDZrm
    364988295U,	// VPSUBDZrmb
    1440253831U,	// VPSUBDZrmbk
    1171670919U,	// VPSUBDZrmbkz
    985139079U,	// VPSUBDZrmk
    890668935U,	// VPSUBDZrmkz
    811648903U,	// VPSUBDZrr
    87050119U,	// VPSUBDZrrk
    890275719U,	// VPSUBDZrrkz
    811845511U,	// VPSUBDrm
    811648903U,	// VPSUBDrr
    812865959U,	// VPSUBQYrm
    811653543U,	// VPSUBQYrr
    811850151U,	// VPSUBQZ128rm
    358717863U,	// VPSUBQZ128rmb
    1433950631U,	// VPSUBQZ128rmbk
    1165285799U,	// VPSUBQZ128rmbkz
    985110951U,	// VPSUBQZ128rmk
    890575271U,	// VPSUBQZ128rmkz
    811653543U,	// VPSUBQZ128rr
    87054759U,	// VPSUBQZ128rrk
    890280359U,	// VPSUBQZ128rrkz
    812865959U,	// VPSUBQZ256rm
    360815015U,	// VPSUBQZ256rmb
    1436047783U,	// VPSUBQZ256rmbk
    1167382951U,	// VPSUBQZ256rmbkz
    985127335U,	// VPSUBQZ256rmk
    890608039U,	// VPSUBQZ256rmkz
    811653543U,	// VPSUBQZ256rr
    87054759U,	// VPSUBQZ256rrk
    890280359U,	// VPSUBQZ256rrkz
    812882343U,	// VPSUBQZrm
    362912167U,	// VPSUBQZrmb
    1438144935U,	// VPSUBQZrmbk
    1169480103U,	// VPSUBQZrmbkz
    985143719U,	// VPSUBQZrmk
    890673575U,	// VPSUBQZrmkz
    811653543U,	// VPSUBQZrr
    87054759U,	// VPSUBQZrrk
    890280359U,	// VPSUBQZrrkz
    811850151U,	// VPSUBQrm
    811653543U,	// VPSUBQrr
    812860849U,	// VPSUBSBYrm
    811648433U,	// VPSUBSBYrr
    811845041U,	// VPSUBSBZ128rm
    985105841U,	// VPSUBSBZ128rmk
    890570161U,	// VPSUBSBZ128rmkz
    811648433U,	// VPSUBSBZ128rr
    87049649U,	// VPSUBSBZ128rrk
    890275249U,	// VPSUBSBZ128rrkz
    812860849U,	// VPSUBSBZ256rm
    985122225U,	// VPSUBSBZ256rmk
    890602929U,	// VPSUBSBZ256rmkz
    811648433U,	// VPSUBSBZ256rr
    87049649U,	// VPSUBSBZ256rrk
    890275249U,	// VPSUBSBZ256rrkz
    812877233U,	// VPSUBSBZrm
    985138609U,	// VPSUBSBZrmk
    890668465U,	// VPSUBSBZrmkz
    811648433U,	// VPSUBSBZrr
    87049649U,	// VPSUBSBZrrk
    890275249U,	// VPSUBSBZrrkz
    811845041U,	// VPSUBSBrm
    811648433U,	// VPSUBSBrr
    812871172U,	// VPSUBSWYrm
    811658756U,	// VPSUBSWYrr
    811855364U,	// VPSUBSWZ128rm
    985116164U,	// VPSUBSWZ128rmk
    890580484U,	// VPSUBSWZ128rmkz
    811658756U,	// VPSUBSWZ128rr
    87059972U,	// VPSUBSWZ128rrk
    890285572U,	// VPSUBSWZ128rrkz
    812871172U,	// VPSUBSWZ256rm
    985132548U,	// VPSUBSWZ256rmk
    890613252U,	// VPSUBSWZ256rmkz
    811658756U,	// VPSUBSWZ256rr
    87059972U,	// VPSUBSWZ256rrk
    890285572U,	// VPSUBSWZ256rrkz
    812887556U,	// VPSUBSWZrm
    985148932U,	// VPSUBSWZrmk
    890678788U,	// VPSUBSWZrmkz
    811658756U,	// VPSUBSWZrr
    87059972U,	// VPSUBSWZrrk
    890285572U,	// VPSUBSWZrrkz
    811855364U,	// VPSUBSWrm
    811658756U,	// VPSUBSWrr
    812860910U,	// VPSUBUSBYrm
    811648494U,	// VPSUBUSBYrr
    811845102U,	// VPSUBUSBZ128rm
    985105902U,	// VPSUBUSBZ128rmk
    890570222U,	// VPSUBUSBZ128rmkz
    811648494U,	// VPSUBUSBZ128rr
    87049710U,	// VPSUBUSBZ128rrk
    890275310U,	// VPSUBUSBZ128rrkz
    812860910U,	// VPSUBUSBZ256rm
    985122286U,	// VPSUBUSBZ256rmk
    890602990U,	// VPSUBUSBZ256rmkz
    811648494U,	// VPSUBUSBZ256rr
    87049710U,	// VPSUBUSBZ256rrk
    890275310U,	// VPSUBUSBZ256rrkz
    812877294U,	// VPSUBUSBZrm
    985138670U,	// VPSUBUSBZrmk
    890668526U,	// VPSUBUSBZrmkz
    811648494U,	// VPSUBUSBZrr
    87049710U,	// VPSUBUSBZrrk
    890275310U,	// VPSUBUSBZrrkz
    811845102U,	// VPSUBUSBrm
    811648494U,	// VPSUBUSBrr
    812871307U,	// VPSUBUSWYrm
    811658891U,	// VPSUBUSWYrr
    811855499U,	// VPSUBUSWZ128rm
    985116299U,	// VPSUBUSWZ128rmk
    890580619U,	// VPSUBUSWZ128rmkz
    811658891U,	// VPSUBUSWZ128rr
    87060107U,	// VPSUBUSWZ128rrk
    890285707U,	// VPSUBUSWZ128rrkz
    812871307U,	// VPSUBUSWZ256rm
    985132683U,	// VPSUBUSWZ256rmk
    890613387U,	// VPSUBUSWZ256rmkz
    811658891U,	// VPSUBUSWZ256rr
    87060107U,	// VPSUBUSWZ256rrk
    890285707U,	// VPSUBUSWZ256rrkz
    812887691U,	// VPSUBUSWZrm
    985149067U,	// VPSUBUSWZrmk
    890678923U,	// VPSUBUSWZrmkz
    811658891U,	// VPSUBUSWZrr
    87060107U,	// VPSUBUSWZrrk
    890285707U,	// VPSUBUSWZrrkz
    811855499U,	// VPSUBUSWrm
    811658891U,	// VPSUBUSWrr
    812870347U,	// VPSUBWYrm
    811657931U,	// VPSUBWYrr
    811854539U,	// VPSUBWZ128rm
    985115339U,	// VPSUBWZ128rmk
    890579659U,	// VPSUBWZ128rmkz
    811657931U,	// VPSUBWZ128rr
    87059147U,	// VPSUBWZ128rrk
    890284747U,	// VPSUBWZ128rrkz
    812870347U,	// VPSUBWZ256rm
    985131723U,	// VPSUBWZ256rmk
    890612427U,	// VPSUBWZ256rmkz
    811657931U,	// VPSUBWZ256rr
    87059147U,	// VPSUBWZ256rrk
    890284747U,	// VPSUBWZ256rrkz
    812886731U,	// VPSUBWZrm
    985148107U,	// VPSUBWZrmk
    890677963U,	// VPSUBWZrmkz
    811657931U,	// VPSUBWZrr
    87059147U,	// VPSUBWZrrk
    890284747U,	// VPSUBWZrrkz
    811854539U,	// VPSUBWrm
    811657931U,	// VPSUBWrr
    1712588856U,	// VPTERNLOGDZ128rmbi
    1710475320U,	// VPTERNLOGDZ128rmbik
    1710475320U,	// VPTERNLOGDZ128rmbikz
    1179912248U,	// VPTERNLOGDZ128rmi
    1983105080U,	// VPTERNLOGDZ128rmik
    2519975992U,	// VPTERNLOGDZ128rmikz
    1357580344U,	// VPTERNLOGDZ128rri
    2163132472U,	// VPTERNLOGDZ128rrik
    2163132472U,	// VPTERNLOGDZ128rrikz
    2517895224U,	// VPTERNLOGDZ256rmbi
    2515781688U,	// VPTERNLOGDZ256rmbik
    2515781688U,	// VPTERNLOGDZ256rmbikz
    1186203704U,	// VPTERNLOGDZ256rmi
    1989396536U,	// VPTERNLOGDZ256rmik
    2526267448U,	// VPTERNLOGDZ256rmikz
    1357580344U,	// VPTERNLOGDZ256rri
    2163132472U,	// VPTERNLOGDZ256rrik
    2163132472U,	// VPTERNLOGDZ256rrikz
    2786330680U,	// VPTERNLOGDZrmbi
    2784217144U,	// VPTERNLOGDZrmbik
    2784217144U,	// VPTERNLOGDZrmbikz
    1192495160U,	// VPTERNLOGDZrmi
    1995687992U,	// VPTERNLOGDZrmik
    2532558904U,	// VPTERNLOGDZrmikz
    1357580344U,	// VPTERNLOGDZrri
    2163132472U,	// VPTERNLOGDZrrik
    2163132472U,	// VPTERNLOGDZrrikz
    3075742795U,	// VPTERNLOGQZ128rmbi
    3073629259U,	// VPTERNLOGQZ128rmbik
    3073629259U,	// VPTERNLOGQZ128rmbikz
    1179917387U,	// VPTERNLOGQZ128rmi
    1983110219U,	// VPTERNLOGQZ128rmik
    2519981131U,	// VPTERNLOGQZ128rmikz
    1357585483U,	// VPTERNLOGQZ128rri
    2163137611U,	// VPTERNLOGQZ128rrik
    2163137611U,	// VPTERNLOGQZ128rrikz
    1733565515U,	// VPTERNLOGQZ256rmbi
    1731451979U,	// VPTERNLOGQZ256rmbik
    1731451979U,	// VPTERNLOGQZ256rmbikz
    1186208843U,	// VPTERNLOGQZ256rmi
    1989401675U,	// VPTERNLOGQZ256rmik
    2526272587U,	// VPTERNLOGQZ256rmikz
    1357585483U,	// VPTERNLOGQZ256rri
    2163137611U,	// VPTERNLOGQZ256rrik
    2163137611U,	// VPTERNLOGQZ256rrikz
    2538871883U,	// VPTERNLOGQZrmbi
    2536758347U,	// VPTERNLOGQZrmbik
    2536758347U,	// VPTERNLOGQZrmbikz
    1192500299U,	// VPTERNLOGQZrmi
    1995693131U,	// VPTERNLOGQZrmik
    2532564043U,	// VPTERNLOGQZrmikz
    1357585483U,	// VPTERNLOGQZrri
    2163137611U,	// VPTERNLOGQZrrik
    2163137611U,	// VPTERNLOGQZrrikz
    811844804U,	// VPTESTMBZ128rm
    890569924U,	// VPTESTMBZ128rmk
    811648196U,	// VPTESTMBZ128rr
    890275012U,	// VPTESTMBZ128rrk
    812860612U,	// VPTESTMBZ256rm
    890602692U,	// VPTESTMBZ256rmk
    811648196U,	// VPTESTMBZ256rr
    890275012U,	// VPTESTMBZ256rrk
    812876996U,	// VPTESTMBZrm
    890668228U,	// VPTESTMBZrmk
    811648196U,	// VPTESTMBZrr
    890275012U,	// VPTESTMBZrrk
    811845835U,	// VPTESTMDZ128rm
    360794315U,	// VPTESTMDZ128rmb
    1167476939U,	// VPTESTMDZ128rmbk
    890570955U,	// VPTESTMDZ128rmk
    811649227U,	// VPTESTMDZ128rr
    890276043U,	// VPTESTMDZ128rrk
    812861643U,	// VPTESTMDZ256rm
    362891467U,	// VPTESTMDZ256rmb
    1169574091U,	// VPTESTMDZ256rmbk
    890603723U,	// VPTESTMDZ256rmk
    811649227U,	// VPTESTMDZ256rr
    890276043U,	// VPTESTMDZ256rrk
    812878027U,	// VPTESTMDZrm
    364988619U,	// VPTESTMDZrmb
    1171671243U,	// VPTESTMDZrmbk
    890669259U,	// VPTESTMDZrmk
    811649227U,	// VPTESTMDZrr
    890276043U,	// VPTESTMDZrrk
    811851067U,	// VPTESTMQZ128rm
    358718779U,	// VPTESTMQZ128rmb
    1165286715U,	// VPTESTMQZ128rmbk
    890576187U,	// VPTESTMQZ128rmk
    811654459U,	// VPTESTMQZ128rr
    890281275U,	// VPTESTMQZ128rrk
    812866875U,	// VPTESTMQZ256rm
    360815931U,	// VPTESTMQZ256rmb
    1167383867U,	// VPTESTMQZ256rmbk
    890608955U,	// VPTESTMQZ256rmk
    811654459U,	// VPTESTMQZ256rr
    890281275U,	// VPTESTMQZ256rrk
    812883259U,	// VPTESTMQZrm
    362913083U,	// VPTESTMQZrmb
    1169481019U,	// VPTESTMQZrmbk
    890674491U,	// VPTESTMQZrmk
    811654459U,	// VPTESTMQZrr
    890281275U,	// VPTESTMQZrrk
    811855059U,	// VPTESTMWZ128rm
    890580179U,	// VPTESTMWZ128rmk
    811658451U,	// VPTESTMWZ128rr
    890285267U,	// VPTESTMWZ128rrk
    812870867U,	// VPTESTMWZ256rm
    890612947U,	// VPTESTMWZ256rmk
    811658451U,	// VPTESTMWZ256rr
    890285267U,	// VPTESTMWZ256rrk
    812887251U,	// VPTESTMWZrm
    890678483U,	// VPTESTMWZrmk
    811658451U,	// VPTESTMWZrr
    890285267U,	// VPTESTMWZrrk
    811844763U,	// VPTESTNMBZ128rm
    890569883U,	// VPTESTNMBZ128rmk
    811648155U,	// VPTESTNMBZ128rr
    890274971U,	// VPTESTNMBZ128rrk
    812860571U,	// VPTESTNMBZ256rm
    890602651U,	// VPTESTNMBZ256rmk
    811648155U,	// VPTESTNMBZ256rr
    890274971U,	// VPTESTNMBZ256rrk
    812876955U,	// VPTESTNMBZrm
    890668187U,	// VPTESTNMBZrmk
    811648155U,	// VPTESTNMBZrr
    890274971U,	// VPTESTNMBZrrk
    811845808U,	// VPTESTNMDZ128rm
    360794288U,	// VPTESTNMDZ128rmb
    1167476912U,	// VPTESTNMDZ128rmbk
    890570928U,	// VPTESTNMDZ128rmk
    811649200U,	// VPTESTNMDZ128rr
    890276016U,	// VPTESTNMDZ128rrk
    812861616U,	// VPTESTNMDZ256rm
    362891440U,	// VPTESTNMDZ256rmb
    1169574064U,	// VPTESTNMDZ256rmbk
    890603696U,	// VPTESTNMDZ256rmk
    811649200U,	// VPTESTNMDZ256rr
    890276016U,	// VPTESTNMDZ256rrk
    812878000U,	// VPTESTNMDZrm
    364988592U,	// VPTESTNMDZrmb
    1171671216U,	// VPTESTNMDZrmbk
    890669232U,	// VPTESTNMDZrmk
    811649200U,	// VPTESTNMDZrr
    890276016U,	// VPTESTNMDZrrk
    811851040U,	// VPTESTNMQZ128rm
    358718752U,	// VPTESTNMQZ128rmb
    1165286688U,	// VPTESTNMQZ128rmbk
    890576160U,	// VPTESTNMQZ128rmk
    811654432U,	// VPTESTNMQZ128rr
    890281248U,	// VPTESTNMQZ128rrk
    812866848U,	// VPTESTNMQZ256rm
    360815904U,	// VPTESTNMQZ256rmb
    1167383840U,	// VPTESTNMQZ256rmbk
    890608928U,	// VPTESTNMQZ256rmk
    811654432U,	// VPTESTNMQZ256rr
    890281248U,	// VPTESTNMQZ256rrk
    812883232U,	// VPTESTNMQZrm
    362913056U,	// VPTESTNMQZrmb
    1169480992U,	// VPTESTNMQZrmbk
    890674464U,	// VPTESTNMQZrmk
    811654432U,	// VPTESTNMQZrr
    890281248U,	// VPTESTNMQZrrk
    811855032U,	// VPTESTNMWZ128rm
    890580152U,	// VPTESTNMWZ128rmk
    811658424U,	// VPTESTNMWZ128rr
    890285240U,	// VPTESTNMWZ128rrk
    812870840U,	// VPTESTNMWZ256rm
    890612920U,	// VPTESTNMWZ256rmk
    811658424U,	// VPTESTNMWZ256rr
    890285240U,	// VPTESTNMWZ256rrk
    812887224U,	// VPTESTNMWZrm
    890678456U,	// VPTESTNMWZrmk
    811658424U,	// VPTESTNMWZrr
    890285240U,	// VPTESTNMWZrrk
    552954252U,	// VPTESTYrm
    551840140U,	// VPTESTYrr
    665996U,	// VPTESTrm
    551840140U,	// VPTESTrr
    812870285U,	// VPUNPCKHBWYrm
    811657869U,	// VPUNPCKHBWYrr
    811854477U,	// VPUNPCKHBWZ128rm
    985115277U,	// VPUNPCKHBWZ128rmk
    890579597U,	// VPUNPCKHBWZ128rmkz
    811657869U,	// VPUNPCKHBWZ128rr
    87059085U,	// VPUNPCKHBWZ128rrk
    890284685U,	// VPUNPCKHBWZ128rrkz
    812870285U,	// VPUNPCKHBWZ256rm
    985131661U,	// VPUNPCKHBWZ256rmk
    890612365U,	// VPUNPCKHBWZ256rmkz
    811657869U,	// VPUNPCKHBWZ256rr
    87059085U,	// VPUNPCKHBWZ256rrk
    890284685U,	// VPUNPCKHBWZ256rrkz
    812886669U,	// VPUNPCKHBWZrm
    985148045U,	// VPUNPCKHBWZrmk
    890677901U,	// VPUNPCKHBWZrmkz
    811657869U,	// VPUNPCKHBWZrr
    87059085U,	// VPUNPCKHBWZrrk
    890284685U,	// VPUNPCKHBWZrrkz
    811854477U,	// VPUNPCKHBWrm
    811657869U,	// VPUNPCKHBWrr
    812866169U,	// VPUNPCKHDQYrm
    811653753U,	// VPUNPCKHDQYrr
    811850361U,	// VPUNPCKHDQZ128rm
    360798841U,	// VPUNPCKHDQZ128rmb
    1436064377U,	// VPUNPCKHDQZ128rmbk
    1167481465U,	// VPUNPCKHDQZ128rmbkz
    985111161U,	// VPUNPCKHDQZ128rmk
    890575481U,	// VPUNPCKHDQZ128rmkz
    811653753U,	// VPUNPCKHDQZ128rr
    87054969U,	// VPUNPCKHDQZ128rrk
    890280569U,	// VPUNPCKHDQZ128rrkz
    812866169U,	// VPUNPCKHDQZ256rm
    362895993U,	// VPUNPCKHDQZ256rmb
    1438161529U,	// VPUNPCKHDQZ256rmbk
    1169578617U,	// VPUNPCKHDQZ256rmbkz
    985127545U,	// VPUNPCKHDQZ256rmk
    890608249U,	// VPUNPCKHDQZ256rmkz
    811653753U,	// VPUNPCKHDQZ256rr
    87054969U,	// VPUNPCKHDQZ256rrk
    890280569U,	// VPUNPCKHDQZ256rrkz
    812882553U,	// VPUNPCKHDQZrm
    364993145U,	// VPUNPCKHDQZrmb
    1440258681U,	// VPUNPCKHDQZrmbk
    1171675769U,	// VPUNPCKHDQZrmbkz
    985143929U,	// VPUNPCKHDQZrmk
    890673785U,	// VPUNPCKHDQZrmkz
    811653753U,	// VPUNPCKHDQZrr
    87054969U,	// VPUNPCKHDQZrrk
    890280569U,	// VPUNPCKHDQZrrkz
    811850361U,	// VPUNPCKHDQrm
    811653753U,	// VPUNPCKHDQrr
    812866287U,	// VPUNPCKHQDQYrm
    811653871U,	// VPUNPCKHQDQYrr
    811850479U,	// VPUNPCKHQDQZ128rm
    358718191U,	// VPUNPCKHQDQZ128rmb
    1433950959U,	// VPUNPCKHQDQZ128rmbk
    1165286127U,	// VPUNPCKHQDQZ128rmbkz
    985111279U,	// VPUNPCKHQDQZ128rmk
    890575599U,	// VPUNPCKHQDQZ128rmkz
    811653871U,	// VPUNPCKHQDQZ128rr
    87055087U,	// VPUNPCKHQDQZ128rrk
    890280687U,	// VPUNPCKHQDQZ128rrkz
    812866287U,	// VPUNPCKHQDQZ256rm
    360815343U,	// VPUNPCKHQDQZ256rmb
    1436048111U,	// VPUNPCKHQDQZ256rmbk
    1167383279U,	// VPUNPCKHQDQZ256rmbkz
    985127663U,	// VPUNPCKHQDQZ256rmk
    890608367U,	// VPUNPCKHQDQZ256rmkz
    811653871U,	// VPUNPCKHQDQZ256rr
    87055087U,	// VPUNPCKHQDQZ256rrk
    890280687U,	// VPUNPCKHQDQZ256rrkz
    812882671U,	// VPUNPCKHQDQZrm
    362912495U,	// VPUNPCKHQDQZrmb
    1438145263U,	// VPUNPCKHQDQZrmbk
    1169480431U,	// VPUNPCKHQDQZrmbkz
    985144047U,	// VPUNPCKHQDQZrmk
    890673903U,	// VPUNPCKHQDQZrmkz
    811653871U,	// VPUNPCKHQDQZrr
    87055087U,	// VPUNPCKHQDQZrrk
    890280687U,	// VPUNPCKHQDQZrrkz
    811850479U,	// VPUNPCKHQDQrm
    811653871U,	// VPUNPCKHQDQrr
    812863767U,	// VPUNPCKHWDYrm
    811651351U,	// VPUNPCKHWDYrr
    811847959U,	// VPUNPCKHWDZ128rm
    985108759U,	// VPUNPCKHWDZ128rmk
    890573079U,	// VPUNPCKHWDZ128rmkz
    811651351U,	// VPUNPCKHWDZ128rr
    87052567U,	// VPUNPCKHWDZ128rrk
    890278167U,	// VPUNPCKHWDZ128rrkz
    812863767U,	// VPUNPCKHWDZ256rm
    985125143U,	// VPUNPCKHWDZ256rmk
    890605847U,	// VPUNPCKHWDZ256rmkz
    811651351U,	// VPUNPCKHWDZ256rr
    87052567U,	// VPUNPCKHWDZ256rrk
    890278167U,	// VPUNPCKHWDZ256rrkz
    812880151U,	// VPUNPCKHWDZrm
    985141527U,	// VPUNPCKHWDZrmk
    890671383U,	// VPUNPCKHWDZrmkz
    811651351U,	// VPUNPCKHWDZrr
    87052567U,	// VPUNPCKHWDZrrk
    890278167U,	// VPUNPCKHWDZrrkz
    811847959U,	// VPUNPCKHWDrm
    811651351U,	// VPUNPCKHWDrr
    812870307U,	// VPUNPCKLBWYrm
    811657891U,	// VPUNPCKLBWYrr
    811854499U,	// VPUNPCKLBWZ128rm
    985115299U,	// VPUNPCKLBWZ128rmk
    890579619U,	// VPUNPCKLBWZ128rmkz
    811657891U,	// VPUNPCKLBWZ128rr
    87059107U,	// VPUNPCKLBWZ128rrk
    890284707U,	// VPUNPCKLBWZ128rrkz
    812870307U,	// VPUNPCKLBWZ256rm
    985131683U,	// VPUNPCKLBWZ256rmk
    890612387U,	// VPUNPCKLBWZ256rmkz
    811657891U,	// VPUNPCKLBWZ256rr
    87059107U,	// VPUNPCKLBWZ256rrk
    890284707U,	// VPUNPCKLBWZ256rrkz
    812886691U,	// VPUNPCKLBWZrm
    985148067U,	// VPUNPCKLBWZrmk
    890677923U,	// VPUNPCKLBWZrmkz
    811657891U,	// VPUNPCKLBWZrr
    87059107U,	// VPUNPCKLBWZrrk
    890284707U,	// VPUNPCKLBWZrrkz
    811854499U,	// VPUNPCKLBWrm
    811657891U,	// VPUNPCKLBWrr
    812866200U,	// VPUNPCKLDQYrm
    811653784U,	// VPUNPCKLDQYrr
    811850392U,	// VPUNPCKLDQZ128rm
    360798872U,	// VPUNPCKLDQZ128rmb
    1436064408U,	// VPUNPCKLDQZ128rmbk
    1167481496U,	// VPUNPCKLDQZ128rmbkz
    985111192U,	// VPUNPCKLDQZ128rmk
    890575512U,	// VPUNPCKLDQZ128rmkz
    811653784U,	// VPUNPCKLDQZ128rr
    87055000U,	// VPUNPCKLDQZ128rrk
    890280600U,	// VPUNPCKLDQZ128rrkz
    812866200U,	// VPUNPCKLDQZ256rm
    362896024U,	// VPUNPCKLDQZ256rmb
    1438161560U,	// VPUNPCKLDQZ256rmbk
    1169578648U,	// VPUNPCKLDQZ256rmbkz
    985127576U,	// VPUNPCKLDQZ256rmk
    890608280U,	// VPUNPCKLDQZ256rmkz
    811653784U,	// VPUNPCKLDQZ256rr
    87055000U,	// VPUNPCKLDQZ256rrk
    890280600U,	// VPUNPCKLDQZ256rrkz
    812882584U,	// VPUNPCKLDQZrm
    364993176U,	// VPUNPCKLDQZrmb
    1440258712U,	// VPUNPCKLDQZrmbk
    1171675800U,	// VPUNPCKLDQZrmbkz
    985143960U,	// VPUNPCKLDQZrmk
    890673816U,	// VPUNPCKLDQZrmkz
    811653784U,	// VPUNPCKLDQZrr
    87055000U,	// VPUNPCKLDQZrrk
    890280600U,	// VPUNPCKLDQZrrkz
    811850392U,	// VPUNPCKLDQrm
    811653784U,	// VPUNPCKLDQrr
    812866300U,	// VPUNPCKLQDQYrm
    811653884U,	// VPUNPCKLQDQYrr
    811850492U,	// VPUNPCKLQDQZ128rm
    358718204U,	// VPUNPCKLQDQZ128rmb
    1433950972U,	// VPUNPCKLQDQZ128rmbk
    1165286140U,	// VPUNPCKLQDQZ128rmbkz
    985111292U,	// VPUNPCKLQDQZ128rmk
    890575612U,	// VPUNPCKLQDQZ128rmkz
    811653884U,	// VPUNPCKLQDQZ128rr
    87055100U,	// VPUNPCKLQDQZ128rrk
    890280700U,	// VPUNPCKLQDQZ128rrkz
    812866300U,	// VPUNPCKLQDQZ256rm
    360815356U,	// VPUNPCKLQDQZ256rmb
    1436048124U,	// VPUNPCKLQDQZ256rmbk
    1167383292U,	// VPUNPCKLQDQZ256rmbkz
    985127676U,	// VPUNPCKLQDQZ256rmk
    890608380U,	// VPUNPCKLQDQZ256rmkz
    811653884U,	// VPUNPCKLQDQZ256rr
    87055100U,	// VPUNPCKLQDQZ256rrk
    890280700U,	// VPUNPCKLQDQZ256rrkz
    812882684U,	// VPUNPCKLQDQZrm
    362912508U,	// VPUNPCKLQDQZrmb
    1438145276U,	// VPUNPCKLQDQZrmbk
    1169480444U,	// VPUNPCKLQDQZrmbkz
    985144060U,	// VPUNPCKLQDQZrmk
    890673916U,	// VPUNPCKLQDQZrmkz
    811653884U,	// VPUNPCKLQDQZrr
    87055100U,	// VPUNPCKLQDQZrrk
    890280700U,	// VPUNPCKLQDQZrrkz
    811850492U,	// VPUNPCKLQDQrm
    811653884U,	// VPUNPCKLQDQrr
    812863789U,	// VPUNPCKLWDYrm
    811651373U,	// VPUNPCKLWDYrr
    811847981U,	// VPUNPCKLWDZ128rm
    985108781U,	// VPUNPCKLWDZ128rmk
    890573101U,	// VPUNPCKLWDZ128rmkz
    811651373U,	// VPUNPCKLWDZ128rr
    87052589U,	// VPUNPCKLWDZ128rrk
    890278189U,	// VPUNPCKLWDZ128rrkz
    812863789U,	// VPUNPCKLWDZ256rm
    985125165U,	// VPUNPCKLWDZ256rmk
    890605869U,	// VPUNPCKLWDZ256rmkz
    811651373U,	// VPUNPCKLWDZ256rr
    87052589U,	// VPUNPCKLWDZ256rrk
    890278189U,	// VPUNPCKLWDZ256rrkz
    812880173U,	// VPUNPCKLWDZrm
    985141549U,	// VPUNPCKLWDZrmk
    890671405U,	// VPUNPCKLWDZrmkz
    811651373U,	// VPUNPCKLWDZrr
    87052589U,	// VPUNPCKLWDZrrk
    890278189U,	// VPUNPCKLWDZrrkz
    811847981U,	// VPUNPCKLWDrm
    811651373U,	// VPUNPCKLWDrr
    811847112U,	// VPXORDZ128rm
    360795592U,	// VPXORDZ128rmb
    1436061128U,	// VPXORDZ128rmbk
    1167478216U,	// VPXORDZ128rmbkz
    985107912U,	// VPXORDZ128rmk
    890572232U,	// VPXORDZ128rmkz
    811650504U,	// VPXORDZ128rr
    87051720U,	// VPXORDZ128rrk
    890277320U,	// VPXORDZ128rrkz
    812862920U,	// VPXORDZ256rm
    362892744U,	// VPXORDZ256rmb
    1438158280U,	// VPXORDZ256rmbk
    1169575368U,	// VPXORDZ256rmbkz
    985124296U,	// VPXORDZ256rmk
    890605000U,	// VPXORDZ256rmkz
    811650504U,	// VPXORDZ256rr
    87051720U,	// VPXORDZ256rrk
    890277320U,	// VPXORDZ256rrkz
    812879304U,	// VPXORDZrm
    364989896U,	// VPXORDZrmb
    1440255432U,	// VPXORDZrmbk
    1171672520U,	// VPXORDZrmbkz
    985140680U,	// VPXORDZrmk
    890670536U,	// VPXORDZrmkz
    811650504U,	// VPXORDZrr
    87051720U,	// VPXORDZrrk
    890277320U,	// VPXORDZrrkz
    811851380U,	// VPXORQZ128rm
    358719092U,	// VPXORQZ128rmb
    1433951860U,	// VPXORQZ128rmbk
    1165287028U,	// VPXORQZ128rmbkz
    985112180U,	// VPXORQZ128rmk
    890576500U,	// VPXORQZ128rmkz
    811654772U,	// VPXORQZ128rr
    87055988U,	// VPXORQZ128rrk
    890281588U,	// VPXORQZ128rrkz
    812867188U,	// VPXORQZ256rm
    360816244U,	// VPXORQZ256rmb
    1436049012U,	// VPXORQZ256rmbk
    1167384180U,	// VPXORQZ256rmbkz
    985128564U,	// VPXORQZ256rmk
    890609268U,	// VPXORQZ256rmkz
    811654772U,	// VPXORQZ256rr
    87055988U,	// VPXORQZ256rrk
    890281588U,	// VPXORQZ256rrkz
    812883572U,	// VPXORQZrm
    362913396U,	// VPXORQZrmb
    1438146164U,	// VPXORQZrmbk
    1169481332U,	// VPXORQZrmbkz
    985144948U,	// VPXORQZrmk
    890674804U,	// VPXORQZrmkz
    811654772U,	// VPXORQZrr
    87055988U,	// VPXORQZrrk
    890281588U,	// VPXORQZrrkz
    812867912U,	// VPXORYrm
    811655496U,	// VPXORYrr
    811852104U,	// VPXORrm
    811655496U,	// VPXORrr
    2999307181U,	// VRANGEPDZ128rmbi
    3111373741U,	// VRANGEPDZ128rmbik
    3079932845U,	// VRANGEPDZ128rmbikz
    300272557U,	// VRANGEPDZ128rmi
    2039729069U,	// VRANGEPDZ128rmik
    1202981805U,	// VRANGEPDZ128rmikz
    1088818093U,	// VRANGEPDZ128rri
    2163133357U,	// VRANGEPDZ128rrik
    1357581229U,	// VRANGEPDZ128rrikz
    1657129901U,	// VRANGEPDZ256rmbi
    1769196461U,	// VRANGEPDZ256rmbik
    1737755565U,	// VRANGEPDZ256rmbikz
    392547245U,	// VRANGEPDZ256rmi
    2041826221U,	// VRANGEPDZ256rmik
    1205078957U,	// VRANGEPDZ256rmikz
    1088818093U,	// VRANGEPDZ256rri
    2163133357U,	// VRANGEPDZ256rrik
    1357581229U,	// VRANGEPDZ256rrikz
    2462436269U,	// VRANGEPDZrmbi
    2574502829U,	// VRANGEPDZrmbik
    2543061933U,	// VRANGEPDZrmbikz
    400935853U,	// VRANGEPDZrmi
    2043923373U,	// VRANGEPDZrmik
    1209273261U,	// VRANGEPDZrmikz
    1088818093U,	// VRANGEPDZrri
    1212550061U,	// VRANGEPDZrrib
    2286865325U,	// VRANGEPDZrribk
    1481313197U,	// VRANGEPDZrribkz
    2163133357U,	// VRANGEPDZrrik
    1357581229U,	// VRANGEPDZrrikz
    1661330625U,	// VRANGEPSZ128rmbi
    1777591489U,	// VRANGEPSZ128rmbik
    1752442049U,	// VRANGEPSZ128rmbikz
    300278977U,	// VRANGEPSZ128rmi
    2039735489U,	// VRANGEPSZ128rmik
    1202988225U,	// VRANGEPSZ128rmikz
    1088824513U,	// VRANGEPSZ128rri
    2163139777U,	// VRANGEPSZ128rrik
    1357587649U,	// VRANGEPSZ128rrikz
    2466636993U,	// VRANGEPSZ256rmbi
    2582897857U,	// VRANGEPSZ256rmbik
    2557748417U,	// VRANGEPSZ256rmbikz
    392553665U,	// VRANGEPSZ256rmi
    2041832641U,	// VRANGEPSZ256rmik
    1205085377U,	// VRANGEPSZ256rmikz
    1088824513U,	// VRANGEPSZ256rri
    2163139777U,	// VRANGEPSZ256rrik
    1357587649U,	// VRANGEPSZ256rrikz
    2735072449U,	// VRANGEPSZrmbi
    2851333313U,	// VRANGEPSZrmbik
    2826183873U,	// VRANGEPSZrmbikz
    400942273U,	// VRANGEPSZrmi
    2043929793U,	// VRANGEPSZrmik
    1209279681U,	// VRANGEPSZrmikz
    1088824513U,	// VRANGEPSZrri
    1212556481U,	// VRANGEPSZrrib
    2286871745U,	// VRANGEPSZrribk
    1481319617U,	// VRANGEPSZrribkz
    2163139777U,	// VRANGEPSZrrik
    1357587649U,	// VRANGEPSZrrikz
    851824412U,	// VRANGESDZrmi
    963890972U,	// VRANGESDZrmik
    932450076U,	// VRANGESDZrmikz
    1088818972U,	// VRANGESDZrri
    1212550940U,	// VRANGESDZrrib
    2286866204U,	// VRANGESDZrribk
    1481314076U,	// VRANGESDZrribkz
    2163134236U,	// VRANGESDZrrik
    1357582108U,	// VRANGESDZrrikz
    856025134U,	// VRANGESSZrmi
    972285998U,	// VRANGESSZrmik
    947136558U,	// VRANGESSZrmikz
    1088825390U,	// VRANGESSZrri
    1212557358U,	// VRANGESSZrrib
    2286872622U,	// VRANGESSZrribk
    1481320494U,	// VRANGESSZrribkz
    2163140654U,	// VRANGESSZrrik
    1357588526U,	// VRANGESSZrrikz
    658038U,	// VRCP14PDZ128m
    627673718U,	// VRCP14PDZ128mb
    628099702U,	// VRCP14PDZ128mbk
    627198582U,	// VRCP14PDZ128mbkz
    3230599798U,	// VRCP14PDZ128mk
    3229747830U,	// VRCP14PDZ128mkz
    551832182U,	// VRCP14PDZ128r
    3230698102U,	// VRCP14PDZ128rk
    3229665910U,	// VRCP14PDZ128rkz
    1346166U,	// VRCP14PDZ256m
    629770870U,	// VRCP14PDZ256mb
    630196854U,	// VRCP14PDZ256mbk
    629295734U,	// VRCP14PDZ256mbkz
    3230730870U,	// VRCP14PDZ256mk
    3230632566U,	// VRCP14PDZ256mkz
    551832182U,	// VRCP14PDZ256r
    3230698102U,	// VRCP14PDZ256rk
    3229665910U,	// VRCP14PDZ256rkz
    1510006U,	// VRCP14PDZm
    631868022U,	// VRCP14PDZmb
    632294006U,	// VRCP14PDZmbk
    631392886U,	// VRCP14PDZmbkz
    3230780022U,	// VRCP14PDZmk
    3230747254U,	// VRCP14PDZmkz
    551832182U,	// VRCP14PDZr
    3230698102U,	// VRCP14PDZrk
    3229665910U,	// VRCP14PDZrkz
    664443U,	// VRCP14PSZ128m
    629793659U,	// VRCP14PSZ128mb
    630399867U,	// VRCP14PSZ128mbk
    629318523U,	// VRCP14PSZ128mbkz
    3230606203U,	// VRCP14PSZ128mk
    3229754235U,	// VRCP14PSZ128mkz
    551838587U,	// VRCP14PSZ128r
    3230704507U,	// VRCP14PSZ128rk
    3229672315U,	// VRCP14PSZ128rkz
    1352571U,	// VRCP14PSZ256m
    631890811U,	// VRCP14PSZ256mb
    632497019U,	// VRCP14PSZ256mbk
    631415675U,	// VRCP14PSZ256mbkz
    3230737275U,	// VRCP14PSZ256mk
    3230638971U,	// VRCP14PSZ256mkz
    551838587U,	// VRCP14PSZ256r
    3230704507U,	// VRCP14PSZ256rk
    3229672315U,	// VRCP14PSZ256rkz
    1516411U,	// VRCP14PSZm
    633987963U,	// VRCP14PSZmb
    634594171U,	// VRCP14PSZmbk
    633512827U,	// VRCP14PSZmbkz
    3230786427U,	// VRCP14PSZmk
    3230753659U,	// VRCP14PSZmkz
    551838587U,	// VRCP14PSZr
    3230704507U,	// VRCP14PSZrk
    3229672315U,	// VRCP14PSZrkz
    283266713U,	// VRCP14SDZrm
    1357893273U,	// VRCP14SDZrmk
    1089474201U,	// VRCP14SDZrmkz
    811650713U,	// VRCP14SDZrr
    87051929U,	// VRCP14SDZrrk
    890277529U,	// VRCP14SDZrrkz
    283289500U,	// VRCP14SSZrm
    1358096284U,	// VRCP14SSZrmk
    1089677212U,	// VRCP14SSZrmkz
    811657116U,	// VRCP14SSZrr
    87058332U,	// VRCP14SSZrrk
    890283932U,	// VRCP14SSZrrkz
    1510028U,	// VRCP28PDZm
    631868044U,	// VRCP28PDZmb
    632294028U,	// VRCP28PDZmbk
    631392908U,	// VRCP28PDZmbkz
    3230780044U,	// VRCP28PDZmk
    3230747276U,	// VRCP28PDZmkz
    551832204U,	// VRCP28PDZr
    551843284U,	// VRCP28PDZrb
    3230709204U,	// VRCP28PDZrbk
    3229677012U,	// VRCP28PDZrbkz
    3230698124U,	// VRCP28PDZrk
    3229665932U,	// VRCP28PDZrkz
    1516433U,	// VRCP28PSZm
    633987985U,	// VRCP28PSZmb
    634594193U,	// VRCP28PSZmbk
    633512849U,	// VRCP28PSZmbkz
    3230786449U,	// VRCP28PSZmk
    3230753681U,	// VRCP28PSZmkz
    551838609U,	// VRCP28PSZr
    551843771U,	// VRCP28PSZrb
    3230709691U,	// VRCP28PSZrbk
    3229677499U,	// VRCP28PSZrbkz
    3230704529U,	// VRCP28PSZrk
    3229672337U,	// VRCP28PSZrkz
    283266735U,	// VRCP28SDZm
    1357893295U,	// VRCP28SDZmk
    1089474223U,	// VRCP28SDZmkz
    811650735U,	// VRCP28SDZr
    811660858U,	// VRCP28SDZrb
    87062074U,	// VRCP28SDZrbk
    890287674U,	// VRCP28SDZrbkz
    87051951U,	// VRCP28SDZrk
    890277551U,	// VRCP28SDZrkz
    283289522U,	// VRCP28SSZm
    1358096306U,	// VRCP28SSZmk
    1089677234U,	// VRCP28SSZmkz
    811657138U,	// VRCP28SSZr
    811661327U,	// VRCP28SSZrb
    87062543U,	// VRCP28SSZrbk
    890288143U,	// VRCP28SSZrbkz
    87058354U,	// VRCP28SSZrk
    890283954U,	// VRCP28SSZrkz
    1353097U,	// VRCPPSYm
    551839113U,	// VRCPPSYr
    664969U,	// VRCPPSm
    551839113U,	// VRCPPSr
    283289728U,	// VRCPSSm
    283289728U,	// VRCPSSm_Int
    811657344U,	// VRCPSSr
    811657344U,	// VRCPSSr_Int
    3032779682U,	// VREDUCEPDZ128rmbi
    3079932834U,	// VREDUCEPDZ128rmbik
    2999307170U,	// VREDUCEPDZ128rmbikz
    77892514U,	// VREDUCEPDZ128rmi
    666110882U,	// VREDUCEPDZ128rmik
    568708002U,	// VREDUCEPDZ128rmikz
    283429794U,	// VREDUCEPDZ128rri
    1357581218U,	// VREDUCEPDZ128rrik
    1088818082U,	// VREDUCEPDZ128rrikz
    1690602402U,	// VREDUCEPDZ256rmbi
    1737755554U,	// VREDUCEPDZ256rmbik
    1657129890U,	// VREDUCEPDZ256rmbikz
    168070050U,	// VREDUCEPDZ256rmi
    668208034U,	// VREDUCEPDZ256rmik
    660982690U,	// VREDUCEPDZ256rmikz
    283429794U,	// VREDUCEPDZ256rri
    1357581218U,	// VREDUCEPDZ256rrik
    1088818082U,	// VREDUCEPDZ256rrikz
    2495908770U,	// VREDUCEPDZrmbi
    2543061922U,	// VREDUCEPDZrmbik
    2462436258U,	// VREDUCEPDZrmbikz
    170167202U,	// VREDUCEPDZrmi
    672402338U,	// VREDUCEPDZrmik
    669371298U,	// VREDUCEPDZrmikz
    283429794U,	// VREDUCEPDZrri
    407161762U,	// VREDUCEPDZrrib
    1481313186U,	// VREDUCEPDZrribk
    1212550050U,	// VREDUCEPDZrribkz
    1357581218U,	// VREDUCEPDZrrik
    1088818082U,	// VREDUCEPDZrrikz
    1692705974U,	// VREDUCEPSZ128rmbi
    1752442038U,	// VREDUCEPSZ128rmbik
    1661330614U,	// VREDUCEPSZ128rmbikz
    77898934U,	// VREDUCEPSZ128rmi
    666117302U,	// VREDUCEPSZ128rmik
    568714422U,	// VREDUCEPSZ128rmikz
    283436214U,	// VREDUCEPSZ128rri
    1357587638U,	// VREDUCEPSZ128rrik
    1088824502U,	// VREDUCEPSZ128rrikz
    2498012342U,	// VREDUCEPSZ256rmbi
    2557748406U,	// VREDUCEPSZ256rmbik
    2466636982U,	// VREDUCEPSZ256rmbikz
    168076470U,	// VREDUCEPSZ256rmi
    668214454U,	// VREDUCEPSZ256rmik
    660989110U,	// VREDUCEPSZ256rmikz
    283436214U,	// VREDUCEPSZ256rri
    1357587638U,	// VREDUCEPSZ256rrik
    1088824502U,	// VREDUCEPSZ256rrikz
    2766447798U,	// VREDUCEPSZrmbi
    2826183862U,	// VREDUCEPSZrmbik
    2735072438U,	// VREDUCEPSZrmbikz
    170173622U,	// VREDUCEPSZrmi
    672408758U,	// VREDUCEPSZrmik
    669377718U,	// VREDUCEPSZrmikz
    283436214U,	// VREDUCEPSZrri
    407168182U,	// VREDUCEPSZrrib
    1481319606U,	// VREDUCEPSZrribk
    1212556470U,	// VREDUCEPSZrribkz
    1357587638U,	// VREDUCEPSZrrik
    1088824502U,	// VREDUCEPSZrrikz
    851824401U,	// VREDUCESDZrmi
    963890961U,	// VREDUCESDZrmik
    932450065U,	// VREDUCESDZrmikz
    1088818961U,	// VREDUCESDZrri
    1212550929U,	// VREDUCESDZrrib
    2286866193U,	// VREDUCESDZrribk
    1481314065U,	// VREDUCESDZrribkz
    2163134225U,	// VREDUCESDZrrik
    1357582097U,	// VREDUCESDZrrikz
    856025123U,	// VREDUCESSZrmi
    972285987U,	// VREDUCESSZrmik
    947136547U,	// VREDUCESSZrmikz
    1088825379U,	// VREDUCESSZrri
    1212557347U,	// VREDUCESSZrrib
    2286872611U,	// VREDUCESSZrribk
    1481320483U,	// VREDUCESSZrribkz
    2163140643U,	// VREDUCESSZrrik
    1357588515U,	// VREDUCESSZrrikz
    3032779703U,	// VRNDSCALEPDZ128rmbi
    3079932855U,	// VRNDSCALEPDZ128rmbik
    2999307191U,	// VRNDSCALEPDZ128rmbikz
    77892535U,	// VRNDSCALEPDZ128rmi
    666110903U,	// VRNDSCALEPDZ128rmik
    568708023U,	// VRNDSCALEPDZ128rmikz
    283429815U,	// VRNDSCALEPDZ128rri
    1357581239U,	// VRNDSCALEPDZ128rrik
    1088818103U,	// VRNDSCALEPDZ128rrikz
    1690602423U,	// VRNDSCALEPDZ256rmbi
    1737755575U,	// VRNDSCALEPDZ256rmbik
    1657129911U,	// VRNDSCALEPDZ256rmbikz
    168070071U,	// VRNDSCALEPDZ256rmi
    668208055U,	// VRNDSCALEPDZ256rmik
    660982711U,	// VRNDSCALEPDZ256rmikz
    283429815U,	// VRNDSCALEPDZ256rri
    1357581239U,	// VRNDSCALEPDZ256rrik
    1088818103U,	// VRNDSCALEPDZ256rrikz
    2495908791U,	// VRNDSCALEPDZrmbi
    2543061943U,	// VRNDSCALEPDZrmbik
    2462436279U,	// VRNDSCALEPDZrmbikz
    170167223U,	// VRNDSCALEPDZrmi
    672402359U,	// VRNDSCALEPDZrmik
    669371319U,	// VRNDSCALEPDZrmikz
    283429815U,	// VRNDSCALEPDZrri
    407161783U,	// VRNDSCALEPDZrrib
    1481313207U,	// VRNDSCALEPDZrribk
    1212550071U,	// VRNDSCALEPDZrribkz
    1357581239U,	// VRNDSCALEPDZrrik
    1088818103U,	// VRNDSCALEPDZrrikz
    1692705995U,	// VRNDSCALEPSZ128rmbi
    1752442059U,	// VRNDSCALEPSZ128rmbik
    1661330635U,	// VRNDSCALEPSZ128rmbikz
    77898955U,	// VRNDSCALEPSZ128rmi
    666117323U,	// VRNDSCALEPSZ128rmik
    568714443U,	// VRNDSCALEPSZ128rmikz
    283436235U,	// VRNDSCALEPSZ128rri
    1357587659U,	// VRNDSCALEPSZ128rrik
    1088824523U,	// VRNDSCALEPSZ128rrikz
    2498012363U,	// VRNDSCALEPSZ256rmbi
    2557748427U,	// VRNDSCALEPSZ256rmbik
    2466637003U,	// VRNDSCALEPSZ256rmbikz
    168076491U,	// VRNDSCALEPSZ256rmi
    668214475U,	// VRNDSCALEPSZ256rmik
    660989131U,	// VRNDSCALEPSZ256rmikz
    283436235U,	// VRNDSCALEPSZ256rri
    1357587659U,	// VRNDSCALEPSZ256rrik
    1088824523U,	// VRNDSCALEPSZ256rrikz
    2766447819U,	// VRNDSCALEPSZrmbi
    2826183883U,	// VRNDSCALEPSZrmbik
    2735072459U,	// VRNDSCALEPSZrmbikz
    170173643U,	// VRNDSCALEPSZrmi
    672408779U,	// VRNDSCALEPSZrmik
    669377739U,	// VRNDSCALEPSZrmikz
    283436235U,	// VRNDSCALEPSZrri
    407168203U,	// VRNDSCALEPSZrrib
    1481319627U,	// VRNDSCALEPSZrribk
    1212556491U,	// VRNDSCALEPSZrribkz
    1357587659U,	// VRNDSCALEPSZrrik
    1088824523U,	// VRNDSCALEPSZrrikz
    851824422U,	// VRNDSCALESDZm
    851824422U,	// VRNDSCALESDZm_Int
    963890982U,	// VRNDSCALESDZm_Intk
    932450086U,	// VRNDSCALESDZm_Intkz
    1088818982U,	// VRNDSCALESDZr
    1088818982U,	// VRNDSCALESDZr_Int
    2163134246U,	// VRNDSCALESDZr_Intk
    1357582118U,	// VRNDSCALESDZr_Intkz
    1212550950U,	// VRNDSCALESDZrb_Int
    2286866214U,	// VRNDSCALESDZrb_Intk
    1481314086U,	// VRNDSCALESDZrb_Intkz
    856025144U,	// VRNDSCALESSZm
    856025144U,	// VRNDSCALESSZm_Int
    972286008U,	// VRNDSCALESSZm_Intk
    947136568U,	// VRNDSCALESSZm_Intkz
    1088825400U,	// VRNDSCALESSZr
    1088825400U,	// VRNDSCALESSZr_Int
    2163140664U,	// VRNDSCALESSZr_Intk
    1357588536U,	// VRNDSCALESSZr_Intkz
    1212557368U,	// VRNDSCALESSZrb_Int
    2286872632U,	// VRNDSCALESSZrb_Intk
    1481320504U,	// VRNDSCALESSZrb_Intkz
    168070015U,	// VROUNDPDYm
    283429759U,	// VROUNDPDYr
    77892479U,	// VROUNDPDm
    283429759U,	// VROUNDPDr
    168076435U,	// VROUNDPSYm
    283436179U,	// VROUNDPSYr
    77898899U,	// VROUNDPSm
    283436179U,	// VROUNDPSr
    851824391U,	// VROUNDSDm
    851824391U,	// VROUNDSDm_Int
    1088818951U,	// VROUNDSDr
    1088818951U,	// VROUNDSDr_Int
    856025113U,	// VROUNDSSm
    856025113U,	// VROUNDSSm_Int
    1088825369U,	// VROUNDSSr
    1088825369U,	// VROUNDSSr_Int
    658048U,	// VRSQRT14PDZ128m
    627673728U,	// VRSQRT14PDZ128mb
    628099712U,	// VRSQRT14PDZ128mbk
    627198592U,	// VRSQRT14PDZ128mbkz
    3230599808U,	// VRSQRT14PDZ128mk
    3229747840U,	// VRSQRT14PDZ128mkz
    551832192U,	// VRSQRT14PDZ128r
    3230698112U,	// VRSQRT14PDZ128rk
    3229665920U,	// VRSQRT14PDZ128rkz
    1346176U,	// VRSQRT14PDZ256m
    629770880U,	// VRSQRT14PDZ256mb
    630196864U,	// VRSQRT14PDZ256mbk
    629295744U,	// VRSQRT14PDZ256mbkz
    3230730880U,	// VRSQRT14PDZ256mk
    3230632576U,	// VRSQRT14PDZ256mkz
    551832192U,	// VRSQRT14PDZ256r
    3230698112U,	// VRSQRT14PDZ256rk
    3229665920U,	// VRSQRT14PDZ256rkz
    1510016U,	// VRSQRT14PDZm
    631868032U,	// VRSQRT14PDZmb
    632294016U,	// VRSQRT14PDZmbk
    631392896U,	// VRSQRT14PDZmbkz
    3230780032U,	// VRSQRT14PDZmk
    3230747264U,	// VRSQRT14PDZmkz
    551832192U,	// VRSQRT14PDZr
    3230698112U,	// VRSQRT14PDZrk
    3229665920U,	// VRSQRT14PDZrkz
    664453U,	// VRSQRT14PSZ128m
    629793669U,	// VRSQRT14PSZ128mb
    630399877U,	// VRSQRT14PSZ128mbk
    629318533U,	// VRSQRT14PSZ128mbkz
    3230606213U,	// VRSQRT14PSZ128mk
    3229754245U,	// VRSQRT14PSZ128mkz
    551838597U,	// VRSQRT14PSZ128r
    3230704517U,	// VRSQRT14PSZ128rk
    3229672325U,	// VRSQRT14PSZ128rkz
    1352581U,	// VRSQRT14PSZ256m
    631890821U,	// VRSQRT14PSZ256mb
    632497029U,	// VRSQRT14PSZ256mbk
    631415685U,	// VRSQRT14PSZ256mbkz
    3230737285U,	// VRSQRT14PSZ256mk
    3230638981U,	// VRSQRT14PSZ256mkz
    551838597U,	// VRSQRT14PSZ256r
    3230704517U,	// VRSQRT14PSZ256rk
    3229672325U,	// VRSQRT14PSZ256rkz
    1516421U,	// VRSQRT14PSZm
    633987973U,	// VRSQRT14PSZmb
    634594181U,	// VRSQRT14PSZmbk
    633512837U,	// VRSQRT14PSZmbkz
    3230786437U,	// VRSQRT14PSZmk
    3230753669U,	// VRSQRT14PSZmkz
    551838597U,	// VRSQRT14PSZr
    3230704517U,	// VRSQRT14PSZrk
    3229672325U,	// VRSQRT14PSZrkz
    283266723U,	// VRSQRT14SDZrm
    1357893283U,	// VRSQRT14SDZrmk
    1089474211U,	// VRSQRT14SDZrmkz
    811650723U,	// VRSQRT14SDZrr
    87051939U,	// VRSQRT14SDZrrk
    890277539U,	// VRSQRT14SDZrrkz
    283289510U,	// VRSQRT14SSZrm
    1358096294U,	// VRSQRT14SSZrmk
    1089677222U,	// VRSQRT14SSZrmkz
    811657126U,	// VRSQRT14SSZrr
    87058342U,	// VRSQRT14SSZrrk
    890283942U,	// VRSQRT14SSZrrkz
    1510038U,	// VRSQRT28PDZm
    631868054U,	// VRSQRT28PDZmb
    632294038U,	// VRSQRT28PDZmbk
    631392918U,	// VRSQRT28PDZmbkz
    3230780054U,	// VRSQRT28PDZmk
    3230747286U,	// VRSQRT28PDZmkz
    551832214U,	// VRSQRT28PDZr
    551843301U,	// VRSQRT28PDZrb
    3230709221U,	// VRSQRT28PDZrbk
    3229677029U,	// VRSQRT28PDZrbkz
    3230698134U,	// VRSQRT28PDZrk
    3229665942U,	// VRSQRT28PDZrkz
    1516443U,	// VRSQRT28PSZm
    633987995U,	// VRSQRT28PSZmb
    634594203U,	// VRSQRT28PSZmbk
    633512859U,	// VRSQRT28PSZmbkz
    3230786459U,	// VRSQRT28PSZmk
    3230753691U,	// VRSQRT28PSZmkz
    551838619U,	// VRSQRT28PSZr
    551843788U,	// VRSQRT28PSZrb
    3230709708U,	// VRSQRT28PSZrbk
    3229677516U,	// VRSQRT28PSZrbkz
    3230704539U,	// VRSQRT28PSZrk
    3229672347U,	// VRSQRT28PSZrkz
    283266745U,	// VRSQRT28SDZm
    1357893305U,	// VRSQRT28SDZmk
    1089474233U,	// VRSQRT28SDZmkz
    811650745U,	// VRSQRT28SDZr
    811660875U,	// VRSQRT28SDZrb
    87062091U,	// VRSQRT28SDZrbk
    890287691U,	// VRSQRT28SDZrbkz
    87051961U,	// VRSQRT28SDZrk
    890277561U,	// VRSQRT28SDZrkz
    283289532U,	// VRSQRT28SSZm
    1358096316U,	// VRSQRT28SSZmk
    1089677244U,	// VRSQRT28SSZmkz
    811657148U,	// VRSQRT28SSZr
    811661344U,	// VRSQRT28SSZrb
    87062560U,	// VRSQRT28SSZrbk
    890288160U,	// VRSQRT28SSZrbkz
    87058364U,	// VRSQRT28SSZrk
    890283964U,	// VRSQRT28SSZrkz
    1353303U,	// VRSQRTPSYm
    551839319U,	// VRSQRTPSYr
    665175U,	// VRSQRTPSm
    551839319U,	// VRSQRTPSr
    283289788U,	// VRSQRTSSm
    283289788U,	// VRSQRTSSm_Int
    811657404U,	// VRSQRTSSr
    811657404U,	// VRSQRTSSr_Int
    811731908U,	// VSCALEFPDZ128rm
    358763460U,	// VSCALEFPDZ128rmb
    1433390020U,	// VSCALEFPDZ128rmbk
    1164970948U,	// VSCALEFPDZ128rmbkz
    86985668U,	// VSCALEFPDZ128rmk
    890178500U,	// VSCALEFPDZ128rmkz
    811649988U,	// VSCALEFPDZ128rr
    87051204U,	// VSCALEFPDZ128rrk
    890276804U,	// VSCALEFPDZ128rrkz
    812616644U,	// VSCALEFPDZ256rm
    360860612U,	// VSCALEFPDZ256rmb
    1435487172U,	// VSCALEFPDZ256rmbk
    1167068100U,	// VSCALEFPDZ256rmbkz
    87083972U,	// VSCALEFPDZ256rmk
    890309572U,	// VSCALEFPDZ256rmkz
    811649988U,	// VSCALEFPDZ256rr
    87051204U,	// VSCALEFPDZ256rrk
    890276804U,	// VSCALEFPDZ256rrkz
    812731332U,	// VSCALEFPDZrm
    362957764U,	// VSCALEFPDZrmb
    1437584324U,	// VSCALEFPDZrmbk
    1169165252U,	// VSCALEFPDZrmbkz
    87133124U,	// VSCALEFPDZrmk
    890358724U,	// VSCALEFPDZrmkz
    811649988U,	// VSCALEFPDZrr
    812780484U,	// VSCALEFPDZrrb
    87182276U,	// VSCALEFPDZrrbk
    890407876U,	// VSCALEFPDZrrbkz
    87051204U,	// VSCALEFPDZrrk
    890276804U,	// VSCALEFPDZrrkz
    811738328U,	// VSCALEFPSZ128rm
    360883416U,	// VSCALEFPSZ128rmb
    1435690200U,	// VSCALEFPSZ128rmbk
    1167271128U,	// VSCALEFPSZ128rmbkz
    86992088U,	// VSCALEFPSZ128rmk
    890184920U,	// VSCALEFPSZ128rmkz
    811656408U,	// VSCALEFPSZ128rr
    87057624U,	// VSCALEFPSZ128rrk
    890283224U,	// VSCALEFPSZ128rrkz
    812623064U,	// VSCALEFPSZ256rm
    362980568U,	// VSCALEFPSZ256rmb
    1437787352U,	// VSCALEFPSZ256rmbk
    1169368280U,	// VSCALEFPSZ256rmbkz
    87090392U,	// VSCALEFPSZ256rmk
    890315992U,	// VSCALEFPSZ256rmkz
    811656408U,	// VSCALEFPSZ256rr
    87057624U,	// VSCALEFPSZ256rrk
    890283224U,	// VSCALEFPSZ256rrkz
    812737752U,	// VSCALEFPSZrm
    365077720U,	// VSCALEFPSZrmb
    1439884504U,	// VSCALEFPSZrmbk
    1171465432U,	// VSCALEFPSZrmbkz
    87139544U,	// VSCALEFPSZrmk
    890365144U,	// VSCALEFPSZrmkz
    811656408U,	// VSCALEFPSZrr
    812786904U,	// VSCALEFPSZrrb
    87188696U,	// VSCALEFPSZrrbk
    890414296U,	// VSCALEFPSZrrbkz
    87057624U,	// VSCALEFPSZrrk
    890283224U,	// VSCALEFPSZrrkz
    283266867U,	// VSCALEFSDZrm
    1357893427U,	// VSCALEFSDZrmk
    1089474355U,	// VSCALEFSDZrmkz
    811650867U,	// VSCALEFSDZrr
    812781363U,	// VSCALEFSDZrrb_Int
    87183155U,	// VSCALEFSDZrrb_Intk
    890408755U,	// VSCALEFSDZrrb_Intkz
    87052083U,	// VSCALEFSDZrrk
    890277683U,	// VSCALEFSDZrrkz
    283289669U,	// VSCALEFSSZrm
    1358096453U,	// VSCALEFSSZrmk
    1089677381U,	// VSCALEFSSZrmkz
    811657285U,	// VSCALEFSSZrr
    812787781U,	// VSCALEFSSZrrb_Int
    87189573U,	// VSCALEFSSZrrb_Intk
    890415173U,	// VSCALEFSSZrrb_Intkz
    87058501U,	// VSCALEFSSZrrk
    890284101U,	// VSCALEFSSZrrkz
    3247721365U,	// VSCATTERDPDZ128mr
    3425979285U,	// VSCATTERDPDZ256mr
    3428076437U,	// VSCATTERDPDZmr
    3247727785U,	// VSCATTERDPSZ128mr
    3425985705U,	// VSCATTERDPSZ256mr
    3428082857U,	// VSCATTERDPSZmr
    172854016U,	// VSCATTERPF0DPDm
    172860413U,	// VSCATTERPF0DPSm
    172854401U,	// VSCATTERPF0QPDm
    173368762U,	// VSCATTERPF0QPSm
    172854047U,	// VSCATTERPF1DPDm
    172860444U,	// VSCATTERPF1DPSm
    172854432U,	// VSCATTERPF1QPDm
    173368793U,	// VSCATTERPF1QPSm
    3247721660U,	// VSCATTERQPDZ128mr
    3425979580U,	// VSCATTERQPDZ256mr
    3428076732U,	// VSCATTERQPDZmr
    3251922421U,	// VSCATTERQPSZ128mr
    3247728117U,	// VSCATTERQPSZ256mr
    3425986037U,	// VSCATTERQPSZmr
    2466627977U,	// VSHUFF32X4Z256rmbi
    2582888841U,	// VSHUFF32X4Z256rmbik
    2557739401U,	// VSHUFF32X4Z256rmbikz
    392544649U,	// VSHUFF32X4Z256rmi
    2041823625U,	// VSHUFF32X4Z256rmik
    1205076361U,	// VSHUFF32X4Z256rmikz
    1088815497U,	// VSHUFF32X4Z256rri
    2163130761U,	// VSHUFF32X4Z256rrik
    1357578633U,	// VSHUFF32X4Z256rrikz
    2735063433U,	// VSHUFF32X4Zrmbi
    2851324297U,	// VSHUFF32X4Zrmbik
    2826174857U,	// VSHUFF32X4Zrmbikz
    400933257U,	// VSHUFF32X4Zrmi
    2043920777U,	// VSHUFF32X4Zrmik
    1209270665U,	// VSHUFF32X4Zrmikz
    1088815497U,	// VSHUFF32X4Zrri
    2163130761U,	// VSHUFF32X4Zrrik
    1357578633U,	// VSHUFF32X4Zrrikz
    1657127092U,	// VSHUFF64X2Z256rmbi
    1769193652U,	// VSHUFF64X2Z256rmbik
    1737752756U,	// VSHUFF64X2Z256rmbikz
    392544436U,	// VSHUFF64X2Z256rmi
    2041823412U,	// VSHUFF64X2Z256rmik
    1205076148U,	// VSHUFF64X2Z256rmikz
    1088815284U,	// VSHUFF64X2Z256rri
    2163130548U,	// VSHUFF64X2Z256rrik
    1357578420U,	// VSHUFF64X2Z256rrikz
    2462433460U,	// VSHUFF64X2Zrmbi
    2574500020U,	// VSHUFF64X2Zrmbik
    2543059124U,	// VSHUFF64X2Zrmbikz
    400933044U,	// VSHUFF64X2Zrmi
    2043920564U,	// VSHUFF64X2Zrmik
    1209270452U,	// VSHUFF64X2Zrmikz
    1088815284U,	// VSHUFF64X2Zrri
    2163130548U,	// VSHUFF64X2Zrrik
    1357578420U,	// VSHUFF64X2Zrrikz
    2491793859U,	// VSHUFI32X4Z256rmbi
    2515780035U,	// VSHUFI32X4Z256rmbik
    2517893571U,	// VSHUFI32X4Z256rmbikz
    375767491U,	// VSHUFI32X4Z256rmi
    1989394883U,	// VSHUFI32X4Z256rmik
    1186202051U,	// VSHUFI32X4Z256rmikz
    1088815555U,	// VSHUFI32X4Z256rri
    2163130819U,	// VSHUFI32X4Z256rrik
    1357578691U,	// VSHUFI32X4Z256rrikz
    2760229315U,	// VSHUFI32X4Zrmbi
    2784215491U,	// VSHUFI32X4Zrmbik
    2786329027U,	// VSHUFI32X4Zrmbikz
    382058947U,	// VSHUFI32X4Zrmi
    1995686339U,	// VSHUFI32X4Zrmik
    1192493507U,	// VSHUFI32X4Zrmikz
    1088815555U,	// VSHUFI32X4Zrri
    2163130819U,	// VSHUFI32X4Zrrik
    1357578691U,	// VSHUFI32X4Zrrikz
    1671807214U,	// VSHUFI64X2Z256rmbi
    1731444974U,	// VSHUFI64X2Z256rmbik
    1733558510U,	// VSHUFI64X2Z256rmbikz
    375767278U,	// VSHUFI64X2Z256rmi
    1989394670U,	// VSHUFI64X2Z256rmik
    1186201838U,	// VSHUFI64X2Z256rmikz
    1088815342U,	// VSHUFI64X2Z256rri
    2163130606U,	// VSHUFI64X2Z256rrik
    1357578478U,	// VSHUFI64X2Z256rrikz
    2477113582U,	// VSHUFI64X2Zrmbi
    2536751342U,	// VSHUFI64X2Zrmbik
    2538864878U,	// VSHUFI64X2Zrmbikz
    382058734U,	// VSHUFI64X2Zrmi
    1995686126U,	// VSHUFI64X2Zrmik
    1192493294U,	// VSHUFI64X2Zrmikz
    1088815342U,	// VSHUFI64X2Zrri
    2163130606U,	// VSHUFI64X2Zrrik
    1357578478U,	// VSHUFI64X2Zrrikz
    392547279U,	// VSHUFPDYrmi
    1088818127U,	// VSHUFPDYrri
    2999307215U,	// VSHUFPDZ128rmbi
    3111373775U,	// VSHUFPDZ128rmbik
    3079932879U,	// VSHUFPDZ128rmbikz
    300272591U,	// VSHUFPDZ128rmi
    2039729103U,	// VSHUFPDZ128rmik
    1202981839U,	// VSHUFPDZ128rmikz
    1088818127U,	// VSHUFPDZ128rri
    2163133391U,	// VSHUFPDZ128rrik
    1357581263U,	// VSHUFPDZ128rrikz
    1657129935U,	// VSHUFPDZ256rmbi
    1769196495U,	// VSHUFPDZ256rmbik
    1737755599U,	// VSHUFPDZ256rmbikz
    392547279U,	// VSHUFPDZ256rmi
    2041826255U,	// VSHUFPDZ256rmik
    1205078991U,	// VSHUFPDZ256rmikz
    1088818127U,	// VSHUFPDZ256rri
    2163133391U,	// VSHUFPDZ256rrik
    1357581263U,	// VSHUFPDZ256rrikz
    2462436303U,	// VSHUFPDZrmbi
    2574502863U,	// VSHUFPDZrmbik
    2543061967U,	// VSHUFPDZrmbikz
    400935887U,	// VSHUFPDZrmi
    2043923407U,	// VSHUFPDZrmik
    1209273295U,	// VSHUFPDZrmikz
    1088818127U,	// VSHUFPDZrri
    2163133391U,	// VSHUFPDZrrik
    1357581263U,	// VSHUFPDZrrikz
    300272591U,	// VSHUFPDrmi
    1088818127U,	// VSHUFPDrri
    392553699U,	// VSHUFPSYrmi
    1088824547U,	// VSHUFPSYrri
    1661330659U,	// VSHUFPSZ128rmbi
    1777591523U,	// VSHUFPSZ128rmbik
    1752442083U,	// VSHUFPSZ128rmbikz
    300279011U,	// VSHUFPSZ128rmi
    2039735523U,	// VSHUFPSZ128rmik
    1202988259U,	// VSHUFPSZ128rmikz
    1088824547U,	// VSHUFPSZ128rri
    2163139811U,	// VSHUFPSZ128rrik
    1357587683U,	// VSHUFPSZ128rrikz
    2466637027U,	// VSHUFPSZ256rmbi
    2582897891U,	// VSHUFPSZ256rmbik
    2557748451U,	// VSHUFPSZ256rmbikz
    392553699U,	// VSHUFPSZ256rmi
    2041832675U,	// VSHUFPSZ256rmik
    1205085411U,	// VSHUFPSZ256rmikz
    1088824547U,	// VSHUFPSZ256rri
    2163139811U,	// VSHUFPSZ256rrik
    1357587683U,	// VSHUFPSZ256rrikz
    2735072483U,	// VSHUFPSZrmbi
    2851333347U,	// VSHUFPSZrmbik
    2826183907U,	// VSHUFPSZrmbikz
    400942307U,	// VSHUFPSZrmi
    2043929827U,	// VSHUFPSZrmik
    1209279715U,	// VSHUFPSZrmikz
    1088824547U,	// VSHUFPSZrri
    2163139811U,	// VSHUFPSZrrik
    1357587683U,	// VSHUFPSZrrikz
    300279011U,	// VSHUFPSrmi
    1088824547U,	// VSHUFPSrri
    1346840U,	// VSQRTPDYm
    551832856U,	// VSQRTPDYr
    658712U,	// VSQRTPDZ128m
    627674392U,	// VSQRTPDZ128mb
    628100376U,	// VSQRTPDZ128mbk
    627199256U,	// VSQRTPDZ128mbkz
    3230600472U,	// VSQRTPDZ128mk
    3229748504U,	// VSQRTPDZ128mkz
    551832856U,	// VSQRTPDZ128r
    3230698776U,	// VSQRTPDZ128rk
    3229666584U,	// VSQRTPDZ128rkz
    1346840U,	// VSQRTPDZ256m
    629771544U,	// VSQRTPDZ256mb
    630197528U,	// VSQRTPDZ256mbk
    629296408U,	// VSQRTPDZ256mbkz
    3230731544U,	// VSQRTPDZ256mk
    3230633240U,	// VSQRTPDZ256mkz
    551832856U,	// VSQRTPDZ256r
    3230698776U,	// VSQRTPDZ256rk
    3229666584U,	// VSQRTPDZ256rkz
    1510680U,	// VSQRTPDZm
    631868696U,	// VSQRTPDZmb
    632294680U,	// VSQRTPDZmbk
    631393560U,	// VSQRTPDZmbkz
    3230780696U,	// VSQRTPDZmk
    3230747928U,	// VSQRTPDZmkz
    551832856U,	// VSQRTPDZr
    1494296U,	// VSQRTPDZrb
    3230829848U,	// VSQRTPDZrbk
    3230797080U,	// VSQRTPDZrbkz
    3230698776U,	// VSQRTPDZrk
    3229666584U,	// VSQRTPDZrkz
    658712U,	// VSQRTPDm
    551832856U,	// VSQRTPDr
    1353313U,	// VSQRTPSYm
    551839329U,	// VSQRTPSYr
    665185U,	// VSQRTPSZ128m
    629794401U,	// VSQRTPSZ128mb
    630400609U,	// VSQRTPSZ128mbk
    629319265U,	// VSQRTPSZ128mbkz
    3230606945U,	// VSQRTPSZ128mk
    3229754977U,	// VSQRTPSZ128mkz
    551839329U,	// VSQRTPSZ128r
    3230705249U,	// VSQRTPSZ128rk
    3229673057U,	// VSQRTPSZ128rkz
    1353313U,	// VSQRTPSZ256m
    631891553U,	// VSQRTPSZ256mb
    632497761U,	// VSQRTPSZ256mbk
    631416417U,	// VSQRTPSZ256mbkz
    3230738017U,	// VSQRTPSZ256mk
    3230639713U,	// VSQRTPSZ256mkz
    551839329U,	// VSQRTPSZ256r
    3230705249U,	// VSQRTPSZ256rk
    3229673057U,	// VSQRTPSZ256rkz
    1517153U,	// VSQRTPSZm
    633988705U,	// VSQRTPSZmb
    634594913U,	// VSQRTPSZmbk
    633513569U,	// VSQRTPSZmbkz
    3230787169U,	// VSQRTPSZmk
    3230754401U,	// VSQRTPSZmkz
    551839329U,	// VSQRTPSZr
    1500769U,	// VSQRTPSZrb
    3230836321U,	// VSQRTPSZrbk
    3230803553U,	// VSQRTPSZrbkz
    3230705249U,	// VSQRTPSZrk
    3229673057U,	// VSQRTPSZrkz
    665185U,	// VSQRTPSm
    551839329U,	// VSQRTPSr
    283267036U,	// VSQRTSDZm
    283267036U,	// VSQRTSDZm_Int
    1357893596U,	// VSQRTSDZm_Intk
    1089474524U,	// VSQRTSDZm_Intkz
    811651036U,	// VSQRTSDZr
    811651036U,	// VSQRTSDZr_Int
    87052252U,	// VSQRTSDZr_Intk
    890277852U,	// VSQRTSDZr_Intkz
    812781532U,	// VSQRTSDZrb_Int
    87183324U,	// VSQRTSDZrb_Intk
    890408924U,	// VSQRTSDZrb_Intkz
    283267036U,	// VSQRTSDm
    283267036U,	// VSQRTSDm_Int
    811651036U,	// VSQRTSDr
    811651036U,	// VSQRTSDr_Int
    283289798U,	// VSQRTSSZm
    283289798U,	// VSQRTSSZm_Int
    1358096582U,	// VSQRTSSZm_Intk
    1089677510U,	// VSQRTSSZm_Intkz
    811657414U,	// VSQRTSSZr
    811657414U,	// VSQRTSSZr_Int
    87058630U,	// VSQRTSSZr_Intk
    890284230U,	// VSQRTSSZr_Intkz
    812787910U,	// VSQRTSSZrb_Int
    87189702U,	// VSQRTSSZrb_Intk
    890415302U,	// VSQRTSSZrb_Intkz
    283289798U,	// VSQRTSSm
    283289798U,	// VSQRTSSm_Int
    811657414U,	// VSQRTSSr
    811657414U,	// VSQRTSSr_Int
    237919U,	// VSTMXCSR
    812616425U,	// VSUBPDYrm
    811649769U,	// VSUBPDYrr
    811731689U,	// VSUBPDZ128rm
    358763241U,	// VSUBPDZ128rmb
    1433389801U,	// VSUBPDZ128rmbk
    1164970729U,	// VSUBPDZ128rmbkz
    86985449U,	// VSUBPDZ128rmk
    890178281U,	// VSUBPDZ128rmkz
    811649769U,	// VSUBPDZ128rr
    87050985U,	// VSUBPDZ128rrk
    890276585U,	// VSUBPDZ128rrkz
    812616425U,	// VSUBPDZ256rm
    360860393U,	// VSUBPDZ256rmb
    1435486953U,	// VSUBPDZ256rmbk
    1167067881U,	// VSUBPDZ256rmbkz
    87083753U,	// VSUBPDZ256rmk
    890309353U,	// VSUBPDZ256rmkz
    811649769U,	// VSUBPDZ256rr
    87050985U,	// VSUBPDZ256rrk
    890276585U,	// VSUBPDZ256rrkz
    812731113U,	// VSUBPDZrm
    362957545U,	// VSUBPDZrmb
    1437584105U,	// VSUBPDZrmbk
    1169165033U,	// VSUBPDZrmbkz
    87132905U,	// VSUBPDZrmk
    890358505U,	// VSUBPDZrmkz
    811649769U,	// VSUBPDZrr
    812780265U,	// VSUBPDZrrb
    87182057U,	// VSUBPDZrrbk
    890407657U,	// VSUBPDZrrbkz
    87050985U,	// VSUBPDZrrk
    890276585U,	// VSUBPDZrrkz
    811731689U,	// VSUBPDrm
    811649769U,	// VSUBPDrr
    812622822U,	// VSUBPSYrm
    811656166U,	// VSUBPSYrr
    811738086U,	// VSUBPSZ128rm
    360883174U,	// VSUBPSZ128rmb
    1435689958U,	// VSUBPSZ128rmbk
    1167270886U,	// VSUBPSZ128rmbkz
    86991846U,	// VSUBPSZ128rmk
    890184678U,	// VSUBPSZ128rmkz
    811656166U,	// VSUBPSZ128rr
    87057382U,	// VSUBPSZ128rrk
    890282982U,	// VSUBPSZ128rrkz
    812622822U,	// VSUBPSZ256rm
    362980326U,	// VSUBPSZ256rmb
    1437787110U,	// VSUBPSZ256rmbk
    1169368038U,	// VSUBPSZ256rmbkz
    87090150U,	// VSUBPSZ256rmk
    890315750U,	// VSUBPSZ256rmkz
    811656166U,	// VSUBPSZ256rr
    87057382U,	// VSUBPSZ256rrk
    890282982U,	// VSUBPSZ256rrkz
    812737510U,	// VSUBPSZrm
    365077478U,	// VSUBPSZrmb
    1439884262U,	// VSUBPSZrmbk
    1171465190U,	// VSUBPSZrmbkz
    87139302U,	// VSUBPSZrmk
    890364902U,	// VSUBPSZrmkz
    811656166U,	// VSUBPSZrr
    812786662U,	// VSUBPSZrrb
    87188454U,	// VSUBPSZrrbk
    890414054U,	// VSUBPSZrrbkz
    87057382U,	// VSUBPSZrrk
    890282982U,	// VSUBPSZrrkz
    811738086U,	// VSUBPSrm
    811656166U,	// VSUBPSrr
    283266786U,	// VSUBSDZrm
    283266786U,	// VSUBSDZrm_Int
    1357893346U,	// VSUBSDZrm_Intk
    1089474274U,	// VSUBSDZrm_Intkz
    811650786U,	// VSUBSDZrr
    811650786U,	// VSUBSDZrr_Int
    87052002U,	// VSUBSDZrr_Intk
    890277602U,	// VSUBSDZrr_Intkz
    812781282U,	// VSUBSDZrrb_Int
    87183074U,	// VSUBSDZrrb_Intk
    890408674U,	// VSUBSDZrrb_Intkz
    283266786U,	// VSUBSDrm
    283266786U,	// VSUBSDrm_Int
    811650786U,	// VSUBSDrr
    811650786U,	// VSUBSDrr_Int
    283289565U,	// VSUBSSZrm
    283289565U,	// VSUBSSZrm_Int
    1358096349U,	// VSUBSSZrm_Intk
    1089677277U,	// VSUBSSZrm_Intkz
    811657181U,	// VSUBSSZrr
    811657181U,	// VSUBSSZrr_Int
    87058397U,	// VSUBSSZrr_Intk
    890283997U,	// VSUBSSZrr_Intkz
    812787677U,	// VSUBSSZrrb_Int
    87189469U,	// VSUBSSZrrb_Intk
    890415069U,	// VSUBSSZrrb_Intkz
    283289565U,	// VSUBSSrm
    283289565U,	// VSUBSSrm_Int
    811657181U,	// VSUBSSrr
    811657181U,	// VSUBSSrr_Int
    1346849U,	// VTESTPDYrm
    551832865U,	// VTESTPDYrr
    658721U,	// VTESTPDrm
    551832865U,	// VTESTPDrr
    1353322U,	// VTESTPSYrm
    551839338U,	// VTESTPSYrr
    665194U,	// VTESTPSrm
    551839338U,	// VTESTPSrr
    552177470U,	// VUCOMISDZrm
    552177470U,	// VUCOMISDZrm_Int
    551833406U,	// VUCOMISDZrr
    551833406U,	// VUCOMISDZrr_Int
    551843422U,	// VUCOMISDZrrb
    552177470U,	// VUCOMISDrm
    552177470U,	// VUCOMISDrm_Int
    551833406U,	// VUCOMISDrr
    551833406U,	// VUCOMISDrr_Int
    552200272U,	// VUCOMISSZrm
    552200272U,	// VUCOMISSZrm_Int
    551839824U,	// VUCOMISSZrr
    551839824U,	// VUCOMISSZrr_Int
    551843891U,	// VUCOMISSZrrb
    552200272U,	// VUCOMISSrm
    552200272U,	// VUCOMISSrm_Int
    551839824U,	// VUCOMISSrr
    551839824U,	// VUCOMISSrr_Int
    812616664U,	// VUNPCKHPDYrm
    811650008U,	// VUNPCKHPDYrr
    811731928U,	// VUNPCKHPDZ128rm
    358763480U,	// VUNPCKHPDZ128rmb
    1433390040U,	// VUNPCKHPDZ128rmbk
    1164970968U,	// VUNPCKHPDZ128rmbkz
    86985688U,	// VUNPCKHPDZ128rmk
    890178520U,	// VUNPCKHPDZ128rmkz
    811650008U,	// VUNPCKHPDZ128rr
    87051224U,	// VUNPCKHPDZ128rrk
    890276824U,	// VUNPCKHPDZ128rrkz
    812616664U,	// VUNPCKHPDZ256rm
    360860632U,	// VUNPCKHPDZ256rmb
    1435487192U,	// VUNPCKHPDZ256rmbk
    1167068120U,	// VUNPCKHPDZ256rmbkz
    87083992U,	// VUNPCKHPDZ256rmk
    890309592U,	// VUNPCKHPDZ256rmkz
    811650008U,	// VUNPCKHPDZ256rr
    87051224U,	// VUNPCKHPDZ256rrk
    890276824U,	// VUNPCKHPDZ256rrkz
    812731352U,	// VUNPCKHPDZrm
    362957784U,	// VUNPCKHPDZrmb
    1437584344U,	// VUNPCKHPDZrmbk
    1169165272U,	// VUNPCKHPDZrmbkz
    87133144U,	// VUNPCKHPDZrmk
    890358744U,	// VUNPCKHPDZrmkz
    811650008U,	// VUNPCKHPDZrr
    87051224U,	// VUNPCKHPDZrrk
    890276824U,	// VUNPCKHPDZrrkz
    811731928U,	// VUNPCKHPDrm
    811650008U,	// VUNPCKHPDrr
    812623084U,	// VUNPCKHPSYrm
    811656428U,	// VUNPCKHPSYrr
    811738348U,	// VUNPCKHPSZ128rm
    360883436U,	// VUNPCKHPSZ128rmb
    1435690220U,	// VUNPCKHPSZ128rmbk
    1167271148U,	// VUNPCKHPSZ128rmbkz
    86992108U,	// VUNPCKHPSZ128rmk
    890184940U,	// VUNPCKHPSZ128rmkz
    811656428U,	// VUNPCKHPSZ128rr
    87057644U,	// VUNPCKHPSZ128rrk
    890283244U,	// VUNPCKHPSZ128rrkz
    812623084U,	// VUNPCKHPSZ256rm
    362980588U,	// VUNPCKHPSZ256rmb
    1437787372U,	// VUNPCKHPSZ256rmbk
    1169368300U,	// VUNPCKHPSZ256rmbkz
    87090412U,	// VUNPCKHPSZ256rmk
    890316012U,	// VUNPCKHPSZ256rmkz
    811656428U,	// VUNPCKHPSZ256rr
    87057644U,	// VUNPCKHPSZ256rrk
    890283244U,	// VUNPCKHPSZ256rrkz
    812737772U,	// VUNPCKHPSZrm
    365077740U,	// VUNPCKHPSZrmb
    1439884524U,	// VUNPCKHPSZrmbk
    1171465452U,	// VUNPCKHPSZrmbkz
    87139564U,	// VUNPCKHPSZrmk
    890365164U,	// VUNPCKHPSZrmkz
    811656428U,	// VUNPCKHPSZrr
    87057644U,	// VUNPCKHPSZrrk
    890283244U,	// VUNPCKHPSZrrkz
    811738348U,	// VUNPCKHPSrm
    811656428U,	// VUNPCKHPSrr
    812616706U,	// VUNPCKLPDYrm
    811650050U,	// VUNPCKLPDYrr
    811731970U,	// VUNPCKLPDZ128rm
    358763522U,	// VUNPCKLPDZ128rmb
    1433390082U,	// VUNPCKLPDZ128rmbk
    1164971010U,	// VUNPCKLPDZ128rmbkz
    86985730U,	// VUNPCKLPDZ128rmk
    890178562U,	// VUNPCKLPDZ128rmkz
    811650050U,	// VUNPCKLPDZ128rr
    87051266U,	// VUNPCKLPDZ128rrk
    890276866U,	// VUNPCKLPDZ128rrkz
    812616706U,	// VUNPCKLPDZ256rm
    360860674U,	// VUNPCKLPDZ256rmb
    1435487234U,	// VUNPCKLPDZ256rmbk
    1167068162U,	// VUNPCKLPDZ256rmbkz
    87084034U,	// VUNPCKLPDZ256rmk
    890309634U,	// VUNPCKLPDZ256rmkz
    811650050U,	// VUNPCKLPDZ256rr
    87051266U,	// VUNPCKLPDZ256rrk
    890276866U,	// VUNPCKLPDZ256rrkz
    812731394U,	// VUNPCKLPDZrm
    362957826U,	// VUNPCKLPDZrmb
    1437584386U,	// VUNPCKLPDZrmbk
    1169165314U,	// VUNPCKLPDZrmbkz
    87133186U,	// VUNPCKLPDZrmk
    890358786U,	// VUNPCKLPDZrmkz
    811650050U,	// VUNPCKLPDZrr
    87051266U,	// VUNPCKLPDZrrk
    890276866U,	// VUNPCKLPDZrrkz
    811731970U,	// VUNPCKLPDrm
    811650050U,	// VUNPCKLPDrr
    812623146U,	// VUNPCKLPSYrm
    811656490U,	// VUNPCKLPSYrr
    811738410U,	// VUNPCKLPSZ128rm
    360883498U,	// VUNPCKLPSZ128rmb
    1435690282U,	// VUNPCKLPSZ128rmbk
    1167271210U,	// VUNPCKLPSZ128rmbkz
    86992170U,	// VUNPCKLPSZ128rmk
    890185002U,	// VUNPCKLPSZ128rmkz
    811656490U,	// VUNPCKLPSZ128rr
    87057706U,	// VUNPCKLPSZ128rrk
    890283306U,	// VUNPCKLPSZ128rrkz
    812623146U,	// VUNPCKLPSZ256rm
    362980650U,	// VUNPCKLPSZ256rmb
    1437787434U,	// VUNPCKLPSZ256rmbk
    1169368362U,	// VUNPCKLPSZ256rmbkz
    87090474U,	// VUNPCKLPSZ256rmk
    890316074U,	// VUNPCKLPSZ256rmkz
    811656490U,	// VUNPCKLPSZ256rr
    87057706U,	// VUNPCKLPSZ256rrk
    890283306U,	// VUNPCKLPSZ256rrkz
    812737834U,	// VUNPCKLPSZrm
    365077802U,	// VUNPCKLPSZrmb
    1439884586U,	// VUNPCKLPSZrmbk
    1171465514U,	// VUNPCKLPSZrmbkz
    87139626U,	// VUNPCKLPSZrmk
    890365226U,	// VUNPCKLPSZrmkz
    811656490U,	// VUNPCKLPSZrr
    87057706U,	// VUNPCKLPSZrrk
    890283306U,	// VUNPCKLPSZrrkz
    811738410U,	// VUNPCKLPSrm
    811656490U,	// VUNPCKLPSrr
    812616912U,	// VXORPDYrm
    811650256U,	// VXORPDYrr
    811732176U,	// VXORPDZ128rm
    358763728U,	// VXORPDZ128rmb
    1433390288U,	// VXORPDZ128rmbk
    1164971216U,	// VXORPDZ128rmbkz
    86985936U,	// VXORPDZ128rmk
    890178768U,	// VXORPDZ128rmkz
    811650256U,	// VXORPDZ128rr
    87051472U,	// VXORPDZ128rrk
    890277072U,	// VXORPDZ128rrkz
    812616912U,	// VXORPDZ256rm
    360860880U,	// VXORPDZ256rmb
    1435487440U,	// VXORPDZ256rmbk
    1167068368U,	// VXORPDZ256rmbkz
    87084240U,	// VXORPDZ256rmk
    890309840U,	// VXORPDZ256rmkz
    811650256U,	// VXORPDZ256rr
    87051472U,	// VXORPDZ256rrk
    890277072U,	// VXORPDZ256rrkz
    812731600U,	// VXORPDZrm
    362958032U,	// VXORPDZrmb
    1437584592U,	// VXORPDZrmbk
    1169165520U,	// VXORPDZrmbkz
    87133392U,	// VXORPDZrmk
    890358992U,	// VXORPDZrmkz
    811650256U,	// VXORPDZrr
    87051472U,	// VXORPDZrrk
    890277072U,	// VXORPDZrrkz
    811732176U,	// VXORPDrm
    811650256U,	// VXORPDrr
    812623369U,	// VXORPSYrm
    811656713U,	// VXORPSYrr
    811738633U,	// VXORPSZ128rm
    360883721U,	// VXORPSZ128rmb
    1435690505U,	// VXORPSZ128rmbk
    1167271433U,	// VXORPSZ128rmbkz
    86992393U,	// VXORPSZ128rmk
    890185225U,	// VXORPSZ128rmkz
    811656713U,	// VXORPSZ128rr
    87057929U,	// VXORPSZ128rrk
    890283529U,	// VXORPSZ128rrkz
    812623369U,	// VXORPSZ256rm
    362980873U,	// VXORPSZ256rmb
    1437787657U,	// VXORPSZ256rmbk
    1169368585U,	// VXORPSZ256rmbkz
    87090697U,	// VXORPSZ256rmk
    890316297U,	// VXORPSZ256rmkz
    811656713U,	// VXORPSZ256rr
    87057929U,	// VXORPSZ256rrk
    890283529U,	// VXORPSZ256rrkz
    812738057U,	// VXORPSZrm
    365078025U,	// VXORPSZrmb
    1439884809U,	// VXORPSZrmbk
    1171465737U,	// VXORPSZrmbkz
    87139849U,	// VXORPSZrmk
    890365449U,	// VXORPSZrmkz
    811656713U,	// VXORPSZrr
    87057929U,	// VXORPSZrrk
    890283529U,	// VXORPSZrrkz
    811738633U,	// VXORPSrm
    811656713U,	// VXORPSrr
    15238U,	// VZEROALL
    15496U,	// VZEROUPPER
    15865U,	// WAIT
    14996U,	// WBINVD
    15003U,	// WBNOINVD
    21627U,	// WRFSBASE
    23544U,	// WRFSBASE64
    21649U,	// WRGSBASE
    23566U,	// WRGSBASE64
    15530U,	// WRMSR
    15919U,	// WRPKRUr
    12619671U,	// WRSSD
    18915114U,	// WRSSQ
    12619690U,	// WRUSSD
    18915121U,	// WRUSSQ
    26977U,	// XABORT
    15062U,	// XACQUIRE_PREFIX
    1088711480U,	// XADD16rm
    84978488U,	// XADD16rr
    14963702U,	// XADD32rm
    84972534U,	// XADD32rr
    551836255U,	// XADD64rm
    84974175U,	// XADD64rr
    1357136882U,	// XADD8rm
    84968434U,	// XADD8rr
    464986U,	// XBEGIN_2
    464986U,	// XBEGIN_4
    292063U,	// XCHG16ar
    1088711686U,	// XCHG16rm
    178318342U,	// XCHG16rr
    292123U,	// XCHG32ar
    14963911U,	// XCHG32rm
    178312391U,	// XCHG32rr
    292188U,	// XCHG64ar
    551836740U,	// XCHG64rm
    178314308U,	// XCHG64rr
    1357136955U,	// XCHG8rm
    178308155U,	// XCHG8rr
    21080U,	// XCH_F
    14914U,	// XCRYPTCBC
    14878U,	// XCRYPTCFB
    15536U,	// XCRYPTCTR
    14868U,	// XCRYPTECB
    14888U,	// XCRYPTOFB
    14977U,	// XEND
    15926U,	// XGETBV
    14898U,	// XLAT
    2125212U,	// XOR16i16
    4238748U,	// XOR16mi
    4238748U,	// XOR16mi8
    4238748U,	// XOR16mr
    6352284U,	// XOR16ri
    6352284U,	// XOR16ri8
    6368668U,	// XOR16rm
    6352284U,	// XOR16rr
    8449436U,	// XOR16rr_REV
    10507871U,	// XOR32i32
    12621407U,	// XOR32mi
    12621407U,	// XOR32mi8
    12621407U,	// XOR32mr
    6346335U,	// XOR32ri
    6346335U,	// XOR32ri8
    283203167U,	// XOR32rm
    6346335U,	// XOR32rr
    8443487U,	// XOR32rr_REV
    16801390U,	// XOR64i32
    18914926U,	// XOR64mi32
    18914926U,	// XOR64mi8
    18914926U,	// XOR64mr
    6348398U,	// XOR64ri32
    6348398U,	// XOR64ri8
    283221614U,	// XOR64rm
    6348398U,	// XOR64rr
    8445550U,	// XOR64rr_REV
    20989303U,	// XOR8i8
    23102839U,	// XOR8mi
    23102839U,	// XOR8mi8
    23102839U,	// XOR8mr
    6342007U,	// XOR8ri
    6342007U,	// XOR8ri8
    6407543U,	// XOR8rm
    6342007U,	// XOR8rr
    8439159U,	// XOR8rr_REV
    8522961U,	// XORPDrm
    8441041U,	// XORPDrr
    8529418U,	// XORPSrm
    8447498U,	// XORPSrr
    15078U,	// XRELEASE_PREFIX
    680256U,	// XRSTOR
    672072U,	// XRSTOR64
    681685U,	// XRSTORS
    672092U,	// XRSTORS64
    676397U,	// XSAVE
    672062U,	// XSAVE64
    673547U,	// XSAVEC
    672051U,	// XSAVEC64
    682308U,	// XSAVEOPT
    672103U,	// XSAVEOPT64
    680381U,	// XSAVES
    672082U,	// XSAVES64
    15933U,	// XSETBV
    14704U,	// XSHA1
    14797U,	// XSHA256
    15071U,	// XSTORE
    15895U,	// XTEST
  };

  static const uint16_t OpInfo1[] = {
    0U,	// PHI
    0U,	// INLINEASM
    0U,	// CFI_INSTRUCTION
    0U,	// EH_LABEL
    0U,	// GC_LABEL
    0U,	// ANNOTATION_LABEL
    0U,	// KILL
    0U,	// EXTRACT_SUBREG
    0U,	// INSERT_SUBREG
    0U,	// IMPLICIT_DEF
    0U,	// SUBREG_TO_REG
    0U,	// COPY_TO_REGCLASS
    0U,	// DBG_VALUE
    0U,	// DBG_LABEL
    0U,	// REG_SEQUENCE
    0U,	// COPY
    0U,	// BUNDLE
    0U,	// LIFETIME_START
    0U,	// LIFETIME_END
    0U,	// STACKMAP
    0U,	// FENTRY_CALL
    0U,	// PATCHPOINT
    0U,	// LOAD_STACK_GUARD
    0U,	// STATEPOINT
    0U,	// LOCAL_ESCAPE
    0U,	// FAULTING_OP
    0U,	// PATCHABLE_OP
    0U,	// PATCHABLE_FUNCTION_ENTER
    0U,	// PATCHABLE_RET
    0U,	// PATCHABLE_FUNCTION_EXIT
    0U,	// PATCHABLE_TAIL_CALL
    0U,	// PATCHABLE_EVENT_CALL
    0U,	// PATCHABLE_TYPED_EVENT_CALL
    0U,	// ICALL_BRANCH_FUNNEL
    0U,	// G_ADD
    0U,	// G_SUB
    0U,	// G_MUL
    0U,	// G_SDIV
    0U,	// G_UDIV
    0U,	// G_SREM
    0U,	// G_UREM
    0U,	// G_AND
    0U,	// G_OR
    0U,	// G_XOR
    0U,	// G_IMPLICIT_DEF
    0U,	// G_PHI
    0U,	// G_FRAME_INDEX
    0U,	// G_GLOBAL_VALUE
    0U,	// G_EXTRACT
    0U,	// G_UNMERGE_VALUES
    0U,	// G_INSERT
    0U,	// G_MERGE_VALUES
    0U,	// G_PTRTOINT
    0U,	// G_INTTOPTR
    0U,	// G_BITCAST
    0U,	// G_LOAD
    0U,	// G_SEXTLOAD
    0U,	// G_ZEXTLOAD
    0U,	// G_STORE
    0U,	// G_ATOMIC_CMPXCHG_WITH_SUCCESS
    0U,	// G_ATOMIC_CMPXCHG
    0U,	// G_ATOMICRMW_XCHG
    0U,	// G_ATOMICRMW_ADD
    0U,	// G_ATOMICRMW_SUB
    0U,	// G_ATOMICRMW_AND
    0U,	// G_ATOMICRMW_NAND
    0U,	// G_ATOMICRMW_OR
    0U,	// G_ATOMICRMW_XOR
    0U,	// G_ATOMICRMW_MAX
    0U,	// G_ATOMICRMW_MIN
    0U,	// G_ATOMICRMW_UMAX
    0U,	// G_ATOMICRMW_UMIN
    0U,	// G_BRCOND
    0U,	// G_BRINDIRECT
    0U,	// G_INTRINSIC
    0U,	// G_INTRINSIC_W_SIDE_EFFECTS
    0U,	// G_ANYEXT
    0U,	// G_TRUNC
    0U,	// G_CONSTANT
    0U,	// G_FCONSTANT
    0U,	// G_VASTART
    0U,	// G_VAARG
    0U,	// G_SEXT
    0U,	// G_ZEXT
    0U,	// G_SHL
    0U,	// G_LSHR
    0U,	// G_ASHR
    0U,	// G_ICMP
    0U,	// G_FCMP
    0U,	// G_SELECT
    0U,	// G_UADDE
    0U,	// G_USUBE
    0U,	// G_SADDO
    0U,	// G_SSUBO
    0U,	// G_UMULO
    0U,	// G_SMULO
    0U,	// G_UMULH
    0U,	// G_SMULH
    0U,	// G_FADD
    0U,	// G_FSUB
    0U,	// G_FMUL
    0U,	// G_FMA
    0U,	// G_FDIV
    0U,	// G_FREM
    0U,	// G_FPOW
    0U,	// G_FEXP
    0U,	// G_FEXP2
    0U,	// G_FLOG
    0U,	// G_FLOG2
    0U,	// G_FNEG
    0U,	// G_FPEXT
    0U,	// G_FPTRUNC
    0U,	// G_FPTOSI
    0U,	// G_FPTOUI
    0U,	// G_SITOFP
    0U,	// G_UITOFP
    0U,	// G_FABS
    0U,	// G_GEP
    0U,	// G_PTR_MASK
    0U,	// G_BR
    0U,	// G_INSERT_VECTOR_ELT
    0U,	// G_EXTRACT_VECTOR_ELT
    0U,	// G_SHUFFLE_VECTOR
    0U,	// G_BSWAP
    0U,	// G_ADDRSPACE_CAST
    0U,	// G_BLOCK_ADDR
    0U,	// AVX1_SETALLONES
    0U,	// AVX2_SETALLONES
    0U,	// AVX512_128_SET0
    0U,	// AVX512_256_SET0
    0U,	// AVX512_512_SET0
    0U,	// AVX512_512_SETALLONES
    0U,	// AVX512_512_SEXT_MASK_32
    0U,	// AVX512_512_SEXT_MASK_64
    0U,	// AVX512_FsFLD0SD
    0U,	// AVX512_FsFLD0SS
    0U,	// AVX_SET0
    0U,	// KSET0D
    0U,	// KSET0Q
    0U,	// KSET0W
    0U,	// KSET1D
    0U,	// KSET1Q
    0U,	// KSET1W
    0U,	// MMX_SET0
    0U,	// V_SET0
    0U,	// V_SETALLONES
    0U,	// AAA
    0U,	// AAD8i8
    0U,	// AAM8i8
    0U,	// AAS
    0U,	// ABS_F
    0U,	// ABS_Fp32
    0U,	// ABS_Fp64
    0U,	// ABS_Fp80
    0U,	// ADC16i16
    0U,	// ADC16mi
    0U,	// ADC16mi8
    0U,	// ADC16mr
    0U,	// ADC16ri
    0U,	// ADC16ri8
    0U,	// ADC16rm
    0U,	// ADC16rr
    0U,	// ADC16rr_REV
    0U,	// ADC32i32
    0U,	// ADC32mi
    0U,	// ADC32mi8
    0U,	// ADC32mr
    0U,	// ADC32ri
    0U,	// ADC32ri8
    0U,	// ADC32rm
    0U,	// ADC32rr
    0U,	// ADC32rr_REV
    0U,	// ADC64i32
    0U,	// ADC64mi32
    0U,	// ADC64mi8
    0U,	// ADC64mr
    0U,	// ADC64ri32
    0U,	// ADC64ri8
    0U,	// ADC64rm
    0U,	// ADC64rr
    0U,	// ADC64rr_REV
    0U,	// ADC8i8
    0U,	// ADC8mi
    0U,	// ADC8mi8
    0U,	// ADC8mr
    0U,	// ADC8ri
    0U,	// ADC8ri8
    0U,	// ADC8rm
    0U,	// ADC8rr
    0U,	// ADC8rr_REV
    0U,	// ADCX32rm
    0U,	// ADCX32rr
    0U,	// ADCX64rm
    0U,	// ADCX64rr
    0U,	// ADD16i16
    0U,	// ADD16mi
    0U,	// ADD16mi8
    0U,	// ADD16mr
    0U,	// ADD16ri
    0U,	// ADD16ri8
    0U,	// ADD16rm
    0U,	// ADD16rr
    0U,	// ADD16rr_REV
    0U,	// ADD32i32
    0U,	// ADD32mi
    0U,	// ADD32mi8
    0U,	// ADD32mr
    0U,	// ADD32ri
    0U,	// ADD32ri8
    0U,	// ADD32rm
    0U,	// ADD32rr
    0U,	// ADD32rr_REV
    0U,	// ADD64i32
    0U,	// ADD64mi32
    0U,	// ADD64mi8
    0U,	// ADD64mr
    0U,	// ADD64ri32
    0U,	// ADD64ri8
    0U,	// ADD64rm
    0U,	// ADD64rr
    0U,	// ADD64rr_REV
    0U,	// ADD8i8
    0U,	// ADD8mi
    0U,	// ADD8mi8
    0U,	// ADD8mr
    0U,	// ADD8ri
    0U,	// ADD8ri8
    0U,	// ADD8rm
    0U,	// ADD8rr
    0U,	// ADD8rr_REV
    0U,	// ADDPDrm
    0U,	// ADDPDrr
    0U,	// ADDPSrm
    0U,	// ADDPSrr
    0U,	// ADDSDrm
    0U,	// ADDSDrm_Int
    0U,	// ADDSDrr
    0U,	// ADDSDrr_Int
    0U,	// ADDSSrm
    0U,	// ADDSSrm_Int
    0U,	// ADDSSrr
    0U,	// ADDSSrr_Int
    0U,	// ADDSUBPDrm
    0U,	// ADDSUBPDrr
    0U,	// ADDSUBPSrm
    0U,	// ADDSUBPSrr
    0U,	// ADD_F32m
    0U,	// ADD_F64m
    0U,	// ADD_FI16m
    0U,	// ADD_FI32m
    0U,	// ADD_FPrST0
    0U,	// ADD_FST0r
    0U,	// ADD_Fp32
    0U,	// ADD_Fp32m
    0U,	// ADD_Fp64
    0U,	// ADD_Fp64m
    0U,	// ADD_Fp64m32
    0U,	// ADD_Fp80
    0U,	// ADD_Fp80m32
    0U,	// ADD_Fp80m64
    0U,	// ADD_FpI16m32
    0U,	// ADD_FpI16m64
    0U,	// ADD_FpI16m80
    0U,	// ADD_FpI32m32
    0U,	// ADD_FpI32m64
    0U,	// ADD_FpI32m80
    0U,	// ADD_FrST0
    0U,	// ADOX32rm
    0U,	// ADOX32rr
    0U,	// ADOX64rm
    0U,	// ADOX64rr
    0U,	// AESDECLASTrm
    0U,	// AESDECLASTrr
    0U,	// AESDECrm
    0U,	// AESDECrr
    0U,	// AESENCLASTrm
    0U,	// AESENCLASTrr
    0U,	// AESENCrm
    0U,	// AESENCrr
    0U,	// AESIMCrm
    0U,	// AESIMCrr
    4U,	// AESKEYGENASSIST128rm
    72U,	// AESKEYGENASSIST128rr
    0U,	// AND16i16
    0U,	// AND16mi
    0U,	// AND16mi8
    0U,	// AND16mr
    0U,	// AND16ri
    0U,	// AND16ri8
    0U,	// AND16rm
    0U,	// AND16rr
    0U,	// AND16rr_REV
    0U,	// AND32i32
    0U,	// AND32mi
    0U,	// AND32mi8
    0U,	// AND32mr
    0U,	// AND32ri
    0U,	// AND32ri8
    0U,	// AND32rm
    0U,	// AND32rr
    0U,	// AND32rr_REV
    0U,	// AND64i32
    0U,	// AND64mi32
    0U,	// AND64mi8
    0U,	// AND64mr
    0U,	// AND64ri32
    0U,	// AND64ri8
    0U,	// AND64rm
    0U,	// AND64rr
    0U,	// AND64rr_REV
    0U,	// AND8i8
    0U,	// AND8mi
    0U,	// AND8mi8
    0U,	// AND8mr
    0U,	// AND8ri
    0U,	// AND8ri8
    0U,	// AND8rm
    0U,	// AND8rr
    0U,	// AND8rr_REV
    72U,	// ANDN32rm
    4U,	// ANDN32rr
    72U,	// ANDN64rm
    4U,	// ANDN64rr
    0U,	// ANDNPDrm
    0U,	// ANDNPDrr
    0U,	// ANDNPSrm
    0U,	// ANDNPSrr
    0U,	// ANDPDrm
    0U,	// ANDPDrr
    0U,	// ANDPSrm
    0U,	// ANDPSrr
    0U,	// ARPL16mr
    0U,	// ARPL16rr
    4U,	// BEXTR32rm
    4U,	// BEXTR32rr
    4U,	// BEXTR64rm
    4U,	// BEXTR64rr
    4U,	// BEXTRI32mi
    4U,	// BEXTRI32ri
    4U,	// BEXTRI64mi
    4U,	// BEXTRI64ri
    0U,	// BLCFILL32rm
    0U,	// BLCFILL32rr
    0U,	// BLCFILL64rm
    0U,	// BLCFILL64rr
    0U,	// BLCI32rm
    0U,	// BLCI32rr
    0U,	// BLCI64rm
    0U,	// BLCI64rr
    0U,	// BLCIC32rm
    0U,	// BLCIC32rr
    0U,	// BLCIC64rm
    0U,	// BLCIC64rr
    0U,	// BLCMSK32rm
    0U,	// BLCMSK32rr
    0U,	// BLCMSK64rm
    0U,	// BLCMSK64rr
    0U,	// BLCS32rm
    0U,	// BLCS32rr
    0U,	// BLCS64rm
    0U,	// BLCS64rr
    0U,	// BLENDPDrmi
    4U,	// BLENDPDrri
    0U,	// BLENDPSrmi
    4U,	// BLENDPSrri
    0U,	// BLENDVPDrm0
    0U,	// BLENDVPDrr0
    0U,	// BLENDVPSrm0
    0U,	// BLENDVPSrr0
    0U,	// BLSFILL32rm
    0U,	// BLSFILL32rr
    0U,	// BLSFILL64rm
    0U,	// BLSFILL64rr
    0U,	// BLSI32rm
    0U,	// BLSI32rr
    0U,	// BLSI64rm
    0U,	// BLSI64rr
    0U,	// BLSIC32rm
    0U,	// BLSIC32rr
    0U,	// BLSIC64rm
    0U,	// BLSIC64rr
    0U,	// BLSMSK32rm
    0U,	// BLSMSK32rr
    0U,	// BLSMSK64rm
    0U,	// BLSMSK64rr
    0U,	// BLSR32rm
    0U,	// BLSR32rr
    0U,	// BLSR64rm
    0U,	// BLSR64rr
    0U,	// BNDCL32rm
    0U,	// BNDCL32rr
    0U,	// BNDCL64rm
    0U,	// BNDCL64rr
    0U,	// BNDCN32rm
    0U,	// BNDCN32rr
    0U,	// BNDCN64rm
    0U,	// BNDCN64rr
    0U,	// BNDCU32rm
    0U,	// BNDCU32rr
    0U,	// BNDCU64rm
    0U,	// BNDCU64rr
    0U,	// BNDLDXrm
    0U,	// BNDMK32rm
    0U,	// BNDMK64rm
    0U,	// BNDMOV32mr
    0U,	// BNDMOV32rm
    0U,	// BNDMOV64mr
    0U,	// BNDMOV64rm
    0U,	// BNDMOVrr
    0U,	// BNDMOVrr_REV
    0U,	// BNDSTXmr
    0U,	// BOUNDS16rm
    0U,	// BOUNDS32rm
    0U,	// BSF16rm
    0U,	// BSF16rr
    0U,	// BSF32rm
    0U,	// BSF32rr
    0U,	// BSF64rm
    0U,	// BSF64rr
    0U,	// BSR16rm
    0U,	// BSR16rr
    0U,	// BSR32rm
    0U,	// BSR32rr
    0U,	// BSR64rm
    0U,	// BSR64rr
    0U,	// BSWAP16r_BAD
    0U,	// BSWAP32r
    0U,	// BSWAP64r
    0U,	// BT16mi8
    0U,	// BT16mr
    0U,	// BT16ri8
    0U,	// BT16rr
    0U,	// BT32mi8
    0U,	// BT32mr
    0U,	// BT32ri8
    0U,	// BT32rr
    0U,	// BT64mi8
    0U,	// BT64mr
    0U,	// BT64ri8
    0U,	// BT64rr
    0U,	// BTC16mi8
    0U,	// BTC16mr
    0U,	// BTC16ri8
    0U,	// BTC16rr
    0U,	// BTC32mi8
    0U,	// BTC32mr
    0U,	// BTC32ri8
    0U,	// BTC32rr
    0U,	// BTC64mi8
    0U,	// BTC64mr
    0U,	// BTC64ri8
    0U,	// BTC64rr
    0U,	// BTR16mi8
    0U,	// BTR16mr
    0U,	// BTR16ri8
    0U,	// BTR16rr
    0U,	// BTR32mi8
    0U,	// BTR32mr
    0U,	// BTR32ri8
    0U,	// BTR32rr
    0U,	// BTR64mi8
    0U,	// BTR64mr
    0U,	// BTR64ri8
    0U,	// BTR64rr
    0U,	// BTS16mi8
    0U,	// BTS16mr
    0U,	// BTS16ri8
    0U,	// BTS16rr
    0U,	// BTS32mi8
    0U,	// BTS32mr
    0U,	// BTS32ri8
    0U,	// BTS32rr
    0U,	// BTS64mi8
    0U,	// BTS64mr
    0U,	// BTS64ri8
    0U,	// BTS64rr
    4U,	// BZHI32rm
    4U,	// BZHI32rr
    4U,	// BZHI64rm
    4U,	// BZHI64rr
    0U,	// CALL16m
    0U,	// CALL16m_NT
    0U,	// CALL16r
    0U,	// CALL16r_NT
    0U,	// CALL32m
    0U,	// CALL32m_NT
    0U,	// CALL32r
    0U,	// CALL32r_NT
    0U,	// CALL64m
    0U,	// CALL64m_NT
    0U,	// CALL64pcrel32
    0U,	// CALL64r
    0U,	// CALL64r_NT
    0U,	// CALLpcrel16
    0U,	// CALLpcrel32
    0U,	// CBW
    0U,	// CDQ
    0U,	// CDQE
    0U,	// CHS_F
    0U,	// CHS_Fp32
    0U,	// CHS_Fp64
    0U,	// CHS_Fp80
    0U,	// CLAC
    0U,	// CLC
    0U,	// CLD
    0U,	// CLDEMOTE
    0U,	// CLFLUSH
    0U,	// CLFLUSHOPT
    0U,	// CLGI
    0U,	// CLI
    0U,	// CLRSSBSY
    0U,	// CLTS
    0U,	// CLWB
    0U,	// CLZEROr
    0U,	// CMC
    0U,	// CMOVA16rm
    0U,	// CMOVA16rr
    0U,	// CMOVA32rm
    0U,	// CMOVA32rr
    0U,	// CMOVA64rm
    0U,	// CMOVA64rr
    0U,	// CMOVAE16rm
    0U,	// CMOVAE16rr
    0U,	// CMOVAE32rm
    0U,	// CMOVAE32rr
    0U,	// CMOVAE64rm
    0U,	// CMOVAE64rr
    0U,	// CMOVB16rm
    0U,	// CMOVB16rr
    0U,	// CMOVB32rm
    0U,	// CMOVB32rr
    0U,	// CMOVB64rm
    0U,	// CMOVB64rr
    0U,	// CMOVBE16rm
    0U,	// CMOVBE16rr
    0U,	// CMOVBE32rm
    0U,	// CMOVBE32rr
    0U,	// CMOVBE64rm
    0U,	// CMOVBE64rr
    0U,	// CMOVBE_F
    0U,	// CMOVBE_Fp32
    0U,	// CMOVBE_Fp64
    0U,	// CMOVBE_Fp80
    0U,	// CMOVB_F
    0U,	// CMOVB_Fp32
    0U,	// CMOVB_Fp64
    0U,	// CMOVB_Fp80
    0U,	// CMOVE16rm
    0U,	// CMOVE16rr
    0U,	// CMOVE32rm
    0U,	// CMOVE32rr
    0U,	// CMOVE64rm
    0U,	// CMOVE64rr
    0U,	// CMOVE_F
    0U,	// CMOVE_Fp32
    0U,	// CMOVE_Fp64
    0U,	// CMOVE_Fp80
    0U,	// CMOVG16rm
    0U,	// CMOVG16rr
    0U,	// CMOVG32rm
    0U,	// CMOVG32rr
    0U,	// CMOVG64rm
    0U,	// CMOVG64rr
    0U,	// CMOVGE16rm
    0U,	// CMOVGE16rr
    0U,	// CMOVGE32rm
    0U,	// CMOVGE32rr
    0U,	// CMOVGE64rm
    0U,	// CMOVGE64rr
    0U,	// CMOVL16rm
    0U,	// CMOVL16rr
    0U,	// CMOVL32rm
    0U,	// CMOVL32rr
    0U,	// CMOVL64rm
    0U,	// CMOVL64rr
    0U,	// CMOVLE16rm
    0U,	// CMOVLE16rr
    0U,	// CMOVLE32rm
    0U,	// CMOVLE32rr
    0U,	// CMOVLE64rm
    0U,	// CMOVLE64rr
    0U,	// CMOVNBE_F
    0U,	// CMOVNBE_Fp32
    0U,	// CMOVNBE_Fp64
    0U,	// CMOVNBE_Fp80
    0U,	// CMOVNB_F
    0U,	// CMOVNB_Fp32
    0U,	// CMOVNB_Fp64
    0U,	// CMOVNB_Fp80
    0U,	// CMOVNE16rm
    0U,	// CMOVNE16rr
    0U,	// CMOVNE32rm
    0U,	// CMOVNE32rr
    0U,	// CMOVNE64rm
    0U,	// CMOVNE64rr
    0U,	// CMOVNE_F
    0U,	// CMOVNE_Fp32
    0U,	// CMOVNE_Fp64
    0U,	// CMOVNE_Fp80
    0U,	// CMOVNO16rm
    0U,	// CMOVNO16rr
    0U,	// CMOVNO32rm
    0U,	// CMOVNO32rr
    0U,	// CMOVNO64rm
    0U,	// CMOVNO64rr
    0U,	// CMOVNP16rm
    0U,	// CMOVNP16rr
    0U,	// CMOVNP32rm
    0U,	// CMOVNP32rr
    0U,	// CMOVNP64rm
    0U,	// CMOVNP64rr
    0U,	// CMOVNP_F
    0U,	// CMOVNP_Fp32
    0U,	// CMOVNP_Fp64
    0U,	// CMOVNP_Fp80
    0U,	// CMOVNS16rm
    0U,	// CMOVNS16rr
    0U,	// CMOVNS32rm
    0U,	// CMOVNS32rr
    0U,	// CMOVNS64rm
    0U,	// CMOVNS64rr
    0U,	// CMOVO16rm
    0U,	// CMOVO16rr
    0U,	// CMOVO32rm
    0U,	// CMOVO32rr
    0U,	// CMOVO64rm
    0U,	// CMOVO64rr
    0U,	// CMOVP16rm
    0U,	// CMOVP16rr
    0U,	// CMOVP32rm
    0U,	// CMOVP32rr
    0U,	// CMOVP64rm
    0U,	// CMOVP64rr
    0U,	// CMOVP_F
    0U,	// CMOVP_Fp32
    0U,	// CMOVP_Fp64
    0U,	// CMOVP_Fp80
    0U,	// CMOVS16rm
    0U,	// CMOVS16rr
    0U,	// CMOVS32rm
    0U,	// CMOVS32rr
    0U,	// CMOVS64rm
    0U,	// CMOVS64rr
    0U,	// CMP16i16
    0U,	// CMP16mi
    0U,	// CMP16mi8
    0U,	// CMP16mr
    0U,	// CMP16ri
    0U,	// CMP16ri8
    0U,	// CMP16rm
    0U,	// CMP16rr
    0U,	// CMP16rr_REV
    0U,	// CMP32i32
    0U,	// CMP32mi
    0U,	// CMP32mi8
    0U,	// CMP32mr
    0U,	// CMP32ri
    0U,	// CMP32ri8
    0U,	// CMP32rm
    0U,	// CMP32rr
    0U,	// CMP32rr_REV
    0U,	// CMP64i32
    0U,	// CMP64mi32
    0U,	// CMP64mi8
    0U,	// CMP64mr
    0U,	// CMP64ri32
    0U,	// CMP64ri8
    0U,	// CMP64rm
    0U,	// CMP64rr
    0U,	// CMP64rr_REV
    0U,	// CMP8i8
    0U,	// CMP8mi
    0U,	// CMP8mi8
    0U,	// CMP8mr
    0U,	// CMP8ri
    0U,	// CMP8ri8
    0U,	// CMP8rm
    0U,	// CMP8rr
    0U,	// CMP8rr_REV
    4U,	// CMPPDrmi
    0U,	// CMPPDrmi_alt
    4U,	// CMPPDrri
    4U,	// CMPPDrri_alt
    4U,	// CMPPSrmi
    0U,	// CMPPSrmi_alt
    4U,	// CMPPSrri
    4U,	// CMPPSrri_alt
    0U,	// CMPSB
    72U,	// CMPSDrm
    72U,	// CMPSDrm_Int
    4U,	// CMPSDrm_alt
    4U,	// CMPSDrr
    4U,	// CMPSDrr_Int
    4U,	// CMPSDrr_alt
    0U,	// CMPSL
    0U,	// CMPSQ
    72U,	// CMPSSrm
    72U,	// CMPSSrm_Int
    4U,	// CMPSSrm_alt
    4U,	// CMPSSrr
    4U,	// CMPSSrr_Int
    4U,	// CMPSSrr_alt
    0U,	// CMPSW
    0U,	// CMPXCHG16B
    0U,	// CMPXCHG16rm
    0U,	// CMPXCHG16rr
    0U,	// CMPXCHG32rm
    0U,	// CMPXCHG32rr
    0U,	// CMPXCHG64rm
    0U,	// CMPXCHG64rr
    0U,	// CMPXCHG8B
    0U,	// CMPXCHG8rm
    0U,	// CMPXCHG8rr
    0U,	// COMISDrm
    0U,	// COMISDrm_Int
    0U,	// COMISDrr
    0U,	// COMISDrr_Int
    0U,	// COMISSrm
    0U,	// COMISSrm_Int
    0U,	// COMISSrr
    0U,	// COMISSrr_Int
    0U,	// COMP_FST0r
    0U,	// COM_FIPr
    0U,	// COM_FIr
    0U,	// COM_FST0r
    0U,	// COS_F
    0U,	// COS_Fp32
    0U,	// COS_Fp64
    0U,	// COS_Fp80
    0U,	// CPUID
    0U,	// CQO
    0U,	// CRC32r32m16
    0U,	// CRC32r32m32
    0U,	// CRC32r32m8
    0U,	// CRC32r32r16
    0U,	// CRC32r32r32
    0U,	// CRC32r32r8
    0U,	// CRC32r64m64
    0U,	// CRC32r64m8
    0U,	// CRC32r64r64
    0U,	// CRC32r64r8
    0U,	// CVTDQ2PDrm
    0U,	// CVTDQ2PDrr
    0U,	// CVTDQ2PSrm
    0U,	// CVTDQ2PSrr
    0U,	// CVTPD2DQrm
    0U,	// CVTPD2DQrr
    0U,	// CVTPD2PSrm
    0U,	// CVTPD2PSrr
    0U,	// CVTPS2DQrm
    0U,	// CVTPS2DQrr
    0U,	// CVTPS2PDrm
    0U,	// CVTPS2PDrr
    0U,	// CVTSD2SI64rm_Int
    0U,	// CVTSD2SI64rr_Int
    0U,	// CVTSD2SIrm_Int
    0U,	// CVTSD2SIrr_Int
    0U,	// CVTSD2SSrm
    0U,	// CVTSD2SSrm_Int
    0U,	// CVTSD2SSrr
    0U,	// CVTSD2SSrr_Int
    0U,	// CVTSI2SDrm
    0U,	// CVTSI2SDrm_Int
    0U,	// CVTSI2SDrr
    0U,	// CVTSI2SDrr_Int
    0U,	// CVTSI2SSrm
    0U,	// CVTSI2SSrm_Int
    0U,	// CVTSI2SSrr
    0U,	// CVTSI2SSrr_Int
    0U,	// CVTSI642SDrm
    0U,	// CVTSI642SDrm_Int
    0U,	// CVTSI642SDrr
    0U,	// CVTSI642SDrr_Int
    0U,	// CVTSI642SSrm
    0U,	// CVTSI642SSrm_Int
    0U,	// CVTSI642SSrr
    0U,	// CVTSI642SSrr_Int
    0U,	// CVTSS2SDrm
    0U,	// CVTSS2SDrm_Int
    0U,	// CVTSS2SDrr
    0U,	// CVTSS2SDrr_Int
    0U,	// CVTSS2SI64rm_Int
    0U,	// CVTSS2SI64rr_Int
    0U,	// CVTSS2SIrm_Int
    0U,	// CVTSS2SIrr_Int
    0U,	// CVTTPD2DQrm
    0U,	// CVTTPD2DQrr
    0U,	// CVTTPS2DQrm
    0U,	// CVTTPS2DQrr
    0U,	// CVTTSD2SI64rm
    0U,	// CVTTSD2SI64rm_Int
    0U,	// CVTTSD2SI64rr
    0U,	// CVTTSD2SI64rr_Int
    0U,	// CVTTSD2SIrm
    0U,	// CVTTSD2SIrm_Int
    0U,	// CVTTSD2SIrr
    0U,	// CVTTSD2SIrr_Int
    0U,	// CVTTSS2SI64rm
    0U,	// CVTTSS2SI64rm_Int
    0U,	// CVTTSS2SI64rr
    0U,	// CVTTSS2SI64rr_Int
    0U,	// CVTTSS2SIrm
    0U,	// CVTTSS2SIrm_Int
    0U,	// CVTTSS2SIrr
    0U,	// CVTTSS2SIrr_Int
    0U,	// CWD
    0U,	// CWDE
    0U,	// DAA
    0U,	// DAS
    0U,	// DATA16_PREFIX
    0U,	// DEC16m
    0U,	// DEC16r
    0U,	// DEC16r_alt
    0U,	// DEC32m
    0U,	// DEC32r
    0U,	// DEC32r_alt
    0U,	// DEC64m
    0U,	// DEC64r
    0U,	// DEC8m
    0U,	// DEC8r
    0U,	// DIV16m
    0U,	// DIV16r
    0U,	// DIV32m
    0U,	// DIV32r
    0U,	// DIV64m
    0U,	// DIV64r
    0U,	// DIV8m
    0U,	// DIV8r
    0U,	// DIVPDrm
    0U,	// DIVPDrr
    0U,	// DIVPSrm
    0U,	// DIVPSrr
    0U,	// DIVR_F32m
    0U,	// DIVR_F64m
    0U,	// DIVR_FI16m
    0U,	// DIVR_FI32m
    0U,	// DIVR_FPrST0
    0U,	// DIVR_FST0r
    0U,	// DIVR_Fp32m
    0U,	// DIVR_Fp64m
    0U,	// DIVR_Fp64m32
    0U,	// DIVR_Fp80m32
    0U,	// DIVR_Fp80m64
    0U,	// DIVR_FpI16m32
    0U,	// DIVR_FpI16m64
    0U,	// DIVR_FpI16m80
    0U,	// DIVR_FpI32m32
    0U,	// DIVR_FpI32m64
    0U,	// DIVR_FpI32m80
    0U,	// DIVR_FrST0
    0U,	// DIVSDrm
    0U,	// DIVSDrm_Int
    0U,	// DIVSDrr
    0U,	// DIVSDrr_Int
    0U,	// DIVSSrm
    0U,	// DIVSSrm_Int
    0U,	// DIVSSrr
    0U,	// DIVSSrr_Int
    0U,	// DIV_F32m
    0U,	// DIV_F64m
    0U,	// DIV_FI16m
    0U,	// DIV_FI32m
    0U,	// DIV_FPrST0
    0U,	// DIV_FST0r
    0U,	// DIV_Fp32
    0U,	// DIV_Fp32m
    0U,	// DIV_Fp64
    0U,	// DIV_Fp64m
    0U,	// DIV_Fp64m32
    0U,	// DIV_Fp80
    0U,	// DIV_Fp80m32
    0U,	// DIV_Fp80m64
    0U,	// DIV_FpI16m32
    0U,	// DIV_FpI16m64
    0U,	// DIV_FpI16m80
    0U,	// DIV_FpI32m32
    0U,	// DIV_FpI32m64
    0U,	// DIV_FpI32m80
    0U,	// DIV_FrST0
    0U,	// DPPDrmi
    4U,	// DPPDrri
    0U,	// DPPSrmi
    4U,	// DPPSrri
    0U,	// ENCLS
    0U,	// ENCLU
    0U,	// ENCLV
    0U,	// ENDBR32
    0U,	// ENDBR64
    0U,	// ENTER
    0U,	// EXTRACTPSmr
    72U,	// EXTRACTPSrr
    0U,	// EXTRQ
    0U,	// EXTRQI
    0U,	// F2XM1
    0U,	// FARCALL16i
    0U,	// FARCALL16m
    0U,	// FARCALL32i
    0U,	// FARCALL32m
    0U,	// FARCALL64
    0U,	// FARJMP16i
    0U,	// FARJMP16m
    0U,	// FARJMP32i
    0U,	// FARJMP32m
    0U,	// FARJMP64
    0U,	// FBLDm
    0U,	// FBSTPm
    0U,	// FCOM32m
    0U,	// FCOM64m
    0U,	// FCOMP32m
    0U,	// FCOMP64m
    0U,	// FCOMPP
    0U,	// FDECSTP
    0U,	// FDISI8087_NOP
    0U,	// FEMMS
    0U,	// FENI8087_NOP
    0U,	// FFREE
    0U,	// FFREEP
    0U,	// FICOM16m
    0U,	// FICOM32m
    0U,	// FICOMP16m
    0U,	// FICOMP32m
    0U,	// FINCSTP
    0U,	// FLDCW16m
    0U,	// FLDENVm
    0U,	// FLDL2E
    0U,	// FLDL2T
    0U,	// FLDLG2
    0U,	// FLDLN2
    0U,	// FLDPI
    0U,	// FNCLEX
    0U,	// FNINIT
    0U,	// FNOP
    0U,	// FNSTCW16m
    0U,	// FNSTSW16r
    0U,	// FNSTSWm
    0U,	// FPATAN
    0U,	// FPNCEST0r
    0U,	// FPREM
    0U,	// FPREM1
    0U,	// FPTAN
    0U,	// FRNDINT
    0U,	// FRSTORm
    0U,	// FSAVEm
    0U,	// FSCALE
    0U,	// FSETPM
    0U,	// FSINCOS
    0U,	// FSTENVm
    0U,	// FXAM
    0U,	// FXRSTOR
    0U,	// FXRSTOR64
    0U,	// FXSAVE
    0U,	// FXSAVE64
    0U,	// FXTRACT
    0U,	// FYL2X
    0U,	// FYL2XP1
    0U,	// GETSEC
    0U,	// GF2P8AFFINEINVQBrmi
    4U,	// GF2P8AFFINEINVQBrri
    0U,	// GF2P8AFFINEQBrmi
    4U,	// GF2P8AFFINEQBrri
    0U,	// GF2P8MULBrm
    0U,	// GF2P8MULBrr
    0U,	// HADDPDrm
    0U,	// HADDPDrr
    0U,	// HADDPSrm
    0U,	// HADDPSrr
    0U,	// HLT
    0U,	// HSUBPDrm
    0U,	// HSUBPDrr
    0U,	// HSUBPSrm
    0U,	// HSUBPSrr
    0U,	// IDIV16m
    0U,	// IDIV16r
    0U,	// IDIV32m
    0U,	// IDIV32r
    0U,	// IDIV64m
    0U,	// IDIV64r
    0U,	// IDIV8m
    0U,	// IDIV8r
    0U,	// ILD_F16m
    0U,	// ILD_F32m
    0U,	// ILD_F64m
    0U,	// ILD_Fp16m32
    0U,	// ILD_Fp16m64
    0U,	// ILD_Fp16m80
    0U,	// ILD_Fp32m32
    0U,	// ILD_Fp32m64
    0U,	// ILD_Fp32m80
    0U,	// ILD_Fp64m32
    0U,	// ILD_Fp64m64
    0U,	// ILD_Fp64m80
    0U,	// IMUL16m
    0U,	// IMUL16r
    0U,	// IMUL16rm
    0U,	// IMUL16rmi
    0U,	// IMUL16rmi8
    0U,	// IMUL16rr
    4U,	// IMUL16rri
    4U,	// IMUL16rri8
    0U,	// IMUL32m
    0U,	// IMUL32r
    0U,	// IMUL32rm
    4U,	// IMUL32rmi
    4U,	// IMUL32rmi8
    0U,	// IMUL32rr
    4U,	// IMUL32rri
    4U,	// IMUL32rri8
    0U,	// IMUL64m
    0U,	// IMUL64r
    0U,	// IMUL64rm
    4U,	// IMUL64rmi32
    4U,	// IMUL64rmi8
    0U,	// IMUL64rr
    4U,	// IMUL64rri32
    4U,	// IMUL64rri8
    0U,	// IMUL8m
    0U,	// IMUL8r
    0U,	// IN16ri
    0U,	// IN16rr
    0U,	// IN32ri
    0U,	// IN32rr
    0U,	// IN8ri
    0U,	// IN8rr
    0U,	// INC16m
    0U,	// INC16r
    0U,	// INC16r_alt
    0U,	// INC32m
    0U,	// INC32r
    0U,	// INC32r_alt
    0U,	// INC64m
    0U,	// INC64r
    0U,	// INC8m
    0U,	// INC8r
    0U,	// INCSSPD
    0U,	// INCSSPQ
    0U,	// INSB
    4U,	// INSERTPSrm
    4U,	// INSERTPSrr
    0U,	// INSERTQ
    1U,	// INSERTQI
    0U,	// INSL
    0U,	// INSW
    0U,	// INT
    0U,	// INT1
    0U,	// INT3
    0U,	// INTO
    0U,	// INVD
    0U,	// INVEPT32
    0U,	// INVEPT64
    0U,	// INVLPG
    0U,	// INVLPGA32
    0U,	// INVLPGA64
    0U,	// INVPCID32
    0U,	// INVPCID64
    0U,	// INVVPID32
    0U,	// INVVPID64
    0U,	// IRET16
    0U,	// IRET32
    0U,	// IRET64
    0U,	// ISTT_FP16m
    0U,	// ISTT_FP32m
    0U,	// ISTT_FP64m
    0U,	// ISTT_Fp16m32
    0U,	// ISTT_Fp16m64
    0U,	// ISTT_Fp16m80
    0U,	// ISTT_Fp32m32
    0U,	// ISTT_Fp32m64
    0U,	// ISTT_Fp32m80
    0U,	// ISTT_Fp64m32
    0U,	// ISTT_Fp64m64
    0U,	// ISTT_Fp64m80
    0U,	// IST_F16m
    0U,	// IST_F32m
    0U,	// IST_FP16m
    0U,	// IST_FP32m
    0U,	// IST_FP64m
    0U,	// IST_Fp16m32
    0U,	// IST_Fp16m64
    0U,	// IST_Fp16m80
    0U,	// IST_Fp32m32
    0U,	// IST_Fp32m64
    0U,	// IST_Fp32m80
    0U,	// IST_Fp64m32
    0U,	// IST_Fp64m64
    0U,	// IST_Fp64m80
    0U,	// JAE_1
    0U,	// JAE_2
    0U,	// JAE_4
    0U,	// JA_1
    0U,	// JA_2
    0U,	// JA_4
    0U,	// JBE_1
    0U,	// JBE_2
    0U,	// JBE_4
    0U,	// JB_1
    0U,	// JB_2
    0U,	// JB_4
    0U,	// JCXZ
    0U,	// JECXZ
    0U,	// JE_1
    0U,	// JE_2
    0U,	// JE_4
    0U,	// JGE_1
    0U,	// JGE_2
    0U,	// JGE_4
    0U,	// JG_1
    0U,	// JG_2
    0U,	// JG_4
    0U,	// JLE_1
    0U,	// JLE_2
    0U,	// JLE_4
    0U,	// JL_1
    0U,	// JL_2
    0U,	// JL_4
    0U,	// JMP16m
    0U,	// JMP16m_NT
    0U,	// JMP16r
    0U,	// JMP16r_NT
    0U,	// JMP32m
    0U,	// JMP32m_NT
    0U,	// JMP32r
    0U,	// JMP32r_NT
    0U,	// JMP64m
    0U,	// JMP64m_NT
    0U,	// JMP64r
    0U,	// JMP64r_NT
    0U,	// JMP_1
    0U,	// JMP_2
    0U,	// JMP_4
    0U,	// JNE_1
    0U,	// JNE_2
    0U,	// JNE_4
    0U,	// JNO_1
    0U,	// JNO_2
    0U,	// JNO_4
    0U,	// JNP_1
    0U,	// JNP_2
    0U,	// JNP_4
    0U,	// JNS_1
    0U,	// JNS_2
    0U,	// JNS_4
    0U,	// JO_1
    0U,	// JO_2
    0U,	// JO_4
    0U,	// JP_1
    0U,	// JP_2
    0U,	// JP_4
    0U,	// JRCXZ
    0U,	// JS_1
    0U,	// JS_2
    0U,	// JS_4
    4U,	// KADDBrr
    4U,	// KADDDrr
    4U,	// KADDQrr
    4U,	// KADDWrr
    4U,	// KANDBrr
    4U,	// KANDDrr
    4U,	// KANDNBrr
    4U,	// KANDNDrr
    4U,	// KANDNQrr
    4U,	// KANDNWrr
    4U,	// KANDQrr
    4U,	// KANDWrr
    0U,	// KMOVBkk
    0U,	// KMOVBkm
    0U,	// KMOVBkr
    0U,	// KMOVBmk
    0U,	// KMOVBrk
    0U,	// KMOVDkk
    0U,	// KMOVDkm
    0U,	// KMOVDkr
    0U,	// KMOVDmk
    0U,	// KMOVDrk
    0U,	// KMOVQkk
    0U,	// KMOVQkm
    0U,	// KMOVQkr
    0U,	// KMOVQmk
    0U,	// KMOVQrk
    0U,	// KMOVWkk
    0U,	// KMOVWkm
    0U,	// KMOVWkr
    0U,	// KMOVWmk
    0U,	// KMOVWrk
    0U,	// KNOTBrr
    0U,	// KNOTDrr
    0U,	// KNOTQrr
    0U,	// KNOTWrr
    4U,	// KORBrr
    4U,	// KORDrr
    4U,	// KORQrr
    0U,	// KORTESTBrr
    0U,	// KORTESTDrr
    0U,	// KORTESTQrr
    0U,	// KORTESTWrr
    4U,	// KORWrr
    72U,	// KSHIFTLBri
    72U,	// KSHIFTLDri
    72U,	// KSHIFTLQri
    72U,	// KSHIFTLWri
    72U,	// KSHIFTRBri
    72U,	// KSHIFTRDri
    72U,	// KSHIFTRQri
    72U,	// KSHIFTRWri
    0U,	// KTESTBrr
    0U,	// KTESTDrr
    0U,	// KTESTQrr
    0U,	// KTESTWrr
    4U,	// KUNPCKBWrr
    4U,	// KUNPCKDQrr
    4U,	// KUNPCKWDrr
    4U,	// KXNORBrr
    4U,	// KXNORDrr
    4U,	// KXNORQrr
    4U,	// KXNORWrr
    4U,	// KXORBrr
    4U,	// KXORDrr
    4U,	// KXORQrr
    4U,	// KXORWrr
    0U,	// LAHF
    0U,	// LAR16rm
    0U,	// LAR16rr
    0U,	// LAR32rm
    0U,	// LAR32rr
    0U,	// LAR64rm
    0U,	// LAR64rr
    0U,	// LDDQUrm
    0U,	// LDMXCSR
    0U,	// LDS16rm
    0U,	// LDS32rm
    0U,	// LD_F0
    0U,	// LD_F1
    0U,	// LD_F32m
    0U,	// LD_F64m
    0U,	// LD_F80m
    0U,	// LD_Fp032
    0U,	// LD_Fp064
    0U,	// LD_Fp080
    0U,	// LD_Fp132
    0U,	// LD_Fp164
    0U,	// LD_Fp180
    0U,	// LD_Fp32m
    0U,	// LD_Fp32m64
    0U,	// LD_Fp32m80
    0U,	// LD_Fp64m
    0U,	// LD_Fp64m80
    0U,	// LD_Fp80m
    0U,	// LD_Frr
    0U,	// LEA16r
    0U,	// LEA32r
    0U,	// LEA64_32r
    0U,	// LEA64r
    0U,	// LEAVE
    0U,	// LEAVE64
    0U,	// LES16rm
    0U,	// LES32rm
    0U,	// LFENCE
    0U,	// LFS16rm
    0U,	// LFS32rm
    0U,	// LFS64rm
    0U,	// LGDT16m
    0U,	// LGDT32m
    0U,	// LGDT64m
    0U,	// LGS16rm
    0U,	// LGS32rm
    0U,	// LGS64rm
    0U,	// LIDT16m
    0U,	// LIDT32m
    0U,	// LIDT64m
    0U,	// LLDT16m
    0U,	// LLDT16r
    0U,	// LLWPCB
    0U,	// LLWPCB64
    0U,	// LMSW16m
    0U,	// LMSW16r
    0U,	// LOCK_PREFIX
    0U,	// LODSB
    0U,	// LODSL
    0U,	// LODSQ
    0U,	// LODSW
    0U,	// LOOP
    0U,	// LOOPE
    0U,	// LOOPNE
    0U,	// LRETIL
    0U,	// LRETIQ
    0U,	// LRETIW
    0U,	// LRETL
    0U,	// LRETQ
    0U,	// LRETW
    0U,	// LSL16rm
    0U,	// LSL16rr
    0U,	// LSL32rm
    0U,	// LSL32rr
    0U,	// LSL64rm
    0U,	// LSL64rr
    0U,	// LSS16rm
    0U,	// LSS32rm
    0U,	// LSS64rm
    0U,	// LTRm
    0U,	// LTRr
    4U,	// LWPINS32rmi
    4U,	// LWPINS32rri
    4U,	// LWPINS64rmi
    4U,	// LWPINS64rri
    4U,	// LWPVAL32rmi
    4U,	// LWPVAL32rri
    4U,	// LWPVAL64rmi
    4U,	// LWPVAL64rri
    0U,	// LZCNT16rm
    0U,	// LZCNT16rr
    0U,	// LZCNT32rm
    0U,	// LZCNT32rr
    0U,	// LZCNT64rm
    0U,	// LZCNT64rr
    0U,	// MASKMOVDQU
    0U,	// MASKMOVDQU64
    0U,	// MAXCPDrm
    0U,	// MAXCPDrr
    0U,	// MAXCPSrm
    0U,	// MAXCPSrr
    0U,	// MAXCSDrm
    0U,	// MAXCSDrr
    0U,	// MAXCSSrm
    0U,	// MAXCSSrr
    0U,	// MAXPDrm
    0U,	// MAXPDrr
    0U,	// MAXPSrm
    0U,	// MAXPSrr
    0U,	// MAXSDrm
    0U,	// MAXSDrm_Int
    0U,	// MAXSDrr
    0U,	// MAXSDrr_Int
    0U,	// MAXSSrm
    0U,	// MAXSSrm_Int
    0U,	// MAXSSrr
    0U,	// MAXSSrr_Int
    0U,	// MFENCE
    0U,	// MINCPDrm
    0U,	// MINCPDrr
    0U,	// MINCPSrm
    0U,	// MINCPSrr
    0U,	// MINCSDrm
    0U,	// MINCSDrr
    0U,	// MINCSSrm
    0U,	// MINCSSrr
    0U,	// MINPDrm
    0U,	// MINPDrr
    0U,	// MINPSrm
    0U,	// MINPSrr
    0U,	// MINSDrm
    0U,	// MINSDrm_Int
    0U,	// MINSDrr
    0U,	// MINSDrr_Int
    0U,	// MINSSrm
    0U,	// MINSSrm_Int
    0U,	// MINSSrr
    0U,	// MINSSrr_Int
    0U,	// MMX_CVTPD2PIirm
    0U,	// MMX_CVTPD2PIirr
    0U,	// MMX_CVTPI2PDirm
    0U,	// MMX_CVTPI2PDirr
    0U,	// MMX_CVTPI2PSirm
    0U,	// MMX_CVTPI2PSirr
    0U,	// MMX_CVTPS2PIirm
    0U,	// MMX_CVTPS2PIirr
    0U,	// MMX_CVTTPD2PIirm
    0U,	// MMX_CVTTPD2PIirr
    0U,	// MMX_CVTTPS2PIirm
    0U,	// MMX_CVTTPS2PIirr
    0U,	// MMX_EMMS
    0U,	// MMX_MASKMOVQ
    0U,	// MMX_MASKMOVQ64
    0U,	// MMX_MOVD64from64rm
    0U,	// MMX_MOVD64from64rr
    0U,	// MMX_MOVD64grr
    0U,	// MMX_MOVD64mr
    0U,	// MMX_MOVD64rm
    0U,	// MMX_MOVD64rr
    0U,	// MMX_MOVD64to64rm
    0U,	// MMX_MOVD64to64rr
    0U,	// MMX_MOVDQ2Qrr
    0U,	// MMX_MOVFR642Qrr
    0U,	// MMX_MOVNTQmr
    0U,	// MMX_MOVQ2DQrr
    0U,	// MMX_MOVQ2FR64rr
    0U,	// MMX_MOVQ64mr
    0U,	// MMX_MOVQ64rm
    0U,	// MMX_MOVQ64rr
    0U,	// MMX_MOVQ64rr_REV
    0U,	// MMX_PABSBrm
    0U,	// MMX_PABSBrr
    0U,	// MMX_PABSDrm
    0U,	// MMX_PABSDrr
    0U,	// MMX_PABSWrm
    0U,	// MMX_PABSWrr
    0U,	// MMX_PACKSSDWirm
    0U,	// MMX_PACKSSDWirr
    0U,	// MMX_PACKSSWBirm
    0U,	// MMX_PACKSSWBirr
    0U,	// MMX_PACKUSWBirm
    0U,	// MMX_PACKUSWBirr
    0U,	// MMX_PADDBirm
    0U,	// MMX_PADDBirr
    0U,	// MMX_PADDDirm
    0U,	// MMX_PADDDirr
    0U,	// MMX_PADDQirm
    0U,	// MMX_PADDQirr
    0U,	// MMX_PADDSBirm
    0U,	// MMX_PADDSBirr
    0U,	// MMX_PADDSWirm
    0U,	// MMX_PADDSWirr
    0U,	// MMX_PADDUSBirm
    0U,	// MMX_PADDUSBirr
    0U,	// MMX_PADDUSWirm
    0U,	// MMX_PADDUSWirr
    0U,	// MMX_PADDWirm
    0U,	// MMX_PADDWirr
    4U,	// MMX_PALIGNRrmi
    4U,	// MMX_PALIGNRrri
    0U,	// MMX_PANDNirm
    0U,	// MMX_PANDNirr
    0U,	// MMX_PANDirm
    0U,	// MMX_PANDirr
    0U,	// MMX_PAVGBirm
    0U,	// MMX_PAVGBirr
    0U,	// MMX_PAVGWirm
    0U,	// MMX_PAVGWirr
    0U,	// MMX_PCMPEQBirm
    0U,	// MMX_PCMPEQBirr
    0U,	// MMX_PCMPEQDirm
    0U,	// MMX_PCMPEQDirr
    0U,	// MMX_PCMPEQWirm
    0U,	// MMX_PCMPEQWirr
    0U,	// MMX_PCMPGTBirm
    0U,	// MMX_PCMPGTBirr
    0U,	// MMX_PCMPGTDirm
    0U,	// MMX_PCMPGTDirr
    0U,	// MMX_PCMPGTWirm
    0U,	// MMX_PCMPGTWirr
    72U,	// MMX_PEXTRWrr
    0U,	// MMX_PHADDDrm
    0U,	// MMX_PHADDDrr
    0U,	// MMX_PHADDSWrm
    0U,	// MMX_PHADDSWrr
    0U,	// MMX_PHADDWrm
    0U,	// MMX_PHADDWrr
    0U,	// MMX_PHSUBDrm
    0U,	// MMX_PHSUBDrr
    0U,	// MMX_PHSUBSWrm
    0U,	// MMX_PHSUBSWrr
    0U,	// MMX_PHSUBWrm
    0U,	// MMX_PHSUBWrr
    0U,	// MMX_PINSRWrm
    4U,	// MMX_PINSRWrr
    0U,	// MMX_PMADDUBSWrm
    0U,	// MMX_PMADDUBSWrr
    0U,	// MMX_PMADDWDirm
    0U,	// MMX_PMADDWDirr
    0U,	// MMX_PMAXSWirm
    0U,	// MMX_PMAXSWirr
    0U,	// MMX_PMAXUBirm
    0U,	// MMX_PMAXUBirr
    0U,	// MMX_PMINSWirm
    0U,	// MMX_PMINSWirr
    0U,	// MMX_PMINUBirm
    0U,	// MMX_PMINUBirr
    0U,	// MMX_PMOVMSKBrr
    0U,	// MMX_PMULHRSWrm
    0U,	// MMX_PMULHRSWrr
    0U,	// MMX_PMULHUWirm
    0U,	// MMX_PMULHUWirr
    0U,	// MMX_PMULHWirm
    0U,	// MMX_PMULHWirr
    0U,	// MMX_PMULLWirm
    0U,	// MMX_PMULLWirr
    0U,	// MMX_PMULUDQirm
    0U,	// MMX_PMULUDQirr
    0U,	// MMX_PORirm
    0U,	// MMX_PORirr
    0U,	// MMX_PSADBWirm
    0U,	// MMX_PSADBWirr
    0U,	// MMX_PSHUFBrm
    0U,	// MMX_PSHUFBrr
    4U,	// MMX_PSHUFWmi
    72U,	// MMX_PSHUFWri
    0U,	// MMX_PSIGNBrm
    0U,	// MMX_PSIGNBrr
    0U,	// MMX_PSIGNDrm
    0U,	// MMX_PSIGNDrr
    0U,	// MMX_PSIGNWrm
    0U,	// MMX_PSIGNWrr
    0U,	// MMX_PSLLDri
    0U,	// MMX_PSLLDrm
    0U,	// MMX_PSLLDrr
    0U,	// MMX_PSLLQri
    0U,	// MMX_PSLLQrm
    0U,	// MMX_PSLLQrr
    0U,	// MMX_PSLLWri
    0U,	// MMX_PSLLWrm
    0U,	// MMX_PSLLWrr
    0U,	// MMX_PSRADri
    0U,	// MMX_PSRADrm
    0U,	// MMX_PSRADrr
    0U,	// MMX_PSRAWri
    0U,	// MMX_PSRAWrm
    0U,	// MMX_PSRAWrr
    0U,	// MMX_PSRLDri
    0U,	// MMX_PSRLDrm
    0U,	// MMX_PSRLDrr
    0U,	// MMX_PSRLQri
    0U,	// MMX_PSRLQrm
    0U,	// MMX_PSRLQrr
    0U,	// MMX_PSRLWri
    0U,	// MMX_PSRLWrm
    0U,	// MMX_PSRLWrr
    0U,	// MMX_PSUBBirm
    0U,	// MMX_PSUBBirr
    0U,	// MMX_PSUBDirm
    0U,	// MMX_PSUBDirr
    0U,	// MMX_PSUBQirm
    0U,	// MMX_PSUBQirr
    0U,	// MMX_PSUBSBirm
    0U,	// MMX_PSUBSBirr
    0U,	// MMX_PSUBSWirm
    0U,	// MMX_PSUBSWirr
    0U,	// MMX_PSUBUSBirm
    0U,	// MMX_PSUBUSBirr
    0U,	// MMX_PSUBUSWirm
    0U,	// MMX_PSUBUSWirr
    0U,	// MMX_PSUBWirm
    0U,	// MMX_PSUBWirr
    0U,	// MMX_PUNPCKHBWirm
    0U,	// MMX_PUNPCKHBWirr
    0U,	// MMX_PUNPCKHDQirm
    0U,	// MMX_PUNPCKHDQirr
    0U,	// MMX_PUNPCKHWDirm
    0U,	// MMX_PUNPCKHWDirr
    0U,	// MMX_PUNPCKLBWirm
    0U,	// MMX_PUNPCKLBWirr
    0U,	// MMX_PUNPCKLDQirm
    0U,	// MMX_PUNPCKLDQirr
    0U,	// MMX_PUNPCKLWDirm
    0U,	// MMX_PUNPCKLWDirr
    0U,	// MMX_PXORirm
    0U,	// MMX_PXORirr
    0U,	// MONITORXrrr
    0U,	// MONITORrrr
    0U,	// MONTMUL
    0U,	// MOV16ao16
    0U,	// MOV16ao32
    0U,	// MOV16ao64
    0U,	// MOV16mi
    0U,	// MOV16mr
    0U,	// MOV16ms
    0U,	// MOV16o16a
    0U,	// MOV16o32a
    0U,	// MOV16o64a
    0U,	// MOV16ri
    0U,	// MOV16ri_alt
    0U,	// MOV16rm
    0U,	// MOV16rr
    0U,	// MOV16rr_REV
    0U,	// MOV16rs
    0U,	// MOV16sm
    0U,	// MOV16sr
    0U,	// MOV32ao16
    0U,	// MOV32ao32
    0U,	// MOV32ao64
    0U,	// MOV32cr
    0U,	// MOV32dr
    0U,	// MOV32mi
    0U,	// MOV32mr
    0U,	// MOV32o16a
    0U,	// MOV32o32a
    0U,	// MOV32o64a
    0U,	// MOV32rc
    0U,	// MOV32rd
    0U,	// MOV32ri
    0U,	// MOV32ri_alt
    0U,	// MOV32rm
    0U,	// MOV32rr
    0U,	// MOV32rr_REV
    0U,	// MOV32rs
    0U,	// MOV32sr
    0U,	// MOV64ao32
    0U,	// MOV64ao64
    0U,	// MOV64cr
    0U,	// MOV64dr
    0U,	// MOV64mi32
    0U,	// MOV64mr
    0U,	// MOV64o32a
    0U,	// MOV64o64a
    0U,	// MOV64rc
    0U,	// MOV64rd
    0U,	// MOV64ri
    0U,	// MOV64ri32
    0U,	// MOV64rm
    0U,	// MOV64rr
    0U,	// MOV64rr_REV
    0U,	// MOV64rs
    0U,	// MOV64sr
    0U,	// MOV64toPQIrm
    0U,	// MOV64toPQIrr
    0U,	// MOV64toSDrm
    0U,	// MOV64toSDrr
    0U,	// MOV8ao16
    0U,	// MOV8ao32
    0U,	// MOV8ao64
    0U,	// MOV8mi
    0U,	// MOV8mr
    0U,	// MOV8mr_NOREX
    0U,	// MOV8o16a
    0U,	// MOV8o32a
    0U,	// MOV8o64a
    0U,	// MOV8ri
    0U,	// MOV8ri_alt
    0U,	// MOV8rm
    0U,	// MOV8rm_NOREX
    0U,	// MOV8rr
    0U,	// MOV8rr_NOREX
    0U,	// MOV8rr_REV
    0U,	// MOVAPDmr
    0U,	// MOVAPDrm
    0U,	// MOVAPDrr
    0U,	// MOVAPDrr_REV
    0U,	// MOVAPSmr
    0U,	// MOVAPSrm
    0U,	// MOVAPSrr
    0U,	// MOVAPSrr_REV
    0U,	// MOVBE16mr
    0U,	// MOVBE16rm
    0U,	// MOVBE32mr
    0U,	// MOVBE32rm
    0U,	// MOVBE64mr
    0U,	// MOVBE64rm
    0U,	// MOVDDUPrm
    0U,	// MOVDDUPrr
    0U,	// MOVDI2PDIrm
    0U,	// MOVDI2PDIrr
    0U,	// MOVDI2SSrm
    0U,	// MOVDI2SSrr
    0U,	// MOVDIR64B16
    0U,	// MOVDIR64B32
    0U,	// MOVDIR64B64
    0U,	// MOVDIRI32
    0U,	// MOVDIRI64
    0U,	// MOVDQAmr
    0U,	// MOVDQArm
    0U,	// MOVDQArr
    0U,	// MOVDQArr_REV
    0U,	// MOVDQUmr
    0U,	// MOVDQUrm
    0U,	// MOVDQUrr
    0U,	// MOVDQUrr_REV
    0U,	// MOVHLPSrr
    0U,	// MOVHPDmr
    0U,	// MOVHPDrm
    0U,	// MOVHPSmr
    0U,	// MOVHPSrm
    0U,	// MOVLHPSrr
    0U,	// MOVLPDmr
    0U,	// MOVLPDrm
    0U,	// MOVLPSmr
    0U,	// MOVLPSrm
    0U,	// MOVMSKPDrr
    0U,	// MOVMSKPSrr
    0U,	// MOVNTDQArm
    0U,	// MOVNTDQmr
    0U,	// MOVNTI_64mr
    0U,	// MOVNTImr
    0U,	// MOVNTPDmr
    0U,	// MOVNTPSmr
    0U,	// MOVNTSD
    0U,	// MOVNTSS
    0U,	// MOVPDI2DImr
    0U,	// MOVPDI2DIrr
    0U,	// MOVPQI2QImr
    0U,	// MOVPQI2QIrr
    0U,	// MOVPQIto64mr
    0U,	// MOVPQIto64rr
    0U,	// MOVQI2PQIrm
    0U,	// MOVSB
    0U,	// MOVSDmr
    0U,	// MOVSDrm
    0U,	// MOVSDrr
    0U,	// MOVSDrr_REV
    0U,	// MOVSDto64mr
    0U,	// MOVSDto64rr
    0U,	// MOVSHDUPrm
    0U,	// MOVSHDUPrr
    0U,	// MOVSL
    0U,	// MOVSLDUPrm
    0U,	// MOVSLDUPrr
    0U,	// MOVSQ
    0U,	// MOVSS2DImr
    0U,	// MOVSS2DIrr
    0U,	// MOVSSmr
    0U,	// MOVSSrm
    0U,	// MOVSSrr
    0U,	// MOVSSrr_REV
    0U,	// MOVSW
    0U,	// MOVSX16rm16
    0U,	// MOVSX16rm8
    0U,	// MOVSX16rr16
    0U,	// MOVSX16rr8
    0U,	// MOVSX32rm16
    0U,	// MOVSX32rm8
    0U,	// MOVSX32rm8_NOREX
    0U,	// MOVSX32rr16
    0U,	// MOVSX32rr8
    0U,	// MOVSX32rr8_NOREX
    0U,	// MOVSX64rm16
    0U,	// MOVSX64rm32
    0U,	// MOVSX64rm8
    0U,	// MOVSX64rr16
    0U,	// MOVSX64rr32
    0U,	// MOVSX64rr8
    0U,	// MOVUPDmr
    0U,	// MOVUPDrm
    0U,	// MOVUPDrr
    0U,	// MOVUPDrr_REV
    0U,	// MOVUPSmr
    0U,	// MOVUPSrm
    0U,	// MOVUPSrr
    0U,	// MOVUPSrr_REV
    0U,	// MOVZPQILo2PQIrr
    0U,	// MOVZX16rm16
    0U,	// MOVZX16rm8
    0U,	// MOVZX16rr16
    0U,	// MOVZX16rr8
    0U,	// MOVZX32rm16
    0U,	// MOVZX32rm8
    0U,	// MOVZX32rm8_NOREX
    0U,	// MOVZX32rr16
    0U,	// MOVZX32rr8
    0U,	// MOVZX32rr8_NOREX
    0U,	// MOVZX64rm16
    0U,	// MOVZX64rm8
    0U,	// MOVZX64rr16
    0U,	// MOVZX64rr8
    0U,	// MPSADBWrmi
    4U,	// MPSADBWrri
    0U,	// MUL16m
    0U,	// MUL16r
    0U,	// MUL32m
    0U,	// MUL32r
    0U,	// MUL64m
    0U,	// MUL64r
    0U,	// MUL8m
    0U,	// MUL8r
    0U,	// MULPDrm
    0U,	// MULPDrr
    0U,	// MULPSrm
    0U,	// MULPSrr
    0U,	// MULSDrm
    0U,	// MULSDrm_Int
    0U,	// MULSDrr
    0U,	// MULSDrr_Int
    0U,	// MULSSrm
    0U,	// MULSSrm_Int
    0U,	// MULSSrr
    0U,	// MULSSrr_Int
    72U,	// MULX32rm
    4U,	// MULX32rr
    72U,	// MULX64rm
    4U,	// MULX64rr
    0U,	// MUL_F32m
    0U,	// MUL_F64m
    0U,	// MUL_FI16m
    0U,	// MUL_FI32m
    0U,	// MUL_FPrST0
    0U,	// MUL_FST0r
    0U,	// MUL_Fp32
    0U,	// MUL_Fp32m
    0U,	// MUL_Fp64
    0U,	// MUL_Fp64m
    0U,	// MUL_Fp64m32
    0U,	// MUL_Fp80
    0U,	// MUL_Fp80m32
    0U,	// MUL_Fp80m64
    0U,	// MUL_FpI16m32
    0U,	// MUL_FpI16m64
    0U,	// MUL_FpI16m80
    0U,	// MUL_FpI32m32
    0U,	// MUL_FpI32m64
    0U,	// MUL_FpI32m80
    0U,	// MUL_FrST0
    0U,	// MWAITXrrr
    0U,	// MWAITrr
    0U,	// NEG16m
    0U,	// NEG16r
    0U,	// NEG32m
    0U,	// NEG32r
    0U,	// NEG64m
    0U,	// NEG64r
    0U,	// NEG8m
    0U,	// NEG8r
    0U,	// NOOP
    0U,	// NOOP18_16m4
    0U,	// NOOP18_16m5
    0U,	// NOOP18_16m6
    0U,	// NOOP18_16m7
    0U,	// NOOP18_16r4
    0U,	// NOOP18_16r5
    0U,	// NOOP18_16r6
    0U,	// NOOP18_16r7
    0U,	// NOOP18_m4
    0U,	// NOOP18_m5
    0U,	// NOOP18_m6
    0U,	// NOOP18_m7
    0U,	// NOOP18_r4
    0U,	// NOOP18_r5
    0U,	// NOOP18_r6
    0U,	// NOOP18_r7
    0U,	// NOOP19rr
    0U,	// NOOPL
    0U,	// NOOPL_19
    0U,	// NOOPL_1d
    0U,	// NOOPL_1e
    0U,	// NOOPLr
    0U,	// NOOPQ
    0U,	// NOOPQr
    0U,	// NOOPW
    0U,	// NOOPW_19
    0U,	// NOOPW_1c
    0U,	// NOOPW_1d
    0U,	// NOOPW_1e
    0U,	// NOOPWr
    0U,	// NOT16m
    0U,	// NOT16r
    0U,	// NOT32m
    0U,	// NOT32r
    0U,	// NOT64m
    0U,	// NOT64r
    0U,	// NOT8m
    0U,	// NOT8r
    0U,	// OR16i16
    0U,	// OR16mi
    0U,	// OR16mi8
    0U,	// OR16mr
    0U,	// OR16ri
    0U,	// OR16ri8
    0U,	// OR16rm
    0U,	// OR16rr
    0U,	// OR16rr_REV
    0U,	// OR32i32
    0U,	// OR32mi
    0U,	// OR32mi8
    0U,	// OR32mr
    0U,	// OR32ri
    0U,	// OR32ri8
    0U,	// OR32rm
    0U,	// OR32rr
    0U,	// OR32rr_REV
    0U,	// OR64i32
    0U,	// OR64mi32
    0U,	// OR64mi8
    0U,	// OR64mr
    0U,	// OR64ri32
    0U,	// OR64ri8
    0U,	// OR64rm
    0U,	// OR64rr
    0U,	// OR64rr_REV
    0U,	// OR8i8
    0U,	// OR8mi
    0U,	// OR8mi8
    0U,	// OR8mr
    0U,	// OR8ri
    0U,	// OR8ri8
    0U,	// OR8rm
    0U,	// OR8rr
    0U,	// OR8rr_REV
    0U,	// ORPDrm
    0U,	// ORPDrr
    0U,	// ORPSrm
    0U,	// ORPSrr
    0U,	// OUT16ir
    0U,	// OUT16rr
    0U,	// OUT32ir
    0U,	// OUT32rr
    0U,	// OUT8ir
    0U,	// OUT8rr
    0U,	// OUTSB
    0U,	// OUTSL
    0U,	// OUTSW
    0U,	// PABSBrm
    0U,	// PABSBrr
    0U,	// PABSDrm
    0U,	// PABSDrr
    0U,	// PABSWrm
    0U,	// PABSWrr
    0U,	// PACKSSDWrm
    0U,	// PACKSSDWrr
    0U,	// PACKSSWBrm
    0U,	// PACKSSWBrr
    0U,	// PACKUSDWrm
    0U,	// PACKUSDWrr
    0U,	// PACKUSWBrm
    0U,	// PACKUSWBrr
    0U,	// PADDBrm
    0U,	// PADDBrr
    0U,	// PADDDrm
    0U,	// PADDDrr
    0U,	// PADDQrm
    0U,	// PADDQrr
    0U,	// PADDSBrm
    0U,	// PADDSBrr
    0U,	// PADDSWrm
    0U,	// PADDSWrr
    0U,	// PADDUSBrm
    0U,	// PADDUSBrr
    0U,	// PADDUSWrm
    0U,	// PADDUSWrr
    0U,	// PADDWrm
    0U,	// PADDWrr
    0U,	// PALIGNRrmi
    4U,	// PALIGNRrri
    0U,	// PANDNrm
    0U,	// PANDNrr
    0U,	// PANDrm
    0U,	// PANDrr
    0U,	// PAUSE
    0U,	// PAVGBrm
    0U,	// PAVGBrr
    0U,	// PAVGUSBrm
    0U,	// PAVGUSBrr
    0U,	// PAVGWrm
    0U,	// PAVGWrr
    0U,	// PBLENDVBrm0
    0U,	// PBLENDVBrr0
    0U,	// PBLENDWrmi
    4U,	// PBLENDWrri
    0U,	// PCLMULQDQrm
    4U,	// PCLMULQDQrr
    0U,	// PCMPEQBrm
    0U,	// PCMPEQBrr
    0U,	// PCMPEQDrm
    0U,	// PCMPEQDrr
    0U,	// PCMPEQQrm
    0U,	// PCMPEQQrr
    0U,	// PCMPEQWrm
    0U,	// PCMPEQWrr
    4U,	// PCMPESTRIrm
    72U,	// PCMPESTRIrr
    4U,	// PCMPESTRMrm
    72U,	// PCMPESTRMrr
    0U,	// PCMPGTBrm
    0U,	// PCMPGTBrr
    0U,	// PCMPGTDrm
    0U,	// PCMPGTDrr
    0U,	// PCMPGTQrm
    0U,	// PCMPGTQrr
    0U,	// PCMPGTWrm
    0U,	// PCMPGTWrr
    4U,	// PCMPISTRIrm
    72U,	// PCMPISTRIrr
    4U,	// PCMPISTRMrm
    72U,	// PCMPISTRMrr
    0U,	// PCONFIG
    72U,	// PDEP32rm
    4U,	// PDEP32rr
    72U,	// PDEP64rm
    4U,	// PDEP64rr
    72U,	// PEXT32rm
    4U,	// PEXT32rr
    72U,	// PEXT64rm
    4U,	// PEXT64rr
    1U,	// PEXTRBmr
    72U,	// PEXTRBrr
    1U,	// PEXTRDmr
    72U,	// PEXTRDrr
    1U,	// PEXTRQmr
    72U,	// PEXTRQrr
    1U,	// PEXTRWmr
    72U,	// PEXTRWrr
    72U,	// PEXTRWrr_REV
    0U,	// PF2IDrm
    0U,	// PF2IDrr
    0U,	// PF2IWrm
    0U,	// PF2IWrr
    0U,	// PFACCrm
    0U,	// PFACCrr
    0U,	// PFADDrm
    0U,	// PFADDrr
    0U,	// PFCMPEQrm
    0U,	// PFCMPEQrr
    0U,	// PFCMPGErm
    0U,	// PFCMPGErr
    0U,	// PFCMPGTrm
    0U,	// PFCMPGTrr
    0U,	// PFMAXrm
    0U,	// PFMAXrr
    0U,	// PFMINrm
    0U,	// PFMINrr
    0U,	// PFMULrm
    0U,	// PFMULrr
    0U,	// PFNACCrm
    0U,	// PFNACCrr
    0U,	// PFPNACCrm
    0U,	// PFPNACCrr
    0U,	// PFRCPIT1rm
    0U,	// PFRCPIT1rr
    0U,	// PFRCPIT2rm
    0U,	// PFRCPIT2rr
    0U,	// PFRCPrm
    0U,	// PFRCPrr
    0U,	// PFRSQIT1rm
    0U,	// PFRSQIT1rr
    0U,	// PFRSQRTrm
    0U,	// PFRSQRTrr
    0U,	// PFSUBRrm
    0U,	// PFSUBRrr
    0U,	// PFSUBrm
    0U,	// PFSUBrr
    0U,	// PHADDDrm
    0U,	// PHADDDrr
    0U,	// PHADDSWrm
    0U,	// PHADDSWrr
    0U,	// PHADDWrm
    0U,	// PHADDWrr
    0U,	// PHMINPOSUWrm
    0U,	// PHMINPOSUWrr
    0U,	// PHSUBDrm
    0U,	// PHSUBDrr
    0U,	// PHSUBSWrm
    0U,	// PHSUBSWrr
    0U,	// PHSUBWrm
    0U,	// PHSUBWrr
    0U,	// PI2FDrm
    0U,	// PI2FDrr
    0U,	// PI2FWrm
    0U,	// PI2FWrr
    4U,	// PINSRBrm
    4U,	// PINSRBrr
    4U,	// PINSRDrm
    4U,	// PINSRDrr
    4U,	// PINSRQrm
    4U,	// PINSRQrr
    0U,	// PINSRWrm
    4U,	// PINSRWrr
    0U,	// PMADDUBSWrm
    0U,	// PMADDUBSWrr
    0U,	// PMADDWDrm
    0U,	// PMADDWDrr
    0U,	// PMAXSBrm
    0U,	// PMAXSBrr
    0U,	// PMAXSDrm
    0U,	// PMAXSDrr
    0U,	// PMAXSWrm
    0U,	// PMAXSWrr
    0U,	// PMAXUBrm
    0U,	// PMAXUBrr
    0U,	// PMAXUDrm
    0U,	// PMAXUDrr
    0U,	// PMAXUWrm
    0U,	// PMAXUWrr
    0U,	// PMINSBrm
    0U,	// PMINSBrr
    0U,	// PMINSDrm
    0U,	// PMINSDrr
    0U,	// PMINSWrm
    0U,	// PMINSWrr
    0U,	// PMINUBrm
    0U,	// PMINUBrr
    0U,	// PMINUDrm
    0U,	// PMINUDrr
    0U,	// PMINUWrm
    0U,	// PMINUWrr
    0U,	// PMOVMSKBrr
    0U,	// PMOVSXBDrm
    0U,	// PMOVSXBDrr
    0U,	// PMOVSXBQrm
    0U,	// PMOVSXBQrr
    0U,	// PMOVSXBWrm
    0U,	// PMOVSXBWrr
    0U,	// PMOVSXDQrm
    0U,	// PMOVSXDQrr
    0U,	// PMOVSXWDrm
    0U,	// PMOVSXWDrr
    0U,	// PMOVSXWQrm
    0U,	// PMOVSXWQrr
    0U,	// PMOVZXBDrm
    0U,	// PMOVZXBDrr
    0U,	// PMOVZXBQrm
    0U,	// PMOVZXBQrr
    0U,	// PMOVZXBWrm
    0U,	// PMOVZXBWrr
    0U,	// PMOVZXDQrm
    0U,	// PMOVZXDQrr
    0U,	// PMOVZXWDrm
    0U,	// PMOVZXWDrr
    0U,	// PMOVZXWQrm
    0U,	// PMOVZXWQrr
    0U,	// PMULDQrm
    0U,	// PMULDQrr
    0U,	// PMULHRSWrm
    0U,	// PMULHRSWrr
    0U,	// PMULHRWrm
    0U,	// PMULHRWrr
    0U,	// PMULHUWrm
    0U,	// PMULHUWrr
    0U,	// PMULHWrm
    0U,	// PMULHWrr
    0U,	// PMULLDrm
    0U,	// PMULLDrr
    0U,	// PMULLWrm
    0U,	// PMULLWrr
    0U,	// PMULUDQrm
    0U,	// PMULUDQrr
    0U,	// POP16r
    0U,	// POP16rmm
    0U,	// POP16rmr
    0U,	// POP32r
    0U,	// POP32rmm
    0U,	// POP32rmr
    0U,	// POP64r
    0U,	// POP64rmm
    0U,	// POP64rmr
    0U,	// POPA16
    0U,	// POPA32
    0U,	// POPCNT16rm
    0U,	// POPCNT16rr
    0U,	// POPCNT32rm
    0U,	// POPCNT32rr
    0U,	// POPCNT64rm
    0U,	// POPCNT64rr
    0U,	// POPDS16
    0U,	// POPDS32
    0U,	// POPES16
    0U,	// POPES32
    0U,	// POPF16
    0U,	// POPF32
    0U,	// POPF64
    0U,	// POPFS16
    0U,	// POPFS32
    0U,	// POPFS64
    0U,	// POPGS16
    0U,	// POPGS32
    0U,	// POPGS64
    0U,	// POPSS16
    0U,	// POPSS32
    0U,	// PORrm
    0U,	// PORrr
    0U,	// PREFETCH
    0U,	// PREFETCHNTA
    0U,	// PREFETCHT0
    0U,	// PREFETCHT1
    0U,	// PREFETCHT2
    0U,	// PREFETCHW
    0U,	// PREFETCHWT1
    0U,	// PSADBWrm
    0U,	// PSADBWrr
    0U,	// PSHUFBrm
    0U,	// PSHUFBrr
    4U,	// PSHUFDmi
    72U,	// PSHUFDri
    4U,	// PSHUFHWmi
    72U,	// PSHUFHWri
    4U,	// PSHUFLWmi
    72U,	// PSHUFLWri
    0U,	// PSIGNBrm
    0U,	// PSIGNBrr
    0U,	// PSIGNDrm
    0U,	// PSIGNDrr
    0U,	// PSIGNWrm
    0U,	// PSIGNWrr
    0U,	// PSLLDQri
    0U,	// PSLLDri
    0U,	// PSLLDrm
    0U,	// PSLLDrr
    0U,	// PSLLQri
    0U,	// PSLLQrm
    0U,	// PSLLQrr
    0U,	// PSLLWri
    0U,	// PSLLWrm
    0U,	// PSLLWrr
    0U,	// PSRADri
    0U,	// PSRADrm
    0U,	// PSRADrr
    0U,	// PSRAWri
    0U,	// PSRAWrm
    0U,	// PSRAWrr
    0U,	// PSRLDQri
    0U,	// PSRLDri
    0U,	// PSRLDrm
    0U,	// PSRLDrr
    0U,	// PSRLQri
    0U,	// PSRLQrm
    0U,	// PSRLQrr
    0U,	// PSRLWri
    0U,	// PSRLWrm
    0U,	// PSRLWrr
    0U,	// PSUBBrm
    0U,	// PSUBBrr
    0U,	// PSUBDrm
    0U,	// PSUBDrr
    0U,	// PSUBQrm
    0U,	// PSUBQrr
    0U,	// PSUBSBrm
    0U,	// PSUBSBrr
    0U,	// PSUBSWrm
    0U,	// PSUBSWrr
    0U,	// PSUBUSBrm
    0U,	// PSUBUSBrr
    0U,	// PSUBUSWrm
    0U,	// PSUBUSWrr
    0U,	// PSUBWrm
    0U,	// PSUBWrr
    0U,	// PSWAPDrm
    0U,	// PSWAPDrr
    0U,	// PTESTrm
    0U,	// PTESTrr
    0U,	// PTWRITE64m
    0U,	// PTWRITE64r
    0U,	// PTWRITEm
    0U,	// PTWRITEr
    0U,	// PUNPCKHBWrm
    0U,	// PUNPCKHBWrr
    0U,	// PUNPCKHDQrm
    0U,	// PUNPCKHDQrr
    0U,	// PUNPCKHQDQrm
    0U,	// PUNPCKHQDQrr
    0U,	// PUNPCKHWDrm
    0U,	// PUNPCKHWDrr
    0U,	// PUNPCKLBWrm
    0U,	// PUNPCKLBWrr
    0U,	// PUNPCKLDQrm
    0U,	// PUNPCKLDQrr
    0U,	// PUNPCKLQDQrm
    0U,	// PUNPCKLQDQrr
    0U,	// PUNPCKLWDrm
    0U,	// PUNPCKLWDrr
    0U,	// PUSH16i8
    0U,	// PUSH16r
    0U,	// PUSH16rmm
    0U,	// PUSH16rmr
    0U,	// PUSH32i8
    0U,	// PUSH32r
    0U,	// PUSH32rmm
    0U,	// PUSH32rmr
    0U,	// PUSH64i32
    0U,	// PUSH64i8
    0U,	// PUSH64r
    0U,	// PUSH64rmm
    0U,	// PUSH64rmr
    0U,	// PUSHA16
    0U,	// PUSHA32
    0U,	// PUSHCS16
    0U,	// PUSHCS32
    0U,	// PUSHDS16
    0U,	// PUSHDS32
    0U,	// PUSHES16
    0U,	// PUSHES32
    0U,	// PUSHF16
    0U,	// PUSHF32
    0U,	// PUSHF64
    0U,	// PUSHFS16
    0U,	// PUSHFS32
    0U,	// PUSHFS64
    0U,	// PUSHGS16
    0U,	// PUSHGS32
    0U,	// PUSHGS64
    0U,	// PUSHSS16
    0U,	// PUSHSS32
    0U,	// PUSHi16
    0U,	// PUSHi32
    0U,	// PXORrm
    0U,	// PXORrr
    0U,	// RCL16m1
    0U,	// RCL16mCL
    1U,	// RCL16mi
    0U,	// RCL16r1
    0U,	// RCL16rCL
    0U,	// RCL16ri
    0U,	// RCL32m1
    0U,	// RCL32mCL
    1U,	// RCL32mi
    0U,	// RCL32r1
    0U,	// RCL32rCL
    0U,	// RCL32ri
    0U,	// RCL64m1
    0U,	// RCL64mCL
    1U,	// RCL64mi
    0U,	// RCL64r1
    0U,	// RCL64rCL
    0U,	// RCL64ri
    0U,	// RCL8m1
    0U,	// RCL8mCL
    1U,	// RCL8mi
    0U,	// RCL8r1
    0U,	// RCL8rCL
    0U,	// RCL8ri
    0U,	// RCPPSm
    0U,	// RCPPSr
    0U,	// RCPSSm
    0U,	// RCPSSm_Int
    0U,	// RCPSSr
    0U,	// RCPSSr_Int
    0U,	// RCR16m1
    0U,	// RCR16mCL
    1U,	// RCR16mi
    0U,	// RCR16r1
    0U,	// RCR16rCL
    0U,	// RCR16ri
    0U,	// RCR32m1
    0U,	// RCR32mCL
    1U,	// RCR32mi
    0U,	// RCR32r1
    0U,	// RCR32rCL
    0U,	// RCR32ri
    0U,	// RCR64m1
    0U,	// RCR64mCL
    1U,	// RCR64mi
    0U,	// RCR64r1
    0U,	// RCR64rCL
    0U,	// RCR64ri
    0U,	// RCR8m1
    0U,	// RCR8mCL
    1U,	// RCR8mi
    0U,	// RCR8r1
    0U,	// RCR8rCL
    0U,	// RCR8ri
    0U,	// RDFSBASE
    0U,	// RDFSBASE64
    0U,	// RDGSBASE
    0U,	// RDGSBASE64
    0U,	// RDMSR
    0U,	// RDPID32
    0U,	// RDPID64
    0U,	// RDPKRUr
    0U,	// RDPMC
    0U,	// RDRAND16r
    0U,	// RDRAND32r
    0U,	// RDRAND64r
    0U,	// RDSEED16r
    0U,	// RDSEED32r
    0U,	// RDSEED64r
    0U,	// RDSSPD
    0U,	// RDSSPQ
    0U,	// RDTSC
    0U,	// RDTSCP
    0U,	// REPNE_PREFIX
    0U,	// REP_PREFIX
    0U,	// RETIL
    0U,	// RETIQ
    0U,	// RETIW
    0U,	// RETL
    0U,	// RETQ
    0U,	// RETW
    0U,	// REX64_PREFIX
    0U,	// ROL16m1
    0U,	// ROL16mCL
    1U,	// ROL16mi
    0U,	// ROL16r1
    0U,	// ROL16rCL
    0U,	// ROL16ri
    0U,	// ROL32m1
    0U,	// ROL32mCL
    1U,	// ROL32mi
    0U,	// ROL32r1
    0U,	// ROL32rCL
    0U,	// ROL32ri
    0U,	// ROL64m1
    0U,	// ROL64mCL
    1U,	// ROL64mi
    0U,	// ROL64r1
    0U,	// ROL64rCL
    0U,	// ROL64ri
    0U,	// ROL8m1
    0U,	// ROL8mCL
    1U,	// ROL8mi
    0U,	// ROL8r1
    0U,	// ROL8rCL
    0U,	// ROL8ri
    0U,	// ROR16m1
    0U,	// ROR16mCL
    1U,	// ROR16mi
    0U,	// ROR16r1
    0U,	// ROR16rCL
    0U,	// ROR16ri
    0U,	// ROR32m1
    0U,	// ROR32mCL
    1U,	// ROR32mi
    0U,	// ROR32r1
    0U,	// ROR32rCL
    0U,	// ROR32ri
    0U,	// ROR64m1
    0U,	// ROR64mCL
    1U,	// ROR64mi
    0U,	// ROR64r1
    0U,	// ROR64rCL
    0U,	// ROR64ri
    0U,	// ROR8m1
    0U,	// ROR8mCL
    1U,	// ROR8mi
    0U,	// ROR8r1
    0U,	// ROR8rCL
    0U,	// ROR8ri
    4U,	// RORX32mi
    72U,	// RORX32ri
    4U,	// RORX64mi
    72U,	// RORX64ri
    0U,	// ROUNDPDm
    72U,	// ROUNDPDr
    0U,	// ROUNDPSm
    72U,	// ROUNDPSr
    4U,	// ROUNDSDm
    4U,	// ROUNDSDm_Int
    72U,	// ROUNDSDr
    4U,	// ROUNDSDr_Int
    4U,	// ROUNDSSm
    4U,	// ROUNDSSm_Int
    72U,	// ROUNDSSr
    4U,	// ROUNDSSr_Int
    0U,	// RSM
    0U,	// RSQRTPSm
    0U,	// RSQRTPSr
    0U,	// RSQRTSSm
    0U,	// RSQRTSSm_Int
    0U,	// RSQRTSSr
    0U,	// RSQRTSSr_Int
    0U,	// RSTORSSP
    0U,	// SAHF
    0U,	// SAL16m1
    0U,	// SAL16mCL
    0U,	// SAL16mi
    0U,	// SAL16r1
    0U,	// SAL16rCL
    0U,	// SAL16ri
    0U,	// SAL32m1
    0U,	// SAL32mCL
    0U,	// SAL32mi
    0U,	// SAL32r1
    0U,	// SAL32rCL
    0U,	// SAL32ri
    0U,	// SAL64m1
    0U,	// SAL64mCL
    0U,	// SAL64mi
    0U,	// SAL64r1
    0U,	// SAL64rCL
    0U,	// SAL64ri
    0U,	// SAL8m1
    0U,	// SAL8mCL
    0U,	// SAL8mi
    0U,	// SAL8r1
    0U,	// SAL8rCL
    0U,	// SAL8ri
    0U,	// SALC
    0U,	// SAR16m1
    0U,	// SAR16mCL
    1U,	// SAR16mi
    0U,	// SAR16r1
    0U,	// SAR16rCL
    0U,	// SAR16ri
    0U,	// SAR32m1
    0U,	// SAR32mCL
    1U,	// SAR32mi
    0U,	// SAR32r1
    0U,	// SAR32rCL
    0U,	// SAR32ri
    0U,	// SAR64m1
    0U,	// SAR64mCL
    1U,	// SAR64mi
    0U,	// SAR64r1
    0U,	// SAR64rCL
    0U,	// SAR64ri
    0U,	// SAR8m1
    0U,	// SAR8mCL
    1U,	// SAR8mi
    0U,	// SAR8r1
    0U,	// SAR8rCL
    0U,	// SAR8ri
    4U,	// SARX32rm
    4U,	// SARX32rr
    4U,	// SARX64rm
    4U,	// SARX64rr
    0U,	// SAVEPREVSSP
    0U,	// SBB16i16
    0U,	// SBB16mi
    0U,	// SBB16mi8
    0U,	// SBB16mr
    0U,	// SBB16ri
    0U,	// SBB16ri8
    0U,	// SBB16rm
    0U,	// SBB16rr
    0U,	// SBB16rr_REV
    0U,	// SBB32i32
    0U,	// SBB32mi
    0U,	// SBB32mi8
    0U,	// SBB32mr
    0U,	// SBB32ri
    0U,	// SBB32ri8
    0U,	// SBB32rm
    0U,	// SBB32rr
    0U,	// SBB32rr_REV
    0U,	// SBB64i32
    0U,	// SBB64mi32
    0U,	// SBB64mi8
    0U,	// SBB64mr
    0U,	// SBB64ri32
    0U,	// SBB64ri8
    0U,	// SBB64rm
    0U,	// SBB64rr
    0U,	// SBB64rr_REV
    0U,	// SBB8i8
    0U,	// SBB8mi
    0U,	// SBB8mi8
    0U,	// SBB8mr
    0U,	// SBB8ri
    0U,	// SBB8ri8
    0U,	// SBB8rm
    0U,	// SBB8rr
    0U,	// SBB8rr_REV
    0U,	// SCASB
    0U,	// SCASL
    0U,	// SCASQ
    0U,	// SCASW
    0U,	// SETAEm
    0U,	// SETAEr
    0U,	// SETAm
    0U,	// SETAr
    0U,	// SETBEm
    0U,	// SETBEr
    0U,	// SETBm
    0U,	// SETBr
    0U,	// SETEm
    0U,	// SETEr
    0U,	// SETGEm
    0U,	// SETGEr
    0U,	// SETGm
    0U,	// SETGr
    0U,	// SETLEm
    0U,	// SETLEr
    0U,	// SETLm
    0U,	// SETLr
    0U,	// SETNEm
    0U,	// SETNEr
    0U,	// SETNOm
    0U,	// SETNOr
    0U,	// SETNPm
    0U,	// SETNPr
    0U,	// SETNSm
    0U,	// SETNSr
    0U,	// SETOm
    0U,	// SETOr
    0U,	// SETPm
    0U,	// SETPr
    0U,	// SETSSBSY
    0U,	// SETSm
    0U,	// SETSr
    0U,	// SFENCE
    0U,	// SGDT16m
    0U,	// SGDT32m
    0U,	// SGDT64m
    0U,	// SHA1MSG1rm
    0U,	// SHA1MSG1rr
    0U,	// SHA1MSG2rm
    0U,	// SHA1MSG2rr
    0U,	// SHA1NEXTErm
    0U,	// SHA1NEXTErr
    0U,	// SHA1RNDS4rmi
    4U,	// SHA1RNDS4rri
    0U,	// SHA256MSG1rm
    0U,	// SHA256MSG1rr
    0U,	// SHA256MSG2rm
    0U,	// SHA256MSG2rr
    0U,	// SHA256RNDS2rm
    0U,	// SHA256RNDS2rr
    0U,	// SHL16m1
    0U,	// SHL16mCL
    1U,	// SHL16mi
    0U,	// SHL16r1
    0U,	// SHL16rCL
    0U,	// SHL16ri
    0U,	// SHL32m1
    0U,	// SHL32mCL
    1U,	// SHL32mi
    0U,	// SHL32r1
    0U,	// SHL32rCL
    0U,	// SHL32ri
    0U,	// SHL64m1
    0U,	// SHL64mCL
    1U,	// SHL64mi
    0U,	// SHL64r1
    0U,	// SHL64rCL
    0U,	// SHL64ri
    0U,	// SHL8m1
    0U,	// SHL8mCL
    1U,	// SHL8mi
    0U,	// SHL8r1
    0U,	// SHL8rCL
    0U,	// SHL8ri
    0U,	// SHLD16mrCL
    1U,	// SHLD16mri8
    0U,	// SHLD16rrCL
    4U,	// SHLD16rri8
    0U,	// SHLD32mrCL
    1U,	// SHLD32mri8
    0U,	// SHLD32rrCL
    4U,	// SHLD32rri8
    0U,	// SHLD64mrCL
    1U,	// SHLD64mri8
    0U,	// SHLD64rrCL
    4U,	// SHLD64rri8
    4U,	// SHLX32rm
    4U,	// SHLX32rr
    4U,	// SHLX64rm
    4U,	// SHLX64rr
    0U,	// SHR16m1
    0U,	// SHR16mCL
    1U,	// SHR16mi
    0U,	// SHR16r1
    0U,	// SHR16rCL
    0U,	// SHR16ri
    0U,	// SHR32m1
    0U,	// SHR32mCL
    1U,	// SHR32mi
    0U,	// SHR32r1
    0U,	// SHR32rCL
    0U,	// SHR32ri
    0U,	// SHR64m1
    0U,	// SHR64mCL
    1U,	// SHR64mi
    0U,	// SHR64r1
    0U,	// SHR64rCL
    0U,	// SHR64ri
    0U,	// SHR8m1
    0U,	// SHR8mCL
    1U,	// SHR8mi
    0U,	// SHR8r1
    0U,	// SHR8rCL
    0U,	// SHR8ri
    0U,	// SHRD16mrCL
    1U,	// SHRD16mri8
    0U,	// SHRD16rrCL
    4U,	// SHRD16rri8
    0U,	// SHRD32mrCL
    1U,	// SHRD32mri8
    0U,	// SHRD32rrCL
    4U,	// SHRD32rri8
    0U,	// SHRD64mrCL
    1U,	// SHRD64mri8
    0U,	// SHRD64rrCL
    4U,	// SHRD64rri8
    4U,	// SHRX32rm
    4U,	// SHRX32rr
    4U,	// SHRX64rm
    4U,	// SHRX64rr
    0U,	// SHUFPDrmi
    4U,	// SHUFPDrri
    0U,	// SHUFPSrmi
    4U,	// SHUFPSrri
    0U,	// SIDT16m
    0U,	// SIDT32m
    0U,	// SIDT64m
    0U,	// SIN_F
    0U,	// SIN_Fp32
    0U,	// SIN_Fp64
    0U,	// SIN_Fp80
    0U,	// SKINIT
    0U,	// SLDT16m
    0U,	// SLDT16r
    0U,	// SLDT32r
    0U,	// SLDT64r
    0U,	// SLWPCB
    0U,	// SLWPCB64
    0U,	// SMSW16m
    0U,	// SMSW16r
    0U,	// SMSW32r
    0U,	// SMSW64r
    0U,	// SQRTPDm
    0U,	// SQRTPDr
    0U,	// SQRTPSm
    0U,	// SQRTPSr
    0U,	// SQRTSDm
    0U,	// SQRTSDm_Int
    0U,	// SQRTSDr
    0U,	// SQRTSDr_Int
    0U,	// SQRTSSm
    0U,	// SQRTSSm_Int
    0U,	// SQRTSSr
    0U,	// SQRTSSr_Int
    0U,	// SQRT_F
    0U,	// SQRT_Fp32
    0U,	// SQRT_Fp64
    0U,	// SQRT_Fp80
    0U,	// STAC
    0U,	// STC
    0U,	// STD
    0U,	// STGI
    0U,	// STI
    0U,	// STMXCSR
    0U,	// STOSB
    0U,	// STOSL
    0U,	// STOSQ
    0U,	// STOSW
    0U,	// STR16r
    0U,	// STR32r
    0U,	// STR64r
    0U,	// STRm
    0U,	// ST_F32m
    0U,	// ST_F64m
    0U,	// ST_FP32m
    0U,	// ST_FP64m
    0U,	// ST_FP80m
    0U,	// ST_FPrr
    0U,	// ST_Fp32m
    0U,	// ST_Fp64m
    0U,	// ST_Fp64m32
    0U,	// ST_Fp80m32
    0U,	// ST_Fp80m64
    0U,	// ST_FpP32m
    0U,	// ST_FpP64m
    0U,	// ST_FpP64m32
    0U,	// ST_FpP80m
    0U,	// ST_FpP80m32
    0U,	// ST_FpP80m64
    0U,	// ST_Frr
    0U,	// SUB16i16
    0U,	// SUB16mi
    0U,	// SUB16mi8
    0U,	// SUB16mr
    0U,	// SUB16ri
    0U,	// SUB16ri8
    0U,	// SUB16rm
    0U,	// SUB16rr
    0U,	// SUB16rr_REV
    0U,	// SUB32i32
    0U,	// SUB32mi
    0U,	// SUB32mi8
    0U,	// SUB32mr
    0U,	// SUB32ri
    0U,	// SUB32ri8
    0U,	// SUB32rm
    0U,	// SUB32rr
    0U,	// SUB32rr_REV
    0U,	// SUB64i32
    0U,	// SUB64mi32
    0U,	// SUB64mi8
    0U,	// SUB64mr
    0U,	// SUB64ri32
    0U,	// SUB64ri8
    0U,	// SUB64rm
    0U,	// SUB64rr
    0U,	// SUB64rr_REV
    0U,	// SUB8i8
    0U,	// SUB8mi
    0U,	// SUB8mi8
    0U,	// SUB8mr
    0U,	// SUB8ri
    0U,	// SUB8ri8
    0U,	// SUB8rm
    0U,	// SUB8rr
    0U,	// SUB8rr_REV
    0U,	// SUBPDrm
    0U,	// SUBPDrr
    0U,	// SUBPSrm
    0U,	// SUBPSrr
    0U,	// SUBR_F32m
    0U,	// SUBR_F64m
    0U,	// SUBR_FI16m
    0U,	// SUBR_FI32m
    0U,	// SUBR_FPrST0
    0U,	// SUBR_FST0r
    0U,	// SUBR_Fp32m
    0U,	// SUBR_Fp64m
    0U,	// SUBR_Fp64m32
    0U,	// SUBR_Fp80m32
    0U,	// SUBR_Fp80m64
    0U,	// SUBR_FpI16m32
    0U,	// SUBR_FpI16m64
    0U,	// SUBR_FpI16m80
    0U,	// SUBR_FpI32m32
    0U,	// SUBR_FpI32m64
    0U,	// SUBR_FpI32m80
    0U,	// SUBR_FrST0
    0U,	// SUBSDrm
    0U,	// SUBSDrm_Int
    0U,	// SUBSDrr
    0U,	// SUBSDrr_Int
    0U,	// SUBSSrm
    0U,	// SUBSSrm_Int
    0U,	// SUBSSrr
    0U,	// SUBSSrr_Int
    0U,	// SUB_F32m
    0U,	// SUB_F64m
    0U,	// SUB_FI16m
    0U,	// SUB_FI32m
    0U,	// SUB_FPrST0
    0U,	// SUB_FST0r
    0U,	// SUB_Fp32
    0U,	// SUB_Fp32m
    0U,	// SUB_Fp64
    0U,	// SUB_Fp64m
    0U,	// SUB_Fp64m32
    0U,	// SUB_Fp80
    0U,	// SUB_Fp80m32
    0U,	// SUB_Fp80m64
    0U,	// SUB_FpI16m32
    0U,	// SUB_FpI16m64
    0U,	// SUB_FpI16m80
    0U,	// SUB_FpI32m32
    0U,	// SUB_FpI32m64
    0U,	// SUB_FpI32m80
    0U,	// SUB_FrST0
    0U,	// SWAPGS
    0U,	// SYSCALL
    0U,	// SYSENTER
    0U,	// SYSEXIT
    0U,	// SYSEXIT64
    0U,	// SYSRET
    0U,	// SYSRET64
    0U,	// T1MSKC32rm
    0U,	// T1MSKC32rr
    0U,	// T1MSKC64rm
    0U,	// T1MSKC64rr
    0U,	// TEST16i16
    0U,	// TEST16mi
    0U,	// TEST16mi_alt
    0U,	// TEST16mr
    0U,	// TEST16ri
    0U,	// TEST16ri_alt
    0U,	// TEST16rr
    0U,	// TEST32i32
    0U,	// TEST32mi
    0U,	// TEST32mi_alt
    0U,	// TEST32mr
    0U,	// TEST32ri
    0U,	// TEST32ri_alt
    0U,	// TEST32rr
    0U,	// TEST64i32
    0U,	// TEST64mi32
    0U,	// TEST64mi32_alt
    0U,	// TEST64mr
    0U,	// TEST64ri32
    0U,	// TEST64ri32_alt
    0U,	// TEST64rr
    0U,	// TEST8i8
    0U,	// TEST8mi
    0U,	// TEST8mi_alt
    0U,	// TEST8mr
    0U,	// TEST8ri
    0U,	// TEST8ri_alt
    0U,	// TEST8rr
    0U,	// TPAUSE
    0U,	// TST_F
    0U,	// TST_Fp32
    0U,	// TST_Fp64
    0U,	// TST_Fp80
    0U,	// TZCNT16rm
    0U,	// TZCNT16rr
    0U,	// TZCNT32rm
    0U,	// TZCNT32rr
    0U,	// TZCNT64rm
    0U,	// TZCNT64rr
    0U,	// TZMSK32rm
    0U,	// TZMSK32rr
    0U,	// TZMSK64rm
    0U,	// TZMSK64rr
    0U,	// UCOMISDrm
    0U,	// UCOMISDrm_Int
    0U,	// UCOMISDrr
    0U,	// UCOMISDrr_Int
    0U,	// UCOMISSrm
    0U,	// UCOMISSrm_Int
    0U,	// UCOMISSrr
    0U,	// UCOMISSrr_Int
    0U,	// UCOM_FIPr
    0U,	// UCOM_FIr
    0U,	// UCOM_FPPr
    0U,	// UCOM_FPr
    0U,	// UCOM_FpIr32
    0U,	// UCOM_FpIr64
    0U,	// UCOM_FpIr80
    0U,	// UCOM_Fpr32
    0U,	// UCOM_Fpr64
    0U,	// UCOM_Fpr80
    0U,	// UCOM_Fr
    0U,	// UD0
    0U,	// UD1
    0U,	// UD2
    0U,	// UMONITOR16
    0U,	// UMONITOR32
    0U,	// UMONITOR64
    0U,	// UMWAIT
    0U,	// UNPCKHPDrm
    0U,	// UNPCKHPDrr
    0U,	// UNPCKHPSrm
    0U,	// UNPCKHPSrr
    0U,	// UNPCKLPDrm
    0U,	// UNPCKLPDrr
    0U,	// UNPCKLPSrm
    0U,	// UNPCKLPSrr
    4U,	// V4FMADDPSrm
    0U,	// V4FMADDPSrmk
    0U,	// V4FMADDPSrmkz
    4U,	// V4FMADDSSrm
    0U,	// V4FMADDSSrmk
    0U,	// V4FMADDSSrmkz
    4U,	// V4FNMADDPSrm
    0U,	// V4FNMADDPSrmk
    0U,	// V4FNMADDPSrmkz
    4U,	// V4FNMADDSSrm
    0U,	// V4FNMADDSSrmk
    0U,	// V4FNMADDSSrmkz
    4U,	// VADDPDYrm
    4U,	// VADDPDYrr
    4U,	// VADDPDZ128rm
    72U,	// VADDPDZ128rmb
    133U,	// VADDPDZ128rmbk
    9348U,	// VADDPDZ128rmbkz
    0U,	// VADDPDZ128rmk
    9348U,	// VADDPDZ128rmkz
    4U,	// VADDPDZ128rr
    0U,	// VADDPDZ128rrk
    9348U,	// VADDPDZ128rrkz
    4U,	// VADDPDZ256rm
    72U,	// VADDPDZ256rmb
    133U,	// VADDPDZ256rmbk
    9348U,	// VADDPDZ256rmbkz
    0U,	// VADDPDZ256rmk
    9348U,	// VADDPDZ256rmkz
    4U,	// VADDPDZ256rr
    0U,	// VADDPDZ256rrk
    9348U,	// VADDPDZ256rrkz
    4U,	// VADDPDZrm
    72U,	// VADDPDZrmb
    133U,	// VADDPDZrmbk
    9348U,	// VADDPDZrmbkz
    0U,	// VADDPDZrmk
    9348U,	// VADDPDZrmkz
    4U,	// VADDPDZrr
    4U,	// VADDPDZrrb
    0U,	// VADDPDZrrbk
    9348U,	// VADDPDZrrbkz
    0U,	// VADDPDZrrk
    9348U,	// VADDPDZrrkz
    4U,	// VADDPDrm
    4U,	// VADDPDrr
    4U,	// VADDPSYrm
    4U,	// VADDPSYrr
    4U,	// VADDPSZ128rm
    72U,	// VADDPSZ128rmb
    133U,	// VADDPSZ128rmbk
    9348U,	// VADDPSZ128rmbkz
    0U,	// VADDPSZ128rmk
    9348U,	// VADDPSZ128rmkz
    4U,	// VADDPSZ128rr
    0U,	// VADDPSZ128rrk
    9348U,	// VADDPSZ128rrkz
    4U,	// VADDPSZ256rm
    72U,	// VADDPSZ256rmb
    133U,	// VADDPSZ256rmbk
    9348U,	// VADDPSZ256rmbkz
    0U,	// VADDPSZ256rmk
    9348U,	// VADDPSZ256rmkz
    4U,	// VADDPSZ256rr
    0U,	// VADDPSZ256rrk
    9348U,	// VADDPSZ256rrkz
    4U,	// VADDPSZrm
    72U,	// VADDPSZrmb
    133U,	// VADDPSZrmbk
    9348U,	// VADDPSZrmbkz
    0U,	// VADDPSZrmk
    9348U,	// VADDPSZrmkz
    4U,	// VADDPSZrr
    4U,	// VADDPSZrrb
    0U,	// VADDPSZrrbk
    9348U,	// VADDPSZrrbkz
    0U,	// VADDPSZrrk
    9348U,	// VADDPSZrrkz
    4U,	// VADDPSrm
    4U,	// VADDPSrr
    72U,	// VADDSDZrm
    72U,	// VADDSDZrm_Int
    133U,	// VADDSDZrm_Intk
    9348U,	// VADDSDZrm_Intkz
    4U,	// VADDSDZrr
    4U,	// VADDSDZrr_Int
    0U,	// VADDSDZrr_Intk
    9348U,	// VADDSDZrr_Intkz
    4U,	// VADDSDZrrb_Int
    0U,	// VADDSDZrrb_Intk
    9348U,	// VADDSDZrrb_Intkz
    72U,	// VADDSDrm
    72U,	// VADDSDrm_Int
    4U,	// VADDSDrr
    4U,	// VADDSDrr_Int
    72U,	// VADDSSZrm
    72U,	// VADDSSZrm_Int
    133U,	// VADDSSZrm_Intk
    9348U,	// VADDSSZrm_Intkz
    4U,	// VADDSSZrr
    4U,	// VADDSSZrr_Int
    0U,	// VADDSSZrr_Intk
    9348U,	// VADDSSZrr_Intkz
    4U,	// VADDSSZrrb_Int
    0U,	// VADDSSZrrb_Intk
    9348U,	// VADDSSZrrb_Intkz
    72U,	// VADDSSrm
    72U,	// VADDSSrm_Int
    4U,	// VADDSSrr
    4U,	// VADDSSrr_Int
    4U,	// VADDSUBPDYrm
    4U,	// VADDSUBPDYrr
    4U,	// VADDSUBPDrm
    4U,	// VADDSUBPDrr
    4U,	// VADDSUBPSYrm
    4U,	// VADDSUBPSYrr
    4U,	// VADDSUBPSrm
    4U,	// VADDSUBPSrr
    4U,	// VAESDECLASTYrm
    4U,	// VAESDECLASTYrr
    4U,	// VAESDECLASTZ128rm
    4U,	// VAESDECLASTZ128rr
    4U,	// VAESDECLASTZ256rm
    4U,	// VAESDECLASTZ256rr
    4U,	// VAESDECLASTZrm
    4U,	// VAESDECLASTZrr
    4U,	// VAESDECLASTrm
    4U,	// VAESDECLASTrr
    4U,	// VAESDECYrm
    4U,	// VAESDECYrr
    4U,	// VAESDECZ128rm
    4U,	// VAESDECZ128rr
    4U,	// VAESDECZ256rm
    4U,	// VAESDECZ256rr
    4U,	// VAESDECZrm
    4U,	// VAESDECZrr
    4U,	// VAESDECrm
    4U,	// VAESDECrr
    4U,	// VAESENCLASTYrm
    4U,	// VAESENCLASTYrr
    4U,	// VAESENCLASTZ128rm
    4U,	// VAESENCLASTZ128rr
    4U,	// VAESENCLASTZ256rm
    4U,	// VAESENCLASTZ256rr
    4U,	// VAESENCLASTZrm
    4U,	// VAESENCLASTZrr
    4U,	// VAESENCLASTrm
    4U,	// VAESENCLASTrr
    4U,	// VAESENCYrm
    4U,	// VAESENCYrr
    4U,	// VAESENCZ128rm
    4U,	// VAESENCZ128rr
    4U,	// VAESENCZ256rm
    4U,	// VAESENCZ256rr
    4U,	// VAESENCZrm
    4U,	// VAESENCZrr
    4U,	// VAESENCrm
    4U,	// VAESENCrr
    0U,	// VAESIMCrm
    0U,	// VAESIMCrr
    4U,	// VAESKEYGENASSIST128rm
    72U,	// VAESKEYGENASSIST128rr
    18637U,	// VALIGNDZ128rmbi
    26833U,	// VALIGNDZ128rmbik
    26837U,	// VALIGNDZ128rmbikz
    72U,	// VALIGNDZ128rmi
    1U,	// VALIGNDZ128rmik
    9348U,	// VALIGNDZ128rmikz
    18636U,	// VALIGNDZ128rri
    25U,	// VALIGNDZ128rrik
    26837U,	// VALIGNDZ128rrikz
    18637U,	// VALIGNDZ256rmbi
    26833U,	// VALIGNDZ256rmbik
    26837U,	// VALIGNDZ256rmbikz
    72U,	// VALIGNDZ256rmi
    1U,	// VALIGNDZ256rmik
    9348U,	// VALIGNDZ256rmikz
    18636U,	// VALIGNDZ256rri
    25U,	// VALIGNDZ256rrik
    26837U,	// VALIGNDZ256rrikz
    18637U,	// VALIGNDZrmbi
    26833U,	// VALIGNDZrmbik
    26837U,	// VALIGNDZrmbikz
    72U,	// VALIGNDZrmi
    1U,	// VALIGNDZrmik
    9348U,	// VALIGNDZrmikz
    18636U,	// VALIGNDZrri
    25U,	// VALIGNDZrrik
    26837U,	// VALIGNDZrrikz
    18637U,	// VALIGNQZ128rmbi
    26833U,	// VALIGNQZ128rmbik
    26837U,	// VALIGNQZ128rmbikz
    72U,	// VALIGNQZ128rmi
    1U,	// VALIGNQZ128rmik
    9348U,	// VALIGNQZ128rmikz
    18636U,	// VALIGNQZ128rri
    25U,	// VALIGNQZ128rrik
    26837U,	// VALIGNQZ128rrikz
    18637U,	// VALIGNQZ256rmbi
    26833U,	// VALIGNQZ256rmbik
    26837U,	// VALIGNQZ256rmbikz
    72U,	// VALIGNQZ256rmi
    1U,	// VALIGNQZ256rmik
    9348U,	// VALIGNQZ256rmikz
    18636U,	// VALIGNQZ256rri
    25U,	// VALIGNQZ256rrik
    26837U,	// VALIGNQZ256rrikz
    18637U,	// VALIGNQZrmbi
    26833U,	// VALIGNQZrmbik
    26837U,	// VALIGNQZrmbikz
    72U,	// VALIGNQZrmi
    1U,	// VALIGNQZrmik
    9348U,	// VALIGNQZrmikz
    18636U,	// VALIGNQZrri
    25U,	// VALIGNQZrrik
    26837U,	// VALIGNQZrrikz
    4U,	// VANDNPDYrm
    4U,	// VANDNPDYrr
    4U,	// VANDNPDZ128rm
    72U,	// VANDNPDZ128rmb
    133U,	// VANDNPDZ128rmbk
    9348U,	// VANDNPDZ128rmbkz
    0U,	// VANDNPDZ128rmk
    9348U,	// VANDNPDZ128rmkz
    4U,	// VANDNPDZ128rr
    0U,	// VANDNPDZ128rrk
    9348U,	// VANDNPDZ128rrkz
    4U,	// VANDNPDZ256rm
    72U,	// VANDNPDZ256rmb
    133U,	// VANDNPDZ256rmbk
    9348U,	// VANDNPDZ256rmbkz
    0U,	// VANDNPDZ256rmk
    9348U,	// VANDNPDZ256rmkz
    4U,	// VANDNPDZ256rr
    0U,	// VANDNPDZ256rrk
    9348U,	// VANDNPDZ256rrkz
    4U,	// VANDNPDZrm
    72U,	// VANDNPDZrmb
    133U,	// VANDNPDZrmbk
    9348U,	// VANDNPDZrmbkz
    0U,	// VANDNPDZrmk
    9348U,	// VANDNPDZrmkz
    4U,	// VANDNPDZrr
    0U,	// VANDNPDZrrk
    9348U,	// VANDNPDZrrkz
    4U,	// VANDNPDrm
    4U,	// VANDNPDrr
    4U,	// VANDNPSYrm
    4U,	// VANDNPSYrr
    4U,	// VANDNPSZ128rm
    72U,	// VANDNPSZ128rmb
    133U,	// VANDNPSZ128rmbk
    9348U,	// VANDNPSZ128rmbkz
    0U,	// VANDNPSZ128rmk
    9348U,	// VANDNPSZ128rmkz
    4U,	// VANDNPSZ128rr
    0U,	// VANDNPSZ128rrk
    9348U,	// VANDNPSZ128rrkz
    4U,	// VANDNPSZ256rm
    72U,	// VANDNPSZ256rmb
    133U,	// VANDNPSZ256rmbk
    9348U,	// VANDNPSZ256rmbkz
    0U,	// VANDNPSZ256rmk
    9348U,	// VANDNPSZ256rmkz
    4U,	// VANDNPSZ256rr
    0U,	// VANDNPSZ256rrk
    9348U,	// VANDNPSZ256rrkz
    4U,	// VANDNPSZrm
    72U,	// VANDNPSZrmb
    133U,	// VANDNPSZrmbk
    9348U,	// VANDNPSZrmbkz
    0U,	// VANDNPSZrmk
    9348U,	// VANDNPSZrmkz
    4U,	// VANDNPSZrr
    0U,	// VANDNPSZrrk
    9348U,	// VANDNPSZrrkz
    4U,	// VANDNPSrm
    4U,	// VANDNPSrr
    4U,	// VANDPDYrm
    4U,	// VANDPDYrr
    4U,	// VANDPDZ128rm
    72U,	// VANDPDZ128rmb
    133U,	// VANDPDZ128rmbk
    9348U,	// VANDPDZ128rmbkz
    0U,	// VANDPDZ128rmk
    9348U,	// VANDPDZ128rmkz
    4U,	// VANDPDZ128rr
    0U,	// VANDPDZ128rrk
    9348U,	// VANDPDZ128rrkz
    4U,	// VANDPDZ256rm
    72U,	// VANDPDZ256rmb
    133U,	// VANDPDZ256rmbk
    9348U,	// VANDPDZ256rmbkz
    0U,	// VANDPDZ256rmk
    9348U,	// VANDPDZ256rmkz
    4U,	// VANDPDZ256rr
    0U,	// VANDPDZ256rrk
    9348U,	// VANDPDZ256rrkz
    4U,	// VANDPDZrm
    72U,	// VANDPDZrmb
    133U,	// VANDPDZrmbk
    9348U,	// VANDPDZrmbkz
    0U,	// VANDPDZrmk
    9348U,	// VANDPDZrmkz
    4U,	// VANDPDZrr
    0U,	// VANDPDZrrk
    9348U,	// VANDPDZrrkz
    4U,	// VANDPDrm
    4U,	// VANDPDrr
    4U,	// VANDPSYrm
    4U,	// VANDPSYrr
    4U,	// VANDPSZ128rm
    72U,	// VANDPSZ128rmb
    133U,	// VANDPSZ128rmbk
    9348U,	// VANDPSZ128rmbkz
    0U,	// VANDPSZ128rmk
    9348U,	// VANDPSZ128rmkz
    4U,	// VANDPSZ128rr
    0U,	// VANDPSZ128rrk
    9348U,	// VANDPSZ128rrkz
    4U,	// VANDPSZ256rm
    72U,	// VANDPSZ256rmb
    133U,	// VANDPSZ256rmbk
    9348U,	// VANDPSZ256rmbkz
    0U,	// VANDPSZ256rmk
    9348U,	// VANDPSZ256rmkz
    4U,	// VANDPSZ256rr
    0U,	// VANDPSZ256rrk
    9348U,	// VANDPSZ256rrkz
    4U,	// VANDPSZrm
    72U,	// VANDPSZrmb
    133U,	// VANDPSZrmbk
    9348U,	// VANDPSZrmbkz
    0U,	// VANDPSZrmk
    9348U,	// VANDPSZrmkz
    4U,	// VANDPSZrr
    0U,	// VANDPSZrrk
    9348U,	// VANDPSZrrkz
    4U,	// VANDPSrm
    4U,	// VANDPSrr
    4U,	// VBLENDMPDZ128rm
    72U,	// VBLENDMPDZ128rmb
    1156U,	// VBLENDMPDZ128rmbk
    9348U,	// VBLENDMPDZ128rmbkz
    1156U,	// VBLENDMPDZ128rmk
    9348U,	// VBLENDMPDZ128rmkz
    4U,	// VBLENDMPDZ128rr
    1156U,	// VBLENDMPDZ128rrk
    9348U,	// VBLENDMPDZ128rrkz
    4U,	// VBLENDMPDZ256rm
    72U,	// VBLENDMPDZ256rmb
    1156U,	// VBLENDMPDZ256rmbk
    9348U,	// VBLENDMPDZ256rmbkz
    1156U,	// VBLENDMPDZ256rmk
    9348U,	// VBLENDMPDZ256rmkz
    4U,	// VBLENDMPDZ256rr
    1156U,	// VBLENDMPDZ256rrk
    9348U,	// VBLENDMPDZ256rrkz
    4U,	// VBLENDMPDZrm
    72U,	// VBLENDMPDZrmb
    1156U,	// VBLENDMPDZrmbk
    9348U,	// VBLENDMPDZrmbkz
    1156U,	// VBLENDMPDZrmk
    9348U,	// VBLENDMPDZrmkz
    4U,	// VBLENDMPDZrr
    1156U,	// VBLENDMPDZrrk
    9348U,	// VBLENDMPDZrrkz
    4U,	// VBLENDMPSZ128rm
    72U,	// VBLENDMPSZ128rmb
    1156U,	// VBLENDMPSZ128rmbk
    9348U,	// VBLENDMPSZ128rmbkz
    1156U,	// VBLENDMPSZ128rmk
    9348U,	// VBLENDMPSZ128rmkz
    4U,	// VBLENDMPSZ128rr
    1156U,	// VBLENDMPSZ128rrk
    9348U,	// VBLENDMPSZ128rrkz
    4U,	// VBLENDMPSZ256rm
    72U,	// VBLENDMPSZ256rmb
    1156U,	// VBLENDMPSZ256rmbk
    9348U,	// VBLENDMPSZ256rmbkz
    1156U,	// VBLENDMPSZ256rmk
    9348U,	// VBLENDMPSZ256rmkz
    4U,	// VBLENDMPSZ256rr
    1156U,	// VBLENDMPSZ256rrk
    9348U,	// VBLENDMPSZ256rrkz
    4U,	// VBLENDMPSZrm
    72U,	// VBLENDMPSZrmb
    1156U,	// VBLENDMPSZrmbk
    9348U,	// VBLENDMPSZrmbkz
    1156U,	// VBLENDMPSZrmk
    9348U,	// VBLENDMPSZrmkz
    4U,	// VBLENDMPSZrr
    1156U,	// VBLENDMPSZrrk
    9348U,	// VBLENDMPSZrrkz
    72U,	// VBLENDPDYrmi
    18636U,	// VBLENDPDYrri
    72U,	// VBLENDPDrmi
    18636U,	// VBLENDPDrri
    72U,	// VBLENDPSYrmi
    18636U,	// VBLENDPSYrri
    72U,	// VBLENDPSrmi
    18636U,	// VBLENDPSrri
    72U,	// VBLENDVPDYrm
    18636U,	// VBLENDVPDYrr
    72U,	// VBLENDVPDrm
    18636U,	// VBLENDVPDrr
    72U,	// VBLENDVPSYrm
    18636U,	// VBLENDVPSYrr
    72U,	// VBLENDVPSrm
    18636U,	// VBLENDVPSrr
    0U,	// VBROADCASTF128
    0U,	// VBROADCASTF32X2Z256m
    3356U,	// VBROADCASTF32X2Z256mk
    4444U,	// VBROADCASTF32X2Z256mkz
    0U,	// VBROADCASTF32X2Z256r
    405U,	// VBROADCASTF32X2Z256rk
    461U,	// VBROADCASTF32X2Z256rkz
    0U,	// VBROADCASTF32X2Zm
    3356U,	// VBROADCASTF32X2Zmk
    4444U,	// VBROADCASTF32X2Zmkz
    0U,	// VBROADCASTF32X2Zr
    405U,	// VBROADCASTF32X2Zrk
    461U,	// VBROADCASTF32X2Zrkz
    0U,	// VBROADCASTF32X4Z256rm
    405U,	// VBROADCASTF32X4Z256rmk
    461U,	// VBROADCASTF32X4Z256rmkz
    0U,	// VBROADCASTF32X4rm
    405U,	// VBROADCASTF32X4rmk
    461U,	// VBROADCASTF32X4rmkz
    0U,	// VBROADCASTF32X8rm
    405U,	// VBROADCASTF32X8rmk
    461U,	// VBROADCASTF32X8rmkz
    0U,	// VBROADCASTF64X2Z128rm
    405U,	// VBROADCASTF64X2Z128rmk
    461U,	// VBROADCASTF64X2Z128rmkz
    0U,	// VBROADCASTF64X2rm
    405U,	// VBROADCASTF64X2rmk
    461U,	// VBROADCASTF64X2rmkz
    0U,	// VBROADCASTF64X4rm
    405U,	// VBROADCASTF64X4rmk
    461U,	// VBROADCASTF64X4rmkz
    0U,	// VBROADCASTI128
    0U,	// VBROADCASTI32X2Z128m
    3356U,	// VBROADCASTI32X2Z128mk
    4444U,	// VBROADCASTI32X2Z128mkz
    0U,	// VBROADCASTI32X2Z128r
    405U,	// VBROADCASTI32X2Z128rk
    461U,	// VBROADCASTI32X2Z128rkz
    0U,	// VBROADCASTI32X2Z256m
    3356U,	// VBROADCASTI32X2Z256mk
    4444U,	// VBROADCASTI32X2Z256mkz
    0U,	// VBROADCASTI32X2Z256r
    405U,	// VBROADCASTI32X2Z256rk
    461U,	// VBROADCASTI32X2Z256rkz
    0U,	// VBROADCASTI32X2Zm
    3356U,	// VBROADCASTI32X2Zmk
    4444U,	// VBROADCASTI32X2Zmkz
    0U,	// VBROADCASTI32X2Zr
    405U,	// VBROADCASTI32X2Zrk
    461U,	// VBROADCASTI32X2Zrkz
    0U,	// VBROADCASTI32X4Z256rm
    405U,	// VBROADCASTI32X4Z256rmk
    461U,	// VBROADCASTI32X4Z256rmkz
    0U,	// VBROADCASTI32X4rm
    405U,	// VBROADCASTI32X4rmk
    461U,	// VBROADCASTI32X4rmkz
    0U,	// VBROADCASTI32X8rm
    405U,	// VBROADCASTI32X8rmk
    461U,	// VBROADCASTI32X8rmkz
    0U,	// VBROADCASTI64X2Z128rm
    405U,	// VBROADCASTI64X2Z128rmk
    461U,	// VBROADCASTI64X2Z128rmkz
    0U,	// VBROADCASTI64X2rm
    405U,	// VBROADCASTI64X2rmk
    461U,	// VBROADCASTI64X2rmkz
    0U,	// VBROADCASTI64X4rm
    405U,	// VBROADCASTI64X4rmk
    461U,	// VBROADCASTI64X4rmkz
    0U,	// VBROADCASTSDYrm
    0U,	// VBROADCASTSDYrr
    0U,	// VBROADCASTSDZ256m
    3356U,	// VBROADCASTSDZ256mk
    4444U,	// VBROADCASTSDZ256mkz
    0U,	// VBROADCASTSDZ256r
    405U,	// VBROADCASTSDZ256rk
    461U,	// VBROADCASTSDZ256rkz
    0U,	// VBROADCASTSDZm
    3356U,	// VBROADCASTSDZmk
    4444U,	// VBROADCASTSDZmkz
    0U,	// VBROADCASTSDZr
    405U,	// VBROADCASTSDZrk
    461U,	// VBROADCASTSDZrkz
    0U,	// VBROADCASTSSYrm
    0U,	// VBROADCASTSSYrr
    0U,	// VBROADCASTSSZ128m
    3356U,	// VBROADCASTSSZ128mk
    4444U,	// VBROADCASTSSZ128mkz
    0U,	// VBROADCASTSSZ128r
    405U,	// VBROADCASTSSZ128rk
    461U,	// VBROADCASTSSZ128rkz
    0U,	// VBROADCASTSSZ256m
    3356U,	// VBROADCASTSSZ256mk
    4444U,	// VBROADCASTSSZ256mkz
    0U,	// VBROADCASTSSZ256r
    405U,	// VBROADCASTSSZ256rk
    461U,	// VBROADCASTSSZ256rkz
    0U,	// VBROADCASTSSZm
    3356U,	// VBROADCASTSSZmk
    4444U,	// VBROADCASTSSZmkz
    0U,	// VBROADCASTSSZr
    405U,	// VBROADCASTSSZrk
    461U,	// VBROADCASTSSZrkz
    0U,	// VBROADCASTSSrm
    0U,	// VBROADCASTSSrr
    1U,	// VCMPPDYrmi
    72U,	// VCMPPDYrmi_alt
    18636U,	// VCMPPDYrri
    18636U,	// VCMPPDYrri_alt
    21856U,	// VCMPPDZ128rmbi
    18637U,	// VCMPPDZ128rmbi_alt
    26837U,	// VCMPPDZ128rmbi_altk
    29985U,	// VCMPPDZ128rmbik
    18636U,	// VCMPPDZ128rmi
    72U,	// VCMPPDZ128rmi_alt
    1156U,	// VCMPPDZ128rmi_altk
    1U,	// VCMPPDZ128rmik
    18636U,	// VCMPPDZ128rri
    18636U,	// VCMPPDZ128rri_alt
    26837U,	// VCMPPDZ128rri_altk
    26837U,	// VCMPPDZ128rrik
    21860U,	// VCMPPDZ256rmbi
    18637U,	// VCMPPDZ256rmbi_alt
    26837U,	// VCMPPDZ256rmbi_altk
    29989U,	// VCMPPDZ256rmbik
    1U,	// VCMPPDZ256rmi
    72U,	// VCMPPDZ256rmi_alt
    1156U,	// VCMPPDZ256rmi_altk
    2U,	// VCMPPDZ256rmik
    18636U,	// VCMPPDZ256rri
    18636U,	// VCMPPDZ256rri_alt
    26837U,	// VCMPPDZ256rri_altk
    26837U,	// VCMPPDZ256rrik
    21864U,	// VCMPPDZrmbi
    18637U,	// VCMPPDZrmbi_alt
    26837U,	// VCMPPDZrmbi_altk
    29993U,	// VCMPPDZrmbik
    2U,	// VCMPPDZrmi
    72U,	// VCMPPDZrmi_alt
    1156U,	// VCMPPDZrmi_altk
    2U,	// VCMPPDZrmik
    18636U,	// VCMPPDZrri
    18636U,	// VCMPPDZrri_alt
    26837U,	// VCMPPDZrri_altk
    18636U,	// VCMPPDZrrib
    18636U,	// VCMPPDZrrib_alt
    26837U,	// VCMPPDZrrib_altk
    26837U,	// VCMPPDZrribk
    26837U,	// VCMPPDZrrik
    18636U,	// VCMPPDrmi
    72U,	// VCMPPDrmi_alt
    18636U,	// VCMPPDrri
    18636U,	// VCMPPDrri_alt
    1U,	// VCMPPSYrmi
    72U,	// VCMPPSYrmi_alt
    18636U,	// VCMPPSYrri
    18636U,	// VCMPPSYrri_alt
    21860U,	// VCMPPSZ128rmbi
    18637U,	// VCMPPSZ128rmbi_alt
    26837U,	// VCMPPSZ128rmbi_altk
    29990U,	// VCMPPSZ128rmbik
    18636U,	// VCMPPSZ128rmi
    72U,	// VCMPPSZ128rmi_alt
    1156U,	// VCMPPSZ128rmi_altk
    1U,	// VCMPPSZ128rmik
    18636U,	// VCMPPSZ128rri
    18636U,	// VCMPPSZ128rri_alt
    26837U,	// VCMPPSZ128rri_altk
    26837U,	// VCMPPSZ128rrik
    21864U,	// VCMPPSZ256rmbi
    18637U,	// VCMPPSZ256rmbi_alt
    26837U,	// VCMPPSZ256rmbi_altk
    29994U,	// VCMPPSZ256rmbik
    1U,	// VCMPPSZ256rmi
    72U,	// VCMPPSZ256rmi_alt
    1156U,	// VCMPPSZ256rmi_altk
    2U,	// VCMPPSZ256rmik
    18636U,	// VCMPPSZ256rri
    18636U,	// VCMPPSZ256rri_alt
    26837U,	// VCMPPSZ256rri_altk
    26837U,	// VCMPPSZ256rrik
    21868U,	// VCMPPSZrmbi
    18637U,	// VCMPPSZrmbi_alt
    26837U,	// VCMPPSZrmbi_altk
    29998U,	// VCMPPSZrmbik
    2U,	// VCMPPSZrmi
    72U,	// VCMPPSZrmi_alt
    1156U,	// VCMPPSZrmi_altk
    2U,	// VCMPPSZrmik
    18636U,	// VCMPPSZrri
    18636U,	// VCMPPSZrri_alt
    26837U,	// VCMPPSZrri_altk
    18636U,	// VCMPPSZrrib
    18636U,	// VCMPPSZrrib_alt
    26837U,	// VCMPPSZrrib_altk
    26837U,	// VCMPPSZrribk
    26837U,	// VCMPPSZrrik
    18636U,	// VCMPPSrmi
    72U,	// VCMPPSrmi_alt
    18636U,	// VCMPPSrri
    18636U,	// VCMPPSrri_alt
    21832U,	// VCMPSDZrm
    21832U,	// VCMPSDZrm_Int
    29961U,	// VCMPSDZrm_Intk
    18636U,	// VCMPSDZrmi_alt
    26836U,	// VCMPSDZrmi_altk
    18636U,	// VCMPSDZrr
    18636U,	// VCMPSDZrr_Int
    26837U,	// VCMPSDZrr_Intk
    18636U,	// VCMPSDZrrb_Int
    26837U,	// VCMPSDZrrb_Intk
    18636U,	// VCMPSDZrrb_alt
    26837U,	// VCMPSDZrrb_altk
    18636U,	// VCMPSDZrri_alt
    26837U,	// VCMPSDZrri_altk
    21832U,	// VCMPSDrm
    21832U,	// VCMPSDrm_Int
    18636U,	// VCMPSDrm_alt
    18636U,	// VCMPSDrr
    18636U,	// VCMPSDrr_Int
    18636U,	// VCMPSDrr_alt
    21832U,	// VCMPSSZrm
    21832U,	// VCMPSSZrm_Int
    29962U,	// VCMPSSZrm_Intk
    18636U,	// VCMPSSZrmi_alt
    26836U,	// VCMPSSZrmi_altk
    18636U,	// VCMPSSZrr
    18636U,	// VCMPSSZrr_Int
    26837U,	// VCMPSSZrr_Intk
    18636U,	// VCMPSSZrrb_Int
    26837U,	// VCMPSSZrrb_Intk
    18636U,	// VCMPSSZrrb_alt
    26837U,	// VCMPSSZrrb_altk
    18636U,	// VCMPSSZrri_alt
    26837U,	// VCMPSSZrri_altk
    21832U,	// VCMPSSrm
    21832U,	// VCMPSSrm_Int
    18636U,	// VCMPSSrm_alt
    18636U,	// VCMPSSrr
    18636U,	// VCMPSSrr_Int
    18636U,	// VCMPSSrr_alt
    0U,	// VCOMISDZrm
    0U,	// VCOMISDZrm_Int
    0U,	// VCOMISDZrr
    0U,	// VCOMISDZrr_Int
    0U,	// VCOMISDZrrb
    0U,	// VCOMISDrm
    0U,	// VCOMISDrm_Int
    0U,	// VCOMISDrr
    0U,	// VCOMISDrr_Int
    0U,	// VCOMISSZrm
    0U,	// VCOMISSZrm_Int
    0U,	// VCOMISSZrr
    0U,	// VCOMISSZrr_Int
    0U,	// VCOMISSZrrb
    0U,	// VCOMISSrm
    0U,	// VCOMISSrm_Int
    0U,	// VCOMISSrr
    0U,	// VCOMISSrr_Int
    0U,	// VCOMPRESSPDZ128mr
    49U,	// VCOMPRESSPDZ128mrk
    0U,	// VCOMPRESSPDZ128rr
    405U,	// VCOMPRESSPDZ128rrk
    461U,	// VCOMPRESSPDZ128rrkz
    0U,	// VCOMPRESSPDZ256mr
    49U,	// VCOMPRESSPDZ256mrk
    0U,	// VCOMPRESSPDZ256rr
    405U,	// VCOMPRESSPDZ256rrk
    461U,	// VCOMPRESSPDZ256rrkz
    0U,	// VCOMPRESSPDZmr
    49U,	// VCOMPRESSPDZmrk
    0U,	// VCOMPRESSPDZrr
    405U,	// VCOMPRESSPDZrrk
    461U,	// VCOMPRESSPDZrrkz
    0U,	// VCOMPRESSPSZ128mr
    49U,	// VCOMPRESSPSZ128mrk
    0U,	// VCOMPRESSPSZ128rr
    405U,	// VCOMPRESSPSZ128rrk
    461U,	// VCOMPRESSPSZ128rrkz
    0U,	// VCOMPRESSPSZ256mr
    49U,	// VCOMPRESSPSZ256mrk
    0U,	// VCOMPRESSPSZ256rr
    405U,	// VCOMPRESSPSZ256rrk
    461U,	// VCOMPRESSPSZ256rrkz
    0U,	// VCOMPRESSPSZmr
    49U,	// VCOMPRESSPSZmrk
    0U,	// VCOMPRESSPSZrr
    405U,	// VCOMPRESSPSZrrk
    461U,	// VCOMPRESSPSZrrkz
    0U,	// VCVTDQ2PDYrm
    0U,	// VCVTDQ2PDYrr
    0U,	// VCVTDQ2PDZ128rm
    0U,	// VCVTDQ2PDZ128rmb
    3356U,	// VCVTDQ2PDZ128rmbk
    4444U,	// VCVTDQ2PDZ128rmbkz
    3356U,	// VCVTDQ2PDZ128rmk
    4444U,	// VCVTDQ2PDZ128rmkz
    0U,	// VCVTDQ2PDZ128rr
    405U,	// VCVTDQ2PDZ128rrk
    461U,	// VCVTDQ2PDZ128rrkz
    0U,	// VCVTDQ2PDZ256rm
    0U,	// VCVTDQ2PDZ256rmb
    3356U,	// VCVTDQ2PDZ256rmbk
    4444U,	// VCVTDQ2PDZ256rmbkz
    405U,	// VCVTDQ2PDZ256rmk
    461U,	// VCVTDQ2PDZ256rmkz
    0U,	// VCVTDQ2PDZ256rr
    405U,	// VCVTDQ2PDZ256rrk
    461U,	// VCVTDQ2PDZ256rrkz
    0U,	// VCVTDQ2PDZrm
    0U,	// VCVTDQ2PDZrmb
    3356U,	// VCVTDQ2PDZrmbk
    4444U,	// VCVTDQ2PDZrmbkz
    405U,	// VCVTDQ2PDZrmk
    461U,	// VCVTDQ2PDZrmkz
    0U,	// VCVTDQ2PDZrr
    405U,	// VCVTDQ2PDZrrk
    461U,	// VCVTDQ2PDZrrkz
    0U,	// VCVTDQ2PDrm
    0U,	// VCVTDQ2PDrr
    0U,	// VCVTDQ2PSYrm
    0U,	// VCVTDQ2PSYrr
    0U,	// VCVTDQ2PSZ128rm
    0U,	// VCVTDQ2PSZ128rmb
    3356U,	// VCVTDQ2PSZ128rmbk
    4444U,	// VCVTDQ2PSZ128rmbkz
    405U,	// VCVTDQ2PSZ128rmk
    461U,	// VCVTDQ2PSZ128rmkz
    0U,	// VCVTDQ2PSZ128rr
    405U,	// VCVTDQ2PSZ128rrk
    461U,	// VCVTDQ2PSZ128rrkz
    0U,	// VCVTDQ2PSZ256rm
    0U,	// VCVTDQ2PSZ256rmb
    3356U,	// VCVTDQ2PSZ256rmbk
    4444U,	// VCVTDQ2PSZ256rmbkz
    405U,	// VCVTDQ2PSZ256rmk
    461U,	// VCVTDQ2PSZ256rmkz
    0U,	// VCVTDQ2PSZ256rr
    405U,	// VCVTDQ2PSZ256rrk
    461U,	// VCVTDQ2PSZ256rrkz
    0U,	// VCVTDQ2PSZrm
    0U,	// VCVTDQ2PSZrmb
    3356U,	// VCVTDQ2PSZrmbk
    4444U,	// VCVTDQ2PSZrmbkz
    405U,	// VCVTDQ2PSZrmk
    461U,	// VCVTDQ2PSZrmkz
    0U,	// VCVTDQ2PSZrr
    0U,	// VCVTDQ2PSZrrb
    405U,	// VCVTDQ2PSZrrbk
    461U,	// VCVTDQ2PSZrrbkz
    405U,	// VCVTDQ2PSZrrk
    461U,	// VCVTDQ2PSZrrkz
    0U,	// VCVTDQ2PSrm
    0U,	// VCVTDQ2PSrr
    0U,	// VCVTPD2DQYrm
    0U,	// VCVTPD2DQYrr
    0U,	// VCVTPD2DQZ128rm
    0U,	// VCVTPD2DQZ128rmb
    3356U,	// VCVTPD2DQZ128rmbk
    4444U,	// VCVTPD2DQZ128rmbkz
    405U,	// VCVTPD2DQZ128rmk
    461U,	// VCVTPD2DQZ128rmkz
    0U,	// VCVTPD2DQZ128rr
    405U,	// VCVTPD2DQZ128rrk
    461U,	// VCVTPD2DQZ128rrkz
    0U,	// VCVTPD2DQZ256rm
    0U,	// VCVTPD2DQZ256rmb
    3356U,	// VCVTPD2DQZ256rmbk
    4444U,	// VCVTPD2DQZ256rmbkz
    405U,	// VCVTPD2DQZ256rmk
    461U,	// VCVTPD2DQZ256rmkz
    0U,	// VCVTPD2DQZ256rr
    405U,	// VCVTPD2DQZ256rrk
    461U,	// VCVTPD2DQZ256rrkz
    0U,	// VCVTPD2DQZrm
    0U,	// VCVTPD2DQZrmb
    3356U,	// VCVTPD2DQZrmbk
    4444U,	// VCVTPD2DQZrmbkz
    405U,	// VCVTPD2DQZrmk
    461U,	// VCVTPD2DQZrmkz
    0U,	// VCVTPD2DQZrr
    0U,	// VCVTPD2DQZrrb
    405U,	// VCVTPD2DQZrrbk
    461U,	// VCVTPD2DQZrrbkz
    405U,	// VCVTPD2DQZrrk
    461U,	// VCVTPD2DQZrrkz
    0U,	// VCVTPD2DQrm
    0U,	// VCVTPD2DQrr
    0U,	// VCVTPD2PSYrm
    0U,	// VCVTPD2PSYrr
    0U,	// VCVTPD2PSZ128rm
    0U,	// VCVTPD2PSZ128rmb
    3356U,	// VCVTPD2PSZ128rmbk
    4444U,	// VCVTPD2PSZ128rmbkz
    405U,	// VCVTPD2PSZ128rmk
    461U,	// VCVTPD2PSZ128rmkz
    0U,	// VCVTPD2PSZ128rr
    405U,	// VCVTPD2PSZ128rrk
    461U,	// VCVTPD2PSZ128rrkz
    0U,	// VCVTPD2PSZ256rm
    0U,	// VCVTPD2PSZ256rmb
    3356U,	// VCVTPD2PSZ256rmbk
    4444U,	// VCVTPD2PSZ256rmbkz
    405U,	// VCVTPD2PSZ256rmk
    461U,	// VCVTPD2PSZ256rmkz
    0U,	// VCVTPD2PSZ256rr
    405U,	// VCVTPD2PSZ256rrk
    461U,	// VCVTPD2PSZ256rrkz
    0U,	// VCVTPD2PSZrm
    0U,	// VCVTPD2PSZrmb
    3356U,	// VCVTPD2PSZrmbk
    4444U,	// VCVTPD2PSZrmbkz
    405U,	// VCVTPD2PSZrmk
    461U,	// VCVTPD2PSZrmkz
    0U,	// VCVTPD2PSZrr
    0U,	// VCVTPD2PSZrrb
    405U,	// VCVTPD2PSZrrbk
    461U,	// VCVTPD2PSZrrbkz
    405U,	// VCVTPD2PSZrrk
    461U,	// VCVTPD2PSZrrkz
    0U,	// VCVTPD2PSrm
    0U,	// VCVTPD2PSrr
    0U,	// VCVTPD2QQZ128rm
    0U,	// VCVTPD2QQZ128rmb
    3356U,	// VCVTPD2QQZ128rmbk
    4444U,	// VCVTPD2QQZ128rmbkz
    405U,	// VCVTPD2QQZ128rmk
    461U,	// VCVTPD2QQZ128rmkz
    0U,	// VCVTPD2QQZ128rr
    405U,	// VCVTPD2QQZ128rrk
    461U,	// VCVTPD2QQZ128rrkz
    0U,	// VCVTPD2QQZ256rm
    0U,	// VCVTPD2QQZ256rmb
    3356U,	// VCVTPD2QQZ256rmbk
    4444U,	// VCVTPD2QQZ256rmbkz
    405U,	// VCVTPD2QQZ256rmk
    461U,	// VCVTPD2QQZ256rmkz
    0U,	// VCVTPD2QQZ256rr
    405U,	// VCVTPD2QQZ256rrk
    461U,	// VCVTPD2QQZ256rrkz
    0U,	// VCVTPD2QQZrm
    0U,	// VCVTPD2QQZrmb
    3356U,	// VCVTPD2QQZrmbk
    4444U,	// VCVTPD2QQZrmbkz
    405U,	// VCVTPD2QQZrmk
    461U,	// VCVTPD2QQZrmkz
    0U,	// VCVTPD2QQZrr
    0U,	// VCVTPD2QQZrrb
    405U,	// VCVTPD2QQZrrbk
    461U,	// VCVTPD2QQZrrbkz
    405U,	// VCVTPD2QQZrrk
    461U,	// VCVTPD2QQZrrkz
    0U,	// VCVTPD2UDQZ128rm
    0U,	// VCVTPD2UDQZ128rmb
    3356U,	// VCVTPD2UDQZ128rmbk
    4444U,	// VCVTPD2UDQZ128rmbkz
    405U,	// VCVTPD2UDQZ128rmk
    461U,	// VCVTPD2UDQZ128rmkz
    0U,	// VCVTPD2UDQZ128rr
    405U,	// VCVTPD2UDQZ128rrk
    461U,	// VCVTPD2UDQZ128rrkz
    0U,	// VCVTPD2UDQZ256rm
    0U,	// VCVTPD2UDQZ256rmb
    3356U,	// VCVTPD2UDQZ256rmbk
    4444U,	// VCVTPD2UDQZ256rmbkz
    405U,	// VCVTPD2UDQZ256rmk
    461U,	// VCVTPD2UDQZ256rmkz
    0U,	// VCVTPD2UDQZ256rr
    405U,	// VCVTPD2UDQZ256rrk
    461U,	// VCVTPD2UDQZ256rrkz
    0U,	// VCVTPD2UDQZrm
    0U,	// VCVTPD2UDQZrmb
    3356U,	// VCVTPD2UDQZrmbk
    4444U,	// VCVTPD2UDQZrmbkz
    405U,	// VCVTPD2UDQZrmk
    461U,	// VCVTPD2UDQZrmkz
    0U,	// VCVTPD2UDQZrr
    0U,	// VCVTPD2UDQZrrb
    405U,	// VCVTPD2UDQZrrbk
    461U,	// VCVTPD2UDQZrrbkz
    405U,	// VCVTPD2UDQZrrk
    461U,	// VCVTPD2UDQZrrkz
    0U,	// VCVTPD2UQQZ128rm
    0U,	// VCVTPD2UQQZ128rmb
    3356U,	// VCVTPD2UQQZ128rmbk
    4444U,	// VCVTPD2UQQZ128rmbkz
    405U,	// VCVTPD2UQQZ128rmk
    461U,	// VCVTPD2UQQZ128rmkz
    0U,	// VCVTPD2UQQZ128rr
    405U,	// VCVTPD2UQQZ128rrk
    461U,	// VCVTPD2UQQZ128rrkz
    0U,	// VCVTPD2UQQZ256rm
    0U,	// VCVTPD2UQQZ256rmb
    3356U,	// VCVTPD2UQQZ256rmbk
    4444U,	// VCVTPD2UQQZ256rmbkz
    405U,	// VCVTPD2UQQZ256rmk
    461U,	// VCVTPD2UQQZ256rmkz
    0U,	// VCVTPD2UQQZ256rr
    405U,	// VCVTPD2UQQZ256rrk
    461U,	// VCVTPD2UQQZ256rrkz
    0U,	// VCVTPD2UQQZrm
    0U,	// VCVTPD2UQQZrmb
    3356U,	// VCVTPD2UQQZrmbk
    4444U,	// VCVTPD2UQQZrmbkz
    405U,	// VCVTPD2UQQZrmk
    461U,	// VCVTPD2UQQZrmkz
    0U,	// VCVTPD2UQQZrr
    0U,	// VCVTPD2UQQZrrb
    405U,	// VCVTPD2UQQZrrbk
    461U,	// VCVTPD2UQQZrrbkz
    405U,	// VCVTPD2UQQZrrk
    461U,	// VCVTPD2UQQZrrkz
    0U,	// VCVTPH2PSYrm
    0U,	// VCVTPH2PSYrr
    0U,	// VCVTPH2PSZ128rm
    3356U,	// VCVTPH2PSZ128rmk
    4444U,	// VCVTPH2PSZ128rmkz
    0U,	// VCVTPH2PSZ128rr
    405U,	// VCVTPH2PSZ128rrk
    461U,	// VCVTPH2PSZ128rrkz
    0U,	// VCVTPH2PSZ256rm
    405U,	// VCVTPH2PSZ256rmk
    461U,	// VCVTPH2PSZ256rmkz
    0U,	// VCVTPH2PSZ256rr
    405U,	// VCVTPH2PSZ256rrk
    461U,	// VCVTPH2PSZ256rrkz
    0U,	// VCVTPH2PSZrm
    405U,	// VCVTPH2PSZrmk
    461U,	// VCVTPH2PSZrmkz
    0U,	// VCVTPH2PSZrr
    0U,	// VCVTPH2PSZrrb
    405U,	// VCVTPH2PSZrrbk
    461U,	// VCVTPH2PSZrrbkz
    405U,	// VCVTPH2PSZrrk
    461U,	// VCVTPH2PSZrrkz
    0U,	// VCVTPH2PSrm
    0U,	// VCVTPH2PSrr
    0U,	// VCVTPS2DQYrm
    0U,	// VCVTPS2DQYrr
    0U,	// VCVTPS2DQZ128rm
    0U,	// VCVTPS2DQZ128rmb
    3356U,	// VCVTPS2DQZ128rmbk
    4444U,	// VCVTPS2DQZ128rmbkz
    405U,	// VCVTPS2DQZ128rmk
    461U,	// VCVTPS2DQZ128rmkz
    0U,	// VCVTPS2DQZ128rr
    405U,	// VCVTPS2DQZ128rrk
    461U,	// VCVTPS2DQZ128rrkz
    0U,	// VCVTPS2DQZ256rm
    0U,	// VCVTPS2DQZ256rmb
    3356U,	// VCVTPS2DQZ256rmbk
    4444U,	// VCVTPS2DQZ256rmbkz
    405U,	// VCVTPS2DQZ256rmk
    461U,	// VCVTPS2DQZ256rmkz
    0U,	// VCVTPS2DQZ256rr
    405U,	// VCVTPS2DQZ256rrk
    461U,	// VCVTPS2DQZ256rrkz
    0U,	// VCVTPS2DQZrm
    0U,	// VCVTPS2DQZrmb
    3356U,	// VCVTPS2DQZrmbk
    4444U,	// VCVTPS2DQZrmbkz
    405U,	// VCVTPS2DQZrmk
    461U,	// VCVTPS2DQZrmkz
    0U,	// VCVTPS2DQZrr
    0U,	// VCVTPS2DQZrrb
    405U,	// VCVTPS2DQZrrbk
    461U,	// VCVTPS2DQZrrbkz
    405U,	// VCVTPS2DQZrrk
    461U,	// VCVTPS2DQZrrkz
    0U,	// VCVTPS2DQrm
    0U,	// VCVTPS2DQrr
    0U,	// VCVTPS2PDYrm
    0U,	// VCVTPS2PDYrr
    0U,	// VCVTPS2PDZ128rm
    0U,	// VCVTPS2PDZ128rmb
    3356U,	// VCVTPS2PDZ128rmbk
    4444U,	// VCVTPS2PDZ128rmbkz
    3356U,	// VCVTPS2PDZ128rmk
    4444U,	// VCVTPS2PDZ128rmkz
    0U,	// VCVTPS2PDZ128rr
    405U,	// VCVTPS2PDZ128rrk
    461U,	// VCVTPS2PDZ128rrkz
    0U,	// VCVTPS2PDZ256rm
    0U,	// VCVTPS2PDZ256rmb
    3356U,	// VCVTPS2PDZ256rmbk
    4444U,	// VCVTPS2PDZ256rmbkz
    405U,	// VCVTPS2PDZ256rmk
    461U,	// VCVTPS2PDZ256rmkz
    0U,	// VCVTPS2PDZ256rr
    405U,	// VCVTPS2PDZ256rrk
    461U,	// VCVTPS2PDZ256rrkz
    0U,	// VCVTPS2PDZrm
    0U,	// VCVTPS2PDZrmb
    3356U,	// VCVTPS2PDZrmbk
    4444U,	// VCVTPS2PDZrmbkz
    405U,	// VCVTPS2PDZrmk
    461U,	// VCVTPS2PDZrmkz
    0U,	// VCVTPS2PDZrr
    0U,	// VCVTPS2PDZrrb
    405U,	// VCVTPS2PDZrrbk
    461U,	// VCVTPS2PDZrrbkz
    405U,	// VCVTPS2PDZrrk
    461U,	// VCVTPS2PDZrrkz
    0U,	// VCVTPS2PDrm
    0U,	// VCVTPS2PDrr
    2U,	// VCVTPS2PHYmr
    72U,	// VCVTPS2PHYrr
    2U,	// VCVTPS2PHZ128mr
    542U,	// VCVTPS2PHZ128mrk
    72U,	// VCVTPS2PHZ128rr
    133U,	// VCVTPS2PHZ128rrk
    9348U,	// VCVTPS2PHZ128rrkz
    2U,	// VCVTPS2PHZ256mr
    542U,	// VCVTPS2PHZ256mrk
    72U,	// VCVTPS2PHZ256rr
    133U,	// VCVTPS2PHZ256rrk
    9348U,	// VCVTPS2PHZ256rrkz
    2U,	// VCVTPS2PHZmr
    542U,	// VCVTPS2PHZmrk
    72U,	// VCVTPS2PHZrr
    72U,	// VCVTPS2PHZrrb
    133U,	// VCVTPS2PHZrrbk
    9348U,	// VCVTPS2PHZrrbkz
    133U,	// VCVTPS2PHZrrk
    9348U,	// VCVTPS2PHZrrkz
    2U,	// VCVTPS2PHmr
    72U,	// VCVTPS2PHrr
    0U,	// VCVTPS2QQZ128rm
    0U,	// VCVTPS2QQZ128rmb
    3356U,	// VCVTPS2QQZ128rmbk
    4444U,	// VCVTPS2QQZ128rmbkz
    3356U,	// VCVTPS2QQZ128rmk
    4444U,	// VCVTPS2QQZ128rmkz
    0U,	// VCVTPS2QQZ128rr
    405U,	// VCVTPS2QQZ128rrk
    461U,	// VCVTPS2QQZ128rrkz
    0U,	// VCVTPS2QQZ256rm
    0U,	// VCVTPS2QQZ256rmb
    3356U,	// VCVTPS2QQZ256rmbk
    4444U,	// VCVTPS2QQZ256rmbkz
    405U,	// VCVTPS2QQZ256rmk
    461U,	// VCVTPS2QQZ256rmkz
    0U,	// VCVTPS2QQZ256rr
    405U,	// VCVTPS2QQZ256rrk
    461U,	// VCVTPS2QQZ256rrkz
    0U,	// VCVTPS2QQZrm
    0U,	// VCVTPS2QQZrmb
    3356U,	// VCVTPS2QQZrmbk
    4444U,	// VCVTPS2QQZrmbkz
    405U,	// VCVTPS2QQZrmk
    461U,	// VCVTPS2QQZrmkz
    0U,	// VCVTPS2QQZrr
    0U,	// VCVTPS2QQZrrb
    405U,	// VCVTPS2QQZrrbk
    461U,	// VCVTPS2QQZrrbkz
    405U,	// VCVTPS2QQZrrk
    461U,	// VCVTPS2QQZrrkz
    0U,	// VCVTPS2UDQZ128rm
    0U,	// VCVTPS2UDQZ128rmb
    3356U,	// VCVTPS2UDQZ128rmbk
    4444U,	// VCVTPS2UDQZ128rmbkz
    405U,	// VCVTPS2UDQZ128rmk
    461U,	// VCVTPS2UDQZ128rmkz
    0U,	// VCVTPS2UDQZ128rr
    405U,	// VCVTPS2UDQZ128rrk
    461U,	// VCVTPS2UDQZ128rrkz
    0U,	// VCVTPS2UDQZ256rm
    0U,	// VCVTPS2UDQZ256rmb
    3356U,	// VCVTPS2UDQZ256rmbk
    4444U,	// VCVTPS2UDQZ256rmbkz
    405U,	// VCVTPS2UDQZ256rmk
    461U,	// VCVTPS2UDQZ256rmkz
    0U,	// VCVTPS2UDQZ256rr
    405U,	// VCVTPS2UDQZ256rrk
    461U,	// VCVTPS2UDQZ256rrkz
    0U,	// VCVTPS2UDQZrm
    0U,	// VCVTPS2UDQZrmb
    3356U,	// VCVTPS2UDQZrmbk
    4444U,	// VCVTPS2UDQZrmbkz
    405U,	// VCVTPS2UDQZrmk
    461U,	// VCVTPS2UDQZrmkz
    0U,	// VCVTPS2UDQZrr
    0U,	// VCVTPS2UDQZrrb
    405U,	// VCVTPS2UDQZrrbk
    461U,	// VCVTPS2UDQZrrbkz
    405U,	// VCVTPS2UDQZrrk
    461U,	// VCVTPS2UDQZrrkz
    0U,	// VCVTPS2UQQZ128rm
    0U,	// VCVTPS2UQQZ128rmb
    3356U,	// VCVTPS2UQQZ128rmbk
    4444U,	// VCVTPS2UQQZ128rmbkz
    3356U,	// VCVTPS2UQQZ128rmk
    4444U,	// VCVTPS2UQQZ128rmkz
    0U,	// VCVTPS2UQQZ128rr
    405U,	// VCVTPS2UQQZ128rrk
    461U,	// VCVTPS2UQQZ128rrkz
    0U,	// VCVTPS2UQQZ256rm
    0U,	// VCVTPS2UQQZ256rmb
    3356U,	// VCVTPS2UQQZ256rmbk
    4444U,	// VCVTPS2UQQZ256rmbkz
    405U,	// VCVTPS2UQQZ256rmk
    461U,	// VCVTPS2UQQZ256rmkz
    0U,	// VCVTPS2UQQZ256rr
    405U,	// VCVTPS2UQQZ256rrk
    461U,	// VCVTPS2UQQZ256rrkz
    0U,	// VCVTPS2UQQZrm
    0U,	// VCVTPS2UQQZrmb
    3356U,	// VCVTPS2UQQZrmbk
    4444U,	// VCVTPS2UQQZrmbkz
    405U,	// VCVTPS2UQQZrmk
    461U,	// VCVTPS2UQQZrmkz
    0U,	// VCVTPS2UQQZrr
    0U,	// VCVTPS2UQQZrrb
    405U,	// VCVTPS2UQQZrrbk
    461U,	// VCVTPS2UQQZrrbkz
    405U,	// VCVTPS2UQQZrrk
    461U,	// VCVTPS2UQQZrrkz
    0U,	// VCVTQQ2PDZ128rm
    0U,	// VCVTQQ2PDZ128rmb
    3356U,	// VCVTQQ2PDZ128rmbk
    4444U,	// VCVTQQ2PDZ128rmbkz
    405U,	// VCVTQQ2PDZ128rmk
    461U,	// VCVTQQ2PDZ128rmkz
    0U,	// VCVTQQ2PDZ128rr
    405U,	// VCVTQQ2PDZ128rrk
    461U,	// VCVTQQ2PDZ128rrkz
    0U,	// VCVTQQ2PDZ256rm
    0U,	// VCVTQQ2PDZ256rmb
    3356U,	// VCVTQQ2PDZ256rmbk
    4444U,	// VCVTQQ2PDZ256rmbkz
    405U,	// VCVTQQ2PDZ256rmk
    461U,	// VCVTQQ2PDZ256rmkz
    0U,	// VCVTQQ2PDZ256rr
    405U,	// VCVTQQ2PDZ256rrk
    461U,	// VCVTQQ2PDZ256rrkz
    0U,	// VCVTQQ2PDZrm
    0U,	// VCVTQQ2PDZrmb
    3356U,	// VCVTQQ2PDZrmbk
    4444U,	// VCVTQQ2PDZrmbkz
    405U,	// VCVTQQ2PDZrmk
    461U,	// VCVTQQ2PDZrmkz
    0U,	// VCVTQQ2PDZrr
    0U,	// VCVTQQ2PDZrrb
    405U,	// VCVTQQ2PDZrrbk
    461U,	// VCVTQQ2PDZrrbkz
    405U,	// VCVTQQ2PDZrrk
    461U,	// VCVTQQ2PDZrrkz
    0U,	// VCVTQQ2PSZ128rm
    0U,	// VCVTQQ2PSZ128rmb
    3356U,	// VCVTQQ2PSZ128rmbk
    4444U,	// VCVTQQ2PSZ128rmbkz
    405U,	// VCVTQQ2PSZ128rmk
    461U,	// VCVTQQ2PSZ128rmkz
    0U,	// VCVTQQ2PSZ128rr
    405U,	// VCVTQQ2PSZ128rrk
    461U,	// VCVTQQ2PSZ128rrkz
    0U,	// VCVTQQ2PSZ256rm
    0U,	// VCVTQQ2PSZ256rmb
    3356U,	// VCVTQQ2PSZ256rmbk
    4444U,	// VCVTQQ2PSZ256rmbkz
    405U,	// VCVTQQ2PSZ256rmk
    461U,	// VCVTQQ2PSZ256rmkz
    0U,	// VCVTQQ2PSZ256rr
    405U,	// VCVTQQ2PSZ256rrk
    461U,	// VCVTQQ2PSZ256rrkz
    0U,	// VCVTQQ2PSZrm
    0U,	// VCVTQQ2PSZrmb
    3356U,	// VCVTQQ2PSZrmbk
    4444U,	// VCVTQQ2PSZrmbkz
    405U,	// VCVTQQ2PSZrmk
    461U,	// VCVTQQ2PSZrmkz
    0U,	// VCVTQQ2PSZrr
    0U,	// VCVTQQ2PSZrrb
    405U,	// VCVTQQ2PSZrrbk
    461U,	// VCVTQQ2PSZrrbkz
    405U,	// VCVTQQ2PSZrrk
    461U,	// VCVTQQ2PSZrrkz
    0U,	// VCVTSD2SI64Zrm_Int
    0U,	// VCVTSD2SI64Zrr_Int
    0U,	// VCVTSD2SI64Zrrb_Int
    0U,	// VCVTSD2SI64rm_Int
    0U,	// VCVTSD2SI64rr_Int
    0U,	// VCVTSD2SIZrm_Int
    0U,	// VCVTSD2SIZrr_Int
    0U,	// VCVTSD2SIZrrb_Int
    0U,	// VCVTSD2SIrm_Int
    0U,	// VCVTSD2SIrr_Int
    72U,	// VCVTSD2SSZrm
    72U,	// VCVTSD2SSZrm_Int
    133U,	// VCVTSD2SSZrm_Intk
    9348U,	// VCVTSD2SSZrm_Intkz
    4U,	// VCVTSD2SSZrr
    4U,	// VCVTSD2SSZrr_Int
    0U,	// VCVTSD2SSZrr_Intk
    9348U,	// VCVTSD2SSZrr_Intkz
    4U,	// VCVTSD2SSZrrb_Int
    0U,	// VCVTSD2SSZrrb_Intk
    9348U,	// VCVTSD2SSZrrb_Intkz
    72U,	// VCVTSD2SSrm
    72U,	// VCVTSD2SSrm_Int
    4U,	// VCVTSD2SSrr
    4U,	// VCVTSD2SSrr_Int
    0U,	// VCVTSD2USI64Zrm_Int
    0U,	// VCVTSD2USI64Zrr_Int
    0U,	// VCVTSD2USI64Zrrb_Int
    0U,	// VCVTSD2USIZrm_Int
    0U,	// VCVTSD2USIZrr_Int
    0U,	// VCVTSD2USIZrrb_Int
    72U,	// VCVTSI2SDZrm
    72U,	// VCVTSI2SDZrm_Int
    4U,	// VCVTSI2SDZrr
    4U,	// VCVTSI2SDZrr_Int
    0U,	// VCVTSI2SDZrrb_Int
    72U,	// VCVTSI2SDrm
    72U,	// VCVTSI2SDrm_Int
    4U,	// VCVTSI2SDrr
    4U,	// VCVTSI2SDrr_Int
    72U,	// VCVTSI2SSZrm
    72U,	// VCVTSI2SSZrm_Int
    4U,	// VCVTSI2SSZrr
    4U,	// VCVTSI2SSZrr_Int
    0U,	// VCVTSI2SSZrrb_Int
    72U,	// VCVTSI2SSrm
    72U,	// VCVTSI2SSrm_Int
    4U,	// VCVTSI2SSrr
    4U,	// VCVTSI2SSrr_Int
    72U,	// VCVTSI642SDZrm
    72U,	// VCVTSI642SDZrm_Int
    4U,	// VCVTSI642SDZrr
    4U,	// VCVTSI642SDZrr_Int
    0U,	// VCVTSI642SDZrrb_Int
    72U,	// VCVTSI642SDrm
    72U,	// VCVTSI642SDrm_Int
    4U,	// VCVTSI642SDrr
    4U,	// VCVTSI642SDrr_Int
    72U,	// VCVTSI642SSZrm
    72U,	// VCVTSI642SSZrm_Int
    4U,	// VCVTSI642SSZrr
    4U,	// VCVTSI642SSZrr_Int
    0U,	// VCVTSI642SSZrrb_Int
    72U,	// VCVTSI642SSrm
    72U,	// VCVTSI642SSrm_Int
    4U,	// VCVTSI642SSrr
    4U,	// VCVTSI642SSrr_Int
    72U,	// VCVTSS2SDZrm
    72U,	// VCVTSS2SDZrm_Int
    133U,	// VCVTSS2SDZrm_Intk
    9348U,	// VCVTSS2SDZrm_Intkz
    4U,	// VCVTSS2SDZrr
    4U,	// VCVTSS2SDZrr_Int
    0U,	// VCVTSS2SDZrr_Intk
    9348U,	// VCVTSS2SDZrr_Intkz
    4U,	// VCVTSS2SDZrrb_Int
    0U,	// VCVTSS2SDZrrb_Intk
    9348U,	// VCVTSS2SDZrrb_Intkz
    72U,	// VCVTSS2SDrm
    72U,	// VCVTSS2SDrm_Int
    4U,	// VCVTSS2SDrr
    4U,	// VCVTSS2SDrr_Int
    0U,	// VCVTSS2SI64Zrm_Int
    0U,	// VCVTSS2SI64Zrr_Int
    0U,	// VCVTSS2SI64Zrrb_Int
    0U,	// VCVTSS2SI64rm_Int
    0U,	// VCVTSS2SI64rr_Int
    0U,	// VCVTSS2SIZrm_Int
    0U,	// VCVTSS2SIZrr_Int
    0U,	// VCVTSS2SIZrrb_Int
    0U,	// VCVTSS2SIrm_Int
    0U,	// VCVTSS2SIrr_Int
    0U,	// VCVTSS2USI64Zrm_Int
    0U,	// VCVTSS2USI64Zrr_Int
    0U,	// VCVTSS2USI64Zrrb_Int
    0U,	// VCVTSS2USIZrm_Int
    0U,	// VCVTSS2USIZrr_Int
    0U,	// VCVTSS2USIZrrb_Int
    0U,	// VCVTTPD2DQYrm
    0U,	// VCVTTPD2DQYrr
    0U,	// VCVTTPD2DQZ128rm
    0U,	// VCVTTPD2DQZ128rmb
    3356U,	// VCVTTPD2DQZ128rmbk
    4444U,	// VCVTTPD2DQZ128rmbkz
    405U,	// VCVTTPD2DQZ128rmk
    461U,	// VCVTTPD2DQZ128rmkz
    0U,	// VCVTTPD2DQZ128rr
    405U,	// VCVTTPD2DQZ128rrk
    461U,	// VCVTTPD2DQZ128rrkz
    0U,	// VCVTTPD2DQZ256rm
    0U,	// VCVTTPD2DQZ256rmb
    3356U,	// VCVTTPD2DQZ256rmbk
    4444U,	// VCVTTPD2DQZ256rmbkz
    405U,	// VCVTTPD2DQZ256rmk
    461U,	// VCVTTPD2DQZ256rmkz
    0U,	// VCVTTPD2DQZ256rr
    405U,	// VCVTTPD2DQZ256rrk
    461U,	// VCVTTPD2DQZ256rrkz
    0U,	// VCVTTPD2DQZrm
    0U,	// VCVTTPD2DQZrmb
    3356U,	// VCVTTPD2DQZrmbk
    4444U,	// VCVTTPD2DQZrmbkz
    405U,	// VCVTTPD2DQZrmk
    461U,	// VCVTTPD2DQZrmkz
    0U,	// VCVTTPD2DQZrr
    0U,	// VCVTTPD2DQZrrb
    405U,	// VCVTTPD2DQZrrbk
    461U,	// VCVTTPD2DQZrrbkz
    405U,	// VCVTTPD2DQZrrk
    461U,	// VCVTTPD2DQZrrkz
    0U,	// VCVTTPD2DQrm
    0U,	// VCVTTPD2DQrr
    0U,	// VCVTTPD2QQZ128rm
    0U,	// VCVTTPD2QQZ128rmb
    3356U,	// VCVTTPD2QQZ128rmbk
    4444U,	// VCVTTPD2QQZ128rmbkz
    405U,	// VCVTTPD2QQZ128rmk
    461U,	// VCVTTPD2QQZ128rmkz
    0U,	// VCVTTPD2QQZ128rr
    405U,	// VCVTTPD2QQZ128rrk
    461U,	// VCVTTPD2QQZ128rrkz
    0U,	// VCVTTPD2QQZ256rm
    0U,	// VCVTTPD2QQZ256rmb
    3356U,	// VCVTTPD2QQZ256rmbk
    4444U,	// VCVTTPD2QQZ256rmbkz
    405U,	// VCVTTPD2QQZ256rmk
    461U,	// VCVTTPD2QQZ256rmkz
    0U,	// VCVTTPD2QQZ256rr
    405U,	// VCVTTPD2QQZ256rrk
    461U,	// VCVTTPD2QQZ256rrkz
    0U,	// VCVTTPD2QQZrm
    0U,	// VCVTTPD2QQZrmb
    3356U,	// VCVTTPD2QQZrmbk
    4444U,	// VCVTTPD2QQZrmbkz
    405U,	// VCVTTPD2QQZrmk
    461U,	// VCVTTPD2QQZrmkz
    0U,	// VCVTTPD2QQZrr
    0U,	// VCVTTPD2QQZrrb
    405U,	// VCVTTPD2QQZrrbk
    461U,	// VCVTTPD2QQZrrbkz
    405U,	// VCVTTPD2QQZrrk
    461U,	// VCVTTPD2QQZrrkz
    0U,	// VCVTTPD2UDQZ128rm
    0U,	// VCVTTPD2UDQZ128rmb
    3356U,	// VCVTTPD2UDQZ128rmbk
    4444U,	// VCVTTPD2UDQZ128rmbkz
    405U,	// VCVTTPD2UDQZ128rmk
    461U,	// VCVTTPD2UDQZ128rmkz
    0U,	// VCVTTPD2UDQZ128rr
    405U,	// VCVTTPD2UDQZ128rrk
    461U,	// VCVTTPD2UDQZ128rrkz
    0U,	// VCVTTPD2UDQZ256rm
    0U,	// VCVTTPD2UDQZ256rmb
    3356U,	// VCVTTPD2UDQZ256rmbk
    4444U,	// VCVTTPD2UDQZ256rmbkz
    405U,	// VCVTTPD2UDQZ256rmk
    461U,	// VCVTTPD2UDQZ256rmkz
    0U,	// VCVTTPD2UDQZ256rr
    405U,	// VCVTTPD2UDQZ256rrk
    461U,	// VCVTTPD2UDQZ256rrkz
    0U,	// VCVTTPD2UDQZrm
    0U,	// VCVTTPD2UDQZrmb
    3356U,	// VCVTTPD2UDQZrmbk
    4444U,	// VCVTTPD2UDQZrmbkz
    405U,	// VCVTTPD2UDQZrmk
    461U,	// VCVTTPD2UDQZrmkz
    0U,	// VCVTTPD2UDQZrr
    0U,	// VCVTTPD2UDQZrrb
    405U,	// VCVTTPD2UDQZrrbk
    461U,	// VCVTTPD2UDQZrrbkz
    405U,	// VCVTTPD2UDQZrrk
    461U,	// VCVTTPD2UDQZrrkz
    0U,	// VCVTTPD2UQQZ128rm
    0U,	// VCVTTPD2UQQZ128rmb
    3356U,	// VCVTTPD2UQQZ128rmbk
    4444U,	// VCVTTPD2UQQZ128rmbkz
    405U,	// VCVTTPD2UQQZ128rmk
    461U,	// VCVTTPD2UQQZ128rmkz
    0U,	// VCVTTPD2UQQZ128rr
    405U,	// VCVTTPD2UQQZ128rrk
    461U,	// VCVTTPD2UQQZ128rrkz
    0U,	// VCVTTPD2UQQZ256rm
    0U,	// VCVTTPD2UQQZ256rmb
    3356U,	// VCVTTPD2UQQZ256rmbk
    4444U,	// VCVTTPD2UQQZ256rmbkz
    405U,	// VCVTTPD2UQQZ256rmk
    461U,	// VCVTTPD2UQQZ256rmkz
    0U,	// VCVTTPD2UQQZ256rr
    405U,	// VCVTTPD2UQQZ256rrk
    461U,	// VCVTTPD2UQQZ256rrkz
    0U,	// VCVTTPD2UQQZrm
    0U,	// VCVTTPD2UQQZrmb
    3356U,	// VCVTTPD2UQQZrmbk
    4444U,	// VCVTTPD2UQQZrmbkz
    405U,	// VCVTTPD2UQQZrmk
    461U,	// VCVTTPD2UQQZrmkz
    0U,	// VCVTTPD2UQQZrr
    0U,	// VCVTTPD2UQQZrrb
    405U,	// VCVTTPD2UQQZrrbk
    461U,	// VCVTTPD2UQQZrrbkz
    405U,	// VCVTTPD2UQQZrrk
    461U,	// VCVTTPD2UQQZrrkz
    0U,	// VCVTTPS2DQYrm
    0U,	// VCVTTPS2DQYrr
    0U,	// VCVTTPS2DQZ128rm
    0U,	// VCVTTPS2DQZ128rmb
    3356U,	// VCVTTPS2DQZ128rmbk
    4444U,	// VCVTTPS2DQZ128rmbkz
    405U,	// VCVTTPS2DQZ128rmk
    461U,	// VCVTTPS2DQZ128rmkz
    0U,	// VCVTTPS2DQZ128rr
    405U,	// VCVTTPS2DQZ128rrk
    461U,	// VCVTTPS2DQZ128rrkz
    0U,	// VCVTTPS2DQZ256rm
    0U,	// VCVTTPS2DQZ256rmb
    3356U,	// VCVTTPS2DQZ256rmbk
    4444U,	// VCVTTPS2DQZ256rmbkz
    405U,	// VCVTTPS2DQZ256rmk
    461U,	// VCVTTPS2DQZ256rmkz
    0U,	// VCVTTPS2DQZ256rr
    405U,	// VCVTTPS2DQZ256rrk
    461U,	// VCVTTPS2DQZ256rrkz
    0U,	// VCVTTPS2DQZrm
    0U,	// VCVTTPS2DQZrmb
    3356U,	// VCVTTPS2DQZrmbk
    4444U,	// VCVTTPS2DQZrmbkz
    405U,	// VCVTTPS2DQZrmk
    461U,	// VCVTTPS2DQZrmkz
    0U,	// VCVTTPS2DQZrr
    0U,	// VCVTTPS2DQZrrb
    405U,	// VCVTTPS2DQZrrbk
    461U,	// VCVTTPS2DQZrrbkz
    405U,	// VCVTTPS2DQZrrk
    461U,	// VCVTTPS2DQZrrkz
    0U,	// VCVTTPS2DQrm
    0U,	// VCVTTPS2DQrr
    0U,	// VCVTTPS2QQZ128rm
    0U,	// VCVTTPS2QQZ128rmb
    3356U,	// VCVTTPS2QQZ128rmbk
    4444U,	// VCVTTPS2QQZ128rmbkz
    3356U,	// VCVTTPS2QQZ128rmk
    4444U,	// VCVTTPS2QQZ128rmkz
    0U,	// VCVTTPS2QQZ128rr
    405U,	// VCVTTPS2QQZ128rrk
    461U,	// VCVTTPS2QQZ128rrkz
    0U,	// VCVTTPS2QQZ256rm
    0U,	// VCVTTPS2QQZ256rmb
    3356U,	// VCVTTPS2QQZ256rmbk
    4444U,	// VCVTTPS2QQZ256rmbkz
    405U,	// VCVTTPS2QQZ256rmk
    461U,	// VCVTTPS2QQZ256rmkz
    0U,	// VCVTTPS2QQZ256rr
    405U,	// VCVTTPS2QQZ256rrk
    461U,	// VCVTTPS2QQZ256rrkz
    0U,	// VCVTTPS2QQZrm
    0U,	// VCVTTPS2QQZrmb
    3356U,	// VCVTTPS2QQZrmbk
    4444U,	// VCVTTPS2QQZrmbkz
    405U,	// VCVTTPS2QQZrmk
    461U,	// VCVTTPS2QQZrmkz
    0U,	// VCVTTPS2QQZrr
    0U,	// VCVTTPS2QQZrrb
    405U,	// VCVTTPS2QQZrrbk
    461U,	// VCVTTPS2QQZrrbkz
    405U,	// VCVTTPS2QQZrrk
    461U,	// VCVTTPS2QQZrrkz
    0U,	// VCVTTPS2UDQZ128rm
    0U,	// VCVTTPS2UDQZ128rmb
    3356U,	// VCVTTPS2UDQZ128rmbk
    4444U,	// VCVTTPS2UDQZ128rmbkz
    405U,	// VCVTTPS2UDQZ128rmk
    461U,	// VCVTTPS2UDQZ128rmkz
    0U,	// VCVTTPS2UDQZ128rr
    405U,	// VCVTTPS2UDQZ128rrk
    461U,	// VCVTTPS2UDQZ128rrkz
    0U,	// VCVTTPS2UDQZ256rm
    0U,	// VCVTTPS2UDQZ256rmb
    3356U,	// VCVTTPS2UDQZ256rmbk
    4444U,	// VCVTTPS2UDQZ256rmbkz
    405U,	// VCVTTPS2UDQZ256rmk
    461U,	// VCVTTPS2UDQZ256rmkz
    0U,	// VCVTTPS2UDQZ256rr
    405U,	// VCVTTPS2UDQZ256rrk
    461U,	// VCVTTPS2UDQZ256rrkz
    0U,	// VCVTTPS2UDQZrm
    0U,	// VCVTTPS2UDQZrmb
    3356U,	// VCVTTPS2UDQZrmbk
    4444U,	// VCVTTPS2UDQZrmbkz
    405U,	// VCVTTPS2UDQZrmk
    461U,	// VCVTTPS2UDQZrmkz
    0U,	// VCVTTPS2UDQZrr
    0U,	// VCVTTPS2UDQZrrb
    405U,	// VCVTTPS2UDQZrrbk
    461U,	// VCVTTPS2UDQZrrbkz
    405U,	// VCVTTPS2UDQZrrk
    461U,	// VCVTTPS2UDQZrrkz
    0U,	// VCVTTPS2UQQZ128rm
    0U,	// VCVTTPS2UQQZ128rmb
    3356U,	// VCVTTPS2UQQZ128rmbk
    4444U,	// VCVTTPS2UQQZ128rmbkz
    3356U,	// VCVTTPS2UQQZ128rmk
    4444U,	// VCVTTPS2UQQZ128rmkz
    0U,	// VCVTTPS2UQQZ128rr
    405U,	// VCVTTPS2UQQZ128rrk
    461U,	// VCVTTPS2UQQZ128rrkz
    0U,	// VCVTTPS2UQQZ256rm
    0U,	// VCVTTPS2UQQZ256rmb
    3356U,	// VCVTTPS2UQQZ256rmbk
    4444U,	// VCVTTPS2UQQZ256rmbkz
    405U,	// VCVTTPS2UQQZ256rmk
    461U,	// VCVTTPS2UQQZ256rmkz
    0U,	// VCVTTPS2UQQZ256rr
    405U,	// VCVTTPS2UQQZ256rrk
    461U,	// VCVTTPS2UQQZ256rrkz
    0U,	// VCVTTPS2UQQZrm
    0U,	// VCVTTPS2UQQZrmb
    3356U,	// VCVTTPS2UQQZrmbk
    4444U,	// VCVTTPS2UQQZrmbkz
    405U,	// VCVTTPS2UQQZrmk
    461U,	// VCVTTPS2UQQZrmkz
    0U,	// VCVTTPS2UQQZrr
    0U,	// VCVTTPS2UQQZrrb
    405U,	// VCVTTPS2UQQZrrbk
    461U,	// VCVTTPS2UQQZrrbkz
    405U,	// VCVTTPS2UQQZrrk
    461U,	// VCVTTPS2UQQZrrkz
    0U,	// VCVTTSD2SI64Zrm
    0U,	// VCVTTSD2SI64Zrm_Int
    0U,	// VCVTTSD2SI64Zrr
    0U,	// VCVTTSD2SI64Zrr_Int
    0U,	// VCVTTSD2SI64Zrrb_Int
    0U,	// VCVTTSD2SI64rm
    0U,	// VCVTTSD2SI64rm_Int
    0U,	// VCVTTSD2SI64rr
    0U,	// VCVTTSD2SI64rr_Int
    0U,	// VCVTTSD2SIZrm
    0U,	// VCVTTSD2SIZrm_Int
    0U,	// VCVTTSD2SIZrr
    0U,	// VCVTTSD2SIZrr_Int
    0U,	// VCVTTSD2SIZrrb_Int
    0U,	// VCVTTSD2SIrm
    0U,	// VCVTTSD2SIrm_Int
    0U,	// VCVTTSD2SIrr
    0U,	// VCVTTSD2SIrr_Int
    0U,	// VCVTTSD2USI64Zrm
    0U,	// VCVTTSD2USI64Zrm_Int
    0U,	// VCVTTSD2USI64Zrr
    0U,	// VCVTTSD2USI64Zrr_Int
    0U,	// VCVTTSD2USI64Zrrb_Int
    0U,	// VCVTTSD2USIZrm
    0U,	// VCVTTSD2USIZrm_Int
    0U,	// VCVTTSD2USIZrr
    0U,	// VCVTTSD2USIZrr_Int
    0U,	// VCVTTSD2USIZrrb_Int
    0U,	// VCVTTSS2SI64Zrm
    0U,	// VCVTTSS2SI64Zrm_Int
    0U,	// VCVTTSS2SI64Zrr
    0U,	// VCVTTSS2SI64Zrr_Int
    0U,	// VCVTTSS2SI64Zrrb_Int
    0U,	// VCVTTSS2SI64rm
    0U,	// VCVTTSS2SI64rm_Int
    0U,	// VCVTTSS2SI64rr
    0U,	// VCVTTSS2SI64rr_Int
    0U,	// VCVTTSS2SIZrm
    0U,	// VCVTTSS2SIZrm_Int
    0U,	// VCVTTSS2SIZrr
    0U,	// VCVTTSS2SIZrr_Int
    0U,	// VCVTTSS2SIZrrb_Int
    0U,	// VCVTTSS2SIrm
    0U,	// VCVTTSS2SIrm_Int
    0U,	// VCVTTSS2SIrr
    0U,	// VCVTTSS2SIrr_Int
    0U,	// VCVTTSS2USI64Zrm
    0U,	// VCVTTSS2USI64Zrm_Int
    0U,	// VCVTTSS2USI64Zrr
    0U,	// VCVTTSS2USI64Zrr_Int
    0U,	// VCVTTSS2USI64Zrrb_Int
    0U,	// VCVTTSS2USIZrm
    0U,	// VCVTTSS2USIZrm_Int
    0U,	// VCVTTSS2USIZrr
    0U,	// VCVTTSS2USIZrr_Int
    0U,	// VCVTTSS2USIZrrb_Int
    0U,	// VCVTUDQ2PDZ128rm
    0U,	// VCVTUDQ2PDZ128rmb
    3356U,	// VCVTUDQ2PDZ128rmbk
    4444U,	// VCVTUDQ2PDZ128rmbkz
    3356U,	// VCVTUDQ2PDZ128rmk
    4444U,	// VCVTUDQ2PDZ128rmkz
    0U,	// VCVTUDQ2PDZ128rr
    405U,	// VCVTUDQ2PDZ128rrk
    461U,	// VCVTUDQ2PDZ128rrkz
    0U,	// VCVTUDQ2PDZ256rm
    0U,	// VCVTUDQ2PDZ256rmb
    3356U,	// VCVTUDQ2PDZ256rmbk
    4444U,	// VCVTUDQ2PDZ256rmbkz
    405U,	// VCVTUDQ2PDZ256rmk
    461U,	// VCVTUDQ2PDZ256rmkz
    0U,	// VCVTUDQ2PDZ256rr
    405U,	// VCVTUDQ2PDZ256rrk
    461U,	// VCVTUDQ2PDZ256rrkz
    0U,	// VCVTUDQ2PDZrm
    0U,	// VCVTUDQ2PDZrmb
    3356U,	// VCVTUDQ2PDZrmbk
    4444U,	// VCVTUDQ2PDZrmbkz
    405U,	// VCVTUDQ2PDZrmk
    461U,	// VCVTUDQ2PDZrmkz
    0U,	// VCVTUDQ2PDZrr
    405U,	// VCVTUDQ2PDZrrk
    461U,	// VCVTUDQ2PDZrrkz
    0U,	// VCVTUDQ2PSZ128rm
    0U,	// VCVTUDQ2PSZ128rmb
    3356U,	// VCVTUDQ2PSZ128rmbk
    4444U,	// VCVTUDQ2PSZ128rmbkz
    405U,	// VCVTUDQ2PSZ128rmk
    461U,	// VCVTUDQ2PSZ128rmkz
    0U,	// VCVTUDQ2PSZ128rr
    405U,	// VCVTUDQ2PSZ128rrk
    461U,	// VCVTUDQ2PSZ128rrkz
    0U,	// VCVTUDQ2PSZ256rm
    0U,	// VCVTUDQ2PSZ256rmb
    3356U,	// VCVTUDQ2PSZ256rmbk
    4444U,	// VCVTUDQ2PSZ256rmbkz
    405U,	// VCVTUDQ2PSZ256rmk
    461U,	// VCVTUDQ2PSZ256rmkz
    0U,	// VCVTUDQ2PSZ256rr
    405U,	// VCVTUDQ2PSZ256rrk
    461U,	// VCVTUDQ2PSZ256rrkz
    0U,	// VCVTUDQ2PSZrm
    0U,	// VCVTUDQ2PSZrmb
    3356U,	// VCVTUDQ2PSZrmbk
    4444U,	// VCVTUDQ2PSZrmbkz
    405U,	// VCVTUDQ2PSZrmk
    461U,	// VCVTUDQ2PSZrmkz
    0U,	// VCVTUDQ2PSZrr
    0U,	// VCVTUDQ2PSZrrb
    405U,	// VCVTUDQ2PSZrrbk
    461U,	// VCVTUDQ2PSZrrbkz
    405U,	// VCVTUDQ2PSZrrk
    461U,	// VCVTUDQ2PSZrrkz
    0U,	// VCVTUQQ2PDZ128rm
    0U,	// VCVTUQQ2PDZ128rmb
    3356U,	// VCVTUQQ2PDZ128rmbk
    4444U,	// VCVTUQQ2PDZ128rmbkz
    405U,	// VCVTUQQ2PDZ128rmk
    461U,	// VCVTUQQ2PDZ128rmkz
    0U,	// VCVTUQQ2PDZ128rr
    405U,	// VCVTUQQ2PDZ128rrk
    461U,	// VCVTUQQ2PDZ128rrkz
    0U,	// VCVTUQQ2PDZ256rm
    0U,	// VCVTUQQ2PDZ256rmb
    3356U,	// VCVTUQQ2PDZ256rmbk
    4444U,	// VCVTUQQ2PDZ256rmbkz
    405U,	// VCVTUQQ2PDZ256rmk
    461U,	// VCVTUQQ2PDZ256rmkz
    0U,	// VCVTUQQ2PDZ256rr
    405U,	// VCVTUQQ2PDZ256rrk
    461U,	// VCVTUQQ2PDZ256rrkz
    0U,	// VCVTUQQ2PDZrm
    0U,	// VCVTUQQ2PDZrmb
    3356U,	// VCVTUQQ2PDZrmbk
    4444U,	// VCVTUQQ2PDZrmbkz
    405U,	// VCVTUQQ2PDZrmk
    461U,	// VCVTUQQ2PDZrmkz
    0U,	// VCVTUQQ2PDZrr
    0U,	// VCVTUQQ2PDZrrb
    405U,	// VCVTUQQ2PDZrrbk
    461U,	// VCVTUQQ2PDZrrbkz
    405U,	// VCVTUQQ2PDZrrk
    461U,	// VCVTUQQ2PDZrrkz
    0U,	// VCVTUQQ2PSZ128rm
    0U,	// VCVTUQQ2PSZ128rmb
    3356U,	// VCVTUQQ2PSZ128rmbk
    4444U,	// VCVTUQQ2PSZ128rmbkz
    405U,	// VCVTUQQ2PSZ128rmk
    461U,	// VCVTUQQ2PSZ128rmkz
    0U,	// VCVTUQQ2PSZ128rr
    405U,	// VCVTUQQ2PSZ128rrk
    461U,	// VCVTUQQ2PSZ128rrkz
    0U,	// VCVTUQQ2PSZ256rm
    0U,	// VCVTUQQ2PSZ256rmb
    3356U,	// VCVTUQQ2PSZ256rmbk
    4444U,	// VCVTUQQ2PSZ256rmbkz
    405U,	// VCVTUQQ2PSZ256rmk
    461U,	// VCVTUQQ2PSZ256rmkz
    0U,	// VCVTUQQ2PSZ256rr
    405U,	// VCVTUQQ2PSZ256rrk
    461U,	// VCVTUQQ2PSZ256rrkz
    0U,	// VCVTUQQ2PSZrm
    0U,	// VCVTUQQ2PSZrmb
    3356U,	// VCVTUQQ2PSZrmbk
    4444U,	// VCVTUQQ2PSZrmbkz
    405U,	// VCVTUQQ2PSZrmk
    461U,	// VCVTUQQ2PSZrmkz
    0U,	// VCVTUQQ2PSZrr
    0U,	// VCVTUQQ2PSZrrb
    405U,	// VCVTUQQ2PSZrrbk
    461U,	// VCVTUQQ2PSZrrbkz
    405U,	// VCVTUQQ2PSZrrk
    461U,	// VCVTUQQ2PSZrrkz
    72U,	// VCVTUSI2SDZrm
    72U,	// VCVTUSI2SDZrm_Int
    4U,	// VCVTUSI2SDZrr
    4U,	// VCVTUSI2SDZrr_Int
    72U,	// VCVTUSI2SSZrm
    72U,	// VCVTUSI2SSZrm_Int
    4U,	// VCVTUSI2SSZrr
    4U,	// VCVTUSI2SSZrr_Int
    0U,	// VCVTUSI2SSZrrb_Int
    72U,	// VCVTUSI642SDZrm
    72U,	// VCVTUSI642SDZrm_Int
    4U,	// VCVTUSI642SDZrr
    4U,	// VCVTUSI642SDZrr_Int
    0U,	// VCVTUSI642SDZrrb_Int
    72U,	// VCVTUSI642SSZrm
    72U,	// VCVTUSI642SSZrm_Int
    4U,	// VCVTUSI642SSZrr
    4U,	// VCVTUSI642SSZrr_Int
    0U,	// VCVTUSI642SSZrrb_Int
    72U,	// VDBPSADBWZ128rmi
    1U,	// VDBPSADBWZ128rmik
    9348U,	// VDBPSADBWZ128rmikz
    18636U,	// VDBPSADBWZ128rri
    25U,	// VDBPSADBWZ128rrik
    26837U,	// VDBPSADBWZ128rrikz
    72U,	// VDBPSADBWZ256rmi
    1U,	// VDBPSADBWZ256rmik
    9348U,	// VDBPSADBWZ256rmikz
    18636U,	// VDBPSADBWZ256rri
    25U,	// VDBPSADBWZ256rrik
    26837U,	// VDBPSADBWZ256rrikz
    72U,	// VDBPSADBWZrmi
    1U,	// VDBPSADBWZrmik
    9348U,	// VDBPSADBWZrmikz
    18636U,	// VDBPSADBWZrri
    25U,	// VDBPSADBWZrrik
    26837U,	// VDBPSADBWZrrikz
    4U,	// VDIVPDYrm
    4U,	// VDIVPDYrr
    4U,	// VDIVPDZ128rm
    72U,	// VDIVPDZ128rmb
    133U,	// VDIVPDZ128rmbk
    9348U,	// VDIVPDZ128rmbkz
    0U,	// VDIVPDZ128rmk
    9348U,	// VDIVPDZ128rmkz
    4U,	// VDIVPDZ128rr
    0U,	// VDIVPDZ128rrk
    9348U,	// VDIVPDZ128rrkz
    4U,	// VDIVPDZ256rm
    72U,	// VDIVPDZ256rmb
    133U,	// VDIVPDZ256rmbk
    9348U,	// VDIVPDZ256rmbkz
    0U,	// VDIVPDZ256rmk
    9348U,	// VDIVPDZ256rmkz
    4U,	// VDIVPDZ256rr
    0U,	// VDIVPDZ256rrk
    9348U,	// VDIVPDZ256rrkz
    4U,	// VDIVPDZrm
    72U,	// VDIVPDZrmb
    133U,	// VDIVPDZrmbk
    9348U,	// VDIVPDZrmbkz
    0U,	// VDIVPDZrmk
    9348U,	// VDIVPDZrmkz
    4U,	// VDIVPDZrr
    4U,	// VDIVPDZrrb
    0U,	// VDIVPDZrrbk
    9348U,	// VDIVPDZrrbkz
    0U,	// VDIVPDZrrk
    9348U,	// VDIVPDZrrkz
    4U,	// VDIVPDrm
    4U,	// VDIVPDrr
    4U,	// VDIVPSYrm
    4U,	// VDIVPSYrr
    4U,	// VDIVPSZ128rm
    72U,	// VDIVPSZ128rmb
    133U,	// VDIVPSZ128rmbk
    9348U,	// VDIVPSZ128rmbkz
    0U,	// VDIVPSZ128rmk
    9348U,	// VDIVPSZ128rmkz
    4U,	// VDIVPSZ128rr
    0U,	// VDIVPSZ128rrk
    9348U,	// VDIVPSZ128rrkz
    4U,	// VDIVPSZ256rm
    72U,	// VDIVPSZ256rmb
    133U,	// VDIVPSZ256rmbk
    9348U,	// VDIVPSZ256rmbkz
    0U,	// VDIVPSZ256rmk
    9348U,	// VDIVPSZ256rmkz
    4U,	// VDIVPSZ256rr
    0U,	// VDIVPSZ256rrk
    9348U,	// VDIVPSZ256rrkz
    4U,	// VDIVPSZrm
    72U,	// VDIVPSZrmb
    133U,	// VDIVPSZrmbk
    9348U,	// VDIVPSZrmbkz
    0U,	// VDIVPSZrmk
    9348U,	// VDIVPSZrmkz
    4U,	// VDIVPSZrr
    4U,	// VDIVPSZrrb
    0U,	// VDIVPSZrrbk
    9348U,	// VDIVPSZrrbkz
    0U,	// VDIVPSZrrk
    9348U,	// VDIVPSZrrkz
    4U,	// VDIVPSrm
    4U,	// VDIVPSrr
    72U,	// VDIVSDZrm
    72U,	// VDIVSDZrm_Int
    133U,	// VDIVSDZrm_Intk
    9348U,	// VDIVSDZrm_Intkz
    4U,	// VDIVSDZrr
    4U,	// VDIVSDZrr_Int
    0U,	// VDIVSDZrr_Intk
    9348U,	// VDIVSDZrr_Intkz
    4U,	// VDIVSDZrrb_Int
    0U,	// VDIVSDZrrb_Intk
    9348U,	// VDIVSDZrrb_Intkz
    72U,	// VDIVSDrm
    72U,	// VDIVSDrm_Int
    4U,	// VDIVSDrr
    4U,	// VDIVSDrr_Int
    72U,	// VDIVSSZrm
    72U,	// VDIVSSZrm_Int
    133U,	// VDIVSSZrm_Intk
    9348U,	// VDIVSSZrm_Intkz
    4U,	// VDIVSSZrr
    4U,	// VDIVSSZrr_Int
    0U,	// VDIVSSZrr_Intk
    9348U,	// VDIVSSZrr_Intkz
    4U,	// VDIVSSZrrb_Int
    0U,	// VDIVSSZrrb_Intk
    9348U,	// VDIVSSZrrb_Intkz
    72U,	// VDIVSSrm
    72U,	// VDIVSSrm_Int
    4U,	// VDIVSSrr
    4U,	// VDIVSSrr_Int
    72U,	// VDPPDrmi
    18636U,	// VDPPDrri
    72U,	// VDPPSYrmi
    18636U,	// VDPPSYrri
    72U,	// VDPPSrmi
    18636U,	// VDPPSrri
    0U,	// VERRm
    0U,	// VERRr
    0U,	// VERWm
    0U,	// VERWr
    0U,	// VEXP2PDZm
    0U,	// VEXP2PDZmb
    3356U,	// VEXP2PDZmbk
    4444U,	// VEXP2PDZmbkz
    405U,	// VEXP2PDZmk
    461U,	// VEXP2PDZmkz
    0U,	// VEXP2PDZr
    0U,	// VEXP2PDZrb
    405U,	// VEXP2PDZrbk
    461U,	// VEXP2PDZrbkz
    405U,	// VEXP2PDZrk
    461U,	// VEXP2PDZrkz
    0U,	// VEXP2PSZm
    0U,	// VEXP2PSZmb
    3356U,	// VEXP2PSZmbk
    4444U,	// VEXP2PSZmbkz
    405U,	// VEXP2PSZmk
    461U,	// VEXP2PSZmkz
    0U,	// VEXP2PSZr
    0U,	// VEXP2PSZrb
    405U,	// VEXP2PSZrbk
    461U,	// VEXP2PSZrbkz
    405U,	// VEXP2PSZrk
    461U,	// VEXP2PSZrkz
    0U,	// VEXPANDPDZ128rm
    405U,	// VEXPANDPDZ128rmk
    461U,	// VEXPANDPDZ128rmkz
    0U,	// VEXPANDPDZ128rr
    405U,	// VEXPANDPDZ128rrk
    461U,	// VEXPANDPDZ128rrkz
    0U,	// VEXPANDPDZ256rm
    405U,	// VEXPANDPDZ256rmk
    461U,	// VEXPANDPDZ256rmkz
    0U,	// VEXPANDPDZ256rr
    405U,	// VEXPANDPDZ256rrk
    461U,	// VEXPANDPDZ256rrkz
    0U,	// VEXPANDPDZrm
    405U,	// VEXPANDPDZrmk
    461U,	// VEXPANDPDZrmkz
    0U,	// VEXPANDPDZrr
    405U,	// VEXPANDPDZrrk
    461U,	// VEXPANDPDZrrkz
    0U,	// VEXPANDPSZ128rm
    405U,	// VEXPANDPSZ128rmk
    461U,	// VEXPANDPSZ128rmkz
    0U,	// VEXPANDPSZ128rr
    405U,	// VEXPANDPSZ128rrk
    461U,	// VEXPANDPSZ128rrkz
    0U,	// VEXPANDPSZ256rm
    405U,	// VEXPANDPSZ256rmk
    461U,	// VEXPANDPSZ256rmkz
    0U,	// VEXPANDPSZ256rr
    405U,	// VEXPANDPSZ256rrk
    461U,	// VEXPANDPSZ256rrkz
    0U,	// VEXPANDPSZrm
    405U,	// VEXPANDPSZrmk
    461U,	// VEXPANDPSZrmkz
    0U,	// VEXPANDPSZrr
    405U,	// VEXPANDPSZrrk
    461U,	// VEXPANDPSZrrkz
    2U,	// VEXTRACTF128mr
    72U,	// VEXTRACTF128rr
    2U,	// VEXTRACTF32x4Z256mr
    542U,	// VEXTRACTF32x4Z256mrk
    72U,	// VEXTRACTF32x4Z256rr
    133U,	// VEXTRACTF32x4Z256rrk
    9348U,	// VEXTRACTF32x4Z256rrkz
    2U,	// VEXTRACTF32x4Zmr
    542U,	// VEXTRACTF32x4Zmrk
    72U,	// VEXTRACTF32x4Zrr
    133U,	// VEXTRACTF32x4Zrrk
    9348U,	// VEXTRACTF32x4Zrrkz
    2U,	// VEXTRACTF32x8Zmr
    542U,	// VEXTRACTF32x8Zmrk
    72U,	// VEXTRACTF32x8Zrr
    133U,	// VEXTRACTF32x8Zrrk
    9348U,	// VEXTRACTF32x8Zrrkz
    2U,	// VEXTRACTF64x2Z256mr
    542U,	// VEXTRACTF64x2Z256mrk
    72U,	// VEXTRACTF64x2Z256rr
    133U,	// VEXTRACTF64x2Z256rrk
    9348U,	// VEXTRACTF64x2Z256rrkz
    2U,	// VEXTRACTF64x2Zmr
    542U,	// VEXTRACTF64x2Zmrk
    72U,	// VEXTRACTF64x2Zrr
    133U,	// VEXTRACTF64x2Zrrk
    9348U,	// VEXTRACTF64x2Zrrkz
    2U,	// VEXTRACTF64x4Zmr
    542U,	// VEXTRACTF64x4Zmrk
    72U,	// VEXTRACTF64x4Zrr
    133U,	// VEXTRACTF64x4Zrrk
    9348U,	// VEXTRACTF64x4Zrrkz
    2U,	// VEXTRACTI128mr
    72U,	// VEXTRACTI128rr
    2U,	// VEXTRACTI32x4Z256mr
    542U,	// VEXTRACTI32x4Z256mrk
    72U,	// VEXTRACTI32x4Z256rr
    133U,	// VEXTRACTI32x4Z256rrk
    9348U,	// VEXTRACTI32x4Z256rrkz
    2U,	// VEXTRACTI32x4Zmr
    542U,	// VEXTRACTI32x4Zmrk
    72U,	// VEXTRACTI32x4Zrr
    133U,	// VEXTRACTI32x4Zrrk
    9348U,	// VEXTRACTI32x4Zrrkz
    2U,	// VEXTRACTI32x8Zmr
    542U,	// VEXTRACTI32x8Zmrk
    72U,	// VEXTRACTI32x8Zrr
    133U,	// VEXTRACTI32x8Zrrk
    9348U,	// VEXTRACTI32x8Zrrkz
    2U,	// VEXTRACTI64x2Z256mr
    542U,	// VEXTRACTI64x2Z256mrk
    72U,	// VEXTRACTI64x2Z256rr
    133U,	// VEXTRACTI64x2Z256rrk
    9348U,	// VEXTRACTI64x2Z256rrkz
    2U,	// VEXTRACTI64x2Zmr
    542U,	// VEXTRACTI64x2Zmrk
    72U,	// VEXTRACTI64x2Zrr
    133U,	// VEXTRACTI64x2Zrrk
    9348U,	// VEXTRACTI64x2Zrrkz
    2U,	// VEXTRACTI64x4Zmr
    542U,	// VEXTRACTI64x4Zmrk
    72U,	// VEXTRACTI64x4Zrr
    133U,	// VEXTRACTI64x4Zrrk
    9348U,	// VEXTRACTI64x4Zrrkz
    0U,	// VEXTRACTPSZmr
    72U,	// VEXTRACTPSZrr
    0U,	// VEXTRACTPSmr
    72U,	// VEXTRACTPSrr
    18645U,	// VFIXUPIMMPDZ128rmbi
    26833U,	// VFIXUPIMMPDZ128rmbik
    26833U,	// VFIXUPIMMPDZ128rmbikz
    4U,	// VFIXUPIMMPDZ128rmi
    1U,	// VFIXUPIMMPDZ128rmik
    2U,	// VFIXUPIMMPDZ128rmikz
    18645U,	// VFIXUPIMMPDZ128rri
    25U,	// VFIXUPIMMPDZ128rrik
    53U,	// VFIXUPIMMPDZ128rrikz
    18645U,	// VFIXUPIMMPDZ256rmbi
    26833U,	// VFIXUPIMMPDZ256rmbik
    26833U,	// VFIXUPIMMPDZ256rmbikz
    4U,	// VFIXUPIMMPDZ256rmi
    1U,	// VFIXUPIMMPDZ256rmik
    2U,	// VFIXUPIMMPDZ256rmikz
    18645U,	// VFIXUPIMMPDZ256rri
    25U,	// VFIXUPIMMPDZ256rrik
    53U,	// VFIXUPIMMPDZ256rrikz
    18645U,	// VFIXUPIMMPDZrmbi
    26833U,	// VFIXUPIMMPDZrmbik
    26833U,	// VFIXUPIMMPDZrmbikz
    4U,	// VFIXUPIMMPDZrmi
    1U,	// VFIXUPIMMPDZrmik
    2U,	// VFIXUPIMMPDZrmikz
    18645U,	// VFIXUPIMMPDZrri
    18645U,	// VFIXUPIMMPDZrrib
    25U,	// VFIXUPIMMPDZrribk
    53U,	// VFIXUPIMMPDZrribkz
    25U,	// VFIXUPIMMPDZrrik
    53U,	// VFIXUPIMMPDZrrikz
    18645U,	// VFIXUPIMMPSZ128rmbi
    26833U,	// VFIXUPIMMPSZ128rmbik
    26833U,	// VFIXUPIMMPSZ128rmbikz
    4U,	// VFIXUPIMMPSZ128rmi
    1U,	// VFIXUPIMMPSZ128rmik
    2U,	// VFIXUPIMMPSZ128rmikz
    18645U,	// VFIXUPIMMPSZ128rri
    25U,	// VFIXUPIMMPSZ128rrik
    53U,	// VFIXUPIMMPSZ128rrikz
    18645U,	// VFIXUPIMMPSZ256rmbi
    26833U,	// VFIXUPIMMPSZ256rmbik
    26833U,	// VFIXUPIMMPSZ256rmbikz
    4U,	// VFIXUPIMMPSZ256rmi
    1U,	// VFIXUPIMMPSZ256rmik
    2U,	// VFIXUPIMMPSZ256rmikz
    18645U,	// VFIXUPIMMPSZ256rri
    25U,	// VFIXUPIMMPSZ256rrik
    53U,	// VFIXUPIMMPSZ256rrikz
    18645U,	// VFIXUPIMMPSZrmbi
    26833U,	// VFIXUPIMMPSZrmbik
    26833U,	// VFIXUPIMMPSZrmbikz
    4U,	// VFIXUPIMMPSZrmi
    1U,	// VFIXUPIMMPSZrmik
    2U,	// VFIXUPIMMPSZrmikz
    18645U,	// VFIXUPIMMPSZrri
    18645U,	// VFIXUPIMMPSZrrib
    25U,	// VFIXUPIMMPSZrribk
    53U,	// VFIXUPIMMPSZrribkz
    25U,	// VFIXUPIMMPSZrrik
    53U,	// VFIXUPIMMPSZrrikz
    18644U,	// VFIXUPIMMSDZrmi
    26832U,	// VFIXUPIMMSDZrmik
    26832U,	// VFIXUPIMMSDZrmikz
    18645U,	// VFIXUPIMMSDZrri
    18645U,	// VFIXUPIMMSDZrrib
    25U,	// VFIXUPIMMSDZrribk
    53U,	// VFIXUPIMMSDZrribkz
    25U,	// VFIXUPIMMSDZrrik
    53U,	// VFIXUPIMMSDZrrikz
    18644U,	// VFIXUPIMMSSZrmi
    26832U,	// VFIXUPIMMSSZrmik
    26832U,	// VFIXUPIMMSSZrmikz
    18645U,	// VFIXUPIMMSSZrri
    18645U,	// VFIXUPIMMSSZrrib
    25U,	// VFIXUPIMMSSZrribk
    53U,	// VFIXUPIMMSSZrribkz
    25U,	// VFIXUPIMMSSZrrik
    53U,	// VFIXUPIMMSSZrrikz
    4U,	// VFMADD132PDYm
    4U,	// VFMADD132PDYr
    4U,	// VFMADD132PDZ128m
    4U,	// VFMADD132PDZ128mb
    133U,	// VFMADD132PDZ128mbk
    8325U,	// VFMADD132PDZ128mbkz
    0U,	// VFMADD132PDZ128mk
    0U,	// VFMADD132PDZ128mkz
    4U,	// VFMADD132PDZ128r
    0U,	// VFMADD132PDZ128rk
    0U,	// VFMADD132PDZ128rkz
    4U,	// VFMADD132PDZ256m
    4U,	// VFMADD132PDZ256mb
    133U,	// VFMADD132PDZ256mbk
    8325U,	// VFMADD132PDZ256mbkz
    0U,	// VFMADD132PDZ256mk
    0U,	// VFMADD132PDZ256mkz
    4U,	// VFMADD132PDZ256r
    0U,	// VFMADD132PDZ256rk
    0U,	// VFMADD132PDZ256rkz
    4U,	// VFMADD132PDZm
    4U,	// VFMADD132PDZmb
    133U,	// VFMADD132PDZmbk
    8325U,	// VFMADD132PDZmbkz
    0U,	// VFMADD132PDZmk
    0U,	// VFMADD132PDZmkz
    4U,	// VFMADD132PDZr
    4U,	// VFMADD132PDZrb
    0U,	// VFMADD132PDZrbk
    0U,	// VFMADD132PDZrbkz
    0U,	// VFMADD132PDZrk
    0U,	// VFMADD132PDZrkz
    4U,	// VFMADD132PDm
    4U,	// VFMADD132PDr
    4U,	// VFMADD132PSYm
    4U,	// VFMADD132PSYr
    4U,	// VFMADD132PSZ128m
    4U,	// VFMADD132PSZ128mb
    133U,	// VFMADD132PSZ128mbk
    8325U,	// VFMADD132PSZ128mbkz
    0U,	// VFMADD132PSZ128mk
    0U,	// VFMADD132PSZ128mkz
    4U,	// VFMADD132PSZ128r
    0U,	// VFMADD132PSZ128rk
    0U,	// VFMADD132PSZ128rkz
    4U,	// VFMADD132PSZ256m
    4U,	// VFMADD132PSZ256mb
    133U,	// VFMADD132PSZ256mbk
    8325U,	// VFMADD132PSZ256mbkz
    0U,	// VFMADD132PSZ256mk
    0U,	// VFMADD132PSZ256mkz
    4U,	// VFMADD132PSZ256r
    0U,	// VFMADD132PSZ256rk
    0U,	// VFMADD132PSZ256rkz
    4U,	// VFMADD132PSZm
    4U,	// VFMADD132PSZmb
    133U,	// VFMADD132PSZmbk
    8325U,	// VFMADD132PSZmbkz
    0U,	// VFMADD132PSZmk
    0U,	// VFMADD132PSZmkz
    4U,	// VFMADD132PSZr
    4U,	// VFMADD132PSZrb
    0U,	// VFMADD132PSZrbk
    0U,	// VFMADD132PSZrbkz
    0U,	// VFMADD132PSZrk
    0U,	// VFMADD132PSZrkz
    4U,	// VFMADD132PSm
    4U,	// VFMADD132PSr
    4U,	// VFMADD132SDZm
    4U,	// VFMADD132SDZm_Int
    133U,	// VFMADD132SDZm_Intk
    8325U,	// VFMADD132SDZm_Intkz
    4U,	// VFMADD132SDZr
    4U,	// VFMADD132SDZr_Int
    0U,	// VFMADD132SDZr_Intk
    0U,	// VFMADD132SDZr_Intkz
    4U,	// VFMADD132SDZrb
    4U,	// VFMADD132SDZrb_Int
    0U,	// VFMADD132SDZrb_Intk
    0U,	// VFMADD132SDZrb_Intkz
    4U,	// VFMADD132SDm
    4U,	// VFMADD132SDm_Int
    4U,	// VFMADD132SDr
    4U,	// VFMADD132SDr_Int
    4U,	// VFMADD132SSZm
    4U,	// VFMADD132SSZm_Int
    133U,	// VFMADD132SSZm_Intk
    8325U,	// VFMADD132SSZm_Intkz
    4U,	// VFMADD132SSZr
    4U,	// VFMADD132SSZr_Int
    0U,	// VFMADD132SSZr_Intk
    0U,	// VFMADD132SSZr_Intkz
    4U,	// VFMADD132SSZrb
    4U,	// VFMADD132SSZrb_Int
    0U,	// VFMADD132SSZrb_Intk
    0U,	// VFMADD132SSZrb_Intkz
    4U,	// VFMADD132SSm
    4U,	// VFMADD132SSm_Int
    4U,	// VFMADD132SSr
    4U,	// VFMADD132SSr_Int
    4U,	// VFMADD213PDYm
    4U,	// VFMADD213PDYr
    4U,	// VFMADD213PDZ128m
    4U,	// VFMADD213PDZ128mb
    133U,	// VFMADD213PDZ128mbk
    8325U,	// VFMADD213PDZ128mbkz
    0U,	// VFMADD213PDZ128mk
    0U,	// VFMADD213PDZ128mkz
    4U,	// VFMADD213PDZ128r
    0U,	// VFMADD213PDZ128rk
    0U,	// VFMADD213PDZ128rkz
    4U,	// VFMADD213PDZ256m
    4U,	// VFMADD213PDZ256mb
    133U,	// VFMADD213PDZ256mbk
    8325U,	// VFMADD213PDZ256mbkz
    0U,	// VFMADD213PDZ256mk
    0U,	// VFMADD213PDZ256mkz
    4U,	// VFMADD213PDZ256r
    0U,	// VFMADD213PDZ256rk
    0U,	// VFMADD213PDZ256rkz
    4U,	// VFMADD213PDZm
    4U,	// VFMADD213PDZmb
    133U,	// VFMADD213PDZmbk
    8325U,	// VFMADD213PDZmbkz
    0U,	// VFMADD213PDZmk
    0U,	// VFMADD213PDZmkz
    4U,	// VFMADD213PDZr
    4U,	// VFMADD213PDZrb
    0U,	// VFMADD213PDZrbk
    0U,	// VFMADD213PDZrbkz
    0U,	// VFMADD213PDZrk
    0U,	// VFMADD213PDZrkz
    4U,	// VFMADD213PDm
    4U,	// VFMADD213PDr
    4U,	// VFMADD213PSYm
    4U,	// VFMADD213PSYr
    4U,	// VFMADD213PSZ128m
    4U,	// VFMADD213PSZ128mb
    133U,	// VFMADD213PSZ128mbk
    8325U,	// VFMADD213PSZ128mbkz
    0U,	// VFMADD213PSZ128mk
    0U,	// VFMADD213PSZ128mkz
    4U,	// VFMADD213PSZ128r
    0U,	// VFMADD213PSZ128rk
    0U,	// VFMADD213PSZ128rkz
    4U,	// VFMADD213PSZ256m
    4U,	// VFMADD213PSZ256mb
    133U,	// VFMADD213PSZ256mbk
    8325U,	// VFMADD213PSZ256mbkz
    0U,	// VFMADD213PSZ256mk
    0U,	// VFMADD213PSZ256mkz
    4U,	// VFMADD213PSZ256r
    0U,	// VFMADD213PSZ256rk
    0U,	// VFMADD213PSZ256rkz
    4U,	// VFMADD213PSZm
    4U,	// VFMADD213PSZmb
    133U,	// VFMADD213PSZmbk
    8325U,	// VFMADD213PSZmbkz
    0U,	// VFMADD213PSZmk
    0U,	// VFMADD213PSZmkz
    4U,	// VFMADD213PSZr
    4U,	// VFMADD213PSZrb
    0U,	// VFMADD213PSZrbk
    0U,	// VFMADD213PSZrbkz
    0U,	// VFMADD213PSZrk
    0U,	// VFMADD213PSZrkz
    4U,	// VFMADD213PSm
    4U,	// VFMADD213PSr
    4U,	// VFMADD213SDZm
    4U,	// VFMADD213SDZm_Int
    133U,	// VFMADD213SDZm_Intk
    8325U,	// VFMADD213SDZm_Intkz
    4U,	// VFMADD213SDZr
    4U,	// VFMADD213SDZr_Int
    0U,	// VFMADD213SDZr_Intk
    0U,	// VFMADD213SDZr_Intkz
    4U,	// VFMADD213SDZrb
    4U,	// VFMADD213SDZrb_Int
    0U,	// VFMADD213SDZrb_Intk
    0U,	// VFMADD213SDZrb_Intkz
    4U,	// VFMADD213SDm
    4U,	// VFMADD213SDm_Int
    4U,	// VFMADD213SDr
    4U,	// VFMADD213SDr_Int
    4U,	// VFMADD213SSZm
    4U,	// VFMADD213SSZm_Int
    133U,	// VFMADD213SSZm_Intk
    8325U,	// VFMADD213SSZm_Intkz
    4U,	// VFMADD213SSZr
    4U,	// VFMADD213SSZr_Int
    0U,	// VFMADD213SSZr_Intk
    0U,	// VFMADD213SSZr_Intkz
    4U,	// VFMADD213SSZrb
    4U,	// VFMADD213SSZrb_Int
    0U,	// VFMADD213SSZrb_Intk
    0U,	// VFMADD213SSZrb_Intkz
    4U,	// VFMADD213SSm
    4U,	// VFMADD213SSm_Int
    4U,	// VFMADD213SSr
    4U,	// VFMADD213SSr_Int
    4U,	// VFMADD231PDYm
    4U,	// VFMADD231PDYr
    4U,	// VFMADD231PDZ128m
    4U,	// VFMADD231PDZ128mb
    133U,	// VFMADD231PDZ128mbk
    8325U,	// VFMADD231PDZ128mbkz
    0U,	// VFMADD231PDZ128mk
    0U,	// VFMADD231PDZ128mkz
    4U,	// VFMADD231PDZ128r
    0U,	// VFMADD231PDZ128rk
    0U,	// VFMADD231PDZ128rkz
    4U,	// VFMADD231PDZ256m
    4U,	// VFMADD231PDZ256mb
    133U,	// VFMADD231PDZ256mbk
    8325U,	// VFMADD231PDZ256mbkz
    0U,	// VFMADD231PDZ256mk
    0U,	// VFMADD231PDZ256mkz
    4U,	// VFMADD231PDZ256r
    0U,	// VFMADD231PDZ256rk
    0U,	// VFMADD231PDZ256rkz
    4U,	// VFMADD231PDZm
    4U,	// VFMADD231PDZmb
    133U,	// VFMADD231PDZmbk
    8325U,	// VFMADD231PDZmbkz
    0U,	// VFMADD231PDZmk
    0U,	// VFMADD231PDZmkz
    4U,	// VFMADD231PDZr
    4U,	// VFMADD231PDZrb
    0U,	// VFMADD231PDZrbk
    0U,	// VFMADD231PDZrbkz
    0U,	// VFMADD231PDZrk
    0U,	// VFMADD231PDZrkz
    4U,	// VFMADD231PDm
    4U,	// VFMADD231PDr
    4U,	// VFMADD231PSYm
    4U,	// VFMADD231PSYr
    4U,	// VFMADD231PSZ128m
    4U,	// VFMADD231PSZ128mb
    133U,	// VFMADD231PSZ128mbk
    8325U,	// VFMADD231PSZ128mbkz
    0U,	// VFMADD231PSZ128mk
    0U,	// VFMADD231PSZ128mkz
    4U,	// VFMADD231PSZ128r
    0U,	// VFMADD231PSZ128rk
    0U,	// VFMADD231PSZ128rkz
    4U,	// VFMADD231PSZ256m
    4U,	// VFMADD231PSZ256mb
    133U,	// VFMADD231PSZ256mbk
    8325U,	// VFMADD231PSZ256mbkz
    0U,	// VFMADD231PSZ256mk
    0U,	// VFMADD231PSZ256mkz
    4U,	// VFMADD231PSZ256r
    0U,	// VFMADD231PSZ256rk
    0U,	// VFMADD231PSZ256rkz
    4U,	// VFMADD231PSZm
    4U,	// VFMADD231PSZmb
    133U,	// VFMADD231PSZmbk
    8325U,	// VFMADD231PSZmbkz
    0U,	// VFMADD231PSZmk
    0U,	// VFMADD231PSZmkz
    4U,	// VFMADD231PSZr
    4U,	// VFMADD231PSZrb
    0U,	// VFMADD231PSZrbk
    0U,	// VFMADD231PSZrbkz
    0U,	// VFMADD231PSZrk
    0U,	// VFMADD231PSZrkz
    4U,	// VFMADD231PSm
    4U,	// VFMADD231PSr
    4U,	// VFMADD231SDZm
    4U,	// VFMADD231SDZm_Int
    133U,	// VFMADD231SDZm_Intk
    8325U,	// VFMADD231SDZm_Intkz
    4U,	// VFMADD231SDZr
    4U,	// VFMADD231SDZr_Int
    0U,	// VFMADD231SDZr_Intk
    0U,	// VFMADD231SDZr_Intkz
    4U,	// VFMADD231SDZrb
    4U,	// VFMADD231SDZrb_Int
    0U,	// VFMADD231SDZrb_Intk
    0U,	// VFMADD231SDZrb_Intkz
    4U,	// VFMADD231SDm
    4U,	// VFMADD231SDm_Int
    4U,	// VFMADD231SDr
    4U,	// VFMADD231SDr_Int
    4U,	// VFMADD231SSZm
    4U,	// VFMADD231SSZm_Int
    133U,	// VFMADD231SSZm_Intk
    8325U,	// VFMADD231SSZm_Intkz
    4U,	// VFMADD231SSZr
    4U,	// VFMADD231SSZr_Int
    0U,	// VFMADD231SSZr_Intk
    0U,	// VFMADD231SSZr_Intkz
    4U,	// VFMADD231SSZrb
    4U,	// VFMADD231SSZrb_Int
    0U,	// VFMADD231SSZrb_Intk
    0U,	// VFMADD231SSZrb_Intkz
    4U,	// VFMADD231SSm
    4U,	// VFMADD231SSm_Int
    4U,	// VFMADD231SSr
    4U,	// VFMADD231SSr_Int
    72U,	// VFMADDPD4Ymr
    18636U,	// VFMADDPD4Yrm
    18636U,	// VFMADDPD4Yrr
    18636U,	// VFMADDPD4Yrr_REV
    72U,	// VFMADDPD4mr
    18636U,	// VFMADDPD4rm
    18636U,	// VFMADDPD4rr
    18636U,	// VFMADDPD4rr_REV
    72U,	// VFMADDPS4Ymr
    18636U,	// VFMADDPS4Yrm
    18636U,	// VFMADDPS4Yrr
    18636U,	// VFMADDPS4Yrr_REV
    72U,	// VFMADDPS4mr
    18636U,	// VFMADDPS4rm
    18636U,	// VFMADDPS4rr
    18636U,	// VFMADDPS4rr_REV
    18636U,	// VFMADDSD4mr
    18636U,	// VFMADDSD4mr_Int
    18636U,	// VFMADDSD4rm
    18636U,	// VFMADDSD4rm_Int
    18636U,	// VFMADDSD4rr
    18636U,	// VFMADDSD4rr_Int
    18636U,	// VFMADDSD4rr_Int_REV
    18636U,	// VFMADDSD4rr_REV
    18636U,	// VFMADDSS4mr
    18636U,	// VFMADDSS4mr_Int
    18636U,	// VFMADDSS4rm
    18636U,	// VFMADDSS4rm_Int
    18636U,	// VFMADDSS4rr
    18636U,	// VFMADDSS4rr_Int
    18636U,	// VFMADDSS4rr_Int_REV
    18636U,	// VFMADDSS4rr_REV
    4U,	// VFMADDSUB132PDYm
    4U,	// VFMADDSUB132PDYr
    4U,	// VFMADDSUB132PDZ128m
    4U,	// VFMADDSUB132PDZ128mb
    133U,	// VFMADDSUB132PDZ128mbk
    8325U,	// VFMADDSUB132PDZ128mbkz
    0U,	// VFMADDSUB132PDZ128mk
    0U,	// VFMADDSUB132PDZ128mkz
    4U,	// VFMADDSUB132PDZ128r
    0U,	// VFMADDSUB132PDZ128rk
    0U,	// VFMADDSUB132PDZ128rkz
    4U,	// VFMADDSUB132PDZ256m
    4U,	// VFMADDSUB132PDZ256mb
    133U,	// VFMADDSUB132PDZ256mbk
    8325U,	// VFMADDSUB132PDZ256mbkz
    0U,	// VFMADDSUB132PDZ256mk
    0U,	// VFMADDSUB132PDZ256mkz
    4U,	// VFMADDSUB132PDZ256r
    0U,	// VFMADDSUB132PDZ256rk
    0U,	// VFMADDSUB132PDZ256rkz
    4U,	// VFMADDSUB132PDZm
    4U,	// VFMADDSUB132PDZmb
    133U,	// VFMADDSUB132PDZmbk
    8325U,	// VFMADDSUB132PDZmbkz
    0U,	// VFMADDSUB132PDZmk
    0U,	// VFMADDSUB132PDZmkz
    4U,	// VFMADDSUB132PDZr
    4U,	// VFMADDSUB132PDZrb
    0U,	// VFMADDSUB132PDZrbk
    0U,	// VFMADDSUB132PDZrbkz
    0U,	// VFMADDSUB132PDZrk
    0U,	// VFMADDSUB132PDZrkz
    4U,	// VFMADDSUB132PDm
    4U,	// VFMADDSUB132PDr
    4U,	// VFMADDSUB132PSYm
    4U,	// VFMADDSUB132PSYr
    4U,	// VFMADDSUB132PSZ128m
    4U,	// VFMADDSUB132PSZ128mb
    133U,	// VFMADDSUB132PSZ128mbk
    8325U,	// VFMADDSUB132PSZ128mbkz
    0U,	// VFMADDSUB132PSZ128mk
    0U,	// VFMADDSUB132PSZ128mkz
    4U,	// VFMADDSUB132PSZ128r
    0U,	// VFMADDSUB132PSZ128rk
    0U,	// VFMADDSUB132PSZ128rkz
    4U,	// VFMADDSUB132PSZ256m
    4U,	// VFMADDSUB132PSZ256mb
    133U,	// VFMADDSUB132PSZ256mbk
    8325U,	// VFMADDSUB132PSZ256mbkz
    0U,	// VFMADDSUB132PSZ256mk
    0U,	// VFMADDSUB132PSZ256mkz
    4U,	// VFMADDSUB132PSZ256r
    0U,	// VFMADDSUB132PSZ256rk
    0U,	// VFMADDSUB132PSZ256rkz
    4U,	// VFMADDSUB132PSZm
    4U,	// VFMADDSUB132PSZmb
    133U,	// VFMADDSUB132PSZmbk
    8325U,	// VFMADDSUB132PSZmbkz
    0U,	// VFMADDSUB132PSZmk
    0U,	// VFMADDSUB132PSZmkz
    4U,	// VFMADDSUB132PSZr
    4U,	// VFMADDSUB132PSZrb
    0U,	// VFMADDSUB132PSZrbk
    0U,	// VFMADDSUB132PSZrbkz
    0U,	// VFMADDSUB132PSZrk
    0U,	// VFMADDSUB132PSZrkz
    4U,	// VFMADDSUB132PSm
    4U,	// VFMADDSUB132PSr
    4U,	// VFMADDSUB213PDYm
    4U,	// VFMADDSUB213PDYr
    4U,	// VFMADDSUB213PDZ128m
    4U,	// VFMADDSUB213PDZ128mb
    133U,	// VFMADDSUB213PDZ128mbk
    8325U,	// VFMADDSUB213PDZ128mbkz
    0U,	// VFMADDSUB213PDZ128mk
    0U,	// VFMADDSUB213PDZ128mkz
    4U,	// VFMADDSUB213PDZ128r
    0U,	// VFMADDSUB213PDZ128rk
    0U,	// VFMADDSUB213PDZ128rkz
    4U,	// VFMADDSUB213PDZ256m
    4U,	// VFMADDSUB213PDZ256mb
    133U,	// VFMADDSUB213PDZ256mbk
    8325U,	// VFMADDSUB213PDZ256mbkz
    0U,	// VFMADDSUB213PDZ256mk
    0U,	// VFMADDSUB213PDZ256mkz
    4U,	// VFMADDSUB213PDZ256r
    0U,	// VFMADDSUB213PDZ256rk
    0U,	// VFMADDSUB213PDZ256rkz
    4U,	// VFMADDSUB213PDZm
    4U,	// VFMADDSUB213PDZmb
    133U,	// VFMADDSUB213PDZmbk
    8325U,	// VFMADDSUB213PDZmbkz
    0U,	// VFMADDSUB213PDZmk
    0U,	// VFMADDSUB213PDZmkz
    4U,	// VFMADDSUB213PDZr
    4U,	// VFMADDSUB213PDZrb
    0U,	// VFMADDSUB213PDZrbk
    0U,	// VFMADDSUB213PDZrbkz
    0U,	// VFMADDSUB213PDZrk
    0U,	// VFMADDSUB213PDZrkz
    4U,	// VFMADDSUB213PDm
    4U,	// VFMADDSUB213PDr
    4U,	// VFMADDSUB213PSYm
    4U,	// VFMADDSUB213PSYr
    4U,	// VFMADDSUB213PSZ128m
    4U,	// VFMADDSUB213PSZ128mb
    133U,	// VFMADDSUB213PSZ128mbk
    8325U,	// VFMADDSUB213PSZ128mbkz
    0U,	// VFMADDSUB213PSZ128mk
    0U,	// VFMADDSUB213PSZ128mkz
    4U,	// VFMADDSUB213PSZ128r
    0U,	// VFMADDSUB213PSZ128rk
    0U,	// VFMADDSUB213PSZ128rkz
    4U,	// VFMADDSUB213PSZ256m
    4U,	// VFMADDSUB213PSZ256mb
    133U,	// VFMADDSUB213PSZ256mbk
    8325U,	// VFMADDSUB213PSZ256mbkz
    0U,	// VFMADDSUB213PSZ256mk
    0U,	// VFMADDSUB213PSZ256mkz
    4U,	// VFMADDSUB213PSZ256r
    0U,	// VFMADDSUB213PSZ256rk
    0U,	// VFMADDSUB213PSZ256rkz
    4U,	// VFMADDSUB213PSZm
    4U,	// VFMADDSUB213PSZmb
    133U,	// VFMADDSUB213PSZmbk
    8325U,	// VFMADDSUB213PSZmbkz
    0U,	// VFMADDSUB213PSZmk
    0U,	// VFMADDSUB213PSZmkz
    4U,	// VFMADDSUB213PSZr
    4U,	// VFMADDSUB213PSZrb
    0U,	// VFMADDSUB213PSZrbk
    0U,	// VFMADDSUB213PSZrbkz
    0U,	// VFMADDSUB213PSZrk
    0U,	// VFMADDSUB213PSZrkz
    4U,	// VFMADDSUB213PSm
    4U,	// VFMADDSUB213PSr
    4U,	// VFMADDSUB231PDYm
    4U,	// VFMADDSUB231PDYr
    4U,	// VFMADDSUB231PDZ128m
    4U,	// VFMADDSUB231PDZ128mb
    133U,	// VFMADDSUB231PDZ128mbk
    8325U,	// VFMADDSUB231PDZ128mbkz
    0U,	// VFMADDSUB231PDZ128mk
    0U,	// VFMADDSUB231PDZ128mkz
    4U,	// VFMADDSUB231PDZ128r
    0U,	// VFMADDSUB231PDZ128rk
    0U,	// VFMADDSUB231PDZ128rkz
    4U,	// VFMADDSUB231PDZ256m
    4U,	// VFMADDSUB231PDZ256mb
    133U,	// VFMADDSUB231PDZ256mbk
    8325U,	// VFMADDSUB231PDZ256mbkz
    0U,	// VFMADDSUB231PDZ256mk
    0U,	// VFMADDSUB231PDZ256mkz
    4U,	// VFMADDSUB231PDZ256r
    0U,	// VFMADDSUB231PDZ256rk
    0U,	// VFMADDSUB231PDZ256rkz
    4U,	// VFMADDSUB231PDZm
    4U,	// VFMADDSUB231PDZmb
    133U,	// VFMADDSUB231PDZmbk
    8325U,	// VFMADDSUB231PDZmbkz
    0U,	// VFMADDSUB231PDZmk
    0U,	// VFMADDSUB231PDZmkz
    4U,	// VFMADDSUB231PDZr
    4U,	// VFMADDSUB231PDZrb
    0U,	// VFMADDSUB231PDZrbk
    0U,	// VFMADDSUB231PDZrbkz
    0U,	// VFMADDSUB231PDZrk
    0U,	// VFMADDSUB231PDZrkz
    4U,	// VFMADDSUB231PDm
    4U,	// VFMADDSUB231PDr
    4U,	// VFMADDSUB231PSYm
    4U,	// VFMADDSUB231PSYr
    4U,	// VFMADDSUB231PSZ128m
    4U,	// VFMADDSUB231PSZ128mb
    133U,	// VFMADDSUB231PSZ128mbk
    8325U,	// VFMADDSUB231PSZ128mbkz
    0U,	// VFMADDSUB231PSZ128mk
    0U,	// VFMADDSUB231PSZ128mkz
    4U,	// VFMADDSUB231PSZ128r
    0U,	// VFMADDSUB231PSZ128rk
    0U,	// VFMADDSUB231PSZ128rkz
    4U,	// VFMADDSUB231PSZ256m
    4U,	// VFMADDSUB231PSZ256mb
    133U,	// VFMADDSUB231PSZ256mbk
    8325U,	// VFMADDSUB231PSZ256mbkz
    0U,	// VFMADDSUB231PSZ256mk
    0U,	// VFMADDSUB231PSZ256mkz
    4U,	// VFMADDSUB231PSZ256r
    0U,	// VFMADDSUB231PSZ256rk
    0U,	// VFMADDSUB231PSZ256rkz
    4U,	// VFMADDSUB231PSZm
    4U,	// VFMADDSUB231PSZmb
    133U,	// VFMADDSUB231PSZmbk
    8325U,	// VFMADDSUB231PSZmbkz
    0U,	// VFMADDSUB231PSZmk
    0U,	// VFMADDSUB231PSZmkz
    4U,	// VFMADDSUB231PSZr
    4U,	// VFMADDSUB231PSZrb
    0U,	// VFMADDSUB231PSZrbk
    0U,	// VFMADDSUB231PSZrbkz
    0U,	// VFMADDSUB231PSZrk
    0U,	// VFMADDSUB231PSZrkz
    4U,	// VFMADDSUB231PSm
    4U,	// VFMADDSUB231PSr
    72U,	// VFMADDSUBPD4Ymr
    18636U,	// VFMADDSUBPD4Yrm
    18636U,	// VFMADDSUBPD4Yrr
    18636U,	// VFMADDSUBPD4Yrr_REV
    72U,	// VFMADDSUBPD4mr
    18636U,	// VFMADDSUBPD4rm
    18636U,	// VFMADDSUBPD4rr
    18636U,	// VFMADDSUBPD4rr_REV
    72U,	// VFMADDSUBPS4Ymr
    18636U,	// VFMADDSUBPS4Yrm
    18636U,	// VFMADDSUBPS4Yrr
    18636U,	// VFMADDSUBPS4Yrr_REV
    72U,	// VFMADDSUBPS4mr
    18636U,	// VFMADDSUBPS4rm
    18636U,	// VFMADDSUBPS4rr
    18636U,	// VFMADDSUBPS4rr_REV
    4U,	// VFMSUB132PDYm
    4U,	// VFMSUB132PDYr
    4U,	// VFMSUB132PDZ128m
    4U,	// VFMSUB132PDZ128mb
    133U,	// VFMSUB132PDZ128mbk
    8325U,	// VFMSUB132PDZ128mbkz
    0U,	// VFMSUB132PDZ128mk
    0U,	// VFMSUB132PDZ128mkz
    4U,	// VFMSUB132PDZ128r
    0U,	// VFMSUB132PDZ128rk
    0U,	// VFMSUB132PDZ128rkz
    4U,	// VFMSUB132PDZ256m
    4U,	// VFMSUB132PDZ256mb
    133U,	// VFMSUB132PDZ256mbk
    8325U,	// VFMSUB132PDZ256mbkz
    0U,	// VFMSUB132PDZ256mk
    0U,	// VFMSUB132PDZ256mkz
    4U,	// VFMSUB132PDZ256r
    0U,	// VFMSUB132PDZ256rk
    0U,	// VFMSUB132PDZ256rkz
    4U,	// VFMSUB132PDZm
    4U,	// VFMSUB132PDZmb
    133U,	// VFMSUB132PDZmbk
    8325U,	// VFMSUB132PDZmbkz
    0U,	// VFMSUB132PDZmk
    0U,	// VFMSUB132PDZmkz
    4U,	// VFMSUB132PDZr
    4U,	// VFMSUB132PDZrb
    0U,	// VFMSUB132PDZrbk
    0U,	// VFMSUB132PDZrbkz
    0U,	// VFMSUB132PDZrk
    0U,	// VFMSUB132PDZrkz
    4U,	// VFMSUB132PDm
    4U,	// VFMSUB132PDr
    4U,	// VFMSUB132PSYm
    4U,	// VFMSUB132PSYr
    4U,	// VFMSUB132PSZ128m
    4U,	// VFMSUB132PSZ128mb
    133U,	// VFMSUB132PSZ128mbk
    8325U,	// VFMSUB132PSZ128mbkz
    0U,	// VFMSUB132PSZ128mk
    0U,	// VFMSUB132PSZ128mkz
    4U,	// VFMSUB132PSZ128r
    0U,	// VFMSUB132PSZ128rk
    0U,	// VFMSUB132PSZ128rkz
    4U,	// VFMSUB132PSZ256m
    4U,	// VFMSUB132PSZ256mb
    133U,	// VFMSUB132PSZ256mbk
    8325U,	// VFMSUB132PSZ256mbkz
    0U,	// VFMSUB132PSZ256mk
    0U,	// VFMSUB132PSZ256mkz
    4U,	// VFMSUB132PSZ256r
    0U,	// VFMSUB132PSZ256rk
    0U,	// VFMSUB132PSZ256rkz
    4U,	// VFMSUB132PSZm
    4U,	// VFMSUB132PSZmb
    133U,	// VFMSUB132PSZmbk
    8325U,	// VFMSUB132PSZmbkz
    0U,	// VFMSUB132PSZmk
    0U,	// VFMSUB132PSZmkz
    4U,	// VFMSUB132PSZr
    4U,	// VFMSUB132PSZrb
    0U,	// VFMSUB132PSZrbk
    0U,	// VFMSUB132PSZrbkz
    0U,	// VFMSUB132PSZrk
    0U,	// VFMSUB132PSZrkz
    4U,	// VFMSUB132PSm
    4U,	// VFMSUB132PSr
    4U,	// VFMSUB132SDZm
    4U,	// VFMSUB132SDZm_Int
    133U,	// VFMSUB132SDZm_Intk
    8325U,	// VFMSUB132SDZm_Intkz
    4U,	// VFMSUB132SDZr
    4U,	// VFMSUB132SDZr_Int
    0U,	// VFMSUB132SDZr_Intk
    0U,	// VFMSUB132SDZr_Intkz
    4U,	// VFMSUB132SDZrb
    4U,	// VFMSUB132SDZrb_Int
    0U,	// VFMSUB132SDZrb_Intk
    0U,	// VFMSUB132SDZrb_Intkz
    4U,	// VFMSUB132SDm
    4U,	// VFMSUB132SDm_Int
    4U,	// VFMSUB132SDr
    4U,	// VFMSUB132SDr_Int
    4U,	// VFMSUB132SSZm
    4U,	// VFMSUB132SSZm_Int
    133U,	// VFMSUB132SSZm_Intk
    8325U,	// VFMSUB132SSZm_Intkz
    4U,	// VFMSUB132SSZr
    4U,	// VFMSUB132SSZr_Int
    0U,	// VFMSUB132SSZr_Intk
    0U,	// VFMSUB132SSZr_Intkz
    4U,	// VFMSUB132SSZrb
    4U,	// VFMSUB132SSZrb_Int
    0U,	// VFMSUB132SSZrb_Intk
    0U,	// VFMSUB132SSZrb_Intkz
    4U,	// VFMSUB132SSm
    4U,	// VFMSUB132SSm_Int
    4U,	// VFMSUB132SSr
    4U,	// VFMSUB132SSr_Int
    4U,	// VFMSUB213PDYm
    4U,	// VFMSUB213PDYr
    4U,	// VFMSUB213PDZ128m
    4U,	// VFMSUB213PDZ128mb
    133U,	// VFMSUB213PDZ128mbk
    8325U,	// VFMSUB213PDZ128mbkz
    0U,	// VFMSUB213PDZ128mk
    0U,	// VFMSUB213PDZ128mkz
    4U,	// VFMSUB213PDZ128r
    0U,	// VFMSUB213PDZ128rk
    0U,	// VFMSUB213PDZ128rkz
    4U,	// VFMSUB213PDZ256m
    4U,	// VFMSUB213PDZ256mb
    133U,	// VFMSUB213PDZ256mbk
    8325U,	// VFMSUB213PDZ256mbkz
    0U,	// VFMSUB213PDZ256mk
    0U,	// VFMSUB213PDZ256mkz
    4U,	// VFMSUB213PDZ256r
    0U,	// VFMSUB213PDZ256rk
    0U,	// VFMSUB213PDZ256rkz
    4U,	// VFMSUB213PDZm
    4U,	// VFMSUB213PDZmb
    133U,	// VFMSUB213PDZmbk
    8325U,	// VFMSUB213PDZmbkz
    0U,	// VFMSUB213PDZmk
    0U,	// VFMSUB213PDZmkz
    4U,	// VFMSUB213PDZr
    4U,	// VFMSUB213PDZrb
    0U,	// VFMSUB213PDZrbk
    0U,	// VFMSUB213PDZrbkz
    0U,	// VFMSUB213PDZrk
    0U,	// VFMSUB213PDZrkz
    4U,	// VFMSUB213PDm
    4U,	// VFMSUB213PDr
    4U,	// VFMSUB213PSYm
    4U,	// VFMSUB213PSYr
    4U,	// VFMSUB213PSZ128m
    4U,	// VFMSUB213PSZ128mb
    133U,	// VFMSUB213PSZ128mbk
    8325U,	// VFMSUB213PSZ128mbkz
    0U,	// VFMSUB213PSZ128mk
    0U,	// VFMSUB213PSZ128mkz
    4U,	// VFMSUB213PSZ128r
    0U,	// VFMSUB213PSZ128rk
    0U,	// VFMSUB213PSZ128rkz
    4U,	// VFMSUB213PSZ256m
    4U,	// VFMSUB213PSZ256mb
    133U,	// VFMSUB213PSZ256mbk
    8325U,	// VFMSUB213PSZ256mbkz
    0U,	// VFMSUB213PSZ256mk
    0U,	// VFMSUB213PSZ256mkz
    4U,	// VFMSUB213PSZ256r
    0U,	// VFMSUB213PSZ256rk
    0U,	// VFMSUB213PSZ256rkz
    4U,	// VFMSUB213PSZm
    4U,	// VFMSUB213PSZmb
    133U,	// VFMSUB213PSZmbk
    8325U,	// VFMSUB213PSZmbkz
    0U,	// VFMSUB213PSZmk
    0U,	// VFMSUB213PSZmkz
    4U,	// VFMSUB213PSZr
    4U,	// VFMSUB213PSZrb
    0U,	// VFMSUB213PSZrbk
    0U,	// VFMSUB213PSZrbkz
    0U,	// VFMSUB213PSZrk
    0U,	// VFMSUB213PSZrkz
    4U,	// VFMSUB213PSm
    4U,	// VFMSUB213PSr
    4U,	// VFMSUB213SDZm
    4U,	// VFMSUB213SDZm_Int
    133U,	// VFMSUB213SDZm_Intk
    8325U,	// VFMSUB213SDZm_Intkz
    4U,	// VFMSUB213SDZr
    4U,	// VFMSUB213SDZr_Int
    0U,	// VFMSUB213SDZr_Intk
    0U,	// VFMSUB213SDZr_Intkz
    4U,	// VFMSUB213SDZrb
    4U,	// VFMSUB213SDZrb_Int
    0U,	// VFMSUB213SDZrb_Intk
    0U,	// VFMSUB213SDZrb_Intkz
    4U,	// VFMSUB213SDm
    4U,	// VFMSUB213SDm_Int
    4U,	// VFMSUB213SDr
    4U,	// VFMSUB213SDr_Int
    4U,	// VFMSUB213SSZm
    4U,	// VFMSUB213SSZm_Int
    133U,	// VFMSUB213SSZm_Intk
    8325U,	// VFMSUB213SSZm_Intkz
    4U,	// VFMSUB213SSZr
    4U,	// VFMSUB213SSZr_Int
    0U,	// VFMSUB213SSZr_Intk
    0U,	// VFMSUB213SSZr_Intkz
    4U,	// VFMSUB213SSZrb
    4U,	// VFMSUB213SSZrb_Int
    0U,	// VFMSUB213SSZrb_Intk
    0U,	// VFMSUB213SSZrb_Intkz
    4U,	// VFMSUB213SSm
    4U,	// VFMSUB213SSm_Int
    4U,	// VFMSUB213SSr
    4U,	// VFMSUB213SSr_Int
    4U,	// VFMSUB231PDYm
    4U,	// VFMSUB231PDYr
    4U,	// VFMSUB231PDZ128m
    4U,	// VFMSUB231PDZ128mb
    133U,	// VFMSUB231PDZ128mbk
    8325U,	// VFMSUB231PDZ128mbkz
    0U,	// VFMSUB231PDZ128mk
    0U,	// VFMSUB231PDZ128mkz
    4U,	// VFMSUB231PDZ128r
    0U,	// VFMSUB231PDZ128rk
    0U,	// VFMSUB231PDZ128rkz
    4U,	// VFMSUB231PDZ256m
    4U,	// VFMSUB231PDZ256mb
    133U,	// VFMSUB231PDZ256mbk
    8325U,	// VFMSUB231PDZ256mbkz
    0U,	// VFMSUB231PDZ256mk
    0U,	// VFMSUB231PDZ256mkz
    4U,	// VFMSUB231PDZ256r
    0U,	// VFMSUB231PDZ256rk
    0U,	// VFMSUB231PDZ256rkz
    4U,	// VFMSUB231PDZm
    4U,	// VFMSUB231PDZmb
    133U,	// VFMSUB231PDZmbk
    8325U,	// VFMSUB231PDZmbkz
    0U,	// VFMSUB231PDZmk
    0U,	// VFMSUB231PDZmkz
    4U,	// VFMSUB231PDZr
    4U,	// VFMSUB231PDZrb
    0U,	// VFMSUB231PDZrbk
    0U,	// VFMSUB231PDZrbkz
    0U,	// VFMSUB231PDZrk
    0U,	// VFMSUB231PDZrkz
    4U,	// VFMSUB231PDm
    4U,	// VFMSUB231PDr
    4U,	// VFMSUB231PSYm
    4U,	// VFMSUB231PSYr
    4U,	// VFMSUB231PSZ128m
    4U,	// VFMSUB231PSZ128mb
    133U,	// VFMSUB231PSZ128mbk
    8325U,	// VFMSUB231PSZ128mbkz
    0U,	// VFMSUB231PSZ128mk
    0U,	// VFMSUB231PSZ128mkz
    4U,	// VFMSUB231PSZ128r
    0U,	// VFMSUB231PSZ128rk
    0U,	// VFMSUB231PSZ128rkz
    4U,	// VFMSUB231PSZ256m
    4U,	// VFMSUB231PSZ256mb
    133U,	// VFMSUB231PSZ256mbk
    8325U,	// VFMSUB231PSZ256mbkz
    0U,	// VFMSUB231PSZ256mk
    0U,	// VFMSUB231PSZ256mkz
    4U,	// VFMSUB231PSZ256r
    0U,	// VFMSUB231PSZ256rk
    0U,	// VFMSUB231PSZ256rkz
    4U,	// VFMSUB231PSZm
    4U,	// VFMSUB231PSZmb
    133U,	// VFMSUB231PSZmbk
    8325U,	// VFMSUB231PSZmbkz
    0U,	// VFMSUB231PSZmk
    0U,	// VFMSUB231PSZmkz
    4U,	// VFMSUB231PSZr
    4U,	// VFMSUB231PSZrb
    0U,	// VFMSUB231PSZrbk
    0U,	// VFMSUB231PSZrbkz
    0U,	// VFMSUB231PSZrk
    0U,	// VFMSUB231PSZrkz
    4U,	// VFMSUB231PSm
    4U,	// VFMSUB231PSr
    4U,	// VFMSUB231SDZm
    4U,	// VFMSUB231SDZm_Int
    133U,	// VFMSUB231SDZm_Intk
    8325U,	// VFMSUB231SDZm_Intkz
    4U,	// VFMSUB231SDZr
    4U,	// VFMSUB231SDZr_Int
    0U,	// VFMSUB231SDZr_Intk
    0U,	// VFMSUB231SDZr_Intkz
    4U,	// VFMSUB231SDZrb
    4U,	// VFMSUB231SDZrb_Int
    0U,	// VFMSUB231SDZrb_Intk
    0U,	// VFMSUB231SDZrb_Intkz
    4U,	// VFMSUB231SDm
    4U,	// VFMSUB231SDm_Int
    4U,	// VFMSUB231SDr
    4U,	// VFMSUB231SDr_Int
    4U,	// VFMSUB231SSZm
    4U,	// VFMSUB231SSZm_Int
    133U,	// VFMSUB231SSZm_Intk
    8325U,	// VFMSUB231SSZm_Intkz
    4U,	// VFMSUB231SSZr
    4U,	// VFMSUB231SSZr_Int
    0U,	// VFMSUB231SSZr_Intk
    0U,	// VFMSUB231SSZr_Intkz
    4U,	// VFMSUB231SSZrb
    4U,	// VFMSUB231SSZrb_Int
    0U,	// VFMSUB231SSZrb_Intk
    0U,	// VFMSUB231SSZrb_Intkz
    4U,	// VFMSUB231SSm
    4U,	// VFMSUB231SSm_Int
    4U,	// VFMSUB231SSr
    4U,	// VFMSUB231SSr_Int
    4U,	// VFMSUBADD132PDYm
    4U,	// VFMSUBADD132PDYr
    4U,	// VFMSUBADD132PDZ128m
    4U,	// VFMSUBADD132PDZ128mb
    133U,	// VFMSUBADD132PDZ128mbk
    8325U,	// VFMSUBADD132PDZ128mbkz
    0U,	// VFMSUBADD132PDZ128mk
    0U,	// VFMSUBADD132PDZ128mkz
    4U,	// VFMSUBADD132PDZ128r
    0U,	// VFMSUBADD132PDZ128rk
    0U,	// VFMSUBADD132PDZ128rkz
    4U,	// VFMSUBADD132PDZ256m
    4U,	// VFMSUBADD132PDZ256mb
    133U,	// VFMSUBADD132PDZ256mbk
    8325U,	// VFMSUBADD132PDZ256mbkz
    0U,	// VFMSUBADD132PDZ256mk
    0U,	// VFMSUBADD132PDZ256mkz
    4U,	// VFMSUBADD132PDZ256r
    0U,	// VFMSUBADD132PDZ256rk
    0U,	// VFMSUBADD132PDZ256rkz
    4U,	// VFMSUBADD132PDZm
    4U,	// VFMSUBADD132PDZmb
    133U,	// VFMSUBADD132PDZmbk
    8325U,	// VFMSUBADD132PDZmbkz
    0U,	// VFMSUBADD132PDZmk
    0U,	// VFMSUBADD132PDZmkz
    4U,	// VFMSUBADD132PDZr
    4U,	// VFMSUBADD132PDZrb
    0U,	// VFMSUBADD132PDZrbk
    0U,	// VFMSUBADD132PDZrbkz
    0U,	// VFMSUBADD132PDZrk
    0U,	// VFMSUBADD132PDZrkz
    4U,	// VFMSUBADD132PDm
    4U,	// VFMSUBADD132PDr
    4U,	// VFMSUBADD132PSYm
    4U,	// VFMSUBADD132PSYr
    4U,	// VFMSUBADD132PSZ128m
    4U,	// VFMSUBADD132PSZ128mb
    133U,	// VFMSUBADD132PSZ128mbk
    8325U,	// VFMSUBADD132PSZ128mbkz
    0U,	// VFMSUBADD132PSZ128mk
    0U,	// VFMSUBADD132PSZ128mkz
    4U,	// VFMSUBADD132PSZ128r
    0U,	// VFMSUBADD132PSZ128rk
    0U,	// VFMSUBADD132PSZ128rkz
    4U,	// VFMSUBADD132PSZ256m
    4U,	// VFMSUBADD132PSZ256mb
    133U,	// VFMSUBADD132PSZ256mbk
    8325U,	// VFMSUBADD132PSZ256mbkz
    0U,	// VFMSUBADD132PSZ256mk
    0U,	// VFMSUBADD132PSZ256mkz
    4U,	// VFMSUBADD132PSZ256r
    0U,	// VFMSUBADD132PSZ256rk
    0U,	// VFMSUBADD132PSZ256rkz
    4U,	// VFMSUBADD132PSZm
    4U,	// VFMSUBADD132PSZmb
    133U,	// VFMSUBADD132PSZmbk
    8325U,	// VFMSUBADD132PSZmbkz
    0U,	// VFMSUBADD132PSZmk
    0U,	// VFMSUBADD132PSZmkz
    4U,	// VFMSUBADD132PSZr
    4U,	// VFMSUBADD132PSZrb
    0U,	// VFMSUBADD132PSZrbk
    0U,	// VFMSUBADD132PSZrbkz
    0U,	// VFMSUBADD132PSZrk
    0U,	// VFMSUBADD132PSZrkz
    4U,	// VFMSUBADD132PSm
    4U,	// VFMSUBADD132PSr
    4U,	// VFMSUBADD213PDYm
    4U,	// VFMSUBADD213PDYr
    4U,	// VFMSUBADD213PDZ128m
    4U,	// VFMSUBADD213PDZ128mb
    133U,	// VFMSUBADD213PDZ128mbk
    8325U,	// VFMSUBADD213PDZ128mbkz
    0U,	// VFMSUBADD213PDZ128mk
    0U,	// VFMSUBADD213PDZ128mkz
    4U,	// VFMSUBADD213PDZ128r
    0U,	// VFMSUBADD213PDZ128rk
    0U,	// VFMSUBADD213PDZ128rkz
    4U,	// VFMSUBADD213PDZ256m
    4U,	// VFMSUBADD213PDZ256mb
    133U,	// VFMSUBADD213PDZ256mbk
    8325U,	// VFMSUBADD213PDZ256mbkz
    0U,	// VFMSUBADD213PDZ256mk
    0U,	// VFMSUBADD213PDZ256mkz
    4U,	// VFMSUBADD213PDZ256r
    0U,	// VFMSUBADD213PDZ256rk
    0U,	// VFMSUBADD213PDZ256rkz
    4U,	// VFMSUBADD213PDZm
    4U,	// VFMSUBADD213PDZmb
    133U,	// VFMSUBADD213PDZmbk
    8325U,	// VFMSUBADD213PDZmbkz
    0U,	// VFMSUBADD213PDZmk
    0U,	// VFMSUBADD213PDZmkz
    4U,	// VFMSUBADD213PDZr
    4U,	// VFMSUBADD213PDZrb
    0U,	// VFMSUBADD213PDZrbk
    0U,	// VFMSUBADD213PDZrbkz
    0U,	// VFMSUBADD213PDZrk
    0U,	// VFMSUBADD213PDZrkz
    4U,	// VFMSUBADD213PDm
    4U,	// VFMSUBADD213PDr
    4U,	// VFMSUBADD213PSYm
    4U,	// VFMSUBADD213PSYr
    4U,	// VFMSUBADD213PSZ128m
    4U,	// VFMSUBADD213PSZ128mb
    133U,	// VFMSUBADD213PSZ128mbk
    8325U,	// VFMSUBADD213PSZ128mbkz
    0U,	// VFMSUBADD213PSZ128mk
    0U,	// VFMSUBADD213PSZ128mkz
    4U,	// VFMSUBADD213PSZ128r
    0U,	// VFMSUBADD213PSZ128rk
    0U,	// VFMSUBADD213PSZ128rkz
    4U,	// VFMSUBADD213PSZ256m
    4U,	// VFMSUBADD213PSZ256mb
    133U,	// VFMSUBADD213PSZ256mbk
    8325U,	// VFMSUBADD213PSZ256mbkz
    0U,	// VFMSUBADD213PSZ256mk
    0U,	// VFMSUBADD213PSZ256mkz
    4U,	// VFMSUBADD213PSZ256r
    0U,	// VFMSUBADD213PSZ256rk
    0U,	// VFMSUBADD213PSZ256rkz
    4U,	// VFMSUBADD213PSZm
    4U,	// VFMSUBADD213PSZmb
    133U,	// VFMSUBADD213PSZmbk
    8325U,	// VFMSUBADD213PSZmbkz
    0U,	// VFMSUBADD213PSZmk
    0U,	// VFMSUBADD213PSZmkz
    4U,	// VFMSUBADD213PSZr
    4U,	// VFMSUBADD213PSZrb
    0U,	// VFMSUBADD213PSZrbk
    0U,	// VFMSUBADD213PSZrbkz
    0U,	// VFMSUBADD213PSZrk
    0U,	// VFMSUBADD213PSZrkz
    4U,	// VFMSUBADD213PSm
    4U,	// VFMSUBADD213PSr
    4U,	// VFMSUBADD231PDYm
    4U,	// VFMSUBADD231PDYr
    4U,	// VFMSUBADD231PDZ128m
    4U,	// VFMSUBADD231PDZ128mb
    133U,	// VFMSUBADD231PDZ128mbk
    8325U,	// VFMSUBADD231PDZ128mbkz
    0U,	// VFMSUBADD231PDZ128mk
    0U,	// VFMSUBADD231PDZ128mkz
    4U,	// VFMSUBADD231PDZ128r
    0U,	// VFMSUBADD231PDZ128rk
    0U,	// VFMSUBADD231PDZ128rkz
    4U,	// VFMSUBADD231PDZ256m
    4U,	// VFMSUBADD231PDZ256mb
    133U,	// VFMSUBADD231PDZ256mbk
    8325U,	// VFMSUBADD231PDZ256mbkz
    0U,	// VFMSUBADD231PDZ256mk
    0U,	// VFMSUBADD231PDZ256mkz
    4U,	// VFMSUBADD231PDZ256r
    0U,	// VFMSUBADD231PDZ256rk
    0U,	// VFMSUBADD231PDZ256rkz
    4U,	// VFMSUBADD231PDZm
    4U,	// VFMSUBADD231PDZmb
    133U,	// VFMSUBADD231PDZmbk
    8325U,	// VFMSUBADD231PDZmbkz
    0U,	// VFMSUBADD231PDZmk
    0U,	// VFMSUBADD231PDZmkz
    4U,	// VFMSUBADD231PDZr
    4U,	// VFMSUBADD231PDZrb
    0U,	// VFMSUBADD231PDZrbk
    0U,	// VFMSUBADD231PDZrbkz
    0U,	// VFMSUBADD231PDZrk
    0U,	// VFMSUBADD231PDZrkz
    4U,	// VFMSUBADD231PDm
    4U,	// VFMSUBADD231PDr
    4U,	// VFMSUBADD231PSYm
    4U,	// VFMSUBADD231PSYr
    4U,	// VFMSUBADD231PSZ128m
    4U,	// VFMSUBADD231PSZ128mb
    133U,	// VFMSUBADD231PSZ128mbk
    8325U,	// VFMSUBADD231PSZ128mbkz
    0U,	// VFMSUBADD231PSZ128mk
    0U,	// VFMSUBADD231PSZ128mkz
    4U,	// VFMSUBADD231PSZ128r
    0U,	// VFMSUBADD231PSZ128rk
    0U,	// VFMSUBADD231PSZ128rkz
    4U,	// VFMSUBADD231PSZ256m
    4U,	// VFMSUBADD231PSZ256mb
    133U,	// VFMSUBADD231PSZ256mbk
    8325U,	// VFMSUBADD231PSZ256mbkz
    0U,	// VFMSUBADD231PSZ256mk
    0U,	// VFMSUBADD231PSZ256mkz
    4U,	// VFMSUBADD231PSZ256r
    0U,	// VFMSUBADD231PSZ256rk
    0U,	// VFMSUBADD231PSZ256rkz
    4U,	// VFMSUBADD231PSZm
    4U,	// VFMSUBADD231PSZmb
    133U,	// VFMSUBADD231PSZmbk
    8325U,	// VFMSUBADD231PSZmbkz
    0U,	// VFMSUBADD231PSZmk
    0U,	// VFMSUBADD231PSZmkz
    4U,	// VFMSUBADD231PSZr
    4U,	// VFMSUBADD231PSZrb
    0U,	// VFMSUBADD231PSZrbk
    0U,	// VFMSUBADD231PSZrbkz
    0U,	// VFMSUBADD231PSZrk
    0U,	// VFMSUBADD231PSZrkz
    4U,	// VFMSUBADD231PSm
    4U,	// VFMSUBADD231PSr
    72U,	// VFMSUBADDPD4Ymr
    18636U,	// VFMSUBADDPD4Yrm
    18636U,	// VFMSUBADDPD4Yrr
    18636U,	// VFMSUBADDPD4Yrr_REV
    72U,	// VFMSUBADDPD4mr
    18636U,	// VFMSUBADDPD4rm
    18636U,	// VFMSUBADDPD4rr
    18636U,	// VFMSUBADDPD4rr_REV
    72U,	// VFMSUBADDPS4Ymr
    18636U,	// VFMSUBADDPS4Yrm
    18636U,	// VFMSUBADDPS4Yrr
    18636U,	// VFMSUBADDPS4Yrr_REV
    72U,	// VFMSUBADDPS4mr
    18636U,	// VFMSUBADDPS4rm
    18636U,	// VFMSUBADDPS4rr
    18636U,	// VFMSUBADDPS4rr_REV
    72U,	// VFMSUBPD4Ymr
    18636U,	// VFMSUBPD4Yrm
    18636U,	// VFMSUBPD4Yrr
    18636U,	// VFMSUBPD4Yrr_REV
    72U,	// VFMSUBPD4mr
    18636U,	// VFMSUBPD4rm
    18636U,	// VFMSUBPD4rr
    18636U,	// VFMSUBPD4rr_REV
    72U,	// VFMSUBPS4Ymr
    18636U,	// VFMSUBPS4Yrm
    18636U,	// VFMSUBPS4Yrr
    18636U,	// VFMSUBPS4Yrr_REV
    72U,	// VFMSUBPS4mr
    18636U,	// VFMSUBPS4rm
    18636U,	// VFMSUBPS4rr
    18636U,	// VFMSUBPS4rr_REV
    18636U,	// VFMSUBSD4mr
    18636U,	// VFMSUBSD4mr_Int
    18636U,	// VFMSUBSD4rm
    18636U,	// VFMSUBSD4rm_Int
    18636U,	// VFMSUBSD4rr
    18636U,	// VFMSUBSD4rr_Int
    18636U,	// VFMSUBSD4rr_Int_REV
    18636U,	// VFMSUBSD4rr_REV
    18636U,	// VFMSUBSS4mr
    18636U,	// VFMSUBSS4mr_Int
    18636U,	// VFMSUBSS4rm
    18636U,	// VFMSUBSS4rm_Int
    18636U,	// VFMSUBSS4rr
    18636U,	// VFMSUBSS4rr_Int
    18636U,	// VFMSUBSS4rr_Int_REV
    18636U,	// VFMSUBSS4rr_REV
    4U,	// VFNMADD132PDYm
    4U,	// VFNMADD132PDYr
    4U,	// VFNMADD132PDZ128m
    4U,	// VFNMADD132PDZ128mb
    133U,	// VFNMADD132PDZ128mbk
    8325U,	// VFNMADD132PDZ128mbkz
    0U,	// VFNMADD132PDZ128mk
    0U,	// VFNMADD132PDZ128mkz
    4U,	// VFNMADD132PDZ128r
    0U,	// VFNMADD132PDZ128rk
    0U,	// VFNMADD132PDZ128rkz
    4U,	// VFNMADD132PDZ256m
    4U,	// VFNMADD132PDZ256mb
    133U,	// VFNMADD132PDZ256mbk
    8325U,	// VFNMADD132PDZ256mbkz
    0U,	// VFNMADD132PDZ256mk
    0U,	// VFNMADD132PDZ256mkz
    4U,	// VFNMADD132PDZ256r
    0U,	// VFNMADD132PDZ256rk
    0U,	// VFNMADD132PDZ256rkz
    4U,	// VFNMADD132PDZm
    4U,	// VFNMADD132PDZmb
    133U,	// VFNMADD132PDZmbk
    8325U,	// VFNMADD132PDZmbkz
    0U,	// VFNMADD132PDZmk
    0U,	// VFNMADD132PDZmkz
    4U,	// VFNMADD132PDZr
    4U,	// VFNMADD132PDZrb
    0U,	// VFNMADD132PDZrbk
    0U,	// VFNMADD132PDZrbkz
    0U,	// VFNMADD132PDZrk
    0U,	// VFNMADD132PDZrkz
    4U,	// VFNMADD132PDm
    4U,	// VFNMADD132PDr
    4U,	// VFNMADD132PSYm
    4U,	// VFNMADD132PSYr
    4U,	// VFNMADD132PSZ128m
    4U,	// VFNMADD132PSZ128mb
    133U,	// VFNMADD132PSZ128mbk
    8325U,	// VFNMADD132PSZ128mbkz
    0U,	// VFNMADD132PSZ128mk
    0U,	// VFNMADD132PSZ128mkz
    4U,	// VFNMADD132PSZ128r
    0U,	// VFNMADD132PSZ128rk
    0U,	// VFNMADD132PSZ128rkz
    4U,	// VFNMADD132PSZ256m
    4U,	// VFNMADD132PSZ256mb
    133U,	// VFNMADD132PSZ256mbk
    8325U,	// VFNMADD132PSZ256mbkz
    0U,	// VFNMADD132PSZ256mk
    0U,	// VFNMADD132PSZ256mkz
    4U,	// VFNMADD132PSZ256r
    0U,	// VFNMADD132PSZ256rk
    0U,	// VFNMADD132PSZ256rkz
    4U,	// VFNMADD132PSZm
    4U,	// VFNMADD132PSZmb
    133U,	// VFNMADD132PSZmbk
    8325U,	// VFNMADD132PSZmbkz
    0U,	// VFNMADD132PSZmk
    0U,	// VFNMADD132PSZmkz
    4U,	// VFNMADD132PSZr
    4U,	// VFNMADD132PSZrb
    0U,	// VFNMADD132PSZrbk
    0U,	// VFNMADD132PSZrbkz
    0U,	// VFNMADD132PSZrk
    0U,	// VFNMADD132PSZrkz
    4U,	// VFNMADD132PSm
    4U,	// VFNMADD132PSr
    4U,	// VFNMADD132SDZm
    4U,	// VFNMADD132SDZm_Int
    133U,	// VFNMADD132SDZm_Intk
    8325U,	// VFNMADD132SDZm_Intkz
    4U,	// VFNMADD132SDZr
    4U,	// VFNMADD132SDZr_Int
    0U,	// VFNMADD132SDZr_Intk
    0U,	// VFNMADD132SDZr_Intkz
    4U,	// VFNMADD132SDZrb
    4U,	// VFNMADD132SDZrb_Int
    0U,	// VFNMADD132SDZrb_Intk
    0U,	// VFNMADD132SDZrb_Intkz
    4U,	// VFNMADD132SDm
    4U,	// VFNMADD132SDm_Int
    4U,	// VFNMADD132SDr
    4U,	// VFNMADD132SDr_Int
    4U,	// VFNMADD132SSZm
    4U,	// VFNMADD132SSZm_Int
    133U,	// VFNMADD132SSZm_Intk
    8325U,	// VFNMADD132SSZm_Intkz
    4U,	// VFNMADD132SSZr
    4U,	// VFNMADD132SSZr_Int
    0U,	// VFNMADD132SSZr_Intk
    0U,	// VFNMADD132SSZr_Intkz
    4U,	// VFNMADD132SSZrb
    4U,	// VFNMADD132SSZrb_Int
    0U,	// VFNMADD132SSZrb_Intk
    0U,	// VFNMADD132SSZrb_Intkz
    4U,	// VFNMADD132SSm
    4U,	// VFNMADD132SSm_Int
    4U,	// VFNMADD132SSr
    4U,	// VFNMADD132SSr_Int
    4U,	// VFNMADD213PDYm
    4U,	// VFNMADD213PDYr
    4U,	// VFNMADD213PDZ128m
    4U,	// VFNMADD213PDZ128mb
    133U,	// VFNMADD213PDZ128mbk
    8325U,	// VFNMADD213PDZ128mbkz
    0U,	// VFNMADD213PDZ128mk
    0U,	// VFNMADD213PDZ128mkz
    4U,	// VFNMADD213PDZ128r
    0U,	// VFNMADD213PDZ128rk
    0U,	// VFNMADD213PDZ128rkz
    4U,	// VFNMADD213PDZ256m
    4U,	// VFNMADD213PDZ256mb
    133U,	// VFNMADD213PDZ256mbk
    8325U,	// VFNMADD213PDZ256mbkz
    0U,	// VFNMADD213PDZ256mk
    0U,	// VFNMADD213PDZ256mkz
    4U,	// VFNMADD213PDZ256r
    0U,	// VFNMADD213PDZ256rk
    0U,	// VFNMADD213PDZ256rkz
    4U,	// VFNMADD213PDZm
    4U,	// VFNMADD213PDZmb
    133U,	// VFNMADD213PDZmbk
    8325U,	// VFNMADD213PDZmbkz
    0U,	// VFNMADD213PDZmk
    0U,	// VFNMADD213PDZmkz
    4U,	// VFNMADD213PDZr
    4U,	// VFNMADD213PDZrb
    0U,	// VFNMADD213PDZrbk
    0U,	// VFNMADD213PDZrbkz
    0U,	// VFNMADD213PDZrk
    0U,	// VFNMADD213PDZrkz
    4U,	// VFNMADD213PDm
    4U,	// VFNMADD213PDr
    4U,	// VFNMADD213PSYm
    4U,	// VFNMADD213PSYr
    4U,	// VFNMADD213PSZ128m
    4U,	// VFNMADD213PSZ128mb
    133U,	// VFNMADD213PSZ128mbk
    8325U,	// VFNMADD213PSZ128mbkz
    0U,	// VFNMADD213PSZ128mk
    0U,	// VFNMADD213PSZ128mkz
    4U,	// VFNMADD213PSZ128r
    0U,	// VFNMADD213PSZ128rk
    0U,	// VFNMADD213PSZ128rkz
    4U,	// VFNMADD213PSZ256m
    4U,	// VFNMADD213PSZ256mb
    133U,	// VFNMADD213PSZ256mbk
    8325U,	// VFNMADD213PSZ256mbkz
    0U,	// VFNMADD213PSZ256mk
    0U,	// VFNMADD213PSZ256mkz
    4U,	// VFNMADD213PSZ256r
    0U,	// VFNMADD213PSZ256rk
    0U,	// VFNMADD213PSZ256rkz
    4U,	// VFNMADD213PSZm
    4U,	// VFNMADD213PSZmb
    133U,	// VFNMADD213PSZmbk
    8325U,	// VFNMADD213PSZmbkz
    0U,	// VFNMADD213PSZmk
    0U,	// VFNMADD213PSZmkz
    4U,	// VFNMADD213PSZr
    4U,	// VFNMADD213PSZrb
    0U,	// VFNMADD213PSZrbk
    0U,	// VFNMADD213PSZrbkz
    0U,	// VFNMADD213PSZrk
    0U,	// VFNMADD213PSZrkz
    4U,	// VFNMADD213PSm
    4U,	// VFNMADD213PSr
    4U,	// VFNMADD213SDZm
    4U,	// VFNMADD213SDZm_Int
    133U,	// VFNMADD213SDZm_Intk
    8325U,	// VFNMADD213SDZm_Intkz
    4U,	// VFNMADD213SDZr
    4U,	// VFNMADD213SDZr_Int
    0U,	// VFNMADD213SDZr_Intk
    0U,	// VFNMADD213SDZr_Intkz
    4U,	// VFNMADD213SDZrb
    4U,	// VFNMADD213SDZrb_Int
    0U,	// VFNMADD213SDZrb_Intk
    0U,	// VFNMADD213SDZrb_Intkz
    4U,	// VFNMADD213SDm
    4U,	// VFNMADD213SDm_Int
    4U,	// VFNMADD213SDr
    4U,	// VFNMADD213SDr_Int
    4U,	// VFNMADD213SSZm
    4U,	// VFNMADD213SSZm_Int
    133U,	// VFNMADD213SSZm_Intk
    8325U,	// VFNMADD213SSZm_Intkz
    4U,	// VFNMADD213SSZr
    4U,	// VFNMADD213SSZr_Int
    0U,	// VFNMADD213SSZr_Intk
    0U,	// VFNMADD213SSZr_Intkz
    4U,	// VFNMADD213SSZrb
    4U,	// VFNMADD213SSZrb_Int
    0U,	// VFNMADD213SSZrb_Intk
    0U,	// VFNMADD213SSZrb_Intkz
    4U,	// VFNMADD213SSm
    4U,	// VFNMADD213SSm_Int
    4U,	// VFNMADD213SSr
    4U,	// VFNMADD213SSr_Int
    4U,	// VFNMADD231PDYm
    4U,	// VFNMADD231PDYr
    4U,	// VFNMADD231PDZ128m
    4U,	// VFNMADD231PDZ128mb
    133U,	// VFNMADD231PDZ128mbk
    8325U,	// VFNMADD231PDZ128mbkz
    0U,	// VFNMADD231PDZ128mk
    0U,	// VFNMADD231PDZ128mkz
    4U,	// VFNMADD231PDZ128r
    0U,	// VFNMADD231PDZ128rk
    0U,	// VFNMADD231PDZ128rkz
    4U,	// VFNMADD231PDZ256m
    4U,	// VFNMADD231PDZ256mb
    133U,	// VFNMADD231PDZ256mbk
    8325U,	// VFNMADD231PDZ256mbkz
    0U,	// VFNMADD231PDZ256mk
    0U,	// VFNMADD231PDZ256mkz
    4U,	// VFNMADD231PDZ256r
    0U,	// VFNMADD231PDZ256rk
    0U,	// VFNMADD231PDZ256rkz
    4U,	// VFNMADD231PDZm
    4U,	// VFNMADD231PDZmb
    133U,	// VFNMADD231PDZmbk
    8325U,	// VFNMADD231PDZmbkz
    0U,	// VFNMADD231PDZmk
    0U,	// VFNMADD231PDZmkz
    4U,	// VFNMADD231PDZr
    4U,	// VFNMADD231PDZrb
    0U,	// VFNMADD231PDZrbk
    0U,	// VFNMADD231PDZrbkz
    0U,	// VFNMADD231PDZrk
    0U,	// VFNMADD231PDZrkz
    4U,	// VFNMADD231PDm
    4U,	// VFNMADD231PDr
    4U,	// VFNMADD231PSYm
    4U,	// VFNMADD231PSYr
    4U,	// VFNMADD231PSZ128m
    4U,	// VFNMADD231PSZ128mb
    133U,	// VFNMADD231PSZ128mbk
    8325U,	// VFNMADD231PSZ128mbkz
    0U,	// VFNMADD231PSZ128mk
    0U,	// VFNMADD231PSZ128mkz
    4U,	// VFNMADD231PSZ128r
    0U,	// VFNMADD231PSZ128rk
    0U,	// VFNMADD231PSZ128rkz
    4U,	// VFNMADD231PSZ256m
    4U,	// VFNMADD231PSZ256mb
    133U,	// VFNMADD231PSZ256mbk
    8325U,	// VFNMADD231PSZ256mbkz
    0U,	// VFNMADD231PSZ256mk
    0U,	// VFNMADD231PSZ256mkz
    4U,	// VFNMADD231PSZ256r
    0U,	// VFNMADD231PSZ256rk
    0U,	// VFNMADD231PSZ256rkz
    4U,	// VFNMADD231PSZm
    4U,	// VFNMADD231PSZmb
    133U,	// VFNMADD231PSZmbk
    8325U,	// VFNMADD231PSZmbkz
    0U,	// VFNMADD231PSZmk
    0U,	// VFNMADD231PSZmkz
    4U,	// VFNMADD231PSZr
    4U,	// VFNMADD231PSZrb
    0U,	// VFNMADD231PSZrbk
    0U,	// VFNMADD231PSZrbkz
    0U,	// VFNMADD231PSZrk
    0U,	// VFNMADD231PSZrkz
    4U,	// VFNMADD231PSm
    4U,	// VFNMADD231PSr
    4U,	// VFNMADD231SDZm
    4U,	// VFNMADD231SDZm_Int
    133U,	// VFNMADD231SDZm_Intk
    8325U,	// VFNMADD231SDZm_Intkz
    4U,	// VFNMADD231SDZr
    4U,	// VFNMADD231SDZr_Int
    0U,	// VFNMADD231SDZr_Intk
    0U,	// VFNMADD231SDZr_Intkz
    4U,	// VFNMADD231SDZrb
    4U,	// VFNMADD231SDZrb_Int
    0U,	// VFNMADD231SDZrb_Intk
    0U,	// VFNMADD231SDZrb_Intkz
    4U,	// VFNMADD231SDm
    4U,	// VFNMADD231SDm_Int
    4U,	// VFNMADD231SDr
    4U,	// VFNMADD231SDr_Int
    4U,	// VFNMADD231SSZm
    4U,	// VFNMADD231SSZm_Int
    133U,	// VFNMADD231SSZm_Intk
    8325U,	// VFNMADD231SSZm_Intkz
    4U,	// VFNMADD231SSZr
    4U,	// VFNMADD231SSZr_Int
    0U,	// VFNMADD231SSZr_Intk
    0U,	// VFNMADD231SSZr_Intkz
    4U,	// VFNMADD231SSZrb
    4U,	// VFNMADD231SSZrb_Int
    0U,	// VFNMADD231SSZrb_Intk
    0U,	// VFNMADD231SSZrb_Intkz
    4U,	// VFNMADD231SSm
    4U,	// VFNMADD231SSm_Int
    4U,	// VFNMADD231SSr
    4U,	// VFNMADD231SSr_Int
    72U,	// VFNMADDPD4Ymr
    18636U,	// VFNMADDPD4Yrm
    18636U,	// VFNMADDPD4Yrr
    18636U,	// VFNMADDPD4Yrr_REV
    72U,	// VFNMADDPD4mr
    18636U,	// VFNMADDPD4rm
    18636U,	// VFNMADDPD4rr
    18636U,	// VFNMADDPD4rr_REV
    72U,	// VFNMADDPS4Ymr
    18636U,	// VFNMADDPS4Yrm
    18636U,	// VFNMADDPS4Yrr
    18636U,	// VFNMADDPS4Yrr_REV
    72U,	// VFNMADDPS4mr
    18636U,	// VFNMADDPS4rm
    18636U,	// VFNMADDPS4rr
    18636U,	// VFNMADDPS4rr_REV
    18636U,	// VFNMADDSD4mr
    18636U,	// VFNMADDSD4mr_Int
    18636U,	// VFNMADDSD4rm
    18636U,	// VFNMADDSD4rm_Int
    18636U,	// VFNMADDSD4rr
    18636U,	// VFNMADDSD4rr_Int
    18636U,	// VFNMADDSD4rr_Int_REV
    18636U,	// VFNMADDSD4rr_REV
    18636U,	// VFNMADDSS4mr
    18636U,	// VFNMADDSS4mr_Int
    18636U,	// VFNMADDSS4rm
    18636U,	// VFNMADDSS4rm_Int
    18636U,	// VFNMADDSS4rr
    18636U,	// VFNMADDSS4rr_Int
    18636U,	// VFNMADDSS4rr_Int_REV
    18636U,	// VFNMADDSS4rr_REV
    4U,	// VFNMSUB132PDYm
    4U,	// VFNMSUB132PDYr
    4U,	// VFNMSUB132PDZ128m
    4U,	// VFNMSUB132PDZ128mb
    133U,	// VFNMSUB132PDZ128mbk
    8325U,	// VFNMSUB132PDZ128mbkz
    0U,	// VFNMSUB132PDZ128mk
    0U,	// VFNMSUB132PDZ128mkz
    4U,	// VFNMSUB132PDZ128r
    0U,	// VFNMSUB132PDZ128rk
    0U,	// VFNMSUB132PDZ128rkz
    4U,	// VFNMSUB132PDZ256m
    4U,	// VFNMSUB132PDZ256mb
    133U,	// VFNMSUB132PDZ256mbk
    8325U,	// VFNMSUB132PDZ256mbkz
    0U,	// VFNMSUB132PDZ256mk
    0U,	// VFNMSUB132PDZ256mkz
    4U,	// VFNMSUB132PDZ256r
    0U,	// VFNMSUB132PDZ256rk
    0U,	// VFNMSUB132PDZ256rkz
    4U,	// VFNMSUB132PDZm
    4U,	// VFNMSUB132PDZmb
    133U,	// VFNMSUB132PDZmbk
    8325U,	// VFNMSUB132PDZmbkz
    0U,	// VFNMSUB132PDZmk
    0U,	// VFNMSUB132PDZmkz
    4U,	// VFNMSUB132PDZr
    4U,	// VFNMSUB132PDZrb
    0U,	// VFNMSUB132PDZrbk
    0U,	// VFNMSUB132PDZrbkz
    0U,	// VFNMSUB132PDZrk
    0U,	// VFNMSUB132PDZrkz
    4U,	// VFNMSUB132PDm
    4U,	// VFNMSUB132PDr
    4U,	// VFNMSUB132PSYm
    4U,	// VFNMSUB132PSYr
    4U,	// VFNMSUB132PSZ128m
    4U,	// VFNMSUB132PSZ128mb
    133U,	// VFNMSUB132PSZ128mbk
    8325U,	// VFNMSUB132PSZ128mbkz
    0U,	// VFNMSUB132PSZ128mk
    0U,	// VFNMSUB132PSZ128mkz
    4U,	// VFNMSUB132PSZ128r
    0U,	// VFNMSUB132PSZ128rk
    0U,	// VFNMSUB132PSZ128rkz
    4U,	// VFNMSUB132PSZ256m
    4U,	// VFNMSUB132PSZ256mb
    133U,	// VFNMSUB132PSZ256mbk
    8325U,	// VFNMSUB132PSZ256mbkz
    0U,	// VFNMSUB132PSZ256mk
    0U,	// VFNMSUB132PSZ256mkz
    4U,	// VFNMSUB132PSZ256r
    0U,	// VFNMSUB132PSZ256rk
    0U,	// VFNMSUB132PSZ256rkz
    4U,	// VFNMSUB132PSZm
    4U,	// VFNMSUB132PSZmb
    133U,	// VFNMSUB132PSZmbk
    8325U,	// VFNMSUB132PSZmbkz
    0U,	// VFNMSUB132PSZmk
    0U,	// VFNMSUB132PSZmkz
    4U,	// VFNMSUB132PSZr
    4U,	// VFNMSUB132PSZrb
    0U,	// VFNMSUB132PSZrbk
    0U,	// VFNMSUB132PSZrbkz
    0U,	// VFNMSUB132PSZrk
    0U,	// VFNMSUB132PSZrkz
    4U,	// VFNMSUB132PSm
    4U,	// VFNMSUB132PSr
    4U,	// VFNMSUB132SDZm
    4U,	// VFNMSUB132SDZm_Int
    133U,	// VFNMSUB132SDZm_Intk
    8325U,	// VFNMSUB132SDZm_Intkz
    4U,	// VFNMSUB132SDZr
    4U,	// VFNMSUB132SDZr_Int
    0U,	// VFNMSUB132SDZr_Intk
    0U,	// VFNMSUB132SDZr_Intkz
    4U,	// VFNMSUB132SDZrb
    4U,	// VFNMSUB132SDZrb_Int
    0U,	// VFNMSUB132SDZrb_Intk
    0U,	// VFNMSUB132SDZrb_Intkz
    4U,	// VFNMSUB132SDm
    4U,	// VFNMSUB132SDm_Int
    4U,	// VFNMSUB132SDr
    4U,	// VFNMSUB132SDr_Int
    4U,	// VFNMSUB132SSZm
    4U,	// VFNMSUB132SSZm_Int
    133U,	// VFNMSUB132SSZm_Intk
    8325U,	// VFNMSUB132SSZm_Intkz
    4U,	// VFNMSUB132SSZr
    4U,	// VFNMSUB132SSZr_Int
    0U,	// VFNMSUB132SSZr_Intk
    0U,	// VFNMSUB132SSZr_Intkz
    4U,	// VFNMSUB132SSZrb
    4U,	// VFNMSUB132SSZrb_Int
    0U,	// VFNMSUB132SSZrb_Intk
    0U,	// VFNMSUB132SSZrb_Intkz
    4U,	// VFNMSUB132SSm
    4U,	// VFNMSUB132SSm_Int
    4U,	// VFNMSUB132SSr
    4U,	// VFNMSUB132SSr_Int
    4U,	// VFNMSUB213PDYm
    4U,	// VFNMSUB213PDYr
    4U,	// VFNMSUB213PDZ128m
    4U,	// VFNMSUB213PDZ128mb
    133U,	// VFNMSUB213PDZ128mbk
    8325U,	// VFNMSUB213PDZ128mbkz
    0U,	// VFNMSUB213PDZ128mk
    0U,	// VFNMSUB213PDZ128mkz
    4U,	// VFNMSUB213PDZ128r
    0U,	// VFNMSUB213PDZ128rk
    0U,	// VFNMSUB213PDZ128rkz
    4U,	// VFNMSUB213PDZ256m
    4U,	// VFNMSUB213PDZ256mb
    133U,	// VFNMSUB213PDZ256mbk
    8325U,	// VFNMSUB213PDZ256mbkz
    0U,	// VFNMSUB213PDZ256mk
    0U,	// VFNMSUB213PDZ256mkz
    4U,	// VFNMSUB213PDZ256r
    0U,	// VFNMSUB213PDZ256rk
    0U,	// VFNMSUB213PDZ256rkz
    4U,	// VFNMSUB213PDZm
    4U,	// VFNMSUB213PDZmb
    133U,	// VFNMSUB213PDZmbk
    8325U,	// VFNMSUB213PDZmbkz
    0U,	// VFNMSUB213PDZmk
    0U,	// VFNMSUB213PDZmkz
    4U,	// VFNMSUB213PDZr
    4U,	// VFNMSUB213PDZrb
    0U,	// VFNMSUB213PDZrbk
    0U,	// VFNMSUB213PDZrbkz
    0U,	// VFNMSUB213PDZrk
    0U,	// VFNMSUB213PDZrkz
    4U,	// VFNMSUB213PDm
    4U,	// VFNMSUB213PDr
    4U,	// VFNMSUB213PSYm
    4U,	// VFNMSUB213PSYr
    4U,	// VFNMSUB213PSZ128m
    4U,	// VFNMSUB213PSZ128mb
    133U,	// VFNMSUB213PSZ128mbk
    8325U,	// VFNMSUB213PSZ128mbkz
    0U,	// VFNMSUB213PSZ128mk
    0U,	// VFNMSUB213PSZ128mkz
    4U,	// VFNMSUB213PSZ128r
    0U,	// VFNMSUB213PSZ128rk
    0U,	// VFNMSUB213PSZ128rkz
    4U,	// VFNMSUB213PSZ256m
    4U,	// VFNMSUB213PSZ256mb
    133U,	// VFNMSUB213PSZ256mbk
    8325U,	// VFNMSUB213PSZ256mbkz
    0U,	// VFNMSUB213PSZ256mk
    0U,	// VFNMSUB213PSZ256mkz
    4U,	// VFNMSUB213PSZ256r
    0U,	// VFNMSUB213PSZ256rk
    0U,	// VFNMSUB213PSZ256rkz
    4U,	// VFNMSUB213PSZm
    4U,	// VFNMSUB213PSZmb
    133U,	// VFNMSUB213PSZmbk
    8325U,	// VFNMSUB213PSZmbkz
    0U,	// VFNMSUB213PSZmk
    0U,	// VFNMSUB213PSZmkz
    4U,	// VFNMSUB213PSZr
    4U,	// VFNMSUB213PSZrb
    0U,	// VFNMSUB213PSZrbk
    0U,	// VFNMSUB213PSZrbkz
    0U,	// VFNMSUB213PSZrk
    0U,	// VFNMSUB213PSZrkz
    4U,	// VFNMSUB213PSm
    4U,	// VFNMSUB213PSr
    4U,	// VFNMSUB213SDZm
    4U,	// VFNMSUB213SDZm_Int
    133U,	// VFNMSUB213SDZm_Intk
    8325U,	// VFNMSUB213SDZm_Intkz
    4U,	// VFNMSUB213SDZr
    4U,	// VFNMSUB213SDZr_Int
    0U,	// VFNMSUB213SDZr_Intk
    0U,	// VFNMSUB213SDZr_Intkz
    4U,	// VFNMSUB213SDZrb
    4U,	// VFNMSUB213SDZrb_Int
    0U,	// VFNMSUB213SDZrb_Intk
    0U,	// VFNMSUB213SDZrb_Intkz
    4U,	// VFNMSUB213SDm
    4U,	// VFNMSUB213SDm_Int
    4U,	// VFNMSUB213SDr
    4U,	// VFNMSUB213SDr_Int
    4U,	// VFNMSUB213SSZm
    4U,	// VFNMSUB213SSZm_Int
    133U,	// VFNMSUB213SSZm_Intk
    8325U,	// VFNMSUB213SSZm_Intkz
    4U,	// VFNMSUB213SSZr
    4U,	// VFNMSUB213SSZr_Int
    0U,	// VFNMSUB213SSZr_Intk
    0U,	// VFNMSUB213SSZr_Intkz
    4U,	// VFNMSUB213SSZrb
    4U,	// VFNMSUB213SSZrb_Int
    0U,	// VFNMSUB213SSZrb_Intk
    0U,	// VFNMSUB213SSZrb_Intkz
    4U,	// VFNMSUB213SSm
    4U,	// VFNMSUB213SSm_Int
    4U,	// VFNMSUB213SSr
    4U,	// VFNMSUB213SSr_Int
    4U,	// VFNMSUB231PDYm
    4U,	// VFNMSUB231PDYr
    4U,	// VFNMSUB231PDZ128m
    4U,	// VFNMSUB231PDZ128mb
    133U,	// VFNMSUB231PDZ128mbk
    8325U,	// VFNMSUB231PDZ128mbkz
    0U,	// VFNMSUB231PDZ128mk
    0U,	// VFNMSUB231PDZ128mkz
    4U,	// VFNMSUB231PDZ128r
    0U,	// VFNMSUB231PDZ128rk
    0U,	// VFNMSUB231PDZ128rkz
    4U,	// VFNMSUB231PDZ256m
    4U,	// VFNMSUB231PDZ256mb
    133U,	// VFNMSUB231PDZ256mbk
    8325U,	// VFNMSUB231PDZ256mbkz
    0U,	// VFNMSUB231PDZ256mk
    0U,	// VFNMSUB231PDZ256mkz
    4U,	// VFNMSUB231PDZ256r
    0U,	// VFNMSUB231PDZ256rk
    0U,	// VFNMSUB231PDZ256rkz
    4U,	// VFNMSUB231PDZm
    4U,	// VFNMSUB231PDZmb
    133U,	// VFNMSUB231PDZmbk
    8325U,	// VFNMSUB231PDZmbkz
    0U,	// VFNMSUB231PDZmk
    0U,	// VFNMSUB231PDZmkz
    4U,	// VFNMSUB231PDZr
    4U,	// VFNMSUB231PDZrb
    0U,	// VFNMSUB231PDZrbk
    0U,	// VFNMSUB231PDZrbkz
    0U,	// VFNMSUB231PDZrk
    0U,	// VFNMSUB231PDZrkz
    4U,	// VFNMSUB231PDm
    4U,	// VFNMSUB231PDr
    4U,	// VFNMSUB231PSYm
    4U,	// VFNMSUB231PSYr
    4U,	// VFNMSUB231PSZ128m
    4U,	// VFNMSUB231PSZ128mb
    133U,	// VFNMSUB231PSZ128mbk
    8325U,	// VFNMSUB231PSZ128mbkz
    0U,	// VFNMSUB231PSZ128mk
    0U,	// VFNMSUB231PSZ128mkz
    4U,	// VFNMSUB231PSZ128r
    0U,	// VFNMSUB231PSZ128rk
    0U,	// VFNMSUB231PSZ128rkz
    4U,	// VFNMSUB231PSZ256m
    4U,	// VFNMSUB231PSZ256mb
    133U,	// VFNMSUB231PSZ256mbk
    8325U,	// VFNMSUB231PSZ256mbkz
    0U,	// VFNMSUB231PSZ256mk
    0U,	// VFNMSUB231PSZ256mkz
    4U,	// VFNMSUB231PSZ256r
    0U,	// VFNMSUB231PSZ256rk
    0U,	// VFNMSUB231PSZ256rkz
    4U,	// VFNMSUB231PSZm
    4U,	// VFNMSUB231PSZmb
    133U,	// VFNMSUB231PSZmbk
    8325U,	// VFNMSUB231PSZmbkz
    0U,	// VFNMSUB231PSZmk
    0U,	// VFNMSUB231PSZmkz
    4U,	// VFNMSUB231PSZr
    4U,	// VFNMSUB231PSZrb
    0U,	// VFNMSUB231PSZrbk
    0U,	// VFNMSUB231PSZrbkz
    0U,	// VFNMSUB231PSZrk
    0U,	// VFNMSUB231PSZrkz
    4U,	// VFNMSUB231PSm
    4U,	// VFNMSUB231PSr
    4U,	// VFNMSUB231SDZm
    4U,	// VFNMSUB231SDZm_Int
    133U,	// VFNMSUB231SDZm_Intk
    8325U,	// VFNMSUB231SDZm_Intkz
    4U,	// VFNMSUB231SDZr
    4U,	// VFNMSUB231SDZr_Int
    0U,	// VFNMSUB231SDZr_Intk
    0U,	// VFNMSUB231SDZr_Intkz
    4U,	// VFNMSUB231SDZrb
    4U,	// VFNMSUB231SDZrb_Int
    0U,	// VFNMSUB231SDZrb_Intk
    0U,	// VFNMSUB231SDZrb_Intkz
    4U,	// VFNMSUB231SDm
    4U,	// VFNMSUB231SDm_Int
    4U,	// VFNMSUB231SDr
    4U,	// VFNMSUB231SDr_Int
    4U,	// VFNMSUB231SSZm
    4U,	// VFNMSUB231SSZm_Int
    133U,	// VFNMSUB231SSZm_Intk
    8325U,	// VFNMSUB231SSZm_Intkz
    4U,	// VFNMSUB231SSZr
    4U,	// VFNMSUB231SSZr_Int
    0U,	// VFNMSUB231SSZr_Intk
    0U,	// VFNMSUB231SSZr_Intkz
    4U,	// VFNMSUB231SSZrb
    4U,	// VFNMSUB231SSZrb_Int
    0U,	// VFNMSUB231SSZrb_Intk
    0U,	// VFNMSUB231SSZrb_Intkz
    4U,	// VFNMSUB231SSm
    4U,	// VFNMSUB231SSm_Int
    4U,	// VFNMSUB231SSr
    4U,	// VFNMSUB231SSr_Int
    72U,	// VFNMSUBPD4Ymr
    18636U,	// VFNMSUBPD4Yrm
    18636U,	// VFNMSUBPD4Yrr
    18636U,	// VFNMSUBPD4Yrr_REV
    72U,	// VFNMSUBPD4mr
    18636U,	// VFNMSUBPD4rm
    18636U,	// VFNMSUBPD4rr
    18636U,	// VFNMSUBPD4rr_REV
    72U,	// VFNMSUBPS4Ymr
    18636U,	// VFNMSUBPS4Yrm
    18636U,	// VFNMSUBPS4Yrr
    18636U,	// VFNMSUBPS4Yrr_REV
    72U,	// VFNMSUBPS4mr
    18636U,	// VFNMSUBPS4rm
    18636U,	// VFNMSUBPS4rr
    18636U,	// VFNMSUBPS4rr_REV
    18636U,	// VFNMSUBSD4mr
    18636U,	// VFNMSUBSD4mr_Int
    18636U,	// VFNMSUBSD4rm
    18636U,	// VFNMSUBSD4rm_Int
    18636U,	// VFNMSUBSD4rr
    18636U,	// VFNMSUBSD4rr_Int
    18636U,	// VFNMSUBSD4rr_Int_REV
    18636U,	// VFNMSUBSD4rr_REV
    18636U,	// VFNMSUBSS4mr
    18636U,	// VFNMSUBSS4mr_Int
    18636U,	// VFNMSUBSS4rm
    18636U,	// VFNMSUBSS4rm_Int
    18636U,	// VFNMSUBSS4rr
    18636U,	// VFNMSUBSS4rr_Int
    18636U,	// VFNMSUBSS4rr_Int_REV
    18636U,	// VFNMSUBSS4rr_REV
    0U,	// VFPCLASSPDZ128rm
    5U,	// VFPCLASSPDZ128rmb
    1157U,	// VFPCLASSPDZ128rmbk
    3420U,	// VFPCLASSPDZ128rmk
    72U,	// VFPCLASSPDZ128rr
    1156U,	// VFPCLASSPDZ128rrk
    0U,	// VFPCLASSPDZ256rm
    5U,	// VFPCLASSPDZ256rmb
    1157U,	// VFPCLASSPDZ256rmbk
    3420U,	// VFPCLASSPDZ256rmk
    72U,	// VFPCLASSPDZ256rr
    1156U,	// VFPCLASSPDZ256rrk
    0U,	// VFPCLASSPDZrm
    5U,	// VFPCLASSPDZrmb
    1157U,	// VFPCLASSPDZrmbk
    3420U,	// VFPCLASSPDZrmk
    72U,	// VFPCLASSPDZrr
    1156U,	// VFPCLASSPDZrrk
    0U,	// VFPCLASSPSZ128rm
    5U,	// VFPCLASSPSZ128rmb
    1157U,	// VFPCLASSPSZ128rmbk
    3420U,	// VFPCLASSPSZ128rmk
    72U,	// VFPCLASSPSZ128rr
    1156U,	// VFPCLASSPSZ128rrk
    0U,	// VFPCLASSPSZ256rm
    5U,	// VFPCLASSPSZ256rmb
    1157U,	// VFPCLASSPSZ256rmbk
    3420U,	// VFPCLASSPSZ256rmk
    72U,	// VFPCLASSPSZ256rr
    1156U,	// VFPCLASSPSZ256rrk
    0U,	// VFPCLASSPSZrm
    5U,	// VFPCLASSPSZrmb
    1157U,	// VFPCLASSPSZrmbk
    3420U,	// VFPCLASSPSZrmk
    72U,	// VFPCLASSPSZrr
    1156U,	// VFPCLASSPSZrrk
    4U,	// VFPCLASSSDZrm
    1156U,	// VFPCLASSSDZrmk
    72U,	// VFPCLASSSDZrr
    1156U,	// VFPCLASSSDZrrk
    4U,	// VFPCLASSSSZrm
    1156U,	// VFPCLASSSSZrmk
    72U,	// VFPCLASSSSZrr
    1156U,	// VFPCLASSSSZrrk
    0U,	// VFRCZPDYrm
    0U,	// VFRCZPDYrr
    0U,	// VFRCZPDrm
    0U,	// VFRCZPDrr
    0U,	// VFRCZPSYrm
    0U,	// VFRCZPSYrr
    0U,	// VFRCZPSrm
    0U,	// VFRCZPSrr
    0U,	// VFRCZSDrm
    0U,	// VFRCZSDrr
    0U,	// VFRCZSSrm
    0U,	// VFRCZSSrr
    0U,	// VGATHERDPDYrm
    401U,	// VGATHERDPDZ128rm
    401U,	// VGATHERDPDZ256rm
    401U,	// VGATHERDPDZrm
    0U,	// VGATHERDPDrm
    0U,	// VGATHERDPSYrm
    401U,	// VGATHERDPSZ128rm
    401U,	// VGATHERDPSZ256rm
    401U,	// VGATHERDPSZrm
    0U,	// VGATHERDPSrm
    0U,	// VGATHERPF0DPDm
    0U,	// VGATHERPF0DPSm
    0U,	// VGATHERPF0QPDm
    0U,	// VGATHERPF0QPSm
    0U,	// VGATHERPF1DPDm
    0U,	// VGATHERPF1DPSm
    0U,	// VGATHERPF1QPDm
    0U,	// VGATHERPF1QPSm
    0U,	// VGATHERQPDYrm
    401U,	// VGATHERQPDZ128rm
    401U,	// VGATHERQPDZ256rm
    401U,	// VGATHERQPDZrm
    0U,	// VGATHERQPDrm
    0U,	// VGATHERQPSYrm
    604U,	// VGATHERQPSZ128rm
    401U,	// VGATHERQPSZ256rm
    401U,	// VGATHERQPSZrm
    4U,	// VGATHERQPSrm
    0U,	// VGETEXPPDZ128m
    0U,	// VGETEXPPDZ128mb
    3356U,	// VGETEXPPDZ128mbk
    4444U,	// VGETEXPPDZ128mbkz
    405U,	// VGETEXPPDZ128mk
    461U,	// VGETEXPPDZ128mkz
    0U,	// VGETEXPPDZ128r
    405U,	// VGETEXPPDZ128rk
    461U,	// VGETEXPPDZ128rkz
    0U,	// VGETEXPPDZ256m
    0U,	// VGETEXPPDZ256mb
    3356U,	// VGETEXPPDZ256mbk
    4444U,	// VGETEXPPDZ256mbkz
    405U,	// VGETEXPPDZ256mk
    461U,	// VGETEXPPDZ256mkz
    0U,	// VGETEXPPDZ256r
    405U,	// VGETEXPPDZ256rk
    461U,	// VGETEXPPDZ256rkz
    0U,	// VGETEXPPDZm
    0U,	// VGETEXPPDZmb
    3356U,	// VGETEXPPDZmbk
    4444U,	// VGETEXPPDZmbkz
    405U,	// VGETEXPPDZmk
    461U,	// VGETEXPPDZmkz
    0U,	// VGETEXPPDZr
    0U,	// VGETEXPPDZrb
    405U,	// VGETEXPPDZrbk
    461U,	// VGETEXPPDZrbkz
    405U,	// VGETEXPPDZrk
    461U,	// VGETEXPPDZrkz
    0U,	// VGETEXPPSZ128m
    0U,	// VGETEXPPSZ128mb
    3356U,	// VGETEXPPSZ128mbk
    4444U,	// VGETEXPPSZ128mbkz
    405U,	// VGETEXPPSZ128mk
    461U,	// VGETEXPPSZ128mkz
    0U,	// VGETEXPPSZ128r
    405U,	// VGETEXPPSZ128rk
    461U,	// VGETEXPPSZ128rkz
    0U,	// VGETEXPPSZ256m
    0U,	// VGETEXPPSZ256mb
    3356U,	// VGETEXPPSZ256mbk
    4444U,	// VGETEXPPSZ256mbkz
    405U,	// VGETEXPPSZ256mk
    461U,	// VGETEXPPSZ256mkz
    0U,	// VGETEXPPSZ256r
    405U,	// VGETEXPPSZ256rk
    461U,	// VGETEXPPSZ256rkz
    0U,	// VGETEXPPSZm
    0U,	// VGETEXPPSZmb
    3356U,	// VGETEXPPSZmbk
    4444U,	// VGETEXPPSZmbkz
    405U,	// VGETEXPPSZmk
    461U,	// VGETEXPPSZmkz
    0U,	// VGETEXPPSZr
    0U,	// VGETEXPPSZrb
    405U,	// VGETEXPPSZrbk
    461U,	// VGETEXPPSZrbkz
    405U,	// VGETEXPPSZrk
    461U,	// VGETEXPPSZrkz
    72U,	// VGETEXPSDZm
    133U,	// VGETEXPSDZmk
    9348U,	// VGETEXPSDZmkz
    4U,	// VGETEXPSDZr
    4U,	// VGETEXPSDZrb
    0U,	// VGETEXPSDZrbk
    9348U,	// VGETEXPSDZrbkz
    0U,	// VGETEXPSDZrk
    9348U,	// VGETEXPSDZrkz
    72U,	// VGETEXPSSZm
    133U,	// VGETEXPSSZmk
    9348U,	// VGETEXPSSZmkz
    4U,	// VGETEXPSSZr
    4U,	// VGETEXPSSZrb
    0U,	// VGETEXPSSZrbk
    9348U,	// VGETEXPSSZrbkz
    0U,	// VGETEXPSSZrk
    9348U,	// VGETEXPSSZrkz
    5U,	// VGETMANTPDZ128rmbi
    133U,	// VGETMANTPDZ128rmbik
    9349U,	// VGETMANTPDZ128rmbikz
    0U,	// VGETMANTPDZ128rmi
    3356U,	// VGETMANTPDZ128rmik
    4444U,	// VGETMANTPDZ128rmikz
    72U,	// VGETMANTPDZ128rri
    133U,	// VGETMANTPDZ128rrik
    9348U,	// VGETMANTPDZ128rrikz
    5U,	// VGETMANTPDZ256rmbi
    133U,	// VGETMANTPDZ256rmbik
    9349U,	// VGETMANTPDZ256rmbikz
    0U,	// VGETMANTPDZ256rmi
    3356U,	// VGETMANTPDZ256rmik
    4444U,	// VGETMANTPDZ256rmikz
    72U,	// VGETMANTPDZ256rri
    133U,	// VGETMANTPDZ256rrik
    9348U,	// VGETMANTPDZ256rrikz
    5U,	// VGETMANTPDZrmbi
    133U,	// VGETMANTPDZrmbik
    9349U,	// VGETMANTPDZrmbikz
    0U,	// VGETMANTPDZrmi
    3356U,	// VGETMANTPDZrmik
    4444U,	// VGETMANTPDZrmikz
    72U,	// VGETMANTPDZrri
    72U,	// VGETMANTPDZrrib
    133U,	// VGETMANTPDZrribk
    9348U,	// VGETMANTPDZrribkz
    133U,	// VGETMANTPDZrrik
    9348U,	// VGETMANTPDZrrikz
    5U,	// VGETMANTPSZ128rmbi
    133U,	// VGETMANTPSZ128rmbik
    9349U,	// VGETMANTPSZ128rmbikz
    0U,	// VGETMANTPSZ128rmi
    3356U,	// VGETMANTPSZ128rmik
    4444U,	// VGETMANTPSZ128rmikz
    72U,	// VGETMANTPSZ128rri
    133U,	// VGETMANTPSZ128rrik
    9348U,	// VGETMANTPSZ128rrikz
    5U,	// VGETMANTPSZ256rmbi
    133U,	// VGETMANTPSZ256rmbik
    9349U,	// VGETMANTPSZ256rmbikz
    0U,	// VGETMANTPSZ256rmi
    3356U,	// VGETMANTPSZ256rmik
    4444U,	// VGETMANTPSZ256rmikz
    72U,	// VGETMANTPSZ256rri
    133U,	// VGETMANTPSZ256rrik
    9348U,	// VGETMANTPSZ256rrikz
    5U,	// VGETMANTPSZrmbi
    133U,	// VGETMANTPSZrmbik
    9349U,	// VGETMANTPSZrmbikz
    0U,	// VGETMANTPSZrmi
    3356U,	// VGETMANTPSZrmik
    4444U,	// VGETMANTPSZrmikz
    72U,	// VGETMANTPSZrri
    72U,	// VGETMANTPSZrrib
    133U,	// VGETMANTPSZrribk
    9348U,	// VGETMANTPSZrribkz
    133U,	// VGETMANTPSZrrik
    9348U,	// VGETMANTPSZrrikz
    18636U,	// VGETMANTSDZrmi
    26832U,	// VGETMANTSDZrmik
    26836U,	// VGETMANTSDZrmikz
    18636U,	// VGETMANTSDZrri
    18636U,	// VGETMANTSDZrrib
    25U,	// VGETMANTSDZrribk
    26837U,	// VGETMANTSDZrribkz
    25U,	// VGETMANTSDZrrik
    26837U,	// VGETMANTSDZrrikz
    18636U,	// VGETMANTSSZrmi
    26832U,	// VGETMANTSSZrmik
    26836U,	// VGETMANTSSZrmikz
    18636U,	// VGETMANTSSZrri
    18636U,	// VGETMANTSSZrrib
    25U,	// VGETMANTSSZrribk
    26837U,	// VGETMANTSSZrribkz
    25U,	// VGETMANTSSZrrik
    26837U,	// VGETMANTSSZrrikz
    72U,	// VGF2P8AFFINEINVQBYrmi
    18636U,	// VGF2P8AFFINEINVQBYrri
    18637U,	// VGF2P8AFFINEINVQBZ128rmbi
    26833U,	// VGF2P8AFFINEINVQBZ128rmbik
    26837U,	// VGF2P8AFFINEINVQBZ128rmbikz
    72U,	// VGF2P8AFFINEINVQBZ128rmi
    1U,	// VGF2P8AFFINEINVQBZ128rmik
    9348U,	// VGF2P8AFFINEINVQBZ128rmikz
    18636U,	// VGF2P8AFFINEINVQBZ128rri
    25U,	// VGF2P8AFFINEINVQBZ128rrik
    26837U,	// VGF2P8AFFINEINVQBZ128rrikz
    18637U,	// VGF2P8AFFINEINVQBZ256rmbi
    26833U,	// VGF2P8AFFINEINVQBZ256rmbik
    26837U,	// VGF2P8AFFINEINVQBZ256rmbikz
    72U,	// VGF2P8AFFINEINVQBZ256rmi
    1U,	// VGF2P8AFFINEINVQBZ256rmik
    9348U,	// VGF2P8AFFINEINVQBZ256rmikz
    18636U,	// VGF2P8AFFINEINVQBZ256rri
    25U,	// VGF2P8AFFINEINVQBZ256rrik
    26837U,	// VGF2P8AFFINEINVQBZ256rrikz
    18637U,	// VGF2P8AFFINEINVQBZrmbi
    26833U,	// VGF2P8AFFINEINVQBZrmbik
    26837U,	// VGF2P8AFFINEINVQBZrmbikz
    72U,	// VGF2P8AFFINEINVQBZrmi
    1U,	// VGF2P8AFFINEINVQBZrmik
    9348U,	// VGF2P8AFFINEINVQBZrmikz
    18636U,	// VGF2P8AFFINEINVQBZrri
    25U,	// VGF2P8AFFINEINVQBZrrik
    26837U,	// VGF2P8AFFINEINVQBZrrikz
    72U,	// VGF2P8AFFINEINVQBrmi
    18636U,	// VGF2P8AFFINEINVQBrri
    72U,	// VGF2P8AFFINEQBYrmi
    18636U,	// VGF2P8AFFINEQBYrri
    18637U,	// VGF2P8AFFINEQBZ128rmbi
    26833U,	// VGF2P8AFFINEQBZ128rmbik
    26837U,	// VGF2P8AFFINEQBZ128rmbikz
    72U,	// VGF2P8AFFINEQBZ128rmi
    1U,	// VGF2P8AFFINEQBZ128rmik
    9348U,	// VGF2P8AFFINEQBZ128rmikz
    18636U,	// VGF2P8AFFINEQBZ128rri
    25U,	// VGF2P8AFFINEQBZ128rrik
    26837U,	// VGF2P8AFFINEQBZ128rrikz
    18637U,	// VGF2P8AFFINEQBZ256rmbi
    26833U,	// VGF2P8AFFINEQBZ256rmbik
    26837U,	// VGF2P8AFFINEQBZ256rmbikz
    72U,	// VGF2P8AFFINEQBZ256rmi
    1U,	// VGF2P8AFFINEQBZ256rmik
    9348U,	// VGF2P8AFFINEQBZ256rmikz
    18636U,	// VGF2P8AFFINEQBZ256rri
    25U,	// VGF2P8AFFINEQBZ256rrik
    26837U,	// VGF2P8AFFINEQBZ256rrikz
    18637U,	// VGF2P8AFFINEQBZrmbi
    26833U,	// VGF2P8AFFINEQBZrmbik
    26837U,	// VGF2P8AFFINEQBZrmbikz
    72U,	// VGF2P8AFFINEQBZrmi
    1U,	// VGF2P8AFFINEQBZrmik
    9348U,	// VGF2P8AFFINEQBZrmikz
    18636U,	// VGF2P8AFFINEQBZrri
    25U,	// VGF2P8AFFINEQBZrrik
    26837U,	// VGF2P8AFFINEQBZrrikz
    72U,	// VGF2P8AFFINEQBrmi
    18636U,	// VGF2P8AFFINEQBrri
    4U,	// VGF2P8MULBYrm
    4U,	// VGF2P8MULBYrr
    4U,	// VGF2P8MULBZ128rm
    132U,	// VGF2P8MULBZ128rmk
    9348U,	// VGF2P8MULBZ128rmkz
    4U,	// VGF2P8MULBZ128rr
    0U,	// VGF2P8MULBZ128rrk
    9348U,	// VGF2P8MULBZ128rrkz
    4U,	// VGF2P8MULBZ256rm
    132U,	// VGF2P8MULBZ256rmk
    9348U,	// VGF2P8MULBZ256rmkz
    4U,	// VGF2P8MULBZ256rr
    0U,	// VGF2P8MULBZ256rrk
    9348U,	// VGF2P8MULBZ256rrkz
    4U,	// VGF2P8MULBZrm
    132U,	// VGF2P8MULBZrmk
    9348U,	// VGF2P8MULBZrmkz
    4U,	// VGF2P8MULBZrr
    0U,	// VGF2P8MULBZrrk
    9348U,	// VGF2P8MULBZrrkz
    4U,	// VGF2P8MULBrm
    4U,	// VGF2P8MULBrr
    4U,	// VHADDPDYrm
    4U,	// VHADDPDYrr
    4U,	// VHADDPDrm
    4U,	// VHADDPDrr
    4U,	// VHADDPSYrm
    4U,	// VHADDPSYrr
    4U,	// VHADDPSrm
    4U,	// VHADDPSrr
    4U,	// VHSUBPDYrm
    4U,	// VHSUBPDYrr
    4U,	// VHSUBPDrm
    4U,	// VHSUBPDrr
    4U,	// VHSUBPSYrm
    4U,	// VHSUBPSYrr
    4U,	// VHSUBPSrm
    4U,	// VHSUBPSrr
    72U,	// VINSERTF128rm
    18636U,	// VINSERTF128rr
    72U,	// VINSERTF32x4Z256rm
    1U,	// VINSERTF32x4Z256rmk
    9348U,	// VINSERTF32x4Z256rmkz
    18636U,	// VINSERTF32x4Z256rr
    25U,	// VINSERTF32x4Z256rrk
    26837U,	// VINSERTF32x4Z256rrkz
    72U,	// VINSERTF32x4Zrm
    1U,	// VINSERTF32x4Zrmk
    9348U,	// VINSERTF32x4Zrmkz
    18636U,	// VINSERTF32x4Zrr
    25U,	// VINSERTF32x4Zrrk
    26837U,	// VINSERTF32x4Zrrkz
    72U,	// VINSERTF32x8Zrm
    1U,	// VINSERTF32x8Zrmk
    9348U,	// VINSERTF32x8Zrmkz
    18636U,	// VINSERTF32x8Zrr
    25U,	// VINSERTF32x8Zrrk
    26837U,	// VINSERTF32x8Zrrkz
    72U,	// VINSERTF64x2Z256rm
    1U,	// VINSERTF64x2Z256rmk
    9348U,	// VINSERTF64x2Z256rmkz
    18636U,	// VINSERTF64x2Z256rr
    25U,	// VINSERTF64x2Z256rrk
    26837U,	// VINSERTF64x2Z256rrkz
    72U,	// VINSERTF64x2Zrm
    1U,	// VINSERTF64x2Zrmk
    9348U,	// VINSERTF64x2Zrmkz
    18636U,	// VINSERTF64x2Zrr
    25U,	// VINSERTF64x2Zrrk
    26837U,	// VINSERTF64x2Zrrkz
    72U,	// VINSERTF64x4Zrm
    1U,	// VINSERTF64x4Zrmk
    9348U,	// VINSERTF64x4Zrmkz
    18636U,	// VINSERTF64x4Zrr
    25U,	// VINSERTF64x4Zrrk
    26837U,	// VINSERTF64x4Zrrkz
    72U,	// VINSERTI128rm
    18636U,	// VINSERTI128rr
    72U,	// VINSERTI32x4Z256rm
    1U,	// VINSERTI32x4Z256rmk
    9348U,	// VINSERTI32x4Z256rmkz
    18636U,	// VINSERTI32x4Z256rr
    25U,	// VINSERTI32x4Z256rrk
    26837U,	// VINSERTI32x4Z256rrkz
    72U,	// VINSERTI32x4Zrm
    1U,	// VINSERTI32x4Zrmk
    9348U,	// VINSERTI32x4Zrmkz
    18636U,	// VINSERTI32x4Zrr
    25U,	// VINSERTI32x4Zrrk
    26837U,	// VINSERTI32x4Zrrkz
    72U,	// VINSERTI32x8Zrm
    1U,	// VINSERTI32x8Zrmk
    9348U,	// VINSERTI32x8Zrmkz
    18636U,	// VINSERTI32x8Zrr
    25U,	// VINSERTI32x8Zrrk
    26837U,	// VINSERTI32x8Zrrkz
    72U,	// VINSERTI64x2Z256rm
    1U,	// VINSERTI64x2Z256rmk
    9348U,	// VINSERTI64x2Z256rmkz
    18636U,	// VINSERTI64x2Z256rr
    25U,	// VINSERTI64x2Z256rrk
    26837U,	// VINSERTI64x2Z256rrkz
    72U,	// VINSERTI64x2Zrm
    1U,	// VINSERTI64x2Zrmk
    9348U,	// VINSERTI64x2Zrmkz
    18636U,	// VINSERTI64x2Zrr
    25U,	// VINSERTI64x2Zrrk
    26837U,	// VINSERTI64x2Zrrkz
    72U,	// VINSERTI64x4Zrm
    1U,	// VINSERTI64x4Zrmk
    9348U,	// VINSERTI64x4Zrmkz
    18636U,	// VINSERTI64x4Zrr
    25U,	// VINSERTI64x4Zrrk
    26837U,	// VINSERTI64x4Zrrkz
    18636U,	// VINSERTPSZrm
    18636U,	// VINSERTPSZrr
    18636U,	// VINSERTPSrm
    18636U,	// VINSERTPSrr
    0U,	// VLDDQUYrm
    0U,	// VLDDQUrm
    0U,	// VLDMXCSR
    0U,	// VMASKMOVDQU
    0U,	// VMASKMOVDQU64
    2U,	// VMASKMOVPDYmr
    4U,	// VMASKMOVPDYrm
    2U,	// VMASKMOVPDmr
    4U,	// VMASKMOVPDrm
    2U,	// VMASKMOVPSYmr
    4U,	// VMASKMOVPSYrm
    2U,	// VMASKMOVPSmr
    4U,	// VMASKMOVPSrm
    4U,	// VMAXCPDYrm
    4U,	// VMAXCPDYrr
    4U,	// VMAXCPDZ128rm
    72U,	// VMAXCPDZ128rmb
    133U,	// VMAXCPDZ128rmbk
    9348U,	// VMAXCPDZ128rmbkz
    0U,	// VMAXCPDZ128rmk
    9348U,	// VMAXCPDZ128rmkz
    4U,	// VMAXCPDZ128rr
    0U,	// VMAXCPDZ128rrk
    9348U,	// VMAXCPDZ128rrkz
    4U,	// VMAXCPDZ256rm
    72U,	// VMAXCPDZ256rmb
    133U,	// VMAXCPDZ256rmbk
    9348U,	// VMAXCPDZ256rmbkz
    0U,	// VMAXCPDZ256rmk
    9348U,	// VMAXCPDZ256rmkz
    4U,	// VMAXCPDZ256rr
    0U,	// VMAXCPDZ256rrk
    9348U,	// VMAXCPDZ256rrkz
    4U,	// VMAXCPDZrm
    72U,	// VMAXCPDZrmb
    133U,	// VMAXCPDZrmbk
    9348U,	// VMAXCPDZrmbkz
    0U,	// VMAXCPDZrmk
    9348U,	// VMAXCPDZrmkz
    4U,	// VMAXCPDZrr
    0U,	// VMAXCPDZrrk
    9348U,	// VMAXCPDZrrkz
    4U,	// VMAXCPDrm
    4U,	// VMAXCPDrr
    4U,	// VMAXCPSYrm
    4U,	// VMAXCPSYrr
    4U,	// VMAXCPSZ128rm
    72U,	// VMAXCPSZ128rmb
    133U,	// VMAXCPSZ128rmbk
    9348U,	// VMAXCPSZ128rmbkz
    0U,	// VMAXCPSZ128rmk
    9348U,	// VMAXCPSZ128rmkz
    4U,	// VMAXCPSZ128rr
    0U,	// VMAXCPSZ128rrk
    9348U,	// VMAXCPSZ128rrkz
    4U,	// VMAXCPSZ256rm
    72U,	// VMAXCPSZ256rmb
    133U,	// VMAXCPSZ256rmbk
    9348U,	// VMAXCPSZ256rmbkz
    0U,	// VMAXCPSZ256rmk
    9348U,	// VMAXCPSZ256rmkz
    4U,	// VMAXCPSZ256rr
    0U,	// VMAXCPSZ256rrk
    9348U,	// VMAXCPSZ256rrkz
    4U,	// VMAXCPSZrm
    72U,	// VMAXCPSZrmb
    133U,	// VMAXCPSZrmbk
    9348U,	// VMAXCPSZrmbkz
    0U,	// VMAXCPSZrmk
    9348U,	// VMAXCPSZrmkz
    4U,	// VMAXCPSZrr
    0U,	// VMAXCPSZrrk
    9348U,	// VMAXCPSZrrkz
    4U,	// VMAXCPSrm
    4U,	// VMAXCPSrr
    72U,	// VMAXCSDZrm
    4U,	// VMAXCSDZrr
    72U,	// VMAXCSDrm
    4U,	// VMAXCSDrr
    72U,	// VMAXCSSZrm
    4U,	// VMAXCSSZrr
    72U,	// VMAXCSSrm
    4U,	// VMAXCSSrr
    4U,	// VMAXPDYrm
    4U,	// VMAXPDYrr
    4U,	// VMAXPDZ128rm
    72U,	// VMAXPDZ128rmb
    133U,	// VMAXPDZ128rmbk
    9348U,	// VMAXPDZ128rmbkz
    0U,	// VMAXPDZ128rmk
    9348U,	// VMAXPDZ128rmkz
    4U,	// VMAXPDZ128rr
    0U,	// VMAXPDZ128rrk
    9348U,	// VMAXPDZ128rrkz
    4U,	// VMAXPDZ256rm
    72U,	// VMAXPDZ256rmb
    133U,	// VMAXPDZ256rmbk
    9348U,	// VMAXPDZ256rmbkz
    0U,	// VMAXPDZ256rmk
    9348U,	// VMAXPDZ256rmkz
    4U,	// VMAXPDZ256rr
    0U,	// VMAXPDZ256rrk
    9348U,	// VMAXPDZ256rrkz
    4U,	// VMAXPDZrm
    72U,	// VMAXPDZrmb
    133U,	// VMAXPDZrmbk
    9348U,	// VMAXPDZrmbkz
    0U,	// VMAXPDZrmk
    9348U,	// VMAXPDZrmkz
    4U,	// VMAXPDZrr
    4U,	// VMAXPDZrrb
    0U,	// VMAXPDZrrbk
    9348U,	// VMAXPDZrrbkz
    0U,	// VMAXPDZrrk
    9348U,	// VMAXPDZrrkz
    4U,	// VMAXPDrm
    4U,	// VMAXPDrr
    4U,	// VMAXPSYrm
    4U,	// VMAXPSYrr
    4U,	// VMAXPSZ128rm
    72U,	// VMAXPSZ128rmb
    133U,	// VMAXPSZ128rmbk
    9348U,	// VMAXPSZ128rmbkz
    0U,	// VMAXPSZ128rmk
    9348U,	// VMAXPSZ128rmkz
    4U,	// VMAXPSZ128rr
    0U,	// VMAXPSZ128rrk
    9348U,	// VMAXPSZ128rrkz
    4U,	// VMAXPSZ256rm
    72U,	// VMAXPSZ256rmb
    133U,	// VMAXPSZ256rmbk
    9348U,	// VMAXPSZ256rmbkz
    0U,	// VMAXPSZ256rmk
    9348U,	// VMAXPSZ256rmkz
    4U,	// VMAXPSZ256rr
    0U,	// VMAXPSZ256rrk
    9348U,	// VMAXPSZ256rrkz
    4U,	// VMAXPSZrm
    72U,	// VMAXPSZrmb
    133U,	// VMAXPSZrmbk
    9348U,	// VMAXPSZrmbkz
    0U,	// VMAXPSZrmk
    9348U,	// VMAXPSZrmkz
    4U,	// VMAXPSZrr
    4U,	// VMAXPSZrrb
    0U,	// VMAXPSZrrbk
    9348U,	// VMAXPSZrrbkz
    0U,	// VMAXPSZrrk
    9348U,	// VMAXPSZrrkz
    4U,	// VMAXPSrm
    4U,	// VMAXPSrr
    72U,	// VMAXSDZrm
    72U,	// VMAXSDZrm_Int
    133U,	// VMAXSDZrm_Intk
    9348U,	// VMAXSDZrm_Intkz
    4U,	// VMAXSDZrr
    4U,	// VMAXSDZrr_Int
    0U,	// VMAXSDZrr_Intk
    9348U,	// VMAXSDZrr_Intkz
    4U,	// VMAXSDZrrb_Int
    0U,	// VMAXSDZrrb_Intk
    9348U,	// VMAXSDZrrb_Intkz
    72U,	// VMAXSDrm
    72U,	// VMAXSDrm_Int
    4U,	// VMAXSDrr
    4U,	// VMAXSDrr_Int
    72U,	// VMAXSSZrm
    72U,	// VMAXSSZrm_Int
    133U,	// VMAXSSZrm_Intk
    9348U,	// VMAXSSZrm_Intkz
    4U,	// VMAXSSZrr
    4U,	// VMAXSSZrr_Int
    0U,	// VMAXSSZrr_Intk
    9348U,	// VMAXSSZrr_Intkz
    4U,	// VMAXSSZrrb_Int
    0U,	// VMAXSSZrrb_Intk
    9348U,	// VMAXSSZrrb_Intkz
    72U,	// VMAXSSrm
    72U,	// VMAXSSrm_Int
    4U,	// VMAXSSrr
    4U,	// VMAXSSrr_Int
    0U,	// VMCALL
    0U,	// VMCLEARm
    0U,	// VMFUNC
    4U,	// VMINCPDYrm
    4U,	// VMINCPDYrr
    4U,	// VMINCPDZ128rm
    72U,	// VMINCPDZ128rmb
    133U,	// VMINCPDZ128rmbk
    9348U,	// VMINCPDZ128rmbkz
    0U,	// VMINCPDZ128rmk
    9348U,	// VMINCPDZ128rmkz
    4U,	// VMINCPDZ128rr
    0U,	// VMINCPDZ128rrk
    9348U,	// VMINCPDZ128rrkz
    4U,	// VMINCPDZ256rm
    72U,	// VMINCPDZ256rmb
    133U,	// VMINCPDZ256rmbk
    9348U,	// VMINCPDZ256rmbkz
    0U,	// VMINCPDZ256rmk
    9348U,	// VMINCPDZ256rmkz
    4U,	// VMINCPDZ256rr
    0U,	// VMINCPDZ256rrk
    9348U,	// VMINCPDZ256rrkz
    4U,	// VMINCPDZrm
    72U,	// VMINCPDZrmb
    133U,	// VMINCPDZrmbk
    9348U,	// VMINCPDZrmbkz
    0U,	// VMINCPDZrmk
    9348U,	// VMINCPDZrmkz
    4U,	// VMINCPDZrr
    0U,	// VMINCPDZrrk
    9348U,	// VMINCPDZrrkz
    4U,	// VMINCPDrm
    4U,	// VMINCPDrr
    4U,	// VMINCPSYrm
    4U,	// VMINCPSYrr
    4U,	// VMINCPSZ128rm
    72U,	// VMINCPSZ128rmb
    133U,	// VMINCPSZ128rmbk
    9348U,	// VMINCPSZ128rmbkz
    0U,	// VMINCPSZ128rmk
    9348U,	// VMINCPSZ128rmkz
    4U,	// VMINCPSZ128rr
    0U,	// VMINCPSZ128rrk
    9348U,	// VMINCPSZ128rrkz
    4U,	// VMINCPSZ256rm
    72U,	// VMINCPSZ256rmb
    133U,	// VMINCPSZ256rmbk
    9348U,	// VMINCPSZ256rmbkz
    0U,	// VMINCPSZ256rmk
    9348U,	// VMINCPSZ256rmkz
    4U,	// VMINCPSZ256rr
    0U,	// VMINCPSZ256rrk
    9348U,	// VMINCPSZ256rrkz
    4U,	// VMINCPSZrm
    72U,	// VMINCPSZrmb
    133U,	// VMINCPSZrmbk
    9348U,	// VMINCPSZrmbkz
    0U,	// VMINCPSZrmk
    9348U,	// VMINCPSZrmkz
    4U,	// VMINCPSZrr
    0U,	// VMINCPSZrrk
    9348U,	// VMINCPSZrrkz
    4U,	// VMINCPSrm
    4U,	// VMINCPSrr
    72U,	// VMINCSDZrm
    4U,	// VMINCSDZrr
    72U,	// VMINCSDrm
    4U,	// VMINCSDrr
    72U,	// VMINCSSZrm
    4U,	// VMINCSSZrr
    72U,	// VMINCSSrm
    4U,	// VMINCSSrr
    4U,	// VMINPDYrm
    4U,	// VMINPDYrr
    4U,	// VMINPDZ128rm
    72U,	// VMINPDZ128rmb
    133U,	// VMINPDZ128rmbk
    9348U,	// VMINPDZ128rmbkz
    0U,	// VMINPDZ128rmk
    9348U,	// VMINPDZ128rmkz
    4U,	// VMINPDZ128rr
    0U,	// VMINPDZ128rrk
    9348U,	// VMINPDZ128rrkz
    4U,	// VMINPDZ256rm
    72U,	// VMINPDZ256rmb
    133U,	// VMINPDZ256rmbk
    9348U,	// VMINPDZ256rmbkz
    0U,	// VMINPDZ256rmk
    9348U,	// VMINPDZ256rmkz
    4U,	// VMINPDZ256rr
    0U,	// VMINPDZ256rrk
    9348U,	// VMINPDZ256rrkz
    4U,	// VMINPDZrm
    72U,	// VMINPDZrmb
    133U,	// VMINPDZrmbk
    9348U,	// VMINPDZrmbkz
    0U,	// VMINPDZrmk
    9348U,	// VMINPDZrmkz
    4U,	// VMINPDZrr
    4U,	// VMINPDZrrb
    0U,	// VMINPDZrrbk
    9348U,	// VMINPDZrrbkz
    0U,	// VMINPDZrrk
    9348U,	// VMINPDZrrkz
    4U,	// VMINPDrm
    4U,	// VMINPDrr
    4U,	// VMINPSYrm
    4U,	// VMINPSYrr
    4U,	// VMINPSZ128rm
    72U,	// VMINPSZ128rmb
    133U,	// VMINPSZ128rmbk
    9348U,	// VMINPSZ128rmbkz
    0U,	// VMINPSZ128rmk
    9348U,	// VMINPSZ128rmkz
    4U,	// VMINPSZ128rr
    0U,	// VMINPSZ128rrk
    9348U,	// VMINPSZ128rrkz
    4U,	// VMINPSZ256rm
    72U,	// VMINPSZ256rmb
    133U,	// VMINPSZ256rmbk
    9348U,	// VMINPSZ256rmbkz
    0U,	// VMINPSZ256rmk
    9348U,	// VMINPSZ256rmkz
    4U,	// VMINPSZ256rr
    0U,	// VMINPSZ256rrk
    9348U,	// VMINPSZ256rrkz
    4U,	// VMINPSZrm
    72U,	// VMINPSZrmb
    133U,	// VMINPSZrmbk
    9348U,	// VMINPSZrmbkz
    0U,	// VMINPSZrmk
    9348U,	// VMINPSZrmkz
    4U,	// VMINPSZrr
    4U,	// VMINPSZrrb
    0U,	// VMINPSZrrbk
    9348U,	// VMINPSZrrbkz
    0U,	// VMINPSZrrk
    9348U,	// VMINPSZrrkz
    4U,	// VMINPSrm
    4U,	// VMINPSrr
    72U,	// VMINSDZrm
    72U,	// VMINSDZrm_Int
    133U,	// VMINSDZrm_Intk
    9348U,	// VMINSDZrm_Intkz
    4U,	// VMINSDZrr
    4U,	// VMINSDZrr_Int
    0U,	// VMINSDZrr_Intk
    9348U,	// VMINSDZrr_Intkz
    4U,	// VMINSDZrrb_Int
    0U,	// VMINSDZrrb_Intk
    9348U,	// VMINSDZrrb_Intkz
    72U,	// VMINSDrm
    72U,	// VMINSDrm_Int
    4U,	// VMINSDrr
    4U,	// VMINSDrr_Int
    72U,	// VMINSSZrm
    72U,	// VMINSSZrm_Int
    133U,	// VMINSSZrm_Intk
    9348U,	// VMINSSZrm_Intkz
    4U,	// VMINSSZrr
    4U,	// VMINSSZrr_Int
    0U,	// VMINSSZrr_Intk
    9348U,	// VMINSSZrr_Intkz
    4U,	// VMINSSZrrb_Int
    0U,	// VMINSSZrrb_Intk
    9348U,	// VMINSSZrrb_Intkz
    72U,	// VMINSSrm
    72U,	// VMINSSrm_Int
    4U,	// VMINSSrr
    4U,	// VMINSSrr_Int
    0U,	// VMLAUNCH
    0U,	// VMLOAD32
    0U,	// VMLOAD64
    0U,	// VMMCALL
    0U,	// VMOV64toPQIZrm
    0U,	// VMOV64toPQIZrr
    0U,	// VMOV64toPQIrm
    0U,	// VMOV64toPQIrr
    0U,	// VMOV64toSDZrm
    0U,	// VMOV64toSDZrr
    0U,	// VMOV64toSDrm
    0U,	// VMOV64toSDrr
    0U,	// VMOVAPDYmr
    0U,	// VMOVAPDYrm
    0U,	// VMOVAPDYrr
    0U,	// VMOVAPDYrr_REV
    0U,	// VMOVAPDZ128mr
    49U,	// VMOVAPDZ128mrk
    0U,	// VMOVAPDZ128rm
    405U,	// VMOVAPDZ128rmk
    461U,	// VMOVAPDZ128rmkz
    0U,	// VMOVAPDZ128rr
    0U,	// VMOVAPDZ128rr_REV
    405U,	// VMOVAPDZ128rrk
    397U,	// VMOVAPDZ128rrk_REV
    461U,	// VMOVAPDZ128rrkz
    461U,	// VMOVAPDZ128rrkz_REV
    0U,	// VMOVAPDZ256mr
    49U,	// VMOVAPDZ256mrk
    0U,	// VMOVAPDZ256rm
    405U,	// VMOVAPDZ256rmk
    461U,	// VMOVAPDZ256rmkz
    0U,	// VMOVAPDZ256rr
    0U,	// VMOVAPDZ256rr_REV
    405U,	// VMOVAPDZ256rrk
    397U,	// VMOVAPDZ256rrk_REV
    461U,	// VMOVAPDZ256rrkz
    461U,	// VMOVAPDZ256rrkz_REV
    0U,	// VMOVAPDZmr
    49U,	// VMOVAPDZmrk
    0U,	// VMOVAPDZrm
    405U,	// VMOVAPDZrmk
    461U,	// VMOVAPDZrmkz
    0U,	// VMOVAPDZrr
    0U,	// VMOVAPDZrr_REV
    405U,	// VMOVAPDZrrk
    397U,	// VMOVAPDZrrk_REV
    461U,	// VMOVAPDZrrkz
    461U,	// VMOVAPDZrrkz_REV
    0U,	// VMOVAPDmr
    0U,	// VMOVAPDrm
    0U,	// VMOVAPDrr
    0U,	// VMOVAPDrr_REV
    0U,	// VMOVAPSYmr
    0U,	// VMOVAPSYrm
    0U,	// VMOVAPSYrr
    0U,	// VMOVAPSYrr_REV
    0U,	// VMOVAPSZ128mr
    49U,	// VMOVAPSZ128mrk
    0U,	// VMOVAPSZ128rm
    405U,	// VMOVAPSZ128rmk
    461U,	// VMOVAPSZ128rmkz
    0U,	// VMOVAPSZ128rr
    0U,	// VMOVAPSZ128rr_REV
    405U,	// VMOVAPSZ128rrk
    397U,	// VMOVAPSZ128rrk_REV
    461U,	// VMOVAPSZ128rrkz
    461U,	// VMOVAPSZ128rrkz_REV
    0U,	// VMOVAPSZ256mr
    49U,	// VMOVAPSZ256mrk
    0U,	// VMOVAPSZ256rm
    405U,	// VMOVAPSZ256rmk
    461U,	// VMOVAPSZ256rmkz
    0U,	// VMOVAPSZ256rr
    0U,	// VMOVAPSZ256rr_REV
    405U,	// VMOVAPSZ256rrk
    397U,	// VMOVAPSZ256rrk_REV
    461U,	// VMOVAPSZ256rrkz
    461U,	// VMOVAPSZ256rrkz_REV
    0U,	// VMOVAPSZmr
    49U,	// VMOVAPSZmrk
    0U,	// VMOVAPSZrm
    405U,	// VMOVAPSZrmk
    461U,	// VMOVAPSZrmkz
    0U,	// VMOVAPSZrr
    0U,	// VMOVAPSZrr_REV
    405U,	// VMOVAPSZrrk
    397U,	// VMOVAPSZrrk_REV
    461U,	// VMOVAPSZrrkz
    461U,	// VMOVAPSZrrkz_REV
    0U,	// VMOVAPSmr
    0U,	// VMOVAPSrm
    0U,	// VMOVAPSrr
    0U,	// VMOVAPSrr_REV
    0U,	// VMOVDDUPYrm
    0U,	// VMOVDDUPYrr
    0U,	// VMOVDDUPZ128rm
    3356U,	// VMOVDDUPZ128rmk
    4444U,	// VMOVDDUPZ128rmkz
    0U,	// VMOVDDUPZ128rr
    405U,	// VMOVDDUPZ128rrk
    461U,	// VMOVDDUPZ128rrkz
    0U,	// VMOVDDUPZ256rm
    405U,	// VMOVDDUPZ256rmk
    461U,	// VMOVDDUPZ256rmkz
    0U,	// VMOVDDUPZ256rr
    405U,	// VMOVDDUPZ256rrk
    461U,	// VMOVDDUPZ256rrkz
    0U,	// VMOVDDUPZrm
    405U,	// VMOVDDUPZrmk
    461U,	// VMOVDDUPZrmkz
    0U,	// VMOVDDUPZrr
    405U,	// VMOVDDUPZrrk
    461U,	// VMOVDDUPZrrkz
    0U,	// VMOVDDUPrm
    0U,	// VMOVDDUPrr
    0U,	// VMOVDI2PDIZrm
    0U,	// VMOVDI2PDIZrr
    0U,	// VMOVDI2PDIrm
    0U,	// VMOVDI2PDIrr
    0U,	// VMOVDI2SSZrm
    0U,	// VMOVDI2SSZrr
    0U,	// VMOVDI2SSrm
    0U,	// VMOVDI2SSrr
    0U,	// VMOVDQA32Z128mr
    49U,	// VMOVDQA32Z128mrk
    0U,	// VMOVDQA32Z128rm
    405U,	// VMOVDQA32Z128rmk
    461U,	// VMOVDQA32Z128rmkz
    0U,	// VMOVDQA32Z128rr
    0U,	// VMOVDQA32Z128rr_REV
    405U,	// VMOVDQA32Z128rrk
    397U,	// VMOVDQA32Z128rrk_REV
    461U,	// VMOVDQA32Z128rrkz
    461U,	// VMOVDQA32Z128rrkz_REV
    0U,	// VMOVDQA32Z256mr
    49U,	// VMOVDQA32Z256mrk
    0U,	// VMOVDQA32Z256rm
    405U,	// VMOVDQA32Z256rmk
    461U,	// VMOVDQA32Z256rmkz
    0U,	// VMOVDQA32Z256rr
    0U,	// VMOVDQA32Z256rr_REV
    405U,	// VMOVDQA32Z256rrk
    397U,	// VMOVDQA32Z256rrk_REV
    461U,	// VMOVDQA32Z256rrkz
    461U,	// VMOVDQA32Z256rrkz_REV
    0U,	// VMOVDQA32Zmr
    49U,	// VMOVDQA32Zmrk
    0U,	// VMOVDQA32Zrm
    405U,	// VMOVDQA32Zrmk
    461U,	// VMOVDQA32Zrmkz
    0U,	// VMOVDQA32Zrr
    0U,	// VMOVDQA32Zrr_REV
    405U,	// VMOVDQA32Zrrk
    397U,	// VMOVDQA32Zrrk_REV
    461U,	// VMOVDQA32Zrrkz
    461U,	// VMOVDQA32Zrrkz_REV
    0U,	// VMOVDQA64Z128mr
    49U,	// VMOVDQA64Z128mrk
    0U,	// VMOVDQA64Z128rm
    405U,	// VMOVDQA64Z128rmk
    461U,	// VMOVDQA64Z128rmkz
    0U,	// VMOVDQA64Z128rr
    0U,	// VMOVDQA64Z128rr_REV
    405U,	// VMOVDQA64Z128rrk
    397U,	// VMOVDQA64Z128rrk_REV
    461U,	// VMOVDQA64Z128rrkz
    461U,	// VMOVDQA64Z128rrkz_REV
    0U,	// VMOVDQA64Z256mr
    49U,	// VMOVDQA64Z256mrk
    0U,	// VMOVDQA64Z256rm
    405U,	// VMOVDQA64Z256rmk
    461U,	// VMOVDQA64Z256rmkz
    0U,	// VMOVDQA64Z256rr
    0U,	// VMOVDQA64Z256rr_REV
    405U,	// VMOVDQA64Z256rrk
    397U,	// VMOVDQA64Z256rrk_REV
    461U,	// VMOVDQA64Z256rrkz
    461U,	// VMOVDQA64Z256rrkz_REV
    0U,	// VMOVDQA64Zmr
    49U,	// VMOVDQA64Zmrk
    0U,	// VMOVDQA64Zrm
    405U,	// VMOVDQA64Zrmk
    461U,	// VMOVDQA64Zrmkz
    0U,	// VMOVDQA64Zrr
    0U,	// VMOVDQA64Zrr_REV
    405U,	// VMOVDQA64Zrrk
    397U,	// VMOVDQA64Zrrk_REV
    461U,	// VMOVDQA64Zrrkz
    461U,	// VMOVDQA64Zrrkz_REV
    0U,	// VMOVDQAYmr
    0U,	// VMOVDQAYrm
    0U,	// VMOVDQAYrr
    0U,	// VMOVDQAYrr_REV
    0U,	// VMOVDQAmr
    0U,	// VMOVDQArm
    0U,	// VMOVDQArr
    0U,	// VMOVDQArr_REV
    0U,	// VMOVDQU16Z128mr
    49U,	// VMOVDQU16Z128mrk
    0U,	// VMOVDQU16Z128rm
    405U,	// VMOVDQU16Z128rmk
    461U,	// VMOVDQU16Z128rmkz
    0U,	// VMOVDQU16Z128rr
    0U,	// VMOVDQU16Z128rr_REV
    405U,	// VMOVDQU16Z128rrk
    397U,	// VMOVDQU16Z128rrk_REV
    461U,	// VMOVDQU16Z128rrkz
    461U,	// VMOVDQU16Z128rrkz_REV
    0U,	// VMOVDQU16Z256mr
    49U,	// VMOVDQU16Z256mrk
    0U,	// VMOVDQU16Z256rm
    405U,	// VMOVDQU16Z256rmk
    461U,	// VMOVDQU16Z256rmkz
    0U,	// VMOVDQU16Z256rr
    0U,	// VMOVDQU16Z256rr_REV
    405U,	// VMOVDQU16Z256rrk
    397U,	// VMOVDQU16Z256rrk_REV
    461U,	// VMOVDQU16Z256rrkz
    461U,	// VMOVDQU16Z256rrkz_REV
    0U,	// VMOVDQU16Zmr
    49U,	// VMOVDQU16Zmrk
    0U,	// VMOVDQU16Zrm
    405U,	// VMOVDQU16Zrmk
    461U,	// VMOVDQU16Zrmkz
    0U,	// VMOVDQU16Zrr
    0U,	// VMOVDQU16Zrr_REV
    405U,	// VMOVDQU16Zrrk
    397U,	// VMOVDQU16Zrrk_REV
    461U,	// VMOVDQU16Zrrkz
    461U,	// VMOVDQU16Zrrkz_REV
    0U,	// VMOVDQU32Z128mr
    49U,	// VMOVDQU32Z128mrk
    0U,	// VMOVDQU32Z128rm
    405U,	// VMOVDQU32Z128rmk
    461U,	// VMOVDQU32Z128rmkz
    0U,	// VMOVDQU32Z128rr
    0U,	// VMOVDQU32Z128rr_REV
    405U,	// VMOVDQU32Z128rrk
    397U,	// VMOVDQU32Z128rrk_REV
    461U,	// VMOVDQU32Z128rrkz
    461U,	// VMOVDQU32Z128rrkz_REV
    0U,	// VMOVDQU32Z256mr
    49U,	// VMOVDQU32Z256mrk
    0U,	// VMOVDQU32Z256rm
    405U,	// VMOVDQU32Z256rmk
    461U,	// VMOVDQU32Z256rmkz
    0U,	// VMOVDQU32Z256rr
    0U,	// VMOVDQU32Z256rr_REV
    405U,	// VMOVDQU32Z256rrk
    397U,	// VMOVDQU32Z256rrk_REV
    461U,	// VMOVDQU32Z256rrkz
    461U,	// VMOVDQU32Z256rrkz_REV
    0U,	// VMOVDQU32Zmr
    49U,	// VMOVDQU32Zmrk
    0U,	// VMOVDQU32Zrm
    405U,	// VMOVDQU32Zrmk
    461U,	// VMOVDQU32Zrmkz
    0U,	// VMOVDQU32Zrr
    0U,	// VMOVDQU32Zrr_REV
    405U,	// VMOVDQU32Zrrk
    397U,	// VMOVDQU32Zrrk_REV
    461U,	// VMOVDQU32Zrrkz
    461U,	// VMOVDQU32Zrrkz_REV
    0U,	// VMOVDQU64Z128mr
    49U,	// VMOVDQU64Z128mrk
    0U,	// VMOVDQU64Z128rm
    405U,	// VMOVDQU64Z128rmk
    461U,	// VMOVDQU64Z128rmkz
    0U,	// VMOVDQU64Z128rr
    0U,	// VMOVDQU64Z128rr_REV
    405U,	// VMOVDQU64Z128rrk
    397U,	// VMOVDQU64Z128rrk_REV
    461U,	// VMOVDQU64Z128rrkz
    461U,	// VMOVDQU64Z128rrkz_REV
    0U,	// VMOVDQU64Z256mr
    49U,	// VMOVDQU64Z256mrk
    0U,	// VMOVDQU64Z256rm
    405U,	// VMOVDQU64Z256rmk
    461U,	// VMOVDQU64Z256rmkz
    0U,	// VMOVDQU64Z256rr
    0U,	// VMOVDQU64Z256rr_REV
    405U,	// VMOVDQU64Z256rrk
    397U,	// VMOVDQU64Z256rrk_REV
    461U,	// VMOVDQU64Z256rrkz
    461U,	// VMOVDQU64Z256rrkz_REV
    0U,	// VMOVDQU64Zmr
    49U,	// VMOVDQU64Zmrk
    0U,	// VMOVDQU64Zrm
    405U,	// VMOVDQU64Zrmk
    461U,	// VMOVDQU64Zrmkz
    0U,	// VMOVDQU64Zrr
    0U,	// VMOVDQU64Zrr_REV
    405U,	// VMOVDQU64Zrrk
    397U,	// VMOVDQU64Zrrk_REV
    461U,	// VMOVDQU64Zrrkz
    461U,	// VMOVDQU64Zrrkz_REV
    0U,	// VMOVDQU8Z128mr
    49U,	// VMOVDQU8Z128mrk
    0U,	// VMOVDQU8Z128rm
    405U,	// VMOVDQU8Z128rmk
    461U,	// VMOVDQU8Z128rmkz
    0U,	// VMOVDQU8Z128rr
    0U,	// VMOVDQU8Z128rr_REV
    405U,	// VMOVDQU8Z128rrk
    397U,	// VMOVDQU8Z128rrk_REV
    461U,	// VMOVDQU8Z128rrkz
    461U,	// VMOVDQU8Z128rrkz_REV
    0U,	// VMOVDQU8Z256mr
    49U,	// VMOVDQU8Z256mrk
    0U,	// VMOVDQU8Z256rm
    405U,	// VMOVDQU8Z256rmk
    461U,	// VMOVDQU8Z256rmkz
    0U,	// VMOVDQU8Z256rr
    0U,	// VMOVDQU8Z256rr_REV
    405U,	// VMOVDQU8Z256rrk
    397U,	// VMOVDQU8Z256rrk_REV
    461U,	// VMOVDQU8Z256rrkz
    461U,	// VMOVDQU8Z256rrkz_REV
    0U,	// VMOVDQU8Zmr
    49U,	// VMOVDQU8Zmrk
    0U,	// VMOVDQU8Zrm
    405U,	// VMOVDQU8Zrmk
    461U,	// VMOVDQU8Zrmkz
    0U,	// VMOVDQU8Zrr
    0U,	// VMOVDQU8Zrr_REV
    405U,	// VMOVDQU8Zrrk
    397U,	// VMOVDQU8Zrrk_REV
    461U,	// VMOVDQU8Zrrkz
    461U,	// VMOVDQU8Zrrkz_REV
    0U,	// VMOVDQUYmr
    0U,	// VMOVDQUYrm
    0U,	// VMOVDQUYrr
    0U,	// VMOVDQUYrr_REV
    0U,	// VMOVDQUmr
    0U,	// VMOVDQUrm
    0U,	// VMOVDQUrr
    0U,	// VMOVDQUrr_REV
    4U,	// VMOVHLPSZrr
    4U,	// VMOVHLPSrr
    0U,	// VMOVHPDZ128mr
    72U,	// VMOVHPDZ128rm
    0U,	// VMOVHPDmr
    72U,	// VMOVHPDrm
    0U,	// VMOVHPSZ128mr
    72U,	// VMOVHPSZ128rm
    0U,	// VMOVHPSmr
    72U,	// VMOVHPSrm
    4U,	// VMOVLHPSZrr
    4U,	// VMOVLHPSrr
    0U,	// VMOVLPDZ128mr
    72U,	// VMOVLPDZ128rm
    0U,	// VMOVLPDmr
    72U,	// VMOVLPDrm
    0U,	// VMOVLPSZ128mr
    72U,	// VMOVLPSZ128rm
    0U,	// VMOVLPSmr
    72U,	// VMOVLPSrm
    0U,	// VMOVMSKPDYrr
    0U,	// VMOVMSKPDrr
    0U,	// VMOVMSKPSYrr
    0U,	// VMOVMSKPSrr
    0U,	// VMOVNTDQAYrm
    0U,	// VMOVNTDQAZ128rm
    0U,	// VMOVNTDQAZ256rm
    0U,	// VMOVNTDQAZrm
    0U,	// VMOVNTDQArm
    0U,	// VMOVNTDQYmr
    0U,	// VMOVNTDQZ128mr
    0U,	// VMOVNTDQZ256mr
    0U,	// VMOVNTDQZmr
    0U,	// VMOVNTDQmr
    0U,	// VMOVNTPDYmr
    0U,	// VMOVNTPDZ128mr
    0U,	// VMOVNTPDZ256mr
    0U,	// VMOVNTPDZmr
    0U,	// VMOVNTPDmr
    0U,	// VMOVNTPSYmr
    0U,	// VMOVNTPSZ128mr
    0U,	// VMOVNTPSZ256mr
    0U,	// VMOVNTPSZmr
    0U,	// VMOVNTPSmr
    0U,	// VMOVPDI2DIZmr
    0U,	// VMOVPDI2DIZrr
    0U,	// VMOVPDI2DImr
    0U,	// VMOVPDI2DIrr
    0U,	// VMOVPQI2QIZmr
    0U,	// VMOVPQI2QIZrr
    0U,	// VMOVPQI2QImr
    0U,	// VMOVPQI2QIrr
    0U,	// VMOVPQIto64Zmr
    0U,	// VMOVPQIto64Zrr
    0U,	// VMOVPQIto64mr
    0U,	// VMOVPQIto64rr
    0U,	// VMOVQI2PQIZrm
    0U,	// VMOVQI2PQIrm
    0U,	// VMOVSDZmr
    49U,	// VMOVSDZmrk
    0U,	// VMOVSDZrm
    3356U,	// VMOVSDZrmk
    4444U,	// VMOVSDZrmkz
    4U,	// VMOVSDZrr
    4U,	// VMOVSDZrr_REV
    0U,	// VMOVSDZrrk
    0U,	// VMOVSDZrrk_REV
    9348U,	// VMOVSDZrrkz
    9348U,	// VMOVSDZrrkz_REV
    0U,	// VMOVSDmr
    0U,	// VMOVSDrm
    4U,	// VMOVSDrr
    4U,	// VMOVSDrr_REV
    0U,	// VMOVSDto64Zmr
    0U,	// VMOVSDto64Zrr
    0U,	// VMOVSDto64mr
    0U,	// VMOVSDto64rr
    0U,	// VMOVSHDUPYrm
    0U,	// VMOVSHDUPYrr
    0U,	// VMOVSHDUPZ128rm
    405U,	// VMOVSHDUPZ128rmk
    461U,	// VMOVSHDUPZ128rmkz
    0U,	// VMOVSHDUPZ128rr
    405U,	// VMOVSHDUPZ128rrk
    461U,	// VMOVSHDUPZ128rrkz
    0U,	// VMOVSHDUPZ256rm
    405U,	// VMOVSHDUPZ256rmk
    461U,	// VMOVSHDUPZ256rmkz
    0U,	// VMOVSHDUPZ256rr
    405U,	// VMOVSHDUPZ256rrk
    461U,	// VMOVSHDUPZ256rrkz
    0U,	// VMOVSHDUPZrm
    405U,	// VMOVSHDUPZrmk
    461U,	// VMOVSHDUPZrmkz
    0U,	// VMOVSHDUPZrr
    405U,	// VMOVSHDUPZrrk
    461U,	// VMOVSHDUPZrrkz
    0U,	// VMOVSHDUPrm
    0U,	// VMOVSHDUPrr
    0U,	// VMOVSLDUPYrm
    0U,	// VMOVSLDUPYrr
    0U,	// VMOVSLDUPZ128rm
    405U,	// VMOVSLDUPZ128rmk
    461U,	// VMOVSLDUPZ128rmkz
    0U,	// VMOVSLDUPZ128rr
    405U,	// VMOVSLDUPZ128rrk
    461U,	// VMOVSLDUPZ128rrkz
    0U,	// VMOVSLDUPZ256rm
    405U,	// VMOVSLDUPZ256rmk
    461U,	// VMOVSLDUPZ256rmkz
    0U,	// VMOVSLDUPZ256rr
    405U,	// VMOVSLDUPZ256rrk
    461U,	// VMOVSLDUPZ256rrkz
    0U,	// VMOVSLDUPZrm
    405U,	// VMOVSLDUPZrmk
    461U,	// VMOVSLDUPZrmkz
    0U,	// VMOVSLDUPZrr
    405U,	// VMOVSLDUPZrrk
    461U,	// VMOVSLDUPZrrkz
    0U,	// VMOVSLDUPrm
    0U,	// VMOVSLDUPrr
    0U,	// VMOVSS2DIZmr
    0U,	// VMOVSS2DIZrr
    0U,	// VMOVSS2DImr
    0U,	// VMOVSS2DIrr
    0U,	// VMOVSSZmr
    49U,	// VMOVSSZmrk
    0U,	// VMOVSSZrm
    3356U,	// VMOVSSZrmk
    4444U,	// VMOVSSZrmkz
    4U,	// VMOVSSZrr
    4U,	// VMOVSSZrr_REV
    0U,	// VMOVSSZrrk
    0U,	// VMOVSSZrrk_REV
    9348U,	// VMOVSSZrrkz
    9348U,	// VMOVSSZrrkz_REV
    0U,	// VMOVSSmr
    0U,	// VMOVSSrm
    4U,	// VMOVSSrr
    4U,	// VMOVSSrr_REV
    0U,	// VMOVUPDYmr
    0U,	// VMOVUPDYrm
    0U,	// VMOVUPDYrr
    0U,	// VMOVUPDYrr_REV
    0U,	// VMOVUPDZ128mr
    49U,	// VMOVUPDZ128mrk
    0U,	// VMOVUPDZ128rm
    405U,	// VMOVUPDZ128rmk
    461U,	// VMOVUPDZ128rmkz
    0U,	// VMOVUPDZ128rr
    0U,	// VMOVUPDZ128rr_REV
    405U,	// VMOVUPDZ128rrk
    397U,	// VMOVUPDZ128rrk_REV
    461U,	// VMOVUPDZ128rrkz
    461U,	// VMOVUPDZ128rrkz_REV
    0U,	// VMOVUPDZ256mr
    49U,	// VMOVUPDZ256mrk
    0U,	// VMOVUPDZ256rm
    405U,	// VMOVUPDZ256rmk
    461U,	// VMOVUPDZ256rmkz
    0U,	// VMOVUPDZ256rr
    0U,	// VMOVUPDZ256rr_REV
    405U,	// VMOVUPDZ256rrk
    397U,	// VMOVUPDZ256rrk_REV
    461U,	// VMOVUPDZ256rrkz
    461U,	// VMOVUPDZ256rrkz_REV
    0U,	// VMOVUPDZmr
    49U,	// VMOVUPDZmrk
    0U,	// VMOVUPDZrm
    405U,	// VMOVUPDZrmk
    461U,	// VMOVUPDZrmkz
    0U,	// VMOVUPDZrr
    0U,	// VMOVUPDZrr_REV
    405U,	// VMOVUPDZrrk
    397U,	// VMOVUPDZrrk_REV
    461U,	// VMOVUPDZrrkz
    461U,	// VMOVUPDZrrkz_REV
    0U,	// VMOVUPDmr
    0U,	// VMOVUPDrm
    0U,	// VMOVUPDrr
    0U,	// VMOVUPDrr_REV
    0U,	// VMOVUPSYmr
    0U,	// VMOVUPSYrm
    0U,	// VMOVUPSYrr
    0U,	// VMOVUPSYrr_REV
    0U,	// VMOVUPSZ128mr
    49U,	// VMOVUPSZ128mrk
    0U,	// VMOVUPSZ128rm
    405U,	// VMOVUPSZ128rmk
    461U,	// VMOVUPSZ128rmkz
    0U,	// VMOVUPSZ128rr
    0U,	// VMOVUPSZ128rr_REV
    405U,	// VMOVUPSZ128rrk
    397U,	// VMOVUPSZ128rrk_REV
    461U,	// VMOVUPSZ128rrkz
    461U,	// VMOVUPSZ128rrkz_REV
    0U,	// VMOVUPSZ256mr
    49U,	// VMOVUPSZ256mrk
    0U,	// VMOVUPSZ256rm
    405U,	// VMOVUPSZ256rmk
    461U,	// VMOVUPSZ256rmkz
    0U,	// VMOVUPSZ256rr
    0U,	// VMOVUPSZ256rr_REV
    405U,	// VMOVUPSZ256rrk
    397U,	// VMOVUPSZ256rrk_REV
    461U,	// VMOVUPSZ256rrkz
    461U,	// VMOVUPSZ256rrkz_REV
    0U,	// VMOVUPSZmr
    49U,	// VMOVUPSZmrk
    0U,	// VMOVUPSZrm
    405U,	// VMOVUPSZrmk
    461U,	// VMOVUPSZrmkz
    0U,	// VMOVUPSZrr
    0U,	// VMOVUPSZrr_REV
    405U,	// VMOVUPSZrrk
    397U,	// VMOVUPSZrrk_REV
    461U,	// VMOVUPSZrrkz
    461U,	// VMOVUPSZrrkz_REV
    0U,	// VMOVUPSmr
    0U,	// VMOVUPSrm
    0U,	// VMOVUPSrr
    0U,	// VMOVUPSrr_REV
    0U,	// VMOVZPQILo2PQIZrr
    0U,	// VMOVZPQILo2PQIrr
    72U,	// VMPSADBWYrmi
    18636U,	// VMPSADBWYrri
    72U,	// VMPSADBWrmi
    18636U,	// VMPSADBWrri
    0U,	// VMPTRLDm
    0U,	// VMPTRSTm
    0U,	// VMREAD32mr
    0U,	// VMREAD32rr
    0U,	// VMREAD64mr
    0U,	// VMREAD64rr
    0U,	// VMRESUME
    0U,	// VMRUN32
    0U,	// VMRUN64
    0U,	// VMSAVE32
    0U,	// VMSAVE64
    4U,	// VMULPDYrm
    4U,	// VMULPDYrr
    4U,	// VMULPDZ128rm
    72U,	// VMULPDZ128rmb
    133U,	// VMULPDZ128rmbk
    9348U,	// VMULPDZ128rmbkz
    0U,	// VMULPDZ128rmk
    9348U,	// VMULPDZ128rmkz
    4U,	// VMULPDZ128rr
    0U,	// VMULPDZ128rrk
    9348U,	// VMULPDZ128rrkz
    4U,	// VMULPDZ256rm
    72U,	// VMULPDZ256rmb
    133U,	// VMULPDZ256rmbk
    9348U,	// VMULPDZ256rmbkz
    0U,	// VMULPDZ256rmk
    9348U,	// VMULPDZ256rmkz
    4U,	// VMULPDZ256rr
    0U,	// VMULPDZ256rrk
    9348U,	// VMULPDZ256rrkz
    4U,	// VMULPDZrm
    72U,	// VMULPDZrmb
    133U,	// VMULPDZrmbk
    9348U,	// VMULPDZrmbkz
    0U,	// VMULPDZrmk
    9348U,	// VMULPDZrmkz
    4U,	// VMULPDZrr
    4U,	// VMULPDZrrb
    0U,	// VMULPDZrrbk
    9348U,	// VMULPDZrrbkz
    0U,	// VMULPDZrrk
    9348U,	// VMULPDZrrkz
    4U,	// VMULPDrm
    4U,	// VMULPDrr
    4U,	// VMULPSYrm
    4U,	// VMULPSYrr
    4U,	// VMULPSZ128rm
    72U,	// VMULPSZ128rmb
    133U,	// VMULPSZ128rmbk
    9348U,	// VMULPSZ128rmbkz
    0U,	// VMULPSZ128rmk
    9348U,	// VMULPSZ128rmkz
    4U,	// VMULPSZ128rr
    0U,	// VMULPSZ128rrk
    9348U,	// VMULPSZ128rrkz
    4U,	// VMULPSZ256rm
    72U,	// VMULPSZ256rmb
    133U,	// VMULPSZ256rmbk
    9348U,	// VMULPSZ256rmbkz
    0U,	// VMULPSZ256rmk
    9348U,	// VMULPSZ256rmkz
    4U,	// VMULPSZ256rr
    0U,	// VMULPSZ256rrk
    9348U,	// VMULPSZ256rrkz
    4U,	// VMULPSZrm
    72U,	// VMULPSZrmb
    133U,	// VMULPSZrmbk
    9348U,	// VMULPSZrmbkz
    0U,	// VMULPSZrmk
    9348U,	// VMULPSZrmkz
    4U,	// VMULPSZrr
    4U,	// VMULPSZrrb
    0U,	// VMULPSZrrbk
    9348U,	// VMULPSZrrbkz
    0U,	// VMULPSZrrk
    9348U,	// VMULPSZrrkz
    4U,	// VMULPSrm
    4U,	// VMULPSrr
    72U,	// VMULSDZrm
    72U,	// VMULSDZrm_Int
    133U,	// VMULSDZrm_Intk
    9348U,	// VMULSDZrm_Intkz
    4U,	// VMULSDZrr
    4U,	// VMULSDZrr_Int
    0U,	// VMULSDZrr_Intk
    9348U,	// VMULSDZrr_Intkz
    4U,	// VMULSDZrrb_Int
    0U,	// VMULSDZrrb_Intk
    9348U,	// VMULSDZrrb_Intkz
    72U,	// VMULSDrm
    72U,	// VMULSDrm_Int
    4U,	// VMULSDrr
    4U,	// VMULSDrr_Int
    72U,	// VMULSSZrm
    72U,	// VMULSSZrm_Int
    133U,	// VMULSSZrm_Intk
    9348U,	// VMULSSZrm_Intkz
    4U,	// VMULSSZrr
    4U,	// VMULSSZrr_Int
    0U,	// VMULSSZrr_Intk
    9348U,	// VMULSSZrr_Intkz
    4U,	// VMULSSZrrb_Int
    0U,	// VMULSSZrrb_Intk
    9348U,	// VMULSSZrrb_Intkz
    72U,	// VMULSSrm
    72U,	// VMULSSrm_Int
    4U,	// VMULSSrr
    4U,	// VMULSSrr_Int
    0U,	// VMWRITE32rm
    0U,	// VMWRITE32rr
    0U,	// VMWRITE64rm
    0U,	// VMWRITE64rr
    0U,	// VMXOFF
    0U,	// VMXON
    4U,	// VORPDYrm
    4U,	// VORPDYrr
    4U,	// VORPDZ128rm
    72U,	// VORPDZ128rmb
    133U,	// VORPDZ128rmbk
    9348U,	// VORPDZ128rmbkz
    0U,	// VORPDZ128rmk
    9348U,	// VORPDZ128rmkz
    4U,	// VORPDZ128rr
    0U,	// VORPDZ128rrk
    9348U,	// VORPDZ128rrkz
    4U,	// VORPDZ256rm
    72U,	// VORPDZ256rmb
    133U,	// VORPDZ256rmbk
    9348U,	// VORPDZ256rmbkz
    0U,	// VORPDZ256rmk
    9348U,	// VORPDZ256rmkz
    4U,	// VORPDZ256rr
    0U,	// VORPDZ256rrk
    9348U,	// VORPDZ256rrkz
    4U,	// VORPDZrm
    72U,	// VORPDZrmb
    133U,	// VORPDZrmbk
    9348U,	// VORPDZrmbkz
    0U,	// VORPDZrmk
    9348U,	// VORPDZrmkz
    4U,	// VORPDZrr
    0U,	// VORPDZrrk
    9348U,	// VORPDZrrkz
    4U,	// VORPDrm
    4U,	// VORPDrr
    4U,	// VORPSYrm
    4U,	// VORPSYrr
    4U,	// VORPSZ128rm
    72U,	// VORPSZ128rmb
    133U,	// VORPSZ128rmbk
    9348U,	// VORPSZ128rmbkz
    0U,	// VORPSZ128rmk
    9348U,	// VORPSZ128rmkz
    4U,	// VORPSZ128rr
    0U,	// VORPSZ128rrk
    9348U,	// VORPSZ128rrkz
    4U,	// VORPSZ256rm
    72U,	// VORPSZ256rmb
    133U,	// VORPSZ256rmbk
    9348U,	// VORPSZ256rmbkz
    0U,	// VORPSZ256rmk
    9348U,	// VORPSZ256rmkz
    4U,	// VORPSZ256rr
    0U,	// VORPSZ256rrk
    9348U,	// VORPSZ256rrkz
    4U,	// VORPSZrm
    72U,	// VORPSZrmb
    133U,	// VORPSZrmbk
    9348U,	// VORPSZrmbkz
    0U,	// VORPSZrmk
    9348U,	// VORPSZrmkz
    4U,	// VORPSZrr
    0U,	// VORPSZrrk
    9348U,	// VORPSZrrkz
    4U,	// VORPSrm
    4U,	// VORPSrr
    4U,	// VP4DPWSSDSrm
    0U,	// VP4DPWSSDSrmk
    0U,	// VP4DPWSSDSrmkz
    4U,	// VP4DPWSSDrm
    0U,	// VP4DPWSSDrmk
    0U,	// VP4DPWSSDrmkz
    0U,	// VPABSBYrm
    0U,	// VPABSBYrr
    0U,	// VPABSBZ128rm
    405U,	// VPABSBZ128rmk
    461U,	// VPABSBZ128rmkz
    0U,	// VPABSBZ128rr
    405U,	// VPABSBZ128rrk
    461U,	// VPABSBZ128rrkz
    0U,	// VPABSBZ256rm
    405U,	// VPABSBZ256rmk
    461U,	// VPABSBZ256rmkz
    0U,	// VPABSBZ256rr
    405U,	// VPABSBZ256rrk
    461U,	// VPABSBZ256rrkz
    0U,	// VPABSBZrm
    405U,	// VPABSBZrmk
    461U,	// VPABSBZrmkz
    0U,	// VPABSBZrr
    405U,	// VPABSBZrrk
    461U,	// VPABSBZrrkz
    0U,	// VPABSBrm
    0U,	// VPABSBrr
    0U,	// VPABSDYrm
    0U,	// VPABSDYrr
    0U,	// VPABSDZ128rm
    0U,	// VPABSDZ128rmb
    3356U,	// VPABSDZ128rmbk
    4444U,	// VPABSDZ128rmbkz
    405U,	// VPABSDZ128rmk
    461U,	// VPABSDZ128rmkz
    0U,	// VPABSDZ128rr
    405U,	// VPABSDZ128rrk
    461U,	// VPABSDZ128rrkz
    0U,	// VPABSDZ256rm
    0U,	// VPABSDZ256rmb
    3356U,	// VPABSDZ256rmbk
    4444U,	// VPABSDZ256rmbkz
    405U,	// VPABSDZ256rmk
    461U,	// VPABSDZ256rmkz
    0U,	// VPABSDZ256rr
    405U,	// VPABSDZ256rrk
    461U,	// VPABSDZ256rrkz
    0U,	// VPABSDZrm
    0U,	// VPABSDZrmb
    3356U,	// VPABSDZrmbk
    4444U,	// VPABSDZrmbkz
    405U,	// VPABSDZrmk
    461U,	// VPABSDZrmkz
    0U,	// VPABSDZrr
    405U,	// VPABSDZrrk
    461U,	// VPABSDZrrkz
    0U,	// VPABSDrm
    0U,	// VPABSDrr
    0U,	// VPABSQZ128rm
    0U,	// VPABSQZ128rmb
    3356U,	// VPABSQZ128rmbk
    4444U,	// VPABSQZ128rmbkz
    405U,	// VPABSQZ128rmk
    461U,	// VPABSQZ128rmkz
    0U,	// VPABSQZ128rr
    405U,	// VPABSQZ128rrk
    461U,	// VPABSQZ128rrkz
    0U,	// VPABSQZ256rm
    0U,	// VPABSQZ256rmb
    3356U,	// VPABSQZ256rmbk
    4444U,	// VPABSQZ256rmbkz
    405U,	// VPABSQZ256rmk
    461U,	// VPABSQZ256rmkz
    0U,	// VPABSQZ256rr
    405U,	// VPABSQZ256rrk
    461U,	// VPABSQZ256rrkz
    0U,	// VPABSQZrm
    0U,	// VPABSQZrmb
    3356U,	// VPABSQZrmbk
    4444U,	// VPABSQZrmbkz
    405U,	// VPABSQZrmk
    461U,	// VPABSQZrmkz
    0U,	// VPABSQZrr
    405U,	// VPABSQZrrk
    461U,	// VPABSQZrrkz
    0U,	// VPABSWYrm
    0U,	// VPABSWYrr
    0U,	// VPABSWZ128rm
    405U,	// VPABSWZ128rmk
    461U,	// VPABSWZ128rmkz
    0U,	// VPABSWZ128rr
    405U,	// VPABSWZ128rrk
    461U,	// VPABSWZ128rrkz
    0U,	// VPABSWZ256rm
    405U,	// VPABSWZ256rmk
    461U,	// VPABSWZ256rmkz
    0U,	// VPABSWZ256rr
    405U,	// VPABSWZ256rrk
    461U,	// VPABSWZ256rrkz
    0U,	// VPABSWZrm
    405U,	// VPABSWZrmk
    461U,	// VPABSWZrmkz
    0U,	// VPABSWZrr
    405U,	// VPABSWZrrk
    461U,	// VPABSWZrrkz
    0U,	// VPABSWrm
    0U,	// VPABSWrr
    4U,	// VPACKSSDWYrm
    4U,	// VPACKSSDWYrr
    4U,	// VPACKSSDWZ128rm
    72U,	// VPACKSSDWZ128rmb
    133U,	// VPACKSSDWZ128rmbk
    9348U,	// VPACKSSDWZ128rmbkz
    132U,	// VPACKSSDWZ128rmk
    9348U,	// VPACKSSDWZ128rmkz
    4U,	// VPACKSSDWZ128rr
    0U,	// VPACKSSDWZ128rrk
    9348U,	// VPACKSSDWZ128rrkz
    4U,	// VPACKSSDWZ256rm
    72U,	// VPACKSSDWZ256rmb
    133U,	// VPACKSSDWZ256rmbk
    9348U,	// VPACKSSDWZ256rmbkz
    132U,	// VPACKSSDWZ256rmk
    9348U,	// VPACKSSDWZ256rmkz
    4U,	// VPACKSSDWZ256rr
    0U,	// VPACKSSDWZ256rrk
    9348U,	// VPACKSSDWZ256rrkz
    4U,	// VPACKSSDWZrm
    72U,	// VPACKSSDWZrmb
    133U,	// VPACKSSDWZrmbk
    9348U,	// VPACKSSDWZrmbkz
    132U,	// VPACKSSDWZrmk
    9348U,	// VPACKSSDWZrmkz
    4U,	// VPACKSSDWZrr
    0U,	// VPACKSSDWZrrk
    9348U,	// VPACKSSDWZrrkz
    4U,	// VPACKSSDWrm
    4U,	// VPACKSSDWrr
    4U,	// VPACKSSWBYrm
    4U,	// VPACKSSWBYrr
    4U,	// VPACKSSWBZ128rm
    132U,	// VPACKSSWBZ128rmk
    9348U,	// VPACKSSWBZ128rmkz
    4U,	// VPACKSSWBZ128rr
    0U,	// VPACKSSWBZ128rrk
    9348U,	// VPACKSSWBZ128rrkz
    4U,	// VPACKSSWBZ256rm
    132U,	// VPACKSSWBZ256rmk
    9348U,	// VPACKSSWBZ256rmkz
    4U,	// VPACKSSWBZ256rr
    0U,	// VPACKSSWBZ256rrk
    9348U,	// VPACKSSWBZ256rrkz
    4U,	// VPACKSSWBZrm
    132U,	// VPACKSSWBZrmk
    9348U,	// VPACKSSWBZrmkz
    4U,	// VPACKSSWBZrr
    0U,	// VPACKSSWBZrrk
    9348U,	// VPACKSSWBZrrkz
    4U,	// VPACKSSWBrm
    4U,	// VPACKSSWBrr
    4U,	// VPACKUSDWYrm
    4U,	// VPACKUSDWYrr
    4U,	// VPACKUSDWZ128rm
    72U,	// VPACKUSDWZ128rmb
    133U,	// VPACKUSDWZ128rmbk
    9348U,	// VPACKUSDWZ128rmbkz
    132U,	// VPACKUSDWZ128rmk
    9348U,	// VPACKUSDWZ128rmkz
    4U,	// VPACKUSDWZ128rr
    0U,	// VPACKUSDWZ128rrk
    9348U,	// VPACKUSDWZ128rrkz
    4U,	// VPACKUSDWZ256rm
    72U,	// VPACKUSDWZ256rmb
    133U,	// VPACKUSDWZ256rmbk
    9348U,	// VPACKUSDWZ256rmbkz
    132U,	// VPACKUSDWZ256rmk
    9348U,	// VPACKUSDWZ256rmkz
    4U,	// VPACKUSDWZ256rr
    0U,	// VPACKUSDWZ256rrk
    9348U,	// VPACKUSDWZ256rrkz
    4U,	// VPACKUSDWZrm
    72U,	// VPACKUSDWZrmb
    133U,	// VPACKUSDWZrmbk
    9348U,	// VPACKUSDWZrmbkz
    132U,	// VPACKUSDWZrmk
    9348U,	// VPACKUSDWZrmkz
    4U,	// VPACKUSDWZrr
    0U,	// VPACKUSDWZrrk
    9348U,	// VPACKUSDWZrrkz
    4U,	// VPACKUSDWrm
    4U,	// VPACKUSDWrr
    4U,	// VPACKUSWBYrm
    4U,	// VPACKUSWBYrr
    4U,	// VPACKUSWBZ128rm
    132U,	// VPACKUSWBZ128rmk
    9348U,	// VPACKUSWBZ128rmkz
    4U,	// VPACKUSWBZ128rr
    0U,	// VPACKUSWBZ128rrk
    9348U,	// VPACKUSWBZ128rrkz
    4U,	// VPACKUSWBZ256rm
    132U,	// VPACKUSWBZ256rmk
    9348U,	// VPACKUSWBZ256rmkz
    4U,	// VPACKUSWBZ256rr
    0U,	// VPACKUSWBZ256rrk
    9348U,	// VPACKUSWBZ256rrkz
    4U,	// VPACKUSWBZrm
    132U,	// VPACKUSWBZrmk
    9348U,	// VPACKUSWBZrmkz
    4U,	// VPACKUSWBZrr
    0U,	// VPACKUSWBZrrk
    9348U,	// VPACKUSWBZrrkz
    4U,	// VPACKUSWBrm
    4U,	// VPACKUSWBrr
    4U,	// VPADDBYrm
    4U,	// VPADDBYrr
    4U,	// VPADDBZ128rm
    132U,	// VPADDBZ128rmk
    9348U,	// VPADDBZ128rmkz
    4U,	// VPADDBZ128rr
    0U,	// VPADDBZ128rrk
    9348U,	// VPADDBZ128rrkz
    4U,	// VPADDBZ256rm
    132U,	// VPADDBZ256rmk
    9348U,	// VPADDBZ256rmkz
    4U,	// VPADDBZ256rr
    0U,	// VPADDBZ256rrk
    9348U,	// VPADDBZ256rrkz
    4U,	// VPADDBZrm
    132U,	// VPADDBZrmk
    9348U,	// VPADDBZrmkz
    4U,	// VPADDBZrr
    0U,	// VPADDBZrrk
    9348U,	// VPADDBZrrkz
    4U,	// VPADDBrm
    4U,	// VPADDBrr
    4U,	// VPADDDYrm
    4U,	// VPADDDYrr
    4U,	// VPADDDZ128rm
    72U,	// VPADDDZ128rmb
    133U,	// VPADDDZ128rmbk
    9348U,	// VPADDDZ128rmbkz
    132U,	// VPADDDZ128rmk
    9348U,	// VPADDDZ128rmkz
    4U,	// VPADDDZ128rr
    0U,	// VPADDDZ128rrk
    9348U,	// VPADDDZ128rrkz
    4U,	// VPADDDZ256rm
    72U,	// VPADDDZ256rmb
    133U,	// VPADDDZ256rmbk
    9348U,	// VPADDDZ256rmbkz
    132U,	// VPADDDZ256rmk
    9348U,	// VPADDDZ256rmkz
    4U,	// VPADDDZ256rr
    0U,	// VPADDDZ256rrk
    9348U,	// VPADDDZ256rrkz
    4U,	// VPADDDZrm
    72U,	// VPADDDZrmb
    133U,	// VPADDDZrmbk
    9348U,	// VPADDDZrmbkz
    132U,	// VPADDDZrmk
    9348U,	// VPADDDZrmkz
    4U,	// VPADDDZrr
    0U,	// VPADDDZrrk
    9348U,	// VPADDDZrrkz
    4U,	// VPADDDrm
    4U,	// VPADDDrr
    4U,	// VPADDQYrm
    4U,	// VPADDQYrr
    4U,	// VPADDQZ128rm
    72U,	// VPADDQZ128rmb
    133U,	// VPADDQZ128rmbk
    9348U,	// VPADDQZ128rmbkz
    132U,	// VPADDQZ128rmk
    9348U,	// VPADDQZ128rmkz
    4U,	// VPADDQZ128rr
    0U,	// VPADDQZ128rrk
    9348U,	// VPADDQZ128rrkz
    4U,	// VPADDQZ256rm
    72U,	// VPADDQZ256rmb
    133U,	// VPADDQZ256rmbk
    9348U,	// VPADDQZ256rmbkz
    132U,	// VPADDQZ256rmk
    9348U,	// VPADDQZ256rmkz
    4U,	// VPADDQZ256rr
    0U,	// VPADDQZ256rrk
    9348U,	// VPADDQZ256rrkz
    4U,	// VPADDQZrm
    72U,	// VPADDQZrmb
    133U,	// VPADDQZrmbk
    9348U,	// VPADDQZrmbkz
    132U,	// VPADDQZrmk
    9348U,	// VPADDQZrmkz
    4U,	// VPADDQZrr
    0U,	// VPADDQZrrk
    9348U,	// VPADDQZrrkz
    4U,	// VPADDQrm
    4U,	// VPADDQrr
    4U,	// VPADDSBYrm
    4U,	// VPADDSBYrr
    4U,	// VPADDSBZ128rm
    132U,	// VPADDSBZ128rmk
    9348U,	// VPADDSBZ128rmkz
    4U,	// VPADDSBZ128rr
    0U,	// VPADDSBZ128rrk
    9348U,	// VPADDSBZ128rrkz
    4U,	// VPADDSBZ256rm
    132U,	// VPADDSBZ256rmk
    9348U,	// VPADDSBZ256rmkz
    4U,	// VPADDSBZ256rr
    0U,	// VPADDSBZ256rrk
    9348U,	// VPADDSBZ256rrkz
    4U,	// VPADDSBZrm
    132U,	// VPADDSBZrmk
    9348U,	// VPADDSBZrmkz
    4U,	// VPADDSBZrr
    0U,	// VPADDSBZrrk
    9348U,	// VPADDSBZrrkz
    4U,	// VPADDSBrm
    4U,	// VPADDSBrr
    4U,	// VPADDSWYrm
    4U,	// VPADDSWYrr
    4U,	// VPADDSWZ128rm
    132U,	// VPADDSWZ128rmk
    9348U,	// VPADDSWZ128rmkz
    4U,	// VPADDSWZ128rr
    0U,	// VPADDSWZ128rrk
    9348U,	// VPADDSWZ128rrkz
    4U,	// VPADDSWZ256rm
    132U,	// VPADDSWZ256rmk
    9348U,	// VPADDSWZ256rmkz
    4U,	// VPADDSWZ256rr
    0U,	// VPADDSWZ256rrk
    9348U,	// VPADDSWZ256rrkz
    4U,	// VPADDSWZrm
    132U,	// VPADDSWZrmk
    9348U,	// VPADDSWZrmkz
    4U,	// VPADDSWZrr
    0U,	// VPADDSWZrrk
    9348U,	// VPADDSWZrrkz
    4U,	// VPADDSWrm
    4U,	// VPADDSWrr
    4U,	// VPADDUSBYrm
    4U,	// VPADDUSBYrr
    4U,	// VPADDUSBZ128rm
    132U,	// VPADDUSBZ128rmk
    9348U,	// VPADDUSBZ128rmkz
    4U,	// VPADDUSBZ128rr
    0U,	// VPADDUSBZ128rrk
    9348U,	// VPADDUSBZ128rrkz
    4U,	// VPADDUSBZ256rm
    132U,	// VPADDUSBZ256rmk
    9348U,	// VPADDUSBZ256rmkz
    4U,	// VPADDUSBZ256rr
    0U,	// VPADDUSBZ256rrk
    9348U,	// VPADDUSBZ256rrkz
    4U,	// VPADDUSBZrm
    132U,	// VPADDUSBZrmk
    9348U,	// VPADDUSBZrmkz
    4U,	// VPADDUSBZrr
    0U,	// VPADDUSBZrrk
    9348U,	// VPADDUSBZrrkz
    4U,	// VPADDUSBrm
    4U,	// VPADDUSBrr
    4U,	// VPADDUSWYrm
    4U,	// VPADDUSWYrr
    4U,	// VPADDUSWZ128rm
    132U,	// VPADDUSWZ128rmk
    9348U,	// VPADDUSWZ128rmkz
    4U,	// VPADDUSWZ128rr
    0U,	// VPADDUSWZ128rrk
    9348U,	// VPADDUSWZ128rrkz
    4U,	// VPADDUSWZ256rm
    132U,	// VPADDUSWZ256rmk
    9348U,	// VPADDUSWZ256rmkz
    4U,	// VPADDUSWZ256rr
    0U,	// VPADDUSWZ256rrk
    9348U,	// VPADDUSWZ256rrkz
    4U,	// VPADDUSWZrm
    132U,	// VPADDUSWZrmk
    9348U,	// VPADDUSWZrmkz
    4U,	// VPADDUSWZrr
    0U,	// VPADDUSWZrrk
    9348U,	// VPADDUSWZrrkz
    4U,	// VPADDUSWrm
    4U,	// VPADDUSWrr
    4U,	// VPADDWYrm
    4U,	// VPADDWYrr
    4U,	// VPADDWZ128rm
    132U,	// VPADDWZ128rmk
    9348U,	// VPADDWZ128rmkz
    4U,	// VPADDWZ128rr
    0U,	// VPADDWZ128rrk
    9348U,	// VPADDWZ128rrkz
    4U,	// VPADDWZ256rm
    132U,	// VPADDWZ256rmk
    9348U,	// VPADDWZ256rmkz
    4U,	// VPADDWZ256rr
    0U,	// VPADDWZ256rrk
    9348U,	// VPADDWZ256rrkz
    4U,	// VPADDWZrm
    132U,	// VPADDWZrmk
    9348U,	// VPADDWZrmkz
    4U,	// VPADDWZrr
    0U,	// VPADDWZrrk
    9348U,	// VPADDWZrrkz
    4U,	// VPADDWrm
    4U,	// VPADDWrr
    72U,	// VPALIGNRYrmi
    18636U,	// VPALIGNRYrri
    72U,	// VPALIGNRZ128rmi
    1U,	// VPALIGNRZ128rmik
    9348U,	// VPALIGNRZ128rmikz
    18636U,	// VPALIGNRZ128rri
    25U,	// VPALIGNRZ128rrik
    26837U,	// VPALIGNRZ128rrikz
    72U,	// VPALIGNRZ256rmi
    1U,	// VPALIGNRZ256rmik
    9348U,	// VPALIGNRZ256rmikz
    18636U,	// VPALIGNRZ256rri
    25U,	// VPALIGNRZ256rrik
    26837U,	// VPALIGNRZ256rrikz
    72U,	// VPALIGNRZrmi
    1U,	// VPALIGNRZrmik
    9348U,	// VPALIGNRZrmikz
    18636U,	// VPALIGNRZrri
    25U,	// VPALIGNRZrrik
    26837U,	// VPALIGNRZrrikz
    72U,	// VPALIGNRrmi
    18636U,	// VPALIGNRrri
    4U,	// VPANDDZ128rm
    72U,	// VPANDDZ128rmb
    133U,	// VPANDDZ128rmbk
    9348U,	// VPANDDZ128rmbkz
    132U,	// VPANDDZ128rmk
    9348U,	// VPANDDZ128rmkz
    4U,	// VPANDDZ128rr
    0U,	// VPANDDZ128rrk
    9348U,	// VPANDDZ128rrkz
    4U,	// VPANDDZ256rm
    72U,	// VPANDDZ256rmb
    133U,	// VPANDDZ256rmbk
    9348U,	// VPANDDZ256rmbkz
    132U,	// VPANDDZ256rmk
    9348U,	// VPANDDZ256rmkz
    4U,	// VPANDDZ256rr
    0U,	// VPANDDZ256rrk
    9348U,	// VPANDDZ256rrkz
    4U,	// VPANDDZrm
    72U,	// VPANDDZrmb
    133U,	// VPANDDZrmbk
    9348U,	// VPANDDZrmbkz
    132U,	// VPANDDZrmk
    9348U,	// VPANDDZrmkz
    4U,	// VPANDDZrr
    0U,	// VPANDDZrrk
    9348U,	// VPANDDZrrkz
    4U,	// VPANDNDZ128rm
    72U,	// VPANDNDZ128rmb
    133U,	// VPANDNDZ128rmbk
    9348U,	// VPANDNDZ128rmbkz
    132U,	// VPANDNDZ128rmk
    9348U,	// VPANDNDZ128rmkz
    4U,	// VPANDNDZ128rr
    0U,	// VPANDNDZ128rrk
    9348U,	// VPANDNDZ128rrkz
    4U,	// VPANDNDZ256rm
    72U,	// VPANDNDZ256rmb
    133U,	// VPANDNDZ256rmbk
    9348U,	// VPANDNDZ256rmbkz
    132U,	// VPANDNDZ256rmk
    9348U,	// VPANDNDZ256rmkz
    4U,	// VPANDNDZ256rr
    0U,	// VPANDNDZ256rrk
    9348U,	// VPANDNDZ256rrkz
    4U,	// VPANDNDZrm
    72U,	// VPANDNDZrmb
    133U,	// VPANDNDZrmbk
    9348U,	// VPANDNDZrmbkz
    132U,	// VPANDNDZrmk
    9348U,	// VPANDNDZrmkz
    4U,	// VPANDNDZrr
    0U,	// VPANDNDZrrk
    9348U,	// VPANDNDZrrkz
    4U,	// VPANDNQZ128rm
    72U,	// VPANDNQZ128rmb
    133U,	// VPANDNQZ128rmbk
    9348U,	// VPANDNQZ128rmbkz
    132U,	// VPANDNQZ128rmk
    9348U,	// VPANDNQZ128rmkz
    4U,	// VPANDNQZ128rr
    0U,	// VPANDNQZ128rrk
    9348U,	// VPANDNQZ128rrkz
    4U,	// VPANDNQZ256rm
    72U,	// VPANDNQZ256rmb
    133U,	// VPANDNQZ256rmbk
    9348U,	// VPANDNQZ256rmbkz
    132U,	// VPANDNQZ256rmk
    9348U,	// VPANDNQZ256rmkz
    4U,	// VPANDNQZ256rr
    0U,	// VPANDNQZ256rrk
    9348U,	// VPANDNQZ256rrkz
    4U,	// VPANDNQZrm
    72U,	// VPANDNQZrmb
    133U,	// VPANDNQZrmbk
    9348U,	// VPANDNQZrmbkz
    132U,	// VPANDNQZrmk
    9348U,	// VPANDNQZrmkz
    4U,	// VPANDNQZrr
    0U,	// VPANDNQZrrk
    9348U,	// VPANDNQZrrkz
    4U,	// VPANDNYrm
    4U,	// VPANDNYrr
    4U,	// VPANDNrm
    4U,	// VPANDNrr
    4U,	// VPANDQZ128rm
    72U,	// VPANDQZ128rmb
    133U,	// VPANDQZ128rmbk
    9348U,	// VPANDQZ128rmbkz
    132U,	// VPANDQZ128rmk
    9348U,	// VPANDQZ128rmkz
    4U,	// VPANDQZ128rr
    0U,	// VPANDQZ128rrk
    9348U,	// VPANDQZ128rrkz
    4U,	// VPANDQZ256rm
    72U,	// VPANDQZ256rmb
    133U,	// VPANDQZ256rmbk
    9348U,	// VPANDQZ256rmbkz
    132U,	// VPANDQZ256rmk
    9348U,	// VPANDQZ256rmkz
    4U,	// VPANDQZ256rr
    0U,	// VPANDQZ256rrk
    9348U,	// VPANDQZ256rrkz
    4U,	// VPANDQZrm
    72U,	// VPANDQZrmb
    133U,	// VPANDQZrmbk
    9348U,	// VPANDQZrmbkz
    132U,	// VPANDQZrmk
    9348U,	// VPANDQZrmkz
    4U,	// VPANDQZrr
    0U,	// VPANDQZrrk
    9348U,	// VPANDQZrrkz
    4U,	// VPANDYrm
    4U,	// VPANDYrr
    4U,	// VPANDrm
    4U,	// VPANDrr
    4U,	// VPAVGBYrm
    4U,	// VPAVGBYrr
    4U,	// VPAVGBZ128rm
    132U,	// VPAVGBZ128rmk
    9348U,	// VPAVGBZ128rmkz
    4U,	// VPAVGBZ128rr
    0U,	// VPAVGBZ128rrk
    9348U,	// VPAVGBZ128rrkz
    4U,	// VPAVGBZ256rm
    132U,	// VPAVGBZ256rmk
    9348U,	// VPAVGBZ256rmkz
    4U,	// VPAVGBZ256rr
    0U,	// VPAVGBZ256rrk
    9348U,	// VPAVGBZ256rrkz
    4U,	// VPAVGBZrm
    132U,	// VPAVGBZrmk
    9348U,	// VPAVGBZrmkz
    4U,	// VPAVGBZrr
    0U,	// VPAVGBZrrk
    9348U,	// VPAVGBZrrkz
    4U,	// VPAVGBrm
    4U,	// VPAVGBrr
    4U,	// VPAVGWYrm
    4U,	// VPAVGWYrr
    4U,	// VPAVGWZ128rm
    132U,	// VPAVGWZ128rmk
    9348U,	// VPAVGWZ128rmkz
    4U,	// VPAVGWZ128rr
    0U,	// VPAVGWZ128rrk
    9348U,	// VPAVGWZ128rrkz
    4U,	// VPAVGWZ256rm
    132U,	// VPAVGWZ256rmk
    9348U,	// VPAVGWZ256rmkz
    4U,	// VPAVGWZ256rr
    0U,	// VPAVGWZ256rrk
    9348U,	// VPAVGWZ256rrkz
    4U,	// VPAVGWZrm
    132U,	// VPAVGWZrmk
    9348U,	// VPAVGWZrmkz
    4U,	// VPAVGWZrr
    0U,	// VPAVGWZrrk
    9348U,	// VPAVGWZrrkz
    4U,	// VPAVGWrm
    4U,	// VPAVGWrr
    72U,	// VPBLENDDYrmi
    18636U,	// VPBLENDDYrri
    72U,	// VPBLENDDrmi
    18636U,	// VPBLENDDrri
    4U,	// VPBLENDMBZ128rm
    1156U,	// VPBLENDMBZ128rmk
    9348U,	// VPBLENDMBZ128rmkz
    4U,	// VPBLENDMBZ128rr
    1156U,	// VPBLENDMBZ128rrk
    9348U,	// VPBLENDMBZ128rrkz
    4U,	// VPBLENDMBZ256rm
    1156U,	// VPBLENDMBZ256rmk
    9348U,	// VPBLENDMBZ256rmkz
    4U,	// VPBLENDMBZ256rr
    1156U,	// VPBLENDMBZ256rrk
    9348U,	// VPBLENDMBZ256rrkz
    4U,	// VPBLENDMBZrm
    1156U,	// VPBLENDMBZrmk
    9348U,	// VPBLENDMBZrmkz
    4U,	// VPBLENDMBZrr
    1156U,	// VPBLENDMBZrrk
    9348U,	// VPBLENDMBZrrkz
    4U,	// VPBLENDMDZ128rm
    72U,	// VPBLENDMDZ128rmb
    1156U,	// VPBLENDMDZ128rmbk
    9348U,	// VPBLENDMDZ128rmbkz
    1156U,	// VPBLENDMDZ128rmk
    9348U,	// VPBLENDMDZ128rmkz
    4U,	// VPBLENDMDZ128rr
    1156U,	// VPBLENDMDZ128rrk
    9348U,	// VPBLENDMDZ128rrkz
    4U,	// VPBLENDMDZ256rm
    72U,	// VPBLENDMDZ256rmb
    1156U,	// VPBLENDMDZ256rmbk
    9348U,	// VPBLENDMDZ256rmbkz
    1156U,	// VPBLENDMDZ256rmk
    9348U,	// VPBLENDMDZ256rmkz
    4U,	// VPBLENDMDZ256rr
    1156U,	// VPBLENDMDZ256rrk
    9348U,	// VPBLENDMDZ256rrkz
    4U,	// VPBLENDMDZrm
    72U,	// VPBLENDMDZrmb
    1156U,	// VPBLENDMDZrmbk
    9348U,	// VPBLENDMDZrmbkz
    1156U,	// VPBLENDMDZrmk
    9348U,	// VPBLENDMDZrmkz
    4U,	// VPBLENDMDZrr
    1156U,	// VPBLENDMDZrrk
    9348U,	// VPBLENDMDZrrkz
    4U,	// VPBLENDMQZ128rm
    72U,	// VPBLENDMQZ128rmb
    1156U,	// VPBLENDMQZ128rmbk
    9348U,	// VPBLENDMQZ128rmbkz
    1156U,	// VPBLENDMQZ128rmk
    9348U,	// VPBLENDMQZ128rmkz
    4U,	// VPBLENDMQZ128rr
    1156U,	// VPBLENDMQZ128rrk
    9348U,	// VPBLENDMQZ128rrkz
    4U,	// VPBLENDMQZ256rm
    72U,	// VPBLENDMQZ256rmb
    1156U,	// VPBLENDMQZ256rmbk
    9348U,	// VPBLENDMQZ256rmbkz
    1156U,	// VPBLENDMQZ256rmk
    9348U,	// VPBLENDMQZ256rmkz
    4U,	// VPBLENDMQZ256rr
    1156U,	// VPBLENDMQZ256rrk
    9348U,	// VPBLENDMQZ256rrkz
    4U,	// VPBLENDMQZrm
    72U,	// VPBLENDMQZrmb
    1156U,	// VPBLENDMQZrmbk
    9348U,	// VPBLENDMQZrmbkz
    1156U,	// VPBLENDMQZrmk
    9348U,	// VPBLENDMQZrmkz
    4U,	// VPBLENDMQZrr
    1156U,	// VPBLENDMQZrrk
    9348U,	// VPBLENDMQZrrkz
    4U,	// VPBLENDMWZ128rm
    1156U,	// VPBLENDMWZ128rmk
    9348U,	// VPBLENDMWZ128rmkz
    4U,	// VPBLENDMWZ128rr
    1156U,	// VPBLENDMWZ128rrk
    9348U,	// VPBLENDMWZ128rrkz
    4U,	// VPBLENDMWZ256rm
    1156U,	// VPBLENDMWZ256rmk
    9348U,	// VPBLENDMWZ256rmkz
    4U,	// VPBLENDMWZ256rr
    1156U,	// VPBLENDMWZ256rrk
    9348U,	// VPBLENDMWZ256rrkz
    4U,	// VPBLENDMWZrm
    1156U,	// VPBLENDMWZrmk
    9348U,	// VPBLENDMWZrmkz
    4U,	// VPBLENDMWZrr
    1156U,	// VPBLENDMWZrrk
    9348U,	// VPBLENDMWZrrkz
    72U,	// VPBLENDVBYrm
    18636U,	// VPBLENDVBYrr
    72U,	// VPBLENDVBrm
    18636U,	// VPBLENDVBrr
    72U,	// VPBLENDWYrmi
    18636U,	// VPBLENDWYrri
    72U,	// VPBLENDWrmi
    18636U,	// VPBLENDWrri
    0U,	// VPBROADCASTBYrm
    0U,	// VPBROADCASTBYrr
    0U,	// VPBROADCASTBZ128m
    0U,	// VPBROADCASTBZ128mk
    461U,	// VPBROADCASTBZ128mkz
    0U,	// VPBROADCASTBZ128r
    405U,	// VPBROADCASTBZ128rk
    461U,	// VPBROADCASTBZ128rkz
    0U,	// VPBROADCASTBZ256m
    0U,	// VPBROADCASTBZ256mk
    461U,	// VPBROADCASTBZ256mkz
    0U,	// VPBROADCASTBZ256r
    405U,	// VPBROADCASTBZ256rk
    461U,	// VPBROADCASTBZ256rkz
    0U,	// VPBROADCASTBZm
    0U,	// VPBROADCASTBZmk
    461U,	// VPBROADCASTBZmkz
    0U,	// VPBROADCASTBZr
    405U,	// VPBROADCASTBZrk
    461U,	// VPBROADCASTBZrkz
    0U,	// VPBROADCASTBrZ128r
    405U,	// VPBROADCASTBrZ128rk
    461U,	// VPBROADCASTBrZ128rkz
    0U,	// VPBROADCASTBrZ256r
    405U,	// VPBROADCASTBrZ256rk
    461U,	// VPBROADCASTBrZ256rkz
    0U,	// VPBROADCASTBrZr
    405U,	// VPBROADCASTBrZrk
    461U,	// VPBROADCASTBrZrkz
    0U,	// VPBROADCASTBrm
    0U,	// VPBROADCASTBrr
    0U,	// VPBROADCASTDYrm
    0U,	// VPBROADCASTDYrr
    0U,	// VPBROADCASTDZ128m
    3356U,	// VPBROADCASTDZ128mk
    4444U,	// VPBROADCASTDZ128mkz
    0U,	// VPBROADCASTDZ128r
    405U,	// VPBROADCASTDZ128rk
    461U,	// VPBROADCASTDZ128rkz
    0U,	// VPBROADCASTDZ256m
    3356U,	// VPBROADCASTDZ256mk
    4444U,	// VPBROADCASTDZ256mkz
    0U,	// VPBROADCASTDZ256r
    405U,	// VPBROADCASTDZ256rk
    461U,	// VPBROADCASTDZ256rkz
    0U,	// VPBROADCASTDZm
    3356U,	// VPBROADCASTDZmk
    4444U,	// VPBROADCASTDZmkz
    0U,	// VPBROADCASTDZr
    405U,	// VPBROADCASTDZrk
    461U,	// VPBROADCASTDZrkz
    0U,	// VPBROADCASTDrZ128r
    405U,	// VPBROADCASTDrZ128rk
    461U,	// VPBROADCASTDrZ128rkz
    0U,	// VPBROADCASTDrZ256r
    405U,	// VPBROADCASTDrZ256rk
    461U,	// VPBROADCASTDrZ256rkz
    0U,	// VPBROADCASTDrZr
    405U,	// VPBROADCASTDrZrk
    461U,	// VPBROADCASTDrZrkz
    0U,	// VPBROADCASTDrm
    0U,	// VPBROADCASTDrr
    0U,	// VPBROADCASTMB2QZ128rr
    0U,	// VPBROADCASTMB2QZ256rr
    0U,	// VPBROADCASTMB2QZrr
    0U,	// VPBROADCASTMW2DZ128rr
    0U,	// VPBROADCASTMW2DZ256rr
    0U,	// VPBROADCASTMW2DZrr
    0U,	// VPBROADCASTQYrm
    0U,	// VPBROADCASTQYrr
    0U,	// VPBROADCASTQZ128m
    3356U,	// VPBROADCASTQZ128mk
    4444U,	// VPBROADCASTQZ128mkz
    0U,	// VPBROADCASTQZ128r
    405U,	// VPBROADCASTQZ128rk
    461U,	// VPBROADCASTQZ128rkz
    0U,	// VPBROADCASTQZ256m
    3356U,	// VPBROADCASTQZ256mk
    4444U,	// VPBROADCASTQZ256mkz
    0U,	// VPBROADCASTQZ256r
    405U,	// VPBROADCASTQZ256rk
    461U,	// VPBROADCASTQZ256rkz
    0U,	// VPBROADCASTQZm
    3356U,	// VPBROADCASTQZmk
    4444U,	// VPBROADCASTQZmkz
    0U,	// VPBROADCASTQZr
    405U,	// VPBROADCASTQZrk
    461U,	// VPBROADCASTQZrkz
    0U,	// VPBROADCASTQrZ128r
    405U,	// VPBROADCASTQrZ128rk
    461U,	// VPBROADCASTQrZ128rkz
    0U,	// VPBROADCASTQrZ256r
    405U,	// VPBROADCASTQrZ256rk
    461U,	// VPBROADCASTQrZ256rkz
    0U,	// VPBROADCASTQrZr
    405U,	// VPBROADCASTQrZrk
    461U,	// VPBROADCASTQrZrkz
    0U,	// VPBROADCASTQrm
    0U,	// VPBROADCASTQrr
    0U,	// VPBROADCASTWYrm
    0U,	// VPBROADCASTWYrr
    0U,	// VPBROADCASTWZ128m
    0U,	// VPBROADCASTWZ128mk
    461U,	// VPBROADCASTWZ128mkz
    0U,	// VPBROADCASTWZ128r
    405U,	// VPBROADCASTWZ128rk
    461U,	// VPBROADCASTWZ128rkz
    0U,	// VPBROADCASTWZ256m
    0U,	// VPBROADCASTWZ256mk
    461U,	// VPBROADCASTWZ256mkz
    0U,	// VPBROADCASTWZ256r
    405U,	// VPBROADCASTWZ256rk
    461U,	// VPBROADCASTWZ256rkz
    0U,	// VPBROADCASTWZm
    0U,	// VPBROADCASTWZmk
    461U,	// VPBROADCASTWZmkz
    0U,	// VPBROADCASTWZr
    405U,	// VPBROADCASTWZrk
    461U,	// VPBROADCASTWZrkz
    0U,	// VPBROADCASTWrZ128r
    405U,	// VPBROADCASTWrZ128rk
    461U,	// VPBROADCASTWrZ128rkz
    0U,	// VPBROADCASTWrZ256r
    405U,	// VPBROADCASTWrZ256rk
    461U,	// VPBROADCASTWrZ256rkz
    0U,	// VPBROADCASTWrZr
    405U,	// VPBROADCASTWrZrk
    461U,	// VPBROADCASTWrZrkz
    0U,	// VPBROADCASTWrm
    0U,	// VPBROADCASTWrr
    72U,	// VPCLMULQDQYrm
    18636U,	// VPCLMULQDQYrr
    72U,	// VPCLMULQDQZ128rm
    18636U,	// VPCLMULQDQZ128rr
    72U,	// VPCLMULQDQZ256rm
    18636U,	// VPCLMULQDQZ256rr
    72U,	// VPCLMULQDQZrm
    18636U,	// VPCLMULQDQZrr
    72U,	// VPCLMULQDQrm
    18636U,	// VPCLMULQDQrr
    72U,	// VPCMOVYrmr
    18636U,	// VPCMOVYrrm
    18636U,	// VPCMOVYrrr
    18636U,	// VPCMOVYrrr_REV
    72U,	// VPCMOVrmr
    18636U,	// VPCMOVrrm
    18636U,	// VPCMOVrrr
    18636U,	// VPCMOVrrr_REV
    2U,	// VPCMPBZ128rmi
    72U,	// VPCMPBZ128rmi_alt
    2U,	// VPCMPBZ128rmik
    1156U,	// VPCMPBZ128rmik_alt
    18636U,	// VPCMPBZ128rri
    18636U,	// VPCMPBZ128rri_alt
    26837U,	// VPCMPBZ128rrik
    26837U,	// VPCMPBZ128rrik_alt
    2U,	// VPCMPBZ256rmi
    72U,	// VPCMPBZ256rmi_alt
    2U,	// VPCMPBZ256rmik
    1156U,	// VPCMPBZ256rmik_alt
    18636U,	// VPCMPBZ256rri
    18636U,	// VPCMPBZ256rri_alt
    26837U,	// VPCMPBZ256rrik
    26837U,	// VPCMPBZ256rrik_alt
    2U,	// VPCMPBZrmi
    72U,	// VPCMPBZrmi_alt
    2U,	// VPCMPBZrmik
    1156U,	// VPCMPBZrmik_alt
    18636U,	// VPCMPBZrri
    18636U,	// VPCMPBZrri_alt
    26837U,	// VPCMPBZrrik
    26837U,	// VPCMPBZrrik_alt
    2U,	// VPCMPDZ128rmi
    72U,	// VPCMPDZ128rmi_alt
    21863U,	// VPCMPDZ128rmib
    18637U,	// VPCMPDZ128rmib_alt
    29991U,	// VPCMPDZ128rmibk
    26837U,	// VPCMPDZ128rmibk_alt
    2U,	// VPCMPDZ128rmik
    1156U,	// VPCMPDZ128rmik_alt
    18636U,	// VPCMPDZ128rri
    18636U,	// VPCMPDZ128rri_alt
    26837U,	// VPCMPDZ128rrik
    26837U,	// VPCMPDZ128rrik_alt
    2U,	// VPCMPDZ256rmi
    72U,	// VPCMPDZ256rmi_alt
    21867U,	// VPCMPDZ256rmib
    18637U,	// VPCMPDZ256rmib_alt
    29995U,	// VPCMPDZ256rmibk
    26837U,	// VPCMPDZ256rmibk_alt
    2U,	// VPCMPDZ256rmik
    1156U,	// VPCMPDZ256rmik_alt
    18636U,	// VPCMPDZ256rri
    18636U,	// VPCMPDZ256rri_alt
    26837U,	// VPCMPDZ256rrik
    26837U,	// VPCMPDZ256rrik_alt
    2U,	// VPCMPDZrmi
    72U,	// VPCMPDZrmi_alt
    21871U,	// VPCMPDZrmib
    18637U,	// VPCMPDZrmib_alt
    29999U,	// VPCMPDZrmibk
    26837U,	// VPCMPDZrmibk_alt
    2U,	// VPCMPDZrmik
    1156U,	// VPCMPDZrmik_alt
    18636U,	// VPCMPDZrri
    18636U,	// VPCMPDZrri_alt
    26837U,	// VPCMPDZrrik
    26837U,	// VPCMPDZrrik_alt
    4U,	// VPCMPEQBYrm
    4U,	// VPCMPEQBYrr
    4U,	// VPCMPEQBZ128rm
    1156U,	// VPCMPEQBZ128rmk
    4U,	// VPCMPEQBZ128rr
    1156U,	// VPCMPEQBZ128rrk
    4U,	// VPCMPEQBZ256rm
    1156U,	// VPCMPEQBZ256rmk
    4U,	// VPCMPEQBZ256rr
    1156U,	// VPCMPEQBZ256rrk
    4U,	// VPCMPEQBZrm
    1156U,	// VPCMPEQBZrmk
    4U,	// VPCMPEQBZrr
    1156U,	// VPCMPEQBZrrk
    4U,	// VPCMPEQBrm
    4U,	// VPCMPEQBrr
    4U,	// VPCMPEQDYrm
    4U,	// VPCMPEQDYrr
    4U,	// VPCMPEQDZ128rm
    72U,	// VPCMPEQDZ128rmb
    1156U,	// VPCMPEQDZ128rmbk
    1156U,	// VPCMPEQDZ128rmk
    4U,	// VPCMPEQDZ128rr
    1156U,	// VPCMPEQDZ128rrk
    4U,	// VPCMPEQDZ256rm
    72U,	// VPCMPEQDZ256rmb
    1156U,	// VPCMPEQDZ256rmbk
    1156U,	// VPCMPEQDZ256rmk
    4U,	// VPCMPEQDZ256rr
    1156U,	// VPCMPEQDZ256rrk
    4U,	// VPCMPEQDZrm
    72U,	// VPCMPEQDZrmb
    1156U,	// VPCMPEQDZrmbk
    1156U,	// VPCMPEQDZrmk
    4U,	// VPCMPEQDZrr
    1156U,	// VPCMPEQDZrrk
    4U,	// VPCMPEQDrm
    4U,	// VPCMPEQDrr
    4U,	// VPCMPEQQYrm
    4U,	// VPCMPEQQYrr
    4U,	// VPCMPEQQZ128rm
    72U,	// VPCMPEQQZ128rmb
    1156U,	// VPCMPEQQZ128rmbk
    1156U,	// VPCMPEQQZ128rmk
    4U,	// VPCMPEQQZ128rr
    1156U,	// VPCMPEQQZ128rrk
    4U,	// VPCMPEQQZ256rm
    72U,	// VPCMPEQQZ256rmb
    1156U,	// VPCMPEQQZ256rmbk
    1156U,	// VPCMPEQQZ256rmk
    4U,	// VPCMPEQQZ256rr
    1156U,	// VPCMPEQQZ256rrk
    4U,	// VPCMPEQQZrm
    72U,	// VPCMPEQQZrmb
    1156U,	// VPCMPEQQZrmbk
    1156U,	// VPCMPEQQZrmk
    4U,	// VPCMPEQQZrr
    1156U,	// VPCMPEQQZrrk
    4U,	// VPCMPEQQrm
    4U,	// VPCMPEQQrr
    4U,	// VPCMPEQWYrm
    4U,	// VPCMPEQWYrr
    4U,	// VPCMPEQWZ128rm
    1156U,	// VPCMPEQWZ128rmk
    4U,	// VPCMPEQWZ128rr
    1156U,	// VPCMPEQWZ128rrk
    4U,	// VPCMPEQWZ256rm
    1156U,	// VPCMPEQWZ256rmk
    4U,	// VPCMPEQWZ256rr
    1156U,	// VPCMPEQWZ256rrk
    4U,	// VPCMPEQWZrm
    1156U,	// VPCMPEQWZrmk
    4U,	// VPCMPEQWZrr
    1156U,	// VPCMPEQWZrrk
    4U,	// VPCMPEQWrm
    4U,	// VPCMPEQWrr
    4U,	// VPCMPESTRIrm
    72U,	// VPCMPESTRIrr
    4U,	// VPCMPESTRMrm
    72U,	// VPCMPESTRMrr
    4U,	// VPCMPGTBYrm
    4U,	// VPCMPGTBYrr
    4U,	// VPCMPGTBZ128rm
    1156U,	// VPCMPGTBZ128rmk
    4U,	// VPCMPGTBZ128rr
    1156U,	// VPCMPGTBZ128rrk
    4U,	// VPCMPGTBZ256rm
    1156U,	// VPCMPGTBZ256rmk
    4U,	// VPCMPGTBZ256rr
    1156U,	// VPCMPGTBZ256rrk
    4U,	// VPCMPGTBZrm
    1156U,	// VPCMPGTBZrmk
    4U,	// VPCMPGTBZrr
    1156U,	// VPCMPGTBZrrk
    4U,	// VPCMPGTBrm
    4U,	// VPCMPGTBrr
    4U,	// VPCMPGTDYrm
    4U,	// VPCMPGTDYrr
    4U,	// VPCMPGTDZ128rm
    72U,	// VPCMPGTDZ128rmb
    1156U,	// VPCMPGTDZ128rmbk
    1156U,	// VPCMPGTDZ128rmk
    4U,	// VPCMPGTDZ128rr
    1156U,	// VPCMPGTDZ128rrk
    4U,	// VPCMPGTDZ256rm
    72U,	// VPCMPGTDZ256rmb
    1156U,	// VPCMPGTDZ256rmbk
    1156U,	// VPCMPGTDZ256rmk
    4U,	// VPCMPGTDZ256rr
    1156U,	// VPCMPGTDZ256rrk
    4U,	// VPCMPGTDZrm
    72U,	// VPCMPGTDZrmb
    1156U,	// VPCMPGTDZrmbk
    1156U,	// VPCMPGTDZrmk
    4U,	// VPCMPGTDZrr
    1156U,	// VPCMPGTDZrrk
    4U,	// VPCMPGTDrm
    4U,	// VPCMPGTDrr
    4U,	// VPCMPGTQYrm
    4U,	// VPCMPGTQYrr
    4U,	// VPCMPGTQZ128rm
    72U,	// VPCMPGTQZ128rmb
    1156U,	// VPCMPGTQZ128rmbk
    1156U,	// VPCMPGTQZ128rmk
    4U,	// VPCMPGTQZ128rr
    1156U,	// VPCMPGTQZ128rrk
    4U,	// VPCMPGTQZ256rm
    72U,	// VPCMPGTQZ256rmb
    1156U,	// VPCMPGTQZ256rmbk
    1156U,	// VPCMPGTQZ256rmk
    4U,	// VPCMPGTQZ256rr
    1156U,	// VPCMPGTQZ256rrk
    4U,	// VPCMPGTQZrm
    72U,	// VPCMPGTQZrmb
    1156U,	// VPCMPGTQZrmbk
    1156U,	// VPCMPGTQZrmk
    4U,	// VPCMPGTQZrr
    1156U,	// VPCMPGTQZrrk
    4U,	// VPCMPGTQrm
    4U,	// VPCMPGTQrr
    4U,	// VPCMPGTWYrm
    4U,	// VPCMPGTWYrr
    4U,	// VPCMPGTWZ128rm
    1156U,	// VPCMPGTWZ128rmk
    4U,	// VPCMPGTWZ128rr
    1156U,	// VPCMPGTWZ128rrk
    4U,	// VPCMPGTWZ256rm
    1156U,	// VPCMPGTWZ256rmk
    4U,	// VPCMPGTWZ256rr
    1156U,	// VPCMPGTWZ256rrk
    4U,	// VPCMPGTWZrm
    1156U,	// VPCMPGTWZrmk
    4U,	// VPCMPGTWZrr
    1156U,	// VPCMPGTWZrrk
    4U,	// VPCMPGTWrm
    4U,	// VPCMPGTWrr
    4U,	// VPCMPISTRIrm
    72U,	// VPCMPISTRIrr
    4U,	// VPCMPISTRMrm
    72U,	// VPCMPISTRMrr
    2U,	// VPCMPQZ128rmi
    72U,	// VPCMPQZ128rmi_alt
    21859U,	// VPCMPQZ128rmib
    18637U,	// VPCMPQZ128rmib_alt
    29987U,	// VPCMPQZ128rmibk
    26837U,	// VPCMPQZ128rmibk_alt
    2U,	// VPCMPQZ128rmik
    1156U,	// VPCMPQZ128rmik_alt
    18636U,	// VPCMPQZ128rri
    18636U,	// VPCMPQZ128rri_alt
    26837U,	// VPCMPQZ128rrik
    26837U,	// VPCMPQZ128rrik_alt
    2U,	// VPCMPQZ256rmi
    72U,	// VPCMPQZ256rmi_alt
    21863U,	// VPCMPQZ256rmib
    18637U,	// VPCMPQZ256rmib_alt
    29991U,	// VPCMPQZ256rmibk
    26837U,	// VPCMPQZ256rmibk_alt
    2U,	// VPCMPQZ256rmik
    1156U,	// VPCMPQZ256rmik_alt
    18636U,	// VPCMPQZ256rri
    18636U,	// VPCMPQZ256rri_alt
    26837U,	// VPCMPQZ256rrik
    26837U,	// VPCMPQZ256rrik_alt
    2U,	// VPCMPQZrmi
    72U,	// VPCMPQZrmi_alt
    21867U,	// VPCMPQZrmib
    18637U,	// VPCMPQZrmib_alt
    29995U,	// VPCMPQZrmibk
    26837U,	// VPCMPQZrmibk_alt
    2U,	// VPCMPQZrmik
    1156U,	// VPCMPQZrmik_alt
    18636U,	// VPCMPQZrri
    18636U,	// VPCMPQZrri_alt
    26837U,	// VPCMPQZrrik
    26837U,	// VPCMPQZrrik_alt
    2U,	// VPCMPUBZ128rmi
    72U,	// VPCMPUBZ128rmi_alt
    2U,	// VPCMPUBZ128rmik
    1156U,	// VPCMPUBZ128rmik_alt
    18636U,	// VPCMPUBZ128rri
    18636U,	// VPCMPUBZ128rri_alt
    26837U,	// VPCMPUBZ128rrik
    26837U,	// VPCMPUBZ128rrik_alt
    2U,	// VPCMPUBZ256rmi
    72U,	// VPCMPUBZ256rmi_alt
    2U,	// VPCMPUBZ256rmik
    1156U,	// VPCMPUBZ256rmik_alt
    18636U,	// VPCMPUBZ256rri
    18636U,	// VPCMPUBZ256rri_alt
    26837U,	// VPCMPUBZ256rrik
    26837U,	// VPCMPUBZ256rrik_alt
    2U,	// VPCMPUBZrmi
    72U,	// VPCMPUBZrmi_alt
    2U,	// VPCMPUBZrmik
    1156U,	// VPCMPUBZrmik_alt
    18636U,	// VPCMPUBZrri
    18636U,	// VPCMPUBZrri_alt
    26837U,	// VPCMPUBZrrik
    26837U,	// VPCMPUBZrrik_alt
    2U,	// VPCMPUDZ128rmi
    72U,	// VPCMPUDZ128rmi_alt
    21863U,	// VPCMPUDZ128rmib
    18637U,	// VPCMPUDZ128rmib_alt
    29991U,	// VPCMPUDZ128rmibk
    26837U,	// VPCMPUDZ128rmibk_alt
    2U,	// VPCMPUDZ128rmik
    1156U,	// VPCMPUDZ128rmik_alt
    18636U,	// VPCMPUDZ128rri
    18636U,	// VPCMPUDZ128rri_alt
    26837U,	// VPCMPUDZ128rrik
    26837U,	// VPCMPUDZ128rrik_alt
    2U,	// VPCMPUDZ256rmi
    72U,	// VPCMPUDZ256rmi_alt
    21867U,	// VPCMPUDZ256rmib
    18637U,	// VPCMPUDZ256rmib_alt
    29995U,	// VPCMPUDZ256rmibk
    26837U,	// VPCMPUDZ256rmibk_alt
    2U,	// VPCMPUDZ256rmik
    1156U,	// VPCMPUDZ256rmik_alt
    18636U,	// VPCMPUDZ256rri
    18636U,	// VPCMPUDZ256rri_alt
    26837U,	// VPCMPUDZ256rrik
    26837U,	// VPCMPUDZ256rrik_alt
    2U,	// VPCMPUDZrmi
    72U,	// VPCMPUDZrmi_alt
    21871U,	// VPCMPUDZrmib
    18637U,	// VPCMPUDZrmib_alt
    29999U,	// VPCMPUDZrmibk
    26837U,	// VPCMPUDZrmibk_alt
    2U,	// VPCMPUDZrmik
    1156U,	// VPCMPUDZrmik_alt
    18636U,	// VPCMPUDZrri
    18636U,	// VPCMPUDZrri_alt
    26837U,	// VPCMPUDZrrik
    26837U,	// VPCMPUDZrrik_alt
    2U,	// VPCMPUQZ128rmi
    72U,	// VPCMPUQZ128rmi_alt
    21859U,	// VPCMPUQZ128rmib
    18637U,	// VPCMPUQZ128rmib_alt
    29987U,	// VPCMPUQZ128rmibk
    26837U,	// VPCMPUQZ128rmibk_alt
    2U,	// VPCMPUQZ128rmik
    1156U,	// VPCMPUQZ128rmik_alt
    18636U,	// VPCMPUQZ128rri
    18636U,	// VPCMPUQZ128rri_alt
    26837U,	// VPCMPUQZ128rrik
    26837U,	// VPCMPUQZ128rrik_alt
    2U,	// VPCMPUQZ256rmi
    72U,	// VPCMPUQZ256rmi_alt
    21863U,	// VPCMPUQZ256rmib
    18637U,	// VPCMPUQZ256rmib_alt
    29991U,	// VPCMPUQZ256rmibk
    26837U,	// VPCMPUQZ256rmibk_alt
    2U,	// VPCMPUQZ256rmik
    1156U,	// VPCMPUQZ256rmik_alt
    18636U,	// VPCMPUQZ256rri
    18636U,	// VPCMPUQZ256rri_alt
    26837U,	// VPCMPUQZ256rrik
    26837U,	// VPCMPUQZ256rrik_alt
    2U,	// VPCMPUQZrmi
    72U,	// VPCMPUQZrmi_alt
    21867U,	// VPCMPUQZrmib
    18637U,	// VPCMPUQZrmib_alt
    29995U,	// VPCMPUQZrmibk
    26837U,	// VPCMPUQZrmibk_alt
    2U,	// VPCMPUQZrmik
    1156U,	// VPCMPUQZrmik_alt
    18636U,	// VPCMPUQZrri
    18636U,	// VPCMPUQZrri_alt
    26837U,	// VPCMPUQZrrik
    26837U,	// VPCMPUQZrrik_alt
    2U,	// VPCMPUWZ128rmi
    72U,	// VPCMPUWZ128rmi_alt
    2U,	// VPCMPUWZ128rmik
    1156U,	// VPCMPUWZ128rmik_alt
    18636U,	// VPCMPUWZ128rri
    18636U,	// VPCMPUWZ128rri_alt
    26837U,	// VPCMPUWZ128rrik
    26837U,	// VPCMPUWZ128rrik_alt
    2U,	// VPCMPUWZ256rmi
    72U,	// VPCMPUWZ256rmi_alt
    2U,	// VPCMPUWZ256rmik
    1156U,	// VPCMPUWZ256rmik_alt
    18636U,	// VPCMPUWZ256rri
    18636U,	// VPCMPUWZ256rri_alt
    26837U,	// VPCMPUWZ256rrik
    26837U,	// VPCMPUWZ256rrik_alt
    2U,	// VPCMPUWZrmi
    72U,	// VPCMPUWZrmi_alt
    2U,	// VPCMPUWZrmik
    1156U,	// VPCMPUWZrmik_alt
    18636U,	// VPCMPUWZrri
    18636U,	// VPCMPUWZrri_alt
    26837U,	// VPCMPUWZrrik
    26837U,	// VPCMPUWZrrik_alt
    2U,	// VPCMPWZ128rmi
    72U,	// VPCMPWZ128rmi_alt
    2U,	// VPCMPWZ128rmik
    1156U,	// VPCMPWZ128rmik_alt
    18636U,	// VPCMPWZ128rri
    18636U,	// VPCMPWZ128rri_alt
    26837U,	// VPCMPWZ128rrik
    26837U,	// VPCMPWZ128rrik_alt
    2U,	// VPCMPWZ256rmi
    72U,	// VPCMPWZ256rmi_alt
    2U,	// VPCMPWZ256rmik
    1156U,	// VPCMPWZ256rmik_alt
    18636U,	// VPCMPWZ256rri
    18636U,	// VPCMPWZ256rri_alt
    26837U,	// VPCMPWZ256rrik
    26837U,	// VPCMPWZ256rrik_alt
    2U,	// VPCMPWZrmi
    72U,	// VPCMPWZrmi_alt
    2U,	// VPCMPWZrmik
    1156U,	// VPCMPWZrmik_alt
    18636U,	// VPCMPWZrri
    18636U,	// VPCMPWZrri_alt
    26837U,	// VPCMPWZrrik
    26837U,	// VPCMPWZrrik_alt
    2U,	// VPCOMBmi
    72U,	// VPCOMBmi_alt
    18636U,	// VPCOMBri
    18636U,	// VPCOMBri_alt
    2U,	// VPCOMDmi
    72U,	// VPCOMDmi_alt
    18636U,	// VPCOMDri
    18636U,	// VPCOMDri_alt
    0U,	// VPCOMPRESSBZ128mr
    49U,	// VPCOMPRESSBZ128mrk
    0U,	// VPCOMPRESSBZ128rr
    405U,	// VPCOMPRESSBZ128rrk
    461U,	// VPCOMPRESSBZ128rrkz
    0U,	// VPCOMPRESSBZ256mr
    49U,	// VPCOMPRESSBZ256mrk
    0U,	// VPCOMPRESSBZ256rr
    405U,	// VPCOMPRESSBZ256rrk
    461U,	// VPCOMPRESSBZ256rrkz
    0U,	// VPCOMPRESSBZmr
    49U,	// VPCOMPRESSBZmrk
    0U,	// VPCOMPRESSBZrr
    405U,	// VPCOMPRESSBZrrk
    461U,	// VPCOMPRESSBZrrkz
    0U,	// VPCOMPRESSDZ128mr
    49U,	// VPCOMPRESSDZ128mrk
    0U,	// VPCOMPRESSDZ128rr
    405U,	// VPCOMPRESSDZ128rrk
    461U,	// VPCOMPRESSDZ128rrkz
    0U,	// VPCOMPRESSDZ256mr
    49U,	// VPCOMPRESSDZ256mrk
    0U,	// VPCOMPRESSDZ256rr
    405U,	// VPCOMPRESSDZ256rrk
    461U,	// VPCOMPRESSDZ256rrkz
    0U,	// VPCOMPRESSDZmr
    49U,	// VPCOMPRESSDZmrk
    0U,	// VPCOMPRESSDZrr
    405U,	// VPCOMPRESSDZrrk
    461U,	// VPCOMPRESSDZrrkz
    0U,	// VPCOMPRESSQZ128mr
    49U,	// VPCOMPRESSQZ128mrk
    0U,	// VPCOMPRESSQZ128rr
    405U,	// VPCOMPRESSQZ128rrk
    461U,	// VPCOMPRESSQZ128rrkz
    0U,	// VPCOMPRESSQZ256mr
    49U,	// VPCOMPRESSQZ256mrk
    0U,	// VPCOMPRESSQZ256rr
    405U,	// VPCOMPRESSQZ256rrk
    461U,	// VPCOMPRESSQZ256rrkz
    0U,	// VPCOMPRESSQZmr
    49U,	// VPCOMPRESSQZmrk
    0U,	// VPCOMPRESSQZrr
    405U,	// VPCOMPRESSQZrrk
    461U,	// VPCOMPRESSQZrrkz
    0U,	// VPCOMPRESSWZ128mr
    49U,	// VPCOMPRESSWZ128mrk
    0U,	// VPCOMPRESSWZ128rr
    405U,	// VPCOMPRESSWZ128rrk
    461U,	// VPCOMPRESSWZ128rrkz
    0U,	// VPCOMPRESSWZ256mr
    49U,	// VPCOMPRESSWZ256mrk
    0U,	// VPCOMPRESSWZ256rr
    405U,	// VPCOMPRESSWZ256rrk
    461U,	// VPCOMPRESSWZ256rrkz
    0U,	// VPCOMPRESSWZmr
    49U,	// VPCOMPRESSWZmrk
    0U,	// VPCOMPRESSWZrr
    405U,	// VPCOMPRESSWZrrk
    461U,	// VPCOMPRESSWZrrkz
    2U,	// VPCOMQmi
    72U,	// VPCOMQmi_alt
    18636U,	// VPCOMQri
    18636U,	// VPCOMQri_alt
    2U,	// VPCOMUBmi
    72U,	// VPCOMUBmi_alt
    18636U,	// VPCOMUBri
    18636U,	// VPCOMUBri_alt
    2U,	// VPCOMUDmi
    72U,	// VPCOMUDmi_alt
    18636U,	// VPCOMUDri
    18636U,	// VPCOMUDri_alt
    2U,	// VPCOMUQmi
    72U,	// VPCOMUQmi_alt
    18636U,	// VPCOMUQri
    18636U,	// VPCOMUQri_alt
    2U,	// VPCOMUWmi
    72U,	// VPCOMUWmi_alt
    18636U,	// VPCOMUWri
    18636U,	// VPCOMUWri_alt
    2U,	// VPCOMWmi
    72U,	// VPCOMWmi_alt
    18636U,	// VPCOMWri
    18636U,	// VPCOMWri_alt
    0U,	// VPCONFLICTDZ128rm
    0U,	// VPCONFLICTDZ128rmb
    3356U,	// VPCONFLICTDZ128rmbk
    4444U,	// VPCONFLICTDZ128rmbkz
    405U,	// VPCONFLICTDZ128rmk
    461U,	// VPCONFLICTDZ128rmkz
    0U,	// VPCONFLICTDZ128rr
    405U,	// VPCONFLICTDZ128rrk
    461U,	// VPCONFLICTDZ128rrkz
    0U,	// VPCONFLICTDZ256rm
    0U,	// VPCONFLICTDZ256rmb
    3356U,	// VPCONFLICTDZ256rmbk
    4444U,	// VPCONFLICTDZ256rmbkz
    405U,	// VPCONFLICTDZ256rmk
    461U,	// VPCONFLICTDZ256rmkz
    0U,	// VPCONFLICTDZ256rr
    405U,	// VPCONFLICTDZ256rrk
    461U,	// VPCONFLICTDZ256rrkz
    0U,	// VPCONFLICTDZrm
    0U,	// VPCONFLICTDZrmb
    3356U,	// VPCONFLICTDZrmbk
    4444U,	// VPCONFLICTDZrmbkz
    405U,	// VPCONFLICTDZrmk
    461U,	// VPCONFLICTDZrmkz
    0U,	// VPCONFLICTDZrr
    405U,	// VPCONFLICTDZrrk
    461U,	// VPCONFLICTDZrrkz
    0U,	// VPCONFLICTQZ128rm
    0U,	// VPCONFLICTQZ128rmb
    3356U,	// VPCONFLICTQZ128rmbk
    4444U,	// VPCONFLICTQZ128rmbkz
    405U,	// VPCONFLICTQZ128rmk
    461U,	// VPCONFLICTQZ128rmkz
    0U,	// VPCONFLICTQZ128rr
    405U,	// VPCONFLICTQZ128rrk
    461U,	// VPCONFLICTQZ128rrkz
    0U,	// VPCONFLICTQZ256rm
    0U,	// VPCONFLICTQZ256rmb
    3356U,	// VPCONFLICTQZ256rmbk
    4444U,	// VPCONFLICTQZ256rmbkz
    405U,	// VPCONFLICTQZ256rmk
    461U,	// VPCONFLICTQZ256rmkz
    0U,	// VPCONFLICTQZ256rr
    405U,	// VPCONFLICTQZ256rrk
    461U,	// VPCONFLICTQZ256rrkz
    0U,	// VPCONFLICTQZrm
    0U,	// VPCONFLICTQZrmb
    3356U,	// VPCONFLICTQZrmbk
    4444U,	// VPCONFLICTQZrmbkz
    405U,	// VPCONFLICTQZrmk
    461U,	// VPCONFLICTQZrmkz
    0U,	// VPCONFLICTQZrr
    405U,	// VPCONFLICTQZrrk
    461U,	// VPCONFLICTQZrrkz
    4U,	// VPDPBUSDSZ128m
    4U,	// VPDPBUSDSZ128mb
    133U,	// VPDPBUSDSZ128mbk
    8325U,	// VPDPBUSDSZ128mbkz
    132U,	// VPDPBUSDSZ128mk
    8324U,	// VPDPBUSDSZ128mkz
    4U,	// VPDPBUSDSZ128r
    0U,	// VPDPBUSDSZ128rk
    0U,	// VPDPBUSDSZ128rkz
    4U,	// VPDPBUSDSZ256m
    4U,	// VPDPBUSDSZ256mb
    133U,	// VPDPBUSDSZ256mbk
    8325U,	// VPDPBUSDSZ256mbkz
    132U,	// VPDPBUSDSZ256mk
    8324U,	// VPDPBUSDSZ256mkz
    4U,	// VPDPBUSDSZ256r
    0U,	// VPDPBUSDSZ256rk
    0U,	// VPDPBUSDSZ256rkz
    4U,	// VPDPBUSDSZm
    4U,	// VPDPBUSDSZmb
    133U,	// VPDPBUSDSZmbk
    8325U,	// VPDPBUSDSZmbkz
    132U,	// VPDPBUSDSZmk
    8324U,	// VPDPBUSDSZmkz
    4U,	// VPDPBUSDSZr
    0U,	// VPDPBUSDSZrk
    0U,	// VPDPBUSDSZrkz
    4U,	// VPDPBUSDZ128m
    4U,	// VPDPBUSDZ128mb
    133U,	// VPDPBUSDZ128mbk
    8325U,	// VPDPBUSDZ128mbkz
    132U,	// VPDPBUSDZ128mk
    8324U,	// VPDPBUSDZ128mkz
    4U,	// VPDPBUSDZ128r
    0U,	// VPDPBUSDZ128rk
    0U,	// VPDPBUSDZ128rkz
    4U,	// VPDPBUSDZ256m
    4U,	// VPDPBUSDZ256mb
    133U,	// VPDPBUSDZ256mbk
    8325U,	// VPDPBUSDZ256mbkz
    132U,	// VPDPBUSDZ256mk
    8324U,	// VPDPBUSDZ256mkz
    4U,	// VPDPBUSDZ256r
    0U,	// VPDPBUSDZ256rk
    0U,	// VPDPBUSDZ256rkz
    4U,	// VPDPBUSDZm
    4U,	// VPDPBUSDZmb
    133U,	// VPDPBUSDZmbk
    8325U,	// VPDPBUSDZmbkz
    132U,	// VPDPBUSDZmk
    8324U,	// VPDPBUSDZmkz
    4U,	// VPDPBUSDZr
    0U,	// VPDPBUSDZrk
    0U,	// VPDPBUSDZrkz
    4U,	// VPDPWSSDSZ128m
    4U,	// VPDPWSSDSZ128mb
    133U,	// VPDPWSSDSZ128mbk
    8325U,	// VPDPWSSDSZ128mbkz
    132U,	// VPDPWSSDSZ128mk
    8324U,	// VPDPWSSDSZ128mkz
    4U,	// VPDPWSSDSZ128r
    0U,	// VPDPWSSDSZ128rk
    0U,	// VPDPWSSDSZ128rkz
    4U,	// VPDPWSSDSZ256m
    4U,	// VPDPWSSDSZ256mb
    133U,	// VPDPWSSDSZ256mbk
    8325U,	// VPDPWSSDSZ256mbkz
    132U,	// VPDPWSSDSZ256mk
    8324U,	// VPDPWSSDSZ256mkz
    4U,	// VPDPWSSDSZ256r
    0U,	// VPDPWSSDSZ256rk
    0U,	// VPDPWSSDSZ256rkz
    4U,	// VPDPWSSDSZm
    4U,	// VPDPWSSDSZmb
    133U,	// VPDPWSSDSZmbk
    8325U,	// VPDPWSSDSZmbkz
    132U,	// VPDPWSSDSZmk
    8324U,	// VPDPWSSDSZmkz
    4U,	// VPDPWSSDSZr
    0U,	// VPDPWSSDSZrk
    0U,	// VPDPWSSDSZrkz
    4U,	// VPDPWSSDZ128m
    4U,	// VPDPWSSDZ128mb
    133U,	// VPDPWSSDZ128mbk
    8325U,	// VPDPWSSDZ128mbkz
    132U,	// VPDPWSSDZ128mk
    8324U,	// VPDPWSSDZ128mkz
    4U,	// VPDPWSSDZ128r
    0U,	// VPDPWSSDZ128rk
    0U,	// VPDPWSSDZ128rkz
    4U,	// VPDPWSSDZ256m
    4U,	// VPDPWSSDZ256mb
    133U,	// VPDPWSSDZ256mbk
    8325U,	// VPDPWSSDZ256mbkz
    132U,	// VPDPWSSDZ256mk
    8324U,	// VPDPWSSDZ256mkz
    4U,	// VPDPWSSDZ256r
    0U,	// VPDPWSSDZ256rk
    0U,	// VPDPWSSDZ256rkz
    4U,	// VPDPWSSDZm
    4U,	// VPDPWSSDZmb
    133U,	// VPDPWSSDZmbk
    8325U,	// VPDPWSSDZmbkz
    132U,	// VPDPWSSDZmk
    8324U,	// VPDPWSSDZmkz
    4U,	// VPDPWSSDZr
    0U,	// VPDPWSSDZrk
    0U,	// VPDPWSSDZrkz
    72U,	// VPERM2F128rm
    18636U,	// VPERM2F128rr
    72U,	// VPERM2I128rm
    18636U,	// VPERM2I128rr
    4U,	// VPERMBZ128rm
    132U,	// VPERMBZ128rmk
    9348U,	// VPERMBZ128rmkz
    4U,	// VPERMBZ128rr
    0U,	// VPERMBZ128rrk
    9348U,	// VPERMBZ128rrkz
    4U,	// VPERMBZ256rm
    132U,	// VPERMBZ256rmk
    9348U,	// VPERMBZ256rmkz
    4U,	// VPERMBZ256rr
    0U,	// VPERMBZ256rrk
    9348U,	// VPERMBZ256rrkz
    4U,	// VPERMBZrm
    132U,	// VPERMBZrmk
    9348U,	// VPERMBZrmkz
    4U,	// VPERMBZrr
    0U,	// VPERMBZrrk
    9348U,	// VPERMBZrrkz
    4U,	// VPERMDYrm
    4U,	// VPERMDYrr
    4U,	// VPERMDZ256rm
    72U,	// VPERMDZ256rmb
    133U,	// VPERMDZ256rmbk
    9348U,	// VPERMDZ256rmbkz
    132U,	// VPERMDZ256rmk
    9348U,	// VPERMDZ256rmkz
    4U,	// VPERMDZ256rr
    0U,	// VPERMDZ256rrk
    9348U,	// VPERMDZ256rrkz
    4U,	// VPERMDZrm
    72U,	// VPERMDZrmb
    133U,	// VPERMDZrmbk
    9348U,	// VPERMDZrmbkz
    132U,	// VPERMDZrmk
    9348U,	// VPERMDZrmkz
    4U,	// VPERMDZrr
    0U,	// VPERMDZrrk
    9348U,	// VPERMDZrrkz
    4U,	// VPERMI2B128rm
    132U,	// VPERMI2B128rmk
    8324U,	// VPERMI2B128rmkz
    4U,	// VPERMI2B128rr
    0U,	// VPERMI2B128rrk
    0U,	// VPERMI2B128rrkz
    4U,	// VPERMI2B256rm
    132U,	// VPERMI2B256rmk
    8324U,	// VPERMI2B256rmkz
    4U,	// VPERMI2B256rr
    0U,	// VPERMI2B256rrk
    0U,	// VPERMI2B256rrkz
    4U,	// VPERMI2Brm
    132U,	// VPERMI2Brmk
    8324U,	// VPERMI2Brmkz
    4U,	// VPERMI2Brr
    0U,	// VPERMI2Brrk
    0U,	// VPERMI2Brrkz
    4U,	// VPERMI2D128rm
    4U,	// VPERMI2D128rmb
    133U,	// VPERMI2D128rmbk
    8325U,	// VPERMI2D128rmbkz
    132U,	// VPERMI2D128rmk
    8324U,	// VPERMI2D128rmkz
    4U,	// VPERMI2D128rr
    0U,	// VPERMI2D128rrk
    0U,	// VPERMI2D128rrkz
    4U,	// VPERMI2D256rm
    4U,	// VPERMI2D256rmb
    133U,	// VPERMI2D256rmbk
    8325U,	// VPERMI2D256rmbkz
    132U,	// VPERMI2D256rmk
    8324U,	// VPERMI2D256rmkz
    4U,	// VPERMI2D256rr
    0U,	// VPERMI2D256rrk
    0U,	// VPERMI2D256rrkz
    4U,	// VPERMI2Drm
    4U,	// VPERMI2Drmb
    133U,	// VPERMI2Drmbk
    8325U,	// VPERMI2Drmbkz
    132U,	// VPERMI2Drmk
    8324U,	// VPERMI2Drmkz
    4U,	// VPERMI2Drr
    0U,	// VPERMI2Drrk
    0U,	// VPERMI2Drrkz
    4U,	// VPERMI2PD128rm
    4U,	// VPERMI2PD128rmb
    133U,	// VPERMI2PD128rmbk
    8325U,	// VPERMI2PD128rmbkz
    0U,	// VPERMI2PD128rmk
    0U,	// VPERMI2PD128rmkz
    4U,	// VPERMI2PD128rr
    0U,	// VPERMI2PD128rrk
    0U,	// VPERMI2PD128rrkz
    4U,	// VPERMI2PD256rm
    4U,	// VPERMI2PD256rmb
    133U,	// VPERMI2PD256rmbk
    8325U,	// VPERMI2PD256rmbkz
    0U,	// VPERMI2PD256rmk
    0U,	// VPERMI2PD256rmkz
    4U,	// VPERMI2PD256rr
    0U,	// VPERMI2PD256rrk
    0U,	// VPERMI2PD256rrkz
    4U,	// VPERMI2PDrm
    4U,	// VPERMI2PDrmb
    133U,	// VPERMI2PDrmbk
    8325U,	// VPERMI2PDrmbkz
    0U,	// VPERMI2PDrmk
    0U,	// VPERMI2PDrmkz
    4U,	// VPERMI2PDrr
    0U,	// VPERMI2PDrrk
    0U,	// VPERMI2PDrrkz
    4U,	// VPERMI2PS128rm
    4U,	// VPERMI2PS128rmb
    133U,	// VPERMI2PS128rmbk
    8325U,	// VPERMI2PS128rmbkz
    0U,	// VPERMI2PS128rmk
    0U,	// VPERMI2PS128rmkz
    4U,	// VPERMI2PS128rr
    0U,	// VPERMI2PS128rrk
    0U,	// VPERMI2PS128rrkz
    4U,	// VPERMI2PS256rm
    4U,	// VPERMI2PS256rmb
    133U,	// VPERMI2PS256rmbk
    8325U,	// VPERMI2PS256rmbkz
    0U,	// VPERMI2PS256rmk
    0U,	// VPERMI2PS256rmkz
    4U,	// VPERMI2PS256rr
    0U,	// VPERMI2PS256rrk
    0U,	// VPERMI2PS256rrkz
    4U,	// VPERMI2PSrm
    4U,	// VPERMI2PSrmb
    133U,	// VPERMI2PSrmbk
    8325U,	// VPERMI2PSrmbkz
    0U,	// VPERMI2PSrmk
    0U,	// VPERMI2PSrmkz
    4U,	// VPERMI2PSrr
    0U,	// VPERMI2PSrrk
    0U,	// VPERMI2PSrrkz
    4U,	// VPERMI2Q128rm
    4U,	// VPERMI2Q128rmb
    133U,	// VPERMI2Q128rmbk
    8325U,	// VPERMI2Q128rmbkz
    132U,	// VPERMI2Q128rmk
    8324U,	// VPERMI2Q128rmkz
    4U,	// VPERMI2Q128rr
    0U,	// VPERMI2Q128rrk
    0U,	// VPERMI2Q128rrkz
    4U,	// VPERMI2Q256rm
    4U,	// VPERMI2Q256rmb
    133U,	// VPERMI2Q256rmbk
    8325U,	// VPERMI2Q256rmbkz
    132U,	// VPERMI2Q256rmk
    8324U,	// VPERMI2Q256rmkz
    4U,	// VPERMI2Q256rr
    0U,	// VPERMI2Q256rrk
    0U,	// VPERMI2Q256rrkz
    4U,	// VPERMI2Qrm
    4U,	// VPERMI2Qrmb
    133U,	// VPERMI2Qrmbk
    8325U,	// VPERMI2Qrmbkz
    132U,	// VPERMI2Qrmk
    8324U,	// VPERMI2Qrmkz
    4U,	// VPERMI2Qrr
    0U,	// VPERMI2Qrrk
    0U,	// VPERMI2Qrrkz
    4U,	// VPERMI2W128rm
    132U,	// VPERMI2W128rmk
    8324U,	// VPERMI2W128rmkz
    4U,	// VPERMI2W128rr
    0U,	// VPERMI2W128rrk
    0U,	// VPERMI2W128rrkz
    4U,	// VPERMI2W256rm
    132U,	// VPERMI2W256rmk
    8324U,	// VPERMI2W256rmkz
    4U,	// VPERMI2W256rr
    0U,	// VPERMI2W256rrk
    0U,	// VPERMI2W256rrkz
    4U,	// VPERMI2Wrm
    132U,	// VPERMI2Wrmk
    8324U,	// VPERMI2Wrmkz
    4U,	// VPERMI2Wrr
    0U,	// VPERMI2Wrrk
    0U,	// VPERMI2Wrrkz
    1U,	// VPERMIL2PDYmr
    18636U,	// VPERMIL2PDYrm
    34005U,	// VPERMIL2PDYrr
    34005U,	// VPERMIL2PDYrr_REV
    18636U,	// VPERMIL2PDmr
    18636U,	// VPERMIL2PDrm
    34005U,	// VPERMIL2PDrr
    34005U,	// VPERMIL2PDrr_REV
    1U,	// VPERMIL2PSYmr
    18636U,	// VPERMIL2PSYrm
    34005U,	// VPERMIL2PSYrr
    34005U,	// VPERMIL2PSYrr_REV
    18636U,	// VPERMIL2PSmr
    18636U,	// VPERMIL2PSrm
    34005U,	// VPERMIL2PSrr
    34005U,	// VPERMIL2PSrr_REV
    0U,	// VPERMILPDYmi
    72U,	// VPERMILPDYri
    4U,	// VPERMILPDYrm
    4U,	// VPERMILPDYrr
    5U,	// VPERMILPDZ128mbi
    133U,	// VPERMILPDZ128mbik
    9349U,	// VPERMILPDZ128mbikz
    0U,	// VPERMILPDZ128mi
    3356U,	// VPERMILPDZ128mik
    4444U,	// VPERMILPDZ128mikz
    72U,	// VPERMILPDZ128ri
    133U,	// VPERMILPDZ128rik
    9348U,	// VPERMILPDZ128rikz
    4U,	// VPERMILPDZ128rm
    72U,	// VPERMILPDZ128rmb
    133U,	// VPERMILPDZ128rmbk
    9348U,	// VPERMILPDZ128rmbkz
    132U,	// VPERMILPDZ128rmk
    9348U,	// VPERMILPDZ128rmkz
    4U,	// VPERMILPDZ128rr
    0U,	// VPERMILPDZ128rrk
    9348U,	// VPERMILPDZ128rrkz
    5U,	// VPERMILPDZ256mbi
    133U,	// VPERMILPDZ256mbik
    9349U,	// VPERMILPDZ256mbikz
    0U,	// VPERMILPDZ256mi
    3356U,	// VPERMILPDZ256mik
    4444U,	// VPERMILPDZ256mikz
    72U,	// VPERMILPDZ256ri
    133U,	// VPERMILPDZ256rik
    9348U,	// VPERMILPDZ256rikz
    4U,	// VPERMILPDZ256rm
    72U,	// VPERMILPDZ256rmb
    133U,	// VPERMILPDZ256rmbk
    9348U,	// VPERMILPDZ256rmbkz
    132U,	// VPERMILPDZ256rmk
    9348U,	// VPERMILPDZ256rmkz
    4U,	// VPERMILPDZ256rr
    0U,	// VPERMILPDZ256rrk
    9348U,	// VPERMILPDZ256rrkz
    5U,	// VPERMILPDZmbi
    133U,	// VPERMILPDZmbik
    9349U,	// VPERMILPDZmbikz
    0U,	// VPERMILPDZmi
    3356U,	// VPERMILPDZmik
    4444U,	// VPERMILPDZmikz
    72U,	// VPERMILPDZri
    133U,	// VPERMILPDZrik
    9348U,	// VPERMILPDZrikz
    4U,	// VPERMILPDZrm
    72U,	// VPERMILPDZrmb
    133U,	// VPERMILPDZrmbk
    9348U,	// VPERMILPDZrmbkz
    132U,	// VPERMILPDZrmk
    9348U,	// VPERMILPDZrmkz
    4U,	// VPERMILPDZrr
    0U,	// VPERMILPDZrrk
    9348U,	// VPERMILPDZrrkz
    0U,	// VPERMILPDmi
    72U,	// VPERMILPDri
    4U,	// VPERMILPDrm
    4U,	// VPERMILPDrr
    0U,	// VPERMILPSYmi
    72U,	// VPERMILPSYri
    4U,	// VPERMILPSYrm
    4U,	// VPERMILPSYrr
    5U,	// VPERMILPSZ128mbi
    133U,	// VPERMILPSZ128mbik
    9349U,	// VPERMILPSZ128mbikz
    0U,	// VPERMILPSZ128mi
    3356U,	// VPERMILPSZ128mik
    4444U,	// VPERMILPSZ128mikz
    72U,	// VPERMILPSZ128ri
    133U,	// VPERMILPSZ128rik
    9348U,	// VPERMILPSZ128rikz
    4U,	// VPERMILPSZ128rm
    72U,	// VPERMILPSZ128rmb
    133U,	// VPERMILPSZ128rmbk
    9348U,	// VPERMILPSZ128rmbkz
    132U,	// VPERMILPSZ128rmk
    9348U,	// VPERMILPSZ128rmkz
    4U,	// VPERMILPSZ128rr
    0U,	// VPERMILPSZ128rrk
    9348U,	// VPERMILPSZ128rrkz
    5U,	// VPERMILPSZ256mbi
    133U,	// VPERMILPSZ256mbik
    9349U,	// VPERMILPSZ256mbikz
    0U,	// VPERMILPSZ256mi
    3356U,	// VPERMILPSZ256mik
    4444U,	// VPERMILPSZ256mikz
    72U,	// VPERMILPSZ256ri
    133U,	// VPERMILPSZ256rik
    9348U,	// VPERMILPSZ256rikz
    4U,	// VPERMILPSZ256rm
    72U,	// VPERMILPSZ256rmb
    133U,	// VPERMILPSZ256rmbk
    9348U,	// VPERMILPSZ256rmbkz
    132U,	// VPERMILPSZ256rmk
    9348U,	// VPERMILPSZ256rmkz
    4U,	// VPERMILPSZ256rr
    0U,	// VPERMILPSZ256rrk
    9348U,	// VPERMILPSZ256rrkz
    5U,	// VPERMILPSZmbi
    133U,	// VPERMILPSZmbik
    9349U,	// VPERMILPSZmbikz
    0U,	// VPERMILPSZmi
    3356U,	// VPERMILPSZmik
    4444U,	// VPERMILPSZmikz
    72U,	// VPERMILPSZri
    133U,	// VPERMILPSZrik
    9348U,	// VPERMILPSZrikz
    4U,	// VPERMILPSZrm
    72U,	// VPERMILPSZrmb
    133U,	// VPERMILPSZrmbk
    9348U,	// VPERMILPSZrmbkz
    132U,	// VPERMILPSZrmk
    9348U,	// VPERMILPSZrmkz
    4U,	// VPERMILPSZrr
    0U,	// VPERMILPSZrrk
    9348U,	// VPERMILPSZrrkz
    0U,	// VPERMILPSmi
    72U,	// VPERMILPSri
    4U,	// VPERMILPSrm
    4U,	// VPERMILPSrr
    0U,	// VPERMPDYmi
    72U,	// VPERMPDYri
    5U,	// VPERMPDZ256mbi
    133U,	// VPERMPDZ256mbik
    9349U,	// VPERMPDZ256mbikz
    0U,	// VPERMPDZ256mi
    3356U,	// VPERMPDZ256mik
    4444U,	// VPERMPDZ256mikz
    72U,	// VPERMPDZ256ri
    133U,	// VPERMPDZ256rik
    9348U,	// VPERMPDZ256rikz
    4U,	// VPERMPDZ256rm
    72U,	// VPERMPDZ256rmb
    133U,	// VPERMPDZ256rmbk
    9348U,	// VPERMPDZ256rmbkz
    0U,	// VPERMPDZ256rmk
    9348U,	// VPERMPDZ256rmkz
    4U,	// VPERMPDZ256rr
    0U,	// VPERMPDZ256rrk
    9348U,	// VPERMPDZ256rrkz
    5U,	// VPERMPDZmbi
    133U,	// VPERMPDZmbik
    9349U,	// VPERMPDZmbikz
    0U,	// VPERMPDZmi
    3356U,	// VPERMPDZmik
    4444U,	// VPERMPDZmikz
    72U,	// VPERMPDZri
    133U,	// VPERMPDZrik
    9348U,	// VPERMPDZrikz
    4U,	// VPERMPDZrm
    72U,	// VPERMPDZrmb
    133U,	// VPERMPDZrmbk
    9348U,	// VPERMPDZrmbkz
    0U,	// VPERMPDZrmk
    9348U,	// VPERMPDZrmkz
    4U,	// VPERMPDZrr
    0U,	// VPERMPDZrrk
    9348U,	// VPERMPDZrrkz
    4U,	// VPERMPSYrm
    4U,	// VPERMPSYrr
    4U,	// VPERMPSZ256rm
    72U,	// VPERMPSZ256rmb
    133U,	// VPERMPSZ256rmbk
    9348U,	// VPERMPSZ256rmbkz
    0U,	// VPERMPSZ256rmk
    9348U,	// VPERMPSZ256rmkz
    4U,	// VPERMPSZ256rr
    0U,	// VPERMPSZ256rrk
    9348U,	// VPERMPSZ256rrkz
    4U,	// VPERMPSZrm
    72U,	// VPERMPSZrmb
    133U,	// VPERMPSZrmbk
    9348U,	// VPERMPSZrmbkz
    0U,	// VPERMPSZrmk
    9348U,	// VPERMPSZrmkz
    4U,	// VPERMPSZrr
    0U,	// VPERMPSZrrk
    9348U,	// VPERMPSZrrkz
    4U,	// VPERMQYmi
    72U,	// VPERMQYri
    5U,	// VPERMQZ256mbi
    133U,	// VPERMQZ256mbik
    9349U,	// VPERMQZ256mbikz
    4U,	// VPERMQZ256mi
    3356U,	// VPERMQZ256mik
    4444U,	// VPERMQZ256mikz
    72U,	// VPERMQZ256ri
    133U,	// VPERMQZ256rik
    9348U,	// VPERMQZ256rikz
    4U,	// VPERMQZ256rm
    72U,	// VPERMQZ256rmb
    133U,	// VPERMQZ256rmbk
    9348U,	// VPERMQZ256rmbkz
    132U,	// VPERMQZ256rmk
    9348U,	// VPERMQZ256rmkz
    4U,	// VPERMQZ256rr
    0U,	// VPERMQZ256rrk
    9348U,	// VPERMQZ256rrkz
    5U,	// VPERMQZmbi
    133U,	// VPERMQZmbik
    9349U,	// VPERMQZmbikz
    4U,	// VPERMQZmi
    3356U,	// VPERMQZmik
    4444U,	// VPERMQZmikz
    72U,	// VPERMQZri
    133U,	// VPERMQZrik
    9348U,	// VPERMQZrikz
    4U,	// VPERMQZrm
    72U,	// VPERMQZrmb
    133U,	// VPERMQZrmbk
    9348U,	// VPERMQZrmbkz
    132U,	// VPERMQZrmk
    9348U,	// VPERMQZrmkz
    4U,	// VPERMQZrr
    0U,	// VPERMQZrrk
    9348U,	// VPERMQZrrkz
    4U,	// VPERMT2B128rm
    132U,	// VPERMT2B128rmk
    8324U,	// VPERMT2B128rmkz
    4U,	// VPERMT2B128rr
    0U,	// VPERMT2B128rrk
    0U,	// VPERMT2B128rrkz
    4U,	// VPERMT2B256rm
    132U,	// VPERMT2B256rmk
    8324U,	// VPERMT2B256rmkz
    4U,	// VPERMT2B256rr
    0U,	// VPERMT2B256rrk
    0U,	// VPERMT2B256rrkz
    4U,	// VPERMT2Brm
    132U,	// VPERMT2Brmk
    8324U,	// VPERMT2Brmkz
    4U,	// VPERMT2Brr
    0U,	// VPERMT2Brrk
    0U,	// VPERMT2Brrkz
    4U,	// VPERMT2D128rm
    4U,	// VPERMT2D128rmb
    133U,	// VPERMT2D128rmbk
    8325U,	// VPERMT2D128rmbkz
    132U,	// VPERMT2D128rmk
    8324U,	// VPERMT2D128rmkz
    4U,	// VPERMT2D128rr
    0U,	// VPERMT2D128rrk
    0U,	// VPERMT2D128rrkz
    4U,	// VPERMT2D256rm
    4U,	// VPERMT2D256rmb
    133U,	// VPERMT2D256rmbk
    8325U,	// VPERMT2D256rmbkz
    132U,	// VPERMT2D256rmk
    8324U,	// VPERMT2D256rmkz
    4U,	// VPERMT2D256rr
    0U,	// VPERMT2D256rrk
    0U,	// VPERMT2D256rrkz
    4U,	// VPERMT2Drm
    4U,	// VPERMT2Drmb
    133U,	// VPERMT2Drmbk
    8325U,	// VPERMT2Drmbkz
    132U,	// VPERMT2Drmk
    8324U,	// VPERMT2Drmkz
    4U,	// VPERMT2Drr
    0U,	// VPERMT2Drrk
    0U,	// VPERMT2Drrkz
    4U,	// VPERMT2PD128rm
    4U,	// VPERMT2PD128rmb
    133U,	// VPERMT2PD128rmbk
    8325U,	// VPERMT2PD128rmbkz
    0U,	// VPERMT2PD128rmk
    0U,	// VPERMT2PD128rmkz
    4U,	// VPERMT2PD128rr
    0U,	// VPERMT2PD128rrk
    0U,	// VPERMT2PD128rrkz
    4U,	// VPERMT2PD256rm
    4U,	// VPERMT2PD256rmb
    133U,	// VPERMT2PD256rmbk
    8325U,	// VPERMT2PD256rmbkz
    0U,	// VPERMT2PD256rmk
    0U,	// VPERMT2PD256rmkz
    4U,	// VPERMT2PD256rr
    0U,	// VPERMT2PD256rrk
    0U,	// VPERMT2PD256rrkz
    4U,	// VPERMT2PDrm
    4U,	// VPERMT2PDrmb
    133U,	// VPERMT2PDrmbk
    8325U,	// VPERMT2PDrmbkz
    0U,	// VPERMT2PDrmk
    0U,	// VPERMT2PDrmkz
    4U,	// VPERMT2PDrr
    0U,	// VPERMT2PDrrk
    0U,	// VPERMT2PDrrkz
    4U,	// VPERMT2PS128rm
    4U,	// VPERMT2PS128rmb
    133U,	// VPERMT2PS128rmbk
    8325U,	// VPERMT2PS128rmbkz
    0U,	// VPERMT2PS128rmk
    0U,	// VPERMT2PS128rmkz
    4U,	// VPERMT2PS128rr
    0U,	// VPERMT2PS128rrk
    0U,	// VPERMT2PS128rrkz
    4U,	// VPERMT2PS256rm
    4U,	// VPERMT2PS256rmb
    133U,	// VPERMT2PS256rmbk
    8325U,	// VPERMT2PS256rmbkz
    0U,	// VPERMT2PS256rmk
    0U,	// VPERMT2PS256rmkz
    4U,	// VPERMT2PS256rr
    0U,	// VPERMT2PS256rrk
    0U,	// VPERMT2PS256rrkz
    4U,	// VPERMT2PSrm
    4U,	// VPERMT2PSrmb
    133U,	// VPERMT2PSrmbk
    8325U,	// VPERMT2PSrmbkz
    0U,	// VPERMT2PSrmk
    0U,	// VPERMT2PSrmkz
    4U,	// VPERMT2PSrr
    0U,	// VPERMT2PSrrk
    0U,	// VPERMT2PSrrkz
    4U,	// VPERMT2Q128rm
    4U,	// VPERMT2Q128rmb
    133U,	// VPERMT2Q128rmbk
    8325U,	// VPERMT2Q128rmbkz
    132U,	// VPERMT2Q128rmk
    8324U,	// VPERMT2Q128rmkz
    4U,	// VPERMT2Q128rr
    0U,	// VPERMT2Q128rrk
    0U,	// VPERMT2Q128rrkz
    4U,	// VPERMT2Q256rm
    4U,	// VPERMT2Q256rmb
    133U,	// VPERMT2Q256rmbk
    8325U,	// VPERMT2Q256rmbkz
    132U,	// VPERMT2Q256rmk
    8324U,	// VPERMT2Q256rmkz
    4U,	// VPERMT2Q256rr
    0U,	// VPERMT2Q256rrk
    0U,	// VPERMT2Q256rrkz
    4U,	// VPERMT2Qrm
    4U,	// VPERMT2Qrmb
    133U,	// VPERMT2Qrmbk
    8325U,	// VPERMT2Qrmbkz
    132U,	// VPERMT2Qrmk
    8324U,	// VPERMT2Qrmkz
    4U,	// VPERMT2Qrr
    0U,	// VPERMT2Qrrk
    0U,	// VPERMT2Qrrkz
    4U,	// VPERMT2W128rm
    132U,	// VPERMT2W128rmk
    8324U,	// VPERMT2W128rmkz
    4U,	// VPERMT2W128rr
    0U,	// VPERMT2W128rrk
    0U,	// VPERMT2W128rrkz
    4U,	// VPERMT2W256rm
    132U,	// VPERMT2W256rmk
    8324U,	// VPERMT2W256rmkz
    4U,	// VPERMT2W256rr
    0U,	// VPERMT2W256rrk
    0U,	// VPERMT2W256rrkz
    4U,	// VPERMT2Wrm
    132U,	// VPERMT2Wrmk
    8324U,	// VPERMT2Wrmkz
    4U,	// VPERMT2Wrr
    0U,	// VPERMT2Wrrk
    0U,	// VPERMT2Wrrkz
    4U,	// VPERMWZ128rm
    132U,	// VPERMWZ128rmk
    9348U,	// VPERMWZ128rmkz
    4U,	// VPERMWZ128rr
    0U,	// VPERMWZ128rrk
    9348U,	// VPERMWZ128rrkz
    4U,	// VPERMWZ256rm
    132U,	// VPERMWZ256rmk
    9348U,	// VPERMWZ256rmkz
    4U,	// VPERMWZ256rr
    0U,	// VPERMWZ256rrk
    9348U,	// VPERMWZ256rrkz
    4U,	// VPERMWZrm
    132U,	// VPERMWZrmk
    9348U,	// VPERMWZrmkz
    4U,	// VPERMWZrr
    0U,	// VPERMWZrrk
    9348U,	// VPERMWZrrkz
    0U,	// VPEXPANDBZ128rm
    405U,	// VPEXPANDBZ128rmk
    461U,	// VPEXPANDBZ128rmkz
    0U,	// VPEXPANDBZ128rr
    405U,	// VPEXPANDBZ128rrk
    461U,	// VPEXPANDBZ128rrkz
    0U,	// VPEXPANDBZ256rm
    405U,	// VPEXPANDBZ256rmk
    461U,	// VPEXPANDBZ256rmkz
    0U,	// VPEXPANDBZ256rr
    405U,	// VPEXPANDBZ256rrk
    461U,	// VPEXPANDBZ256rrkz
    0U,	// VPEXPANDBZrm
    405U,	// VPEXPANDBZrmk
    461U,	// VPEXPANDBZrmkz
    0U,	// VPEXPANDBZrr
    405U,	// VPEXPANDBZrrk
    461U,	// VPEXPANDBZrrkz
    0U,	// VPEXPANDDZ128rm
    405U,	// VPEXPANDDZ128rmk
    461U,	// VPEXPANDDZ128rmkz
    0U,	// VPEXPANDDZ128rr
    405U,	// VPEXPANDDZ128rrk
    461U,	// VPEXPANDDZ128rrkz
    0U,	// VPEXPANDDZ256rm
    405U,	// VPEXPANDDZ256rmk
    461U,	// VPEXPANDDZ256rmkz
    0U,	// VPEXPANDDZ256rr
    405U,	// VPEXPANDDZ256rrk
    461U,	// VPEXPANDDZ256rrkz
    0U,	// VPEXPANDDZrm
    405U,	// VPEXPANDDZrmk
    461U,	// VPEXPANDDZrmkz
    0U,	// VPEXPANDDZrr
    405U,	// VPEXPANDDZrrk
    461U,	// VPEXPANDDZrrkz
    0U,	// VPEXPANDQZ128rm
    405U,	// VPEXPANDQZ128rmk
    461U,	// VPEXPANDQZ128rmkz
    0U,	// VPEXPANDQZ128rr
    405U,	// VPEXPANDQZ128rrk
    461U,	// VPEXPANDQZ128rrkz
    0U,	// VPEXPANDQZ256rm
    405U,	// VPEXPANDQZ256rmk
    461U,	// VPEXPANDQZ256rmkz
    0U,	// VPEXPANDQZ256rr
    405U,	// VPEXPANDQZ256rrk
    461U,	// VPEXPANDQZ256rrkz
    0U,	// VPEXPANDQZrm
    405U,	// VPEXPANDQZrmk
    461U,	// VPEXPANDQZrmkz
    0U,	// VPEXPANDQZrr
    405U,	// VPEXPANDQZrrk
    461U,	// VPEXPANDQZrrkz
    0U,	// VPEXPANDWZ128rm
    405U,	// VPEXPANDWZ128rmk
    461U,	// VPEXPANDWZ128rmkz
    0U,	// VPEXPANDWZ128rr
    405U,	// VPEXPANDWZ128rrk
    461U,	// VPEXPANDWZ128rrkz
    0U,	// VPEXPANDWZ256rm
    405U,	// VPEXPANDWZ256rmk
    461U,	// VPEXPANDWZ256rmkz
    0U,	// VPEXPANDWZ256rr
    405U,	// VPEXPANDWZ256rrk
    461U,	// VPEXPANDWZ256rrkz
    0U,	// VPEXPANDWZrm
    405U,	// VPEXPANDWZrmk
    461U,	// VPEXPANDWZrmkz
    0U,	// VPEXPANDWZrr
    405U,	// VPEXPANDWZrrk
    461U,	// VPEXPANDWZrrkz
    1U,	// VPEXTRBZmr
    72U,	// VPEXTRBZrr
    1U,	// VPEXTRBmr
    72U,	// VPEXTRBrr
    1U,	// VPEXTRDZmr
    72U,	// VPEXTRDZrr
    1U,	// VPEXTRDmr
    72U,	// VPEXTRDrr
    1U,	// VPEXTRQZmr
    72U,	// VPEXTRQZrr
    1U,	// VPEXTRQmr
    72U,	// VPEXTRQrr
    1U,	// VPEXTRWZmr
    72U,	// VPEXTRWZrr
    72U,	// VPEXTRWZrr_REV
    1U,	// VPEXTRWmr
    72U,	// VPEXTRWrr
    72U,	// VPEXTRWrr_REV
    0U,	// VPGATHERDDYrm
    401U,	// VPGATHERDDZ128rm
    401U,	// VPGATHERDDZ256rm
    401U,	// VPGATHERDDZrm
    0U,	// VPGATHERDDrm
    0U,	// VPGATHERDQYrm
    401U,	// VPGATHERDQZ128rm
    401U,	// VPGATHERDQZ256rm
    401U,	// VPGATHERDQZrm
    0U,	// VPGATHERDQrm
    0U,	// VPGATHERQDYrm
    604U,	// VPGATHERQDZ128rm
    401U,	// VPGATHERQDZ256rm
    401U,	// VPGATHERQDZrm
    4U,	// VPGATHERQDrm
    0U,	// VPGATHERQQYrm
    401U,	// VPGATHERQQZ128rm
    401U,	// VPGATHERQQZ256rm
    401U,	// VPGATHERQQZrm
    0U,	// VPGATHERQQrm
    0U,	// VPHADDBDrm
    0U,	// VPHADDBDrr
    0U,	// VPHADDBQrm
    0U,	// VPHADDBQrr
    0U,	// VPHADDBWrm
    0U,	// VPHADDBWrr
    0U,	// VPHADDDQrm
    0U,	// VPHADDDQrr
    4U,	// VPHADDDYrm
    4U,	// VPHADDDYrr
    4U,	// VPHADDDrm
    4U,	// VPHADDDrr
    4U,	// VPHADDSWYrm
    4U,	// VPHADDSWYrr
    4U,	// VPHADDSWrm
    4U,	// VPHADDSWrr
    0U,	// VPHADDUBDrm
    0U,	// VPHADDUBDrr
    0U,	// VPHADDUBQrm
    0U,	// VPHADDUBQrr
    0U,	// VPHADDUBWrm
    0U,	// VPHADDUBWrr
    0U,	// VPHADDUDQrm
    0U,	// VPHADDUDQrr
    0U,	// VPHADDUWDrm
    0U,	// VPHADDUWDrr
    0U,	// VPHADDUWQrm
    0U,	// VPHADDUWQrr
    0U,	// VPHADDWDrm
    0U,	// VPHADDWDrr
    0U,	// VPHADDWQrm
    0U,	// VPHADDWQrr
    4U,	// VPHADDWYrm
    4U,	// VPHADDWYrr
    4U,	// VPHADDWrm
    4U,	// VPHADDWrr
    0U,	// VPHMINPOSUWrm
    0U,	// VPHMINPOSUWrr
    0U,	// VPHSUBBWrm
    0U,	// VPHSUBBWrr
    0U,	// VPHSUBDQrm
    0U,	// VPHSUBDQrr
    4U,	// VPHSUBDYrm
    4U,	// VPHSUBDYrr
    4U,	// VPHSUBDrm
    4U,	// VPHSUBDrr
    4U,	// VPHSUBSWYrm
    4U,	// VPHSUBSWYrr
    4U,	// VPHSUBSWrm
    4U,	// VPHSUBSWrr
    0U,	// VPHSUBWDrm
    0U,	// VPHSUBWDrr
    4U,	// VPHSUBWYrm
    4U,	// VPHSUBWYrr
    4U,	// VPHSUBWrm
    4U,	// VPHSUBWrr
    18636U,	// VPINSRBZrm
    18636U,	// VPINSRBZrr
    18636U,	// VPINSRBrm
    18636U,	// VPINSRBrr
    18636U,	// VPINSRDZrm
    18636U,	// VPINSRDZrr
    18636U,	// VPINSRDrm
    18636U,	// VPINSRDrr
    18636U,	// VPINSRQZrm
    18636U,	// VPINSRQZrr
    18636U,	// VPINSRQrm
    18636U,	// VPINSRQrr
    72U,	// VPINSRWZrm
    18636U,	// VPINSRWZrr
    72U,	// VPINSRWrm
    18636U,	// VPINSRWrr
    0U,	// VPLZCNTDZ128rm
    0U,	// VPLZCNTDZ128rmb
    3356U,	// VPLZCNTDZ128rmbk
    4444U,	// VPLZCNTDZ128rmbkz
    405U,	// VPLZCNTDZ128rmk
    461U,	// VPLZCNTDZ128rmkz
    0U,	// VPLZCNTDZ128rr
    405U,	// VPLZCNTDZ128rrk
    461U,	// VPLZCNTDZ128rrkz
    0U,	// VPLZCNTDZ256rm
    0U,	// VPLZCNTDZ256rmb
    3356U,	// VPLZCNTDZ256rmbk
    4444U,	// VPLZCNTDZ256rmbkz
    405U,	// VPLZCNTDZ256rmk
    461U,	// VPLZCNTDZ256rmkz
    0U,	// VPLZCNTDZ256rr
    405U,	// VPLZCNTDZ256rrk
    461U,	// VPLZCNTDZ256rrkz
    0U,	// VPLZCNTDZrm
    0U,	// VPLZCNTDZrmb
    3356U,	// VPLZCNTDZrmbk
    4444U,	// VPLZCNTDZrmbkz
    405U,	// VPLZCNTDZrmk
    461U,	// VPLZCNTDZrmkz
    0U,	// VPLZCNTDZrr
    405U,	// VPLZCNTDZrrk
    461U,	// VPLZCNTDZrrkz
    0U,	// VPLZCNTQZ128rm
    0U,	// VPLZCNTQZ128rmb
    3356U,	// VPLZCNTQZ128rmbk
    4444U,	// VPLZCNTQZ128rmbkz
    405U,	// VPLZCNTQZ128rmk
    461U,	// VPLZCNTQZ128rmkz
    0U,	// VPLZCNTQZ128rr
    405U,	// VPLZCNTQZ128rrk
    461U,	// VPLZCNTQZ128rrkz
    0U,	// VPLZCNTQZ256rm
    0U,	// VPLZCNTQZ256rmb
    3356U,	// VPLZCNTQZ256rmbk
    4444U,	// VPLZCNTQZ256rmbkz
    405U,	// VPLZCNTQZ256rmk
    461U,	// VPLZCNTQZ256rmkz
    0U,	// VPLZCNTQZ256rr
    405U,	// VPLZCNTQZ256rrk
    461U,	// VPLZCNTQZ256rrkz
    0U,	// VPLZCNTQZrm
    0U,	// VPLZCNTQZrmb
    3356U,	// VPLZCNTQZrmbk
    4444U,	// VPLZCNTQZrmbkz
    405U,	// VPLZCNTQZrmk
    461U,	// VPLZCNTQZrmkz
    0U,	// VPLZCNTQZrr
    405U,	// VPLZCNTQZrrk
    461U,	// VPLZCNTQZrrkz
    72U,	// VPMACSDDrm
    18636U,	// VPMACSDDrr
    72U,	// VPMACSDQHrm
    18636U,	// VPMACSDQHrr
    72U,	// VPMACSDQLrm
    18636U,	// VPMACSDQLrr
    72U,	// VPMACSSDDrm
    18636U,	// VPMACSSDDrr
    72U,	// VPMACSSDQHrm
    18636U,	// VPMACSSDQHrr
    72U,	// VPMACSSDQLrm
    18636U,	// VPMACSSDQLrr
    72U,	// VPMACSSWDrm
    18636U,	// VPMACSSWDrr
    72U,	// VPMACSSWWrm
    18636U,	// VPMACSSWWrr
    72U,	// VPMACSWDrm
    18636U,	// VPMACSWDrr
    72U,	// VPMACSWWrm
    18636U,	// VPMACSWWrr
    72U,	// VPMADCSSWDrm
    18636U,	// VPMADCSSWDrr
    72U,	// VPMADCSWDrm
    18636U,	// VPMADCSWDrr
    4U,	// VPMADD52HUQZ128m
    4U,	// VPMADD52HUQZ128mb
    133U,	// VPMADD52HUQZ128mbk
    8325U,	// VPMADD52HUQZ128mbkz
    132U,	// VPMADD52HUQZ128mk
    8324U,	// VPMADD52HUQZ128mkz
    4U,	// VPMADD52HUQZ128r
    0U,	// VPMADD52HUQZ128rk
    0U,	// VPMADD52HUQZ128rkz
    4U,	// VPMADD52HUQZ256m
    4U,	// VPMADD52HUQZ256mb
    133U,	// VPMADD52HUQZ256mbk
    8325U,	// VPMADD52HUQZ256mbkz
    132U,	// VPMADD52HUQZ256mk
    8324U,	// VPMADD52HUQZ256mkz
    4U,	// VPMADD52HUQZ256r
    0U,	// VPMADD52HUQZ256rk
    0U,	// VPMADD52HUQZ256rkz
    4U,	// VPMADD52HUQZm
    4U,	// VPMADD52HUQZmb
    133U,	// VPMADD52HUQZmbk
    8325U,	// VPMADD52HUQZmbkz
    132U,	// VPMADD52HUQZmk
    8324U,	// VPMADD52HUQZmkz
    4U,	// VPMADD52HUQZr
    0U,	// VPMADD52HUQZrk
    0U,	// VPMADD52HUQZrkz
    4U,	// VPMADD52LUQZ128m
    4U,	// VPMADD52LUQZ128mb
    133U,	// VPMADD52LUQZ128mbk
    8325U,	// VPMADD52LUQZ128mbkz
    132U,	// VPMADD52LUQZ128mk
    8324U,	// VPMADD52LUQZ128mkz
    4U,	// VPMADD52LUQZ128r
    0U,	// VPMADD52LUQZ128rk
    0U,	// VPMADD52LUQZ128rkz
    4U,	// VPMADD52LUQZ256m
    4U,	// VPMADD52LUQZ256mb
    133U,	// VPMADD52LUQZ256mbk
    8325U,	// VPMADD52LUQZ256mbkz
    132U,	// VPMADD52LUQZ256mk
    8324U,	// VPMADD52LUQZ256mkz
    4U,	// VPMADD52LUQZ256r
    0U,	// VPMADD52LUQZ256rk
    0U,	// VPMADD52LUQZ256rkz
    4U,	// VPMADD52LUQZm
    4U,	// VPMADD52LUQZmb
    133U,	// VPMADD52LUQZmbk
    8325U,	// VPMADD52LUQZmbkz
    132U,	// VPMADD52LUQZmk
    8324U,	// VPMADD52LUQZmkz
    4U,	// VPMADD52LUQZr
    0U,	// VPMADD52LUQZrk
    0U,	// VPMADD52LUQZrkz
    4U,	// VPMADDUBSWYrm
    4U,	// VPMADDUBSWYrr
    4U,	// VPMADDUBSWZ128rm
    132U,	// VPMADDUBSWZ128rmk
    9348U,	// VPMADDUBSWZ128rmkz
    4U,	// VPMADDUBSWZ128rr
    0U,	// VPMADDUBSWZ128rrk
    9348U,	// VPMADDUBSWZ128rrkz
    4U,	// VPMADDUBSWZ256rm
    132U,	// VPMADDUBSWZ256rmk
    9348U,	// VPMADDUBSWZ256rmkz
    4U,	// VPMADDUBSWZ256rr
    0U,	// VPMADDUBSWZ256rrk
    9348U,	// VPMADDUBSWZ256rrkz
    4U,	// VPMADDUBSWZrm
    132U,	// VPMADDUBSWZrmk
    9348U,	// VPMADDUBSWZrmkz
    4U,	// VPMADDUBSWZrr
    0U,	// VPMADDUBSWZrrk
    9348U,	// VPMADDUBSWZrrkz
    4U,	// VPMADDUBSWrm
    4U,	// VPMADDUBSWrr
    4U,	// VPMADDWDYrm
    4U,	// VPMADDWDYrr
    4U,	// VPMADDWDZ128rm
    132U,	// VPMADDWDZ128rmk
    9348U,	// VPMADDWDZ128rmkz
    4U,	// VPMADDWDZ128rr
    0U,	// VPMADDWDZ128rrk
    9348U,	// VPMADDWDZ128rrkz
    4U,	// VPMADDWDZ256rm
    132U,	// VPMADDWDZ256rmk
    9348U,	// VPMADDWDZ256rmkz
    4U,	// VPMADDWDZ256rr
    0U,	// VPMADDWDZ256rrk
    9348U,	// VPMADDWDZ256rrkz
    4U,	// VPMADDWDZrm
    132U,	// VPMADDWDZrmk
    9348U,	// VPMADDWDZrmkz
    4U,	// VPMADDWDZrr
    0U,	// VPMADDWDZrrk
    9348U,	// VPMADDWDZrrkz
    4U,	// VPMADDWDrm
    4U,	// VPMADDWDrr
    2U,	// VPMASKMOVDYmr
    4U,	// VPMASKMOVDYrm
    2U,	// VPMASKMOVDmr
    4U,	// VPMASKMOVDrm
    2U,	// VPMASKMOVQYmr
    4U,	// VPMASKMOVQYrm
    2U,	// VPMASKMOVQmr
    4U,	// VPMASKMOVQrm
    4U,	// VPMAXSBYrm
    4U,	// VPMAXSBYrr
    4U,	// VPMAXSBZ128rm
    132U,	// VPMAXSBZ128rmk
    9348U,	// VPMAXSBZ128rmkz
    4U,	// VPMAXSBZ128rr
    0U,	// VPMAXSBZ128rrk
    9348U,	// VPMAXSBZ128rrkz
    4U,	// VPMAXSBZ256rm
    132U,	// VPMAXSBZ256rmk
    9348U,	// VPMAXSBZ256rmkz
    4U,	// VPMAXSBZ256rr
    0U,	// VPMAXSBZ256rrk
    9348U,	// VPMAXSBZ256rrkz
    4U,	// VPMAXSBZrm
    132U,	// VPMAXSBZrmk
    9348U,	// VPMAXSBZrmkz
    4U,	// VPMAXSBZrr
    0U,	// VPMAXSBZrrk
    9348U,	// VPMAXSBZrrkz
    4U,	// VPMAXSBrm
    4U,	// VPMAXSBrr
    4U,	// VPMAXSDYrm
    4U,	// VPMAXSDYrr
    4U,	// VPMAXSDZ128rm
    72U,	// VPMAXSDZ128rmb
    133U,	// VPMAXSDZ128rmbk
    9348U,	// VPMAXSDZ128rmbkz
    132U,	// VPMAXSDZ128rmk
    9348U,	// VPMAXSDZ128rmkz
    4U,	// VPMAXSDZ128rr
    0U,	// VPMAXSDZ128rrk
    9348U,	// VPMAXSDZ128rrkz
    4U,	// VPMAXSDZ256rm
    72U,	// VPMAXSDZ256rmb
    133U,	// VPMAXSDZ256rmbk
    9348U,	// VPMAXSDZ256rmbkz
    132U,	// VPMAXSDZ256rmk
    9348U,	// VPMAXSDZ256rmkz
    4U,	// VPMAXSDZ256rr
    0U,	// VPMAXSDZ256rrk
    9348U,	// VPMAXSDZ256rrkz
    4U,	// VPMAXSDZrm
    72U,	// VPMAXSDZrmb
    133U,	// VPMAXSDZrmbk
    9348U,	// VPMAXSDZrmbkz
    132U,	// VPMAXSDZrmk
    9348U,	// VPMAXSDZrmkz
    4U,	// VPMAXSDZrr
    0U,	// VPMAXSDZrrk
    9348U,	// VPMAXSDZrrkz
    4U,	// VPMAXSDrm
    4U,	// VPMAXSDrr
    4U,	// VPMAXSQZ128rm
    72U,	// VPMAXSQZ128rmb
    133U,	// VPMAXSQZ128rmbk
    9348U,	// VPMAXSQZ128rmbkz
    132U,	// VPMAXSQZ128rmk
    9348U,	// VPMAXSQZ128rmkz
    4U,	// VPMAXSQZ128rr
    0U,	// VPMAXSQZ128rrk
    9348U,	// VPMAXSQZ128rrkz
    4U,	// VPMAXSQZ256rm
    72U,	// VPMAXSQZ256rmb
    133U,	// VPMAXSQZ256rmbk
    9348U,	// VPMAXSQZ256rmbkz
    132U,	// VPMAXSQZ256rmk
    9348U,	// VPMAXSQZ256rmkz
    4U,	// VPMAXSQZ256rr
    0U,	// VPMAXSQZ256rrk
    9348U,	// VPMAXSQZ256rrkz
    4U,	// VPMAXSQZrm
    72U,	// VPMAXSQZrmb
    133U,	// VPMAXSQZrmbk
    9348U,	// VPMAXSQZrmbkz
    132U,	// VPMAXSQZrmk
    9348U,	// VPMAXSQZrmkz
    4U,	// VPMAXSQZrr
    0U,	// VPMAXSQZrrk
    9348U,	// VPMAXSQZrrkz
    4U,	// VPMAXSWYrm
    4U,	// VPMAXSWYrr
    4U,	// VPMAXSWZ128rm
    132U,	// VPMAXSWZ128rmk
    9348U,	// VPMAXSWZ128rmkz
    4U,	// VPMAXSWZ128rr
    0U,	// VPMAXSWZ128rrk
    9348U,	// VPMAXSWZ128rrkz
    4U,	// VPMAXSWZ256rm
    132U,	// VPMAXSWZ256rmk
    9348U,	// VPMAXSWZ256rmkz
    4U,	// VPMAXSWZ256rr
    0U,	// VPMAXSWZ256rrk
    9348U,	// VPMAXSWZ256rrkz
    4U,	// VPMAXSWZrm
    132U,	// VPMAXSWZrmk
    9348U,	// VPMAXSWZrmkz
    4U,	// VPMAXSWZrr
    0U,	// VPMAXSWZrrk
    9348U,	// VPMAXSWZrrkz
    4U,	// VPMAXSWrm
    4U,	// VPMAXSWrr
    4U,	// VPMAXUBYrm
    4U,	// VPMAXUBYrr
    4U,	// VPMAXUBZ128rm
    132U,	// VPMAXUBZ128rmk
    9348U,	// VPMAXUBZ128rmkz
    4U,	// VPMAXUBZ128rr
    0U,	// VPMAXUBZ128rrk
    9348U,	// VPMAXUBZ128rrkz
    4U,	// VPMAXUBZ256rm
    132U,	// VPMAXUBZ256rmk
    9348U,	// VPMAXUBZ256rmkz
    4U,	// VPMAXUBZ256rr
    0U,	// VPMAXUBZ256rrk
    9348U,	// VPMAXUBZ256rrkz
    4U,	// VPMAXUBZrm
    132U,	// VPMAXUBZrmk
    9348U,	// VPMAXUBZrmkz
    4U,	// VPMAXUBZrr
    0U,	// VPMAXUBZrrk
    9348U,	// VPMAXUBZrrkz
    4U,	// VPMAXUBrm
    4U,	// VPMAXUBrr
    4U,	// VPMAXUDYrm
    4U,	// VPMAXUDYrr
    4U,	// VPMAXUDZ128rm
    72U,	// VPMAXUDZ128rmb
    133U,	// VPMAXUDZ128rmbk
    9348U,	// VPMAXUDZ128rmbkz
    132U,	// VPMAXUDZ128rmk
    9348U,	// VPMAXUDZ128rmkz
    4U,	// VPMAXUDZ128rr
    0U,	// VPMAXUDZ128rrk
    9348U,	// VPMAXUDZ128rrkz
    4U,	// VPMAXUDZ256rm
    72U,	// VPMAXUDZ256rmb
    133U,	// VPMAXUDZ256rmbk
    9348U,	// VPMAXUDZ256rmbkz
    132U,	// VPMAXUDZ256rmk
    9348U,	// VPMAXUDZ256rmkz
    4U,	// VPMAXUDZ256rr
    0U,	// VPMAXUDZ256rrk
    9348U,	// VPMAXUDZ256rrkz
    4U,	// VPMAXUDZrm
    72U,	// VPMAXUDZrmb
    133U,	// VPMAXUDZrmbk
    9348U,	// VPMAXUDZrmbkz
    132U,	// VPMAXUDZrmk
    9348U,	// VPMAXUDZrmkz
    4U,	// VPMAXUDZrr
    0U,	// VPMAXUDZrrk
    9348U,	// VPMAXUDZrrkz
    4U,	// VPMAXUDrm
    4U,	// VPMAXUDrr
    4U,	// VPMAXUQZ128rm
    72U,	// VPMAXUQZ128rmb
    133U,	// VPMAXUQZ128rmbk
    9348U,	// VPMAXUQZ128rmbkz
    132U,	// VPMAXUQZ128rmk
    9348U,	// VPMAXUQZ128rmkz
    4U,	// VPMAXUQZ128rr
    0U,	// VPMAXUQZ128rrk
    9348U,	// VPMAXUQZ128rrkz
    4U,	// VPMAXUQZ256rm
    72U,	// VPMAXUQZ256rmb
    133U,	// VPMAXUQZ256rmbk
    9348U,	// VPMAXUQZ256rmbkz
    132U,	// VPMAXUQZ256rmk
    9348U,	// VPMAXUQZ256rmkz
    4U,	// VPMAXUQZ256rr
    0U,	// VPMAXUQZ256rrk
    9348U,	// VPMAXUQZ256rrkz
    4U,	// VPMAXUQZrm
    72U,	// VPMAXUQZrmb
    133U,	// VPMAXUQZrmbk
    9348U,	// VPMAXUQZrmbkz
    132U,	// VPMAXUQZrmk
    9348U,	// VPMAXUQZrmkz
    4U,	// VPMAXUQZrr
    0U,	// VPMAXUQZrrk
    9348U,	// VPMAXUQZrrkz
    4U,	// VPMAXUWYrm
    4U,	// VPMAXUWYrr
    4U,	// VPMAXUWZ128rm
    132U,	// VPMAXUWZ128rmk
    9348U,	// VPMAXUWZ128rmkz
    4U,	// VPMAXUWZ128rr
    0U,	// VPMAXUWZ128rrk
    9348U,	// VPMAXUWZ128rrkz
    4U,	// VPMAXUWZ256rm
    132U,	// VPMAXUWZ256rmk
    9348U,	// VPMAXUWZ256rmkz
    4U,	// VPMAXUWZ256rr
    0U,	// VPMAXUWZ256rrk
    9348U,	// VPMAXUWZ256rrkz
    4U,	// VPMAXUWZrm
    132U,	// VPMAXUWZrmk
    9348U,	// VPMAXUWZrmkz
    4U,	// VPMAXUWZrr
    0U,	// VPMAXUWZrrk
    9348U,	// VPMAXUWZrrkz
    4U,	// VPMAXUWrm
    4U,	// VPMAXUWrr
    4U,	// VPMINSBYrm
    4U,	// VPMINSBYrr
    4U,	// VPMINSBZ128rm
    132U,	// VPMINSBZ128rmk
    9348U,	// VPMINSBZ128rmkz
    4U,	// VPMINSBZ128rr
    0U,	// VPMINSBZ128rrk
    9348U,	// VPMINSBZ128rrkz
    4U,	// VPMINSBZ256rm
    132U,	// VPMINSBZ256rmk
    9348U,	// VPMINSBZ256rmkz
    4U,	// VPMINSBZ256rr
    0U,	// VPMINSBZ256rrk
    9348U,	// VPMINSBZ256rrkz
    4U,	// VPMINSBZrm
    132U,	// VPMINSBZrmk
    9348U,	// VPMINSBZrmkz
    4U,	// VPMINSBZrr
    0U,	// VPMINSBZrrk
    9348U,	// VPMINSBZrrkz
    4U,	// VPMINSBrm
    4U,	// VPMINSBrr
    4U,	// VPMINSDYrm
    4U,	// VPMINSDYrr
    4U,	// VPMINSDZ128rm
    72U,	// VPMINSDZ128rmb
    133U,	// VPMINSDZ128rmbk
    9348U,	// VPMINSDZ128rmbkz
    132U,	// VPMINSDZ128rmk
    9348U,	// VPMINSDZ128rmkz
    4U,	// VPMINSDZ128rr
    0U,	// VPMINSDZ128rrk
    9348U,	// VPMINSDZ128rrkz
    4U,	// VPMINSDZ256rm
    72U,	// VPMINSDZ256rmb
    133U,	// VPMINSDZ256rmbk
    9348U,	// VPMINSDZ256rmbkz
    132U,	// VPMINSDZ256rmk
    9348U,	// VPMINSDZ256rmkz
    4U,	// VPMINSDZ256rr
    0U,	// VPMINSDZ256rrk
    9348U,	// VPMINSDZ256rrkz
    4U,	// VPMINSDZrm
    72U,	// VPMINSDZrmb
    133U,	// VPMINSDZrmbk
    9348U,	// VPMINSDZrmbkz
    132U,	// VPMINSDZrmk
    9348U,	// VPMINSDZrmkz
    4U,	// VPMINSDZrr
    0U,	// VPMINSDZrrk
    9348U,	// VPMINSDZrrkz
    4U,	// VPMINSDrm
    4U,	// VPMINSDrr
    4U,	// VPMINSQZ128rm
    72U,	// VPMINSQZ128rmb
    133U,	// VPMINSQZ128rmbk
    9348U,	// VPMINSQZ128rmbkz
    132U,	// VPMINSQZ128rmk
    9348U,	// VPMINSQZ128rmkz
    4U,	// VPMINSQZ128rr
    0U,	// VPMINSQZ128rrk
    9348U,	// VPMINSQZ128rrkz
    4U,	// VPMINSQZ256rm
    72U,	// VPMINSQZ256rmb
    133U,	// VPMINSQZ256rmbk
    9348U,	// VPMINSQZ256rmbkz
    132U,	// VPMINSQZ256rmk
    9348U,	// VPMINSQZ256rmkz
    4U,	// VPMINSQZ256rr
    0U,	// VPMINSQZ256rrk
    9348U,	// VPMINSQZ256rrkz
    4U,	// VPMINSQZrm
    72U,	// VPMINSQZrmb
    133U,	// VPMINSQZrmbk
    9348U,	// VPMINSQZrmbkz
    132U,	// VPMINSQZrmk
    9348U,	// VPMINSQZrmkz
    4U,	// VPMINSQZrr
    0U,	// VPMINSQZrrk
    9348U,	// VPMINSQZrrkz
    4U,	// VPMINSWYrm
    4U,	// VPMINSWYrr
    4U,	// VPMINSWZ128rm
    132U,	// VPMINSWZ128rmk
    9348U,	// VPMINSWZ128rmkz
    4U,	// VPMINSWZ128rr
    0U,	// VPMINSWZ128rrk
    9348U,	// VPMINSWZ128rrkz
    4U,	// VPMINSWZ256rm
    132U,	// VPMINSWZ256rmk
    9348U,	// VPMINSWZ256rmkz
    4U,	// VPMINSWZ256rr
    0U,	// VPMINSWZ256rrk
    9348U,	// VPMINSWZ256rrkz
    4U,	// VPMINSWZrm
    132U,	// VPMINSWZrmk
    9348U,	// VPMINSWZrmkz
    4U,	// VPMINSWZrr
    0U,	// VPMINSWZrrk
    9348U,	// VPMINSWZrrkz
    4U,	// VPMINSWrm
    4U,	// VPMINSWrr
    4U,	// VPMINUBYrm
    4U,	// VPMINUBYrr
    4U,	// VPMINUBZ128rm
    132U,	// VPMINUBZ128rmk
    9348U,	// VPMINUBZ128rmkz
    4U,	// VPMINUBZ128rr
    0U,	// VPMINUBZ128rrk
    9348U,	// VPMINUBZ128rrkz
    4U,	// VPMINUBZ256rm
    132U,	// VPMINUBZ256rmk
    9348U,	// VPMINUBZ256rmkz
    4U,	// VPMINUBZ256rr
    0U,	// VPMINUBZ256rrk
    9348U,	// VPMINUBZ256rrkz
    4U,	// VPMINUBZrm
    132U,	// VPMINUBZrmk
    9348U,	// VPMINUBZrmkz
    4U,	// VPMINUBZrr
    0U,	// VPMINUBZrrk
    9348U,	// VPMINUBZrrkz
    4U,	// VPMINUBrm
    4U,	// VPMINUBrr
    4U,	// VPMINUDYrm
    4U,	// VPMINUDYrr
    4U,	// VPMINUDZ128rm
    72U,	// VPMINUDZ128rmb
    133U,	// VPMINUDZ128rmbk
    9348U,	// VPMINUDZ128rmbkz
    132U,	// VPMINUDZ128rmk
    9348U,	// VPMINUDZ128rmkz
    4U,	// VPMINUDZ128rr
    0U,	// VPMINUDZ128rrk
    9348U,	// VPMINUDZ128rrkz
    4U,	// VPMINUDZ256rm
    72U,	// VPMINUDZ256rmb
    133U,	// VPMINUDZ256rmbk
    9348U,	// VPMINUDZ256rmbkz
    132U,	// VPMINUDZ256rmk
    9348U,	// VPMINUDZ256rmkz
    4U,	// VPMINUDZ256rr
    0U,	// VPMINUDZ256rrk
    9348U,	// VPMINUDZ256rrkz
    4U,	// VPMINUDZrm
    72U,	// VPMINUDZrmb
    133U,	// VPMINUDZrmbk
    9348U,	// VPMINUDZrmbkz
    132U,	// VPMINUDZrmk
    9348U,	// VPMINUDZrmkz
    4U,	// VPMINUDZrr
    0U,	// VPMINUDZrrk
    9348U,	// VPMINUDZrrkz
    4U,	// VPMINUDrm
    4U,	// VPMINUDrr
    4U,	// VPMINUQZ128rm
    72U,	// VPMINUQZ128rmb
    133U,	// VPMINUQZ128rmbk
    9348U,	// VPMINUQZ128rmbkz
    132U,	// VPMINUQZ128rmk
    9348U,	// VPMINUQZ128rmkz
    4U,	// VPMINUQZ128rr
    0U,	// VPMINUQZ128rrk
    9348U,	// VPMINUQZ128rrkz
    4U,	// VPMINUQZ256rm
    72U,	// VPMINUQZ256rmb
    133U,	// VPMINUQZ256rmbk
    9348U,	// VPMINUQZ256rmbkz
    132U,	// VPMINUQZ256rmk
    9348U,	// VPMINUQZ256rmkz
    4U,	// VPMINUQZ256rr
    0U,	// VPMINUQZ256rrk
    9348U,	// VPMINUQZ256rrkz
    4U,	// VPMINUQZrm
    72U,	// VPMINUQZrmb
    133U,	// VPMINUQZrmbk
    9348U,	// VPMINUQZrmbkz
    132U,	// VPMINUQZrmk
    9348U,	// VPMINUQZrmkz
    4U,	// VPMINUQZrr
    0U,	// VPMINUQZrrk
    9348U,	// VPMINUQZrrkz
    4U,	// VPMINUWYrm
    4U,	// VPMINUWYrr
    4U,	// VPMINUWZ128rm
    132U,	// VPMINUWZ128rmk
    9348U,	// VPMINUWZ128rmkz
    4U,	// VPMINUWZ128rr
    0U,	// VPMINUWZ128rrk
    9348U,	// VPMINUWZ128rrkz
    4U,	// VPMINUWZ256rm
    132U,	// VPMINUWZ256rmk
    9348U,	// VPMINUWZ256rmkz
    4U,	// VPMINUWZ256rr
    0U,	// VPMINUWZ256rrk
    9348U,	// VPMINUWZ256rrkz
    4U,	// VPMINUWZrm
    132U,	// VPMINUWZrmk
    9348U,	// VPMINUWZrmkz
    4U,	// VPMINUWZrr
    0U,	// VPMINUWZrrk
    9348U,	// VPMINUWZrrkz
    4U,	// VPMINUWrm
    4U,	// VPMINUWrr
    0U,	// VPMOVB2MZ128rr
    0U,	// VPMOVB2MZ256rr
    0U,	// VPMOVB2MZrr
    0U,	// VPMOVD2MZ128rr
    0U,	// VPMOVD2MZ256rr
    0U,	// VPMOVD2MZrr
    0U,	// VPMOVDBZ128mr
    49U,	// VPMOVDBZ128mrk
    0U,	// VPMOVDBZ128rr
    405U,	// VPMOVDBZ128rrk
    461U,	// VPMOVDBZ128rrkz
    0U,	// VPMOVDBZ256mr
    49U,	// VPMOVDBZ256mrk
    0U,	// VPMOVDBZ256rr
    405U,	// VPMOVDBZ256rrk
    461U,	// VPMOVDBZ256rrkz
    0U,	// VPMOVDBZmr
    49U,	// VPMOVDBZmrk
    0U,	// VPMOVDBZrr
    405U,	// VPMOVDBZrrk
    461U,	// VPMOVDBZrrkz
    0U,	// VPMOVDWZ128mr
    49U,	// VPMOVDWZ128mrk
    0U,	// VPMOVDWZ128rr
    405U,	// VPMOVDWZ128rrk
    461U,	// VPMOVDWZ128rrkz
    0U,	// VPMOVDWZ256mr
    49U,	// VPMOVDWZ256mrk
    0U,	// VPMOVDWZ256rr
    405U,	// VPMOVDWZ256rrk
    461U,	// VPMOVDWZ256rrkz
    0U,	// VPMOVDWZmr
    49U,	// VPMOVDWZmrk
    0U,	// VPMOVDWZrr
    405U,	// VPMOVDWZrrk
    461U,	// VPMOVDWZrrkz
    0U,	// VPMOVM2BZ128rr
    0U,	// VPMOVM2BZ256rr
    0U,	// VPMOVM2BZrr
    0U,	// VPMOVM2DZ128rr
    0U,	// VPMOVM2DZ256rr
    0U,	// VPMOVM2DZrr
    0U,	// VPMOVM2QZ128rr
    0U,	// VPMOVM2QZ256rr
    0U,	// VPMOVM2QZrr
    0U,	// VPMOVM2WZ128rr
    0U,	// VPMOVM2WZ256rr
    0U,	// VPMOVM2WZrr
    0U,	// VPMOVMSKBYrr
    0U,	// VPMOVMSKBrr
    0U,	// VPMOVQ2MZ128rr
    0U,	// VPMOVQ2MZ256rr
    0U,	// VPMOVQ2MZrr
    0U,	// VPMOVQBZ128mr
    49U,	// VPMOVQBZ128mrk
    0U,	// VPMOVQBZ128rr
    405U,	// VPMOVQBZ128rrk
    461U,	// VPMOVQBZ128rrkz
    0U,	// VPMOVQBZ256mr
    49U,	// VPMOVQBZ256mrk
    0U,	// VPMOVQBZ256rr
    405U,	// VPMOVQBZ256rrk
    461U,	// VPMOVQBZ256rrkz
    0U,	// VPMOVQBZmr
    49U,	// VPMOVQBZmrk
    0U,	// VPMOVQBZrr
    405U,	// VPMOVQBZrrk
    461U,	// VPMOVQBZrrkz
    0U,	// VPMOVQDZ128mr
    49U,	// VPMOVQDZ128mrk
    0U,	// VPMOVQDZ128rr
    405U,	// VPMOVQDZ128rrk
    461U,	// VPMOVQDZ128rrkz
    0U,	// VPMOVQDZ256mr
    49U,	// VPMOVQDZ256mrk
    0U,	// VPMOVQDZ256rr
    405U,	// VPMOVQDZ256rrk
    461U,	// VPMOVQDZ256rrkz
    0U,	// VPMOVQDZmr
    49U,	// VPMOVQDZmrk
    0U,	// VPMOVQDZrr
    405U,	// VPMOVQDZrrk
    461U,	// VPMOVQDZrrkz
    0U,	// VPMOVQWZ128mr
    49U,	// VPMOVQWZ128mrk
    0U,	// VPMOVQWZ128rr
    405U,	// VPMOVQWZ128rrk
    461U,	// VPMOVQWZ128rrkz
    0U,	// VPMOVQWZ256mr
    49U,	// VPMOVQWZ256mrk
    0U,	// VPMOVQWZ256rr
    405U,	// VPMOVQWZ256rrk
    461U,	// VPMOVQWZ256rrkz
    0U,	// VPMOVQWZmr
    49U,	// VPMOVQWZmrk
    0U,	// VPMOVQWZrr
    405U,	// VPMOVQWZrrk
    461U,	// VPMOVQWZrrkz
    0U,	// VPMOVSDBZ128mr
    49U,	// VPMOVSDBZ128mrk
    0U,	// VPMOVSDBZ128rr
    405U,	// VPMOVSDBZ128rrk
    461U,	// VPMOVSDBZ128rrkz
    0U,	// VPMOVSDBZ256mr
    49U,	// VPMOVSDBZ256mrk
    0U,	// VPMOVSDBZ256rr
    405U,	// VPMOVSDBZ256rrk
    461U,	// VPMOVSDBZ256rrkz
    0U,	// VPMOVSDBZmr
    49U,	// VPMOVSDBZmrk
    0U,	// VPMOVSDBZrr
    405U,	// VPMOVSDBZrrk
    461U,	// VPMOVSDBZrrkz
    0U,	// VPMOVSDWZ128mr
    49U,	// VPMOVSDWZ128mrk
    0U,	// VPMOVSDWZ128rr
    405U,	// VPMOVSDWZ128rrk
    461U,	// VPMOVSDWZ128rrkz
    0U,	// VPMOVSDWZ256mr
    49U,	// VPMOVSDWZ256mrk
    0U,	// VPMOVSDWZ256rr
    405U,	// VPMOVSDWZ256rrk
    461U,	// VPMOVSDWZ256rrkz
    0U,	// VPMOVSDWZmr
    49U,	// VPMOVSDWZmrk
    0U,	// VPMOVSDWZrr
    405U,	// VPMOVSDWZrrk
    461U,	// VPMOVSDWZrrkz
    0U,	// VPMOVSQBZ128mr
    49U,	// VPMOVSQBZ128mrk
    0U,	// VPMOVSQBZ128rr
    405U,	// VPMOVSQBZ128rrk
    461U,	// VPMOVSQBZ128rrkz
    0U,	// VPMOVSQBZ256mr
    49U,	// VPMOVSQBZ256mrk
    0U,	// VPMOVSQBZ256rr
    405U,	// VPMOVSQBZ256rrk
    461U,	// VPMOVSQBZ256rrkz
    0U,	// VPMOVSQBZmr
    49U,	// VPMOVSQBZmrk
    0U,	// VPMOVSQBZrr
    405U,	// VPMOVSQBZrrk
    461U,	// VPMOVSQBZrrkz
    0U,	// VPMOVSQDZ128mr
    49U,	// VPMOVSQDZ128mrk
    0U,	// VPMOVSQDZ128rr
    405U,	// VPMOVSQDZ128rrk
    461U,	// VPMOVSQDZ128rrkz
    0U,	// VPMOVSQDZ256mr
    49U,	// VPMOVSQDZ256mrk
    0U,	// VPMOVSQDZ256rr
    405U,	// VPMOVSQDZ256rrk
    461U,	// VPMOVSQDZ256rrkz
    0U,	// VPMOVSQDZmr
    49U,	// VPMOVSQDZmrk
    0U,	// VPMOVSQDZrr
    405U,	// VPMOVSQDZrrk
    461U,	// VPMOVSQDZrrkz
    0U,	// VPMOVSQWZ128mr
    49U,	// VPMOVSQWZ128mrk
    0U,	// VPMOVSQWZ128rr
    405U,	// VPMOVSQWZ128rrk
    461U,	// VPMOVSQWZ128rrkz
    0U,	// VPMOVSQWZ256mr
    49U,	// VPMOVSQWZ256mrk
    0U,	// VPMOVSQWZ256rr
    405U,	// VPMOVSQWZ256rrk
    461U,	// VPMOVSQWZ256rrkz
    0U,	// VPMOVSQWZmr
    49U,	// VPMOVSQWZmrk
    0U,	// VPMOVSQWZrr
    405U,	// VPMOVSQWZrrk
    461U,	// VPMOVSQWZrrkz
    0U,	// VPMOVSWBZ128mr
    49U,	// VPMOVSWBZ128mrk
    0U,	// VPMOVSWBZ128rr
    405U,	// VPMOVSWBZ128rrk
    461U,	// VPMOVSWBZ128rrkz
    0U,	// VPMOVSWBZ256mr
    49U,	// VPMOVSWBZ256mrk
    0U,	// VPMOVSWBZ256rr
    405U,	// VPMOVSWBZ256rrk
    461U,	// VPMOVSWBZ256rrkz
    0U,	// VPMOVSWBZmr
    49U,	// VPMOVSWBZmrk
    0U,	// VPMOVSWBZrr
    405U,	// VPMOVSWBZrrk
    461U,	// VPMOVSWBZrrkz
    0U,	// VPMOVSXBDYrm
    0U,	// VPMOVSXBDYrr
    0U,	// VPMOVSXBDZ128rm
    3356U,	// VPMOVSXBDZ128rmk
    4444U,	// VPMOVSXBDZ128rmkz
    0U,	// VPMOVSXBDZ128rr
    405U,	// VPMOVSXBDZ128rrk
    461U,	// VPMOVSXBDZ128rrkz
    0U,	// VPMOVSXBDZ256rm
    3356U,	// VPMOVSXBDZ256rmk
    4444U,	// VPMOVSXBDZ256rmkz
    0U,	// VPMOVSXBDZ256rr
    405U,	// VPMOVSXBDZ256rrk
    461U,	// VPMOVSXBDZ256rrkz
    0U,	// VPMOVSXBDZrm
    405U,	// VPMOVSXBDZrmk
    461U,	// VPMOVSXBDZrmkz
    0U,	// VPMOVSXBDZrr
    405U,	// VPMOVSXBDZrrk
    461U,	// VPMOVSXBDZrrkz
    0U,	// VPMOVSXBDrm
    0U,	// VPMOVSXBDrr
    0U,	// VPMOVSXBQYrm
    0U,	// VPMOVSXBQYrr
    0U,	// VPMOVSXBQZ128rm
    0U,	// VPMOVSXBQZ128rmk
    461U,	// VPMOVSXBQZ128rmkz
    0U,	// VPMOVSXBQZ128rr
    405U,	// VPMOVSXBQZ128rrk
    461U,	// VPMOVSXBQZ128rrkz
    0U,	// VPMOVSXBQZ256rm
    3356U,	// VPMOVSXBQZ256rmk
    4444U,	// VPMOVSXBQZ256rmkz
    0U,	// VPMOVSXBQZ256rr
    405U,	// VPMOVSXBQZ256rrk
    461U,	// VPMOVSXBQZ256rrkz
    0U,	// VPMOVSXBQZrm
    3356U,	// VPMOVSXBQZrmk
    4444U,	// VPMOVSXBQZrmkz
    0U,	// VPMOVSXBQZrr
    405U,	// VPMOVSXBQZrrk
    461U,	// VPMOVSXBQZrrkz
    0U,	// VPMOVSXBQrm
    0U,	// VPMOVSXBQrr
    0U,	// VPMOVSXBWYrm
    0U,	// VPMOVSXBWYrr
    0U,	// VPMOVSXBWZ128rm
    3356U,	// VPMOVSXBWZ128rmk
    4444U,	// VPMOVSXBWZ128rmkz
    0U,	// VPMOVSXBWZ128rr
    405U,	// VPMOVSXBWZ128rrk
    461U,	// VPMOVSXBWZ128rrkz
    0U,	// VPMOVSXBWZ256rm
    405U,	// VPMOVSXBWZ256rmk
    461U,	// VPMOVSXBWZ256rmkz
    0U,	// VPMOVSXBWZ256rr
    405U,	// VPMOVSXBWZ256rrk
    461U,	// VPMOVSXBWZ256rrkz
    0U,	// VPMOVSXBWZrm
    405U,	// VPMOVSXBWZrmk
    461U,	// VPMOVSXBWZrmkz
    0U,	// VPMOVSXBWZrr
    405U,	// VPMOVSXBWZrrk
    461U,	// VPMOVSXBWZrrkz
    0U,	// VPMOVSXBWrm
    0U,	// VPMOVSXBWrr
    0U,	// VPMOVSXDQYrm
    0U,	// VPMOVSXDQYrr
    0U,	// VPMOVSXDQZ128rm
    3356U,	// VPMOVSXDQZ128rmk
    4444U,	// VPMOVSXDQZ128rmkz
    0U,	// VPMOVSXDQZ128rr
    405U,	// VPMOVSXDQZ128rrk
    461U,	// VPMOVSXDQZ128rrkz
    0U,	// VPMOVSXDQZ256rm
    405U,	// VPMOVSXDQZ256rmk
    461U,	// VPMOVSXDQZ256rmkz
    0U,	// VPMOVSXDQZ256rr
    405U,	// VPMOVSXDQZ256rrk
    461U,	// VPMOVSXDQZ256rrkz
    0U,	// VPMOVSXDQZrm
    405U,	// VPMOVSXDQZrmk
    461U,	// VPMOVSXDQZrmkz
    0U,	// VPMOVSXDQZrr
    405U,	// VPMOVSXDQZrrk
    461U,	// VPMOVSXDQZrrkz
    0U,	// VPMOVSXDQrm
    0U,	// VPMOVSXDQrr
    0U,	// VPMOVSXWDYrm
    0U,	// VPMOVSXWDYrr
    0U,	// VPMOVSXWDZ128rm
    3356U,	// VPMOVSXWDZ128rmk
    4444U,	// VPMOVSXWDZ128rmkz
    0U,	// VPMOVSXWDZ128rr
    405U,	// VPMOVSXWDZ128rrk
    461U,	// VPMOVSXWDZ128rrkz
    0U,	// VPMOVSXWDZ256rm
    405U,	// VPMOVSXWDZ256rmk
    461U,	// VPMOVSXWDZ256rmkz
    0U,	// VPMOVSXWDZ256rr
    405U,	// VPMOVSXWDZ256rrk
    461U,	// VPMOVSXWDZ256rrkz
    0U,	// VPMOVSXWDZrm
    405U,	// VPMOVSXWDZrmk
    461U,	// VPMOVSXWDZrmkz
    0U,	// VPMOVSXWDZrr
    405U,	// VPMOVSXWDZrrk
    461U,	// VPMOVSXWDZrrkz
    0U,	// VPMOVSXWDrm
    0U,	// VPMOVSXWDrr
    0U,	// VPMOVSXWQYrm
    0U,	// VPMOVSXWQYrr
    0U,	// VPMOVSXWQZ128rm
    3356U,	// VPMOVSXWQZ128rmk
    4444U,	// VPMOVSXWQZ128rmkz
    0U,	// VPMOVSXWQZ128rr
    405U,	// VPMOVSXWQZ128rrk
    461U,	// VPMOVSXWQZ128rrkz
    0U,	// VPMOVSXWQZ256rm
    3356U,	// VPMOVSXWQZ256rmk
    4444U,	// VPMOVSXWQZ256rmkz
    0U,	// VPMOVSXWQZ256rr
    405U,	// VPMOVSXWQZ256rrk
    461U,	// VPMOVSXWQZ256rrkz
    0U,	// VPMOVSXWQZrm
    405U,	// VPMOVSXWQZrmk
    461U,	// VPMOVSXWQZrmkz
    0U,	// VPMOVSXWQZrr
    405U,	// VPMOVSXWQZrrk
    461U,	// VPMOVSXWQZrrkz
    0U,	// VPMOVSXWQrm
    0U,	// VPMOVSXWQrr
    0U,	// VPMOVUSDBZ128mr
    49U,	// VPMOVUSDBZ128mrk
    0U,	// VPMOVUSDBZ128rr
    405U,	// VPMOVUSDBZ128rrk
    461U,	// VPMOVUSDBZ128rrkz
    0U,	// VPMOVUSDBZ256mr
    49U,	// VPMOVUSDBZ256mrk
    0U,	// VPMOVUSDBZ256rr
    405U,	// VPMOVUSDBZ256rrk
    461U,	// VPMOVUSDBZ256rrkz
    0U,	// VPMOVUSDBZmr
    49U,	// VPMOVUSDBZmrk
    0U,	// VPMOVUSDBZrr
    405U,	// VPMOVUSDBZrrk
    461U,	// VPMOVUSDBZrrkz
    0U,	// VPMOVUSDWZ128mr
    49U,	// VPMOVUSDWZ128mrk
    0U,	// VPMOVUSDWZ128rr
    405U,	// VPMOVUSDWZ128rrk
    461U,	// VPMOVUSDWZ128rrkz
    0U,	// VPMOVUSDWZ256mr
    49U,	// VPMOVUSDWZ256mrk
    0U,	// VPMOVUSDWZ256rr
    405U,	// VPMOVUSDWZ256rrk
    461U,	// VPMOVUSDWZ256rrkz
    0U,	// VPMOVUSDWZmr
    49U,	// VPMOVUSDWZmrk
    0U,	// VPMOVUSDWZrr
    405U,	// VPMOVUSDWZrrk
    461U,	// VPMOVUSDWZrrkz
    0U,	// VPMOVUSQBZ128mr
    49U,	// VPMOVUSQBZ128mrk
    0U,	// VPMOVUSQBZ128rr
    405U,	// VPMOVUSQBZ128rrk
    461U,	// VPMOVUSQBZ128rrkz
    0U,	// VPMOVUSQBZ256mr
    49U,	// VPMOVUSQBZ256mrk
    0U,	// VPMOVUSQBZ256rr
    405U,	// VPMOVUSQBZ256rrk
    461U,	// VPMOVUSQBZ256rrkz
    0U,	// VPMOVUSQBZmr
    49U,	// VPMOVUSQBZmrk
    0U,	// VPMOVUSQBZrr
    405U,	// VPMOVUSQBZrrk
    461U,	// VPMOVUSQBZrrkz
    0U,	// VPMOVUSQDZ128mr
    49U,	// VPMOVUSQDZ128mrk
    0U,	// VPMOVUSQDZ128rr
    405U,	// VPMOVUSQDZ128rrk
    461U,	// VPMOVUSQDZ128rrkz
    0U,	// VPMOVUSQDZ256mr
    49U,	// VPMOVUSQDZ256mrk
    0U,	// VPMOVUSQDZ256rr
    405U,	// VPMOVUSQDZ256rrk
    461U,	// VPMOVUSQDZ256rrkz
    0U,	// VPMOVUSQDZmr
    49U,	// VPMOVUSQDZmrk
    0U,	// VPMOVUSQDZrr
    405U,	// VPMOVUSQDZrrk
    461U,	// VPMOVUSQDZrrkz
    0U,	// VPMOVUSQWZ128mr
    49U,	// VPMOVUSQWZ128mrk
    0U,	// VPMOVUSQWZ128rr
    405U,	// VPMOVUSQWZ128rrk
    461U,	// VPMOVUSQWZ128rrkz
    0U,	// VPMOVUSQWZ256mr
    49U,	// VPMOVUSQWZ256mrk
    0U,	// VPMOVUSQWZ256rr
    405U,	// VPMOVUSQWZ256rrk
    461U,	// VPMOVUSQWZ256rrkz
    0U,	// VPMOVUSQWZmr
    49U,	// VPMOVUSQWZmrk
    0U,	// VPMOVUSQWZrr
    405U,	// VPMOVUSQWZrrk
    461U,	// VPMOVUSQWZrrkz
    0U,	// VPMOVUSWBZ128mr
    49U,	// VPMOVUSWBZ128mrk
    0U,	// VPMOVUSWBZ128rr
    405U,	// VPMOVUSWBZ128rrk
    461U,	// VPMOVUSWBZ128rrkz
    0U,	// VPMOVUSWBZ256mr
    49U,	// VPMOVUSWBZ256mrk
    0U,	// VPMOVUSWBZ256rr
    405U,	// VPMOVUSWBZ256rrk
    461U,	// VPMOVUSWBZ256rrkz
    0U,	// VPMOVUSWBZmr
    49U,	// VPMOVUSWBZmrk
    0U,	// VPMOVUSWBZrr
    405U,	// VPMOVUSWBZrrk
    461U,	// VPMOVUSWBZrrkz
    0U,	// VPMOVW2MZ128rr
    0U,	// VPMOVW2MZ256rr
    0U,	// VPMOVW2MZrr
    0U,	// VPMOVWBZ128mr
    49U,	// VPMOVWBZ128mrk
    0U,	// VPMOVWBZ128rr
    405U,	// VPMOVWBZ128rrk
    461U,	// VPMOVWBZ128rrkz
    0U,	// VPMOVWBZ256mr
    49U,	// VPMOVWBZ256mrk
    0U,	// VPMOVWBZ256rr
    405U,	// VPMOVWBZ256rrk
    461U,	// VPMOVWBZ256rrkz
    0U,	// VPMOVWBZmr
    49U,	// VPMOVWBZmrk
    0U,	// VPMOVWBZrr
    405U,	// VPMOVWBZrrk
    461U,	// VPMOVWBZrrkz
    0U,	// VPMOVZXBDYrm
    0U,	// VPMOVZXBDYrr
    0U,	// VPMOVZXBDZ128rm
    3356U,	// VPMOVZXBDZ128rmk
    4444U,	// VPMOVZXBDZ128rmkz
    0U,	// VPMOVZXBDZ128rr
    405U,	// VPMOVZXBDZ128rrk
    461U,	// VPMOVZXBDZ128rrkz
    0U,	// VPMOVZXBDZ256rm
    3356U,	// VPMOVZXBDZ256rmk
    4444U,	// VPMOVZXBDZ256rmkz
    0U,	// VPMOVZXBDZ256rr
    405U,	// VPMOVZXBDZ256rrk
    461U,	// VPMOVZXBDZ256rrkz
    0U,	// VPMOVZXBDZrm
    405U,	// VPMOVZXBDZrmk
    461U,	// VPMOVZXBDZrmkz
    0U,	// VPMOVZXBDZrr
    405U,	// VPMOVZXBDZrrk
    461U,	// VPMOVZXBDZrrkz
    0U,	// VPMOVZXBDrm
    0U,	// VPMOVZXBDrr
    0U,	// VPMOVZXBQYrm
    0U,	// VPMOVZXBQYrr
    0U,	// VPMOVZXBQZ128rm
    0U,	// VPMOVZXBQZ128rmk
    461U,	// VPMOVZXBQZ128rmkz
    0U,	// VPMOVZXBQZ128rr
    405U,	// VPMOVZXBQZ128rrk
    461U,	// VPMOVZXBQZ128rrkz
    0U,	// VPMOVZXBQZ256rm
    3356U,	// VPMOVZXBQZ256rmk
    4444U,	// VPMOVZXBQZ256rmkz
    0U,	// VPMOVZXBQZ256rr
    405U,	// VPMOVZXBQZ256rrk
    461U,	// VPMOVZXBQZ256rrkz
    0U,	// VPMOVZXBQZrm
    3356U,	// VPMOVZXBQZrmk
    4444U,	// VPMOVZXBQZrmkz
    0U,	// VPMOVZXBQZrr
    405U,	// VPMOVZXBQZrrk
    461U,	// VPMOVZXBQZrrkz
    0U,	// VPMOVZXBQrm
    0U,	// VPMOVZXBQrr
    0U,	// VPMOVZXBWYrm
    0U,	// VPMOVZXBWYrr
    0U,	// VPMOVZXBWZ128rm
    3356U,	// VPMOVZXBWZ128rmk
    4444U,	// VPMOVZXBWZ128rmkz
    0U,	// VPMOVZXBWZ128rr
    405U,	// VPMOVZXBWZ128rrk
    461U,	// VPMOVZXBWZ128rrkz
    0U,	// VPMOVZXBWZ256rm
    405U,	// VPMOVZXBWZ256rmk
    461U,	// VPMOVZXBWZ256rmkz
    0U,	// VPMOVZXBWZ256rr
    405U,	// VPMOVZXBWZ256rrk
    461U,	// VPMOVZXBWZ256rrkz
    0U,	// VPMOVZXBWZrm
    405U,	// VPMOVZXBWZrmk
    461U,	// VPMOVZXBWZrmkz
    0U,	// VPMOVZXBWZrr
    405U,	// VPMOVZXBWZrrk
    461U,	// VPMOVZXBWZrrkz
    0U,	// VPMOVZXBWrm
    0U,	// VPMOVZXBWrr
    0U,	// VPMOVZXDQYrm
    0U,	// VPMOVZXDQYrr
    0U,	// VPMOVZXDQZ128rm
    3356U,	// VPMOVZXDQZ128rmk
    4444U,	// VPMOVZXDQZ128rmkz
    0U,	// VPMOVZXDQZ128rr
    405U,	// VPMOVZXDQZ128rrk
    461U,	// VPMOVZXDQZ128rrkz
    0U,	// VPMOVZXDQZ256rm
    405U,	// VPMOVZXDQZ256rmk
    461U,	// VPMOVZXDQZ256rmkz
    0U,	// VPMOVZXDQZ256rr
    405U,	// VPMOVZXDQZ256rrk
    461U,	// VPMOVZXDQZ256rrkz
    0U,	// VPMOVZXDQZrm
    405U,	// VPMOVZXDQZrmk
    461U,	// VPMOVZXDQZrmkz
    0U,	// VPMOVZXDQZrr
    405U,	// VPMOVZXDQZrrk
    461U,	// VPMOVZXDQZrrkz
    0U,	// VPMOVZXDQrm
    0U,	// VPMOVZXDQrr
    0U,	// VPMOVZXWDYrm
    0U,	// VPMOVZXWDYrr
    0U,	// VPMOVZXWDZ128rm
    3356U,	// VPMOVZXWDZ128rmk
    4444U,	// VPMOVZXWDZ128rmkz
    0U,	// VPMOVZXWDZ128rr
    405U,	// VPMOVZXWDZ128rrk
    461U,	// VPMOVZXWDZ128rrkz
    0U,	// VPMOVZXWDZ256rm
    405U,	// VPMOVZXWDZ256rmk
    461U,	// VPMOVZXWDZ256rmkz
    0U,	// VPMOVZXWDZ256rr
    405U,	// VPMOVZXWDZ256rrk
    461U,	// VPMOVZXWDZ256rrkz
    0U,	// VPMOVZXWDZrm
    405U,	// VPMOVZXWDZrmk
    461U,	// VPMOVZXWDZrmkz
    0U,	// VPMOVZXWDZrr
    405U,	// VPMOVZXWDZrrk
    461U,	// VPMOVZXWDZrrkz
    0U,	// VPMOVZXWDrm
    0U,	// VPMOVZXWDrr
    0U,	// VPMOVZXWQYrm
    0U,	// VPMOVZXWQYrr
    0U,	// VPMOVZXWQZ128rm
    3356U,	// VPMOVZXWQZ128rmk
    4444U,	// VPMOVZXWQZ128rmkz
    0U,	// VPMOVZXWQZ128rr
    405U,	// VPMOVZXWQZ128rrk
    461U,	// VPMOVZXWQZ128rrkz
    0U,	// VPMOVZXWQZ256rm
    3356U,	// VPMOVZXWQZ256rmk
    4444U,	// VPMOVZXWQZ256rmkz
    0U,	// VPMOVZXWQZ256rr
    405U,	// VPMOVZXWQZ256rrk
    461U,	// VPMOVZXWQZ256rrkz
    0U,	// VPMOVZXWQZrm
    405U,	// VPMOVZXWQZrmk
    461U,	// VPMOVZXWQZrmkz
    0U,	// VPMOVZXWQZrr
    405U,	// VPMOVZXWQZrrk
    461U,	// VPMOVZXWQZrrkz
    0U,	// VPMOVZXWQrm
    0U,	// VPMOVZXWQrr
    4U,	// VPMULDQYrm
    4U,	// VPMULDQYrr
    4U,	// VPMULDQZ128rm
    72U,	// VPMULDQZ128rmb
    133U,	// VPMULDQZ128rmbk
    9348U,	// VPMULDQZ128rmbkz
    132U,	// VPMULDQZ128rmk
    9348U,	// VPMULDQZ128rmkz
    4U,	// VPMULDQZ128rr
    0U,	// VPMULDQZ128rrk
    9348U,	// VPMULDQZ128rrkz
    4U,	// VPMULDQZ256rm
    72U,	// VPMULDQZ256rmb
    133U,	// VPMULDQZ256rmbk
    9348U,	// VPMULDQZ256rmbkz
    132U,	// VPMULDQZ256rmk
    9348U,	// VPMULDQZ256rmkz
    4U,	// VPMULDQZ256rr
    0U,	// VPMULDQZ256rrk
    9348U,	// VPMULDQZ256rrkz
    4U,	// VPMULDQZrm
    72U,	// VPMULDQZrmb
    133U,	// VPMULDQZrmbk
    9348U,	// VPMULDQZrmbkz
    132U,	// VPMULDQZrmk
    9348U,	// VPMULDQZrmkz
    4U,	// VPMULDQZrr
    0U,	// VPMULDQZrrk
    9348U,	// VPMULDQZrrkz
    4U,	// VPMULDQrm
    4U,	// VPMULDQrr
    4U,	// VPMULHRSWYrm
    4U,	// VPMULHRSWYrr
    4U,	// VPMULHRSWZ128rm
    132U,	// VPMULHRSWZ128rmk
    9348U,	// VPMULHRSWZ128rmkz
    4U,	// VPMULHRSWZ128rr
    0U,	// VPMULHRSWZ128rrk
    9348U,	// VPMULHRSWZ128rrkz
    4U,	// VPMULHRSWZ256rm
    132U,	// VPMULHRSWZ256rmk
    9348U,	// VPMULHRSWZ256rmkz
    4U,	// VPMULHRSWZ256rr
    0U,	// VPMULHRSWZ256rrk
    9348U,	// VPMULHRSWZ256rrkz
    4U,	// VPMULHRSWZrm
    132U,	// VPMULHRSWZrmk
    9348U,	// VPMULHRSWZrmkz
    4U,	// VPMULHRSWZrr
    0U,	// VPMULHRSWZrrk
    9348U,	// VPMULHRSWZrrkz
    4U,	// VPMULHRSWrm
    4U,	// VPMULHRSWrr
    4U,	// VPMULHUWYrm
    4U,	// VPMULHUWYrr
    4U,	// VPMULHUWZ128rm
    132U,	// VPMULHUWZ128rmk
    9348U,	// VPMULHUWZ128rmkz
    4U,	// VPMULHUWZ128rr
    0U,	// VPMULHUWZ128rrk
    9348U,	// VPMULHUWZ128rrkz
    4U,	// VPMULHUWZ256rm
    132U,	// VPMULHUWZ256rmk
    9348U,	// VPMULHUWZ256rmkz
    4U,	// VPMULHUWZ256rr
    0U,	// VPMULHUWZ256rrk
    9348U,	// VPMULHUWZ256rrkz
    4U,	// VPMULHUWZrm
    132U,	// VPMULHUWZrmk
    9348U,	// VPMULHUWZrmkz
    4U,	// VPMULHUWZrr
    0U,	// VPMULHUWZrrk
    9348U,	// VPMULHUWZrrkz
    4U,	// VPMULHUWrm
    4U,	// VPMULHUWrr
    4U,	// VPMULHWYrm
    4U,	// VPMULHWYrr
    4U,	// VPMULHWZ128rm
    132U,	// VPMULHWZ128rmk
    9348U,	// VPMULHWZ128rmkz
    4U,	// VPMULHWZ128rr
    0U,	// VPMULHWZ128rrk
    9348U,	// VPMULHWZ128rrkz
    4U,	// VPMULHWZ256rm
    132U,	// VPMULHWZ256rmk
    9348U,	// VPMULHWZ256rmkz
    4U,	// VPMULHWZ256rr
    0U,	// VPMULHWZ256rrk
    9348U,	// VPMULHWZ256rrkz
    4U,	// VPMULHWZrm
    132U,	// VPMULHWZrmk
    9348U,	// VPMULHWZrmkz
    4U,	// VPMULHWZrr
    0U,	// VPMULHWZrrk
    9348U,	// VPMULHWZrrkz
    4U,	// VPMULHWrm
    4U,	// VPMULHWrr
    4U,	// VPMULLDYrm
    4U,	// VPMULLDYrr
    4U,	// VPMULLDZ128rm
    72U,	// VPMULLDZ128rmb
    133U,	// VPMULLDZ128rmbk
    9348U,	// VPMULLDZ128rmbkz
    132U,	// VPMULLDZ128rmk
    9348U,	// VPMULLDZ128rmkz
    4U,	// VPMULLDZ128rr
    0U,	// VPMULLDZ128rrk
    9348U,	// VPMULLDZ128rrkz
    4U,	// VPMULLDZ256rm
    72U,	// VPMULLDZ256rmb
    133U,	// VPMULLDZ256rmbk
    9348U,	// VPMULLDZ256rmbkz
    132U,	// VPMULLDZ256rmk
    9348U,	// VPMULLDZ256rmkz
    4U,	// VPMULLDZ256rr
    0U,	// VPMULLDZ256rrk
    9348U,	// VPMULLDZ256rrkz
    4U,	// VPMULLDZrm
    72U,	// VPMULLDZrmb
    133U,	// VPMULLDZrmbk
    9348U,	// VPMULLDZrmbkz
    132U,	// VPMULLDZrmk
    9348U,	// VPMULLDZrmkz
    4U,	// VPMULLDZrr
    0U,	// VPMULLDZrrk
    9348U,	// VPMULLDZrrkz
    4U,	// VPMULLDrm
    4U,	// VPMULLDrr
    4U,	// VPMULLQZ128rm
    72U,	// VPMULLQZ128rmb
    133U,	// VPMULLQZ128rmbk
    9348U,	// VPMULLQZ128rmbkz
    132U,	// VPMULLQZ128rmk
    9348U,	// VPMULLQZ128rmkz
    4U,	// VPMULLQZ128rr
    0U,	// VPMULLQZ128rrk
    9348U,	// VPMULLQZ128rrkz
    4U,	// VPMULLQZ256rm
    72U,	// VPMULLQZ256rmb
    133U,	// VPMULLQZ256rmbk
    9348U,	// VPMULLQZ256rmbkz
    132U,	// VPMULLQZ256rmk
    9348U,	// VPMULLQZ256rmkz
    4U,	// VPMULLQZ256rr
    0U,	// VPMULLQZ256rrk
    9348U,	// VPMULLQZ256rrkz
    4U,	// VPMULLQZrm
    72U,	// VPMULLQZrmb
    133U,	// VPMULLQZrmbk
    9348U,	// VPMULLQZrmbkz
    132U,	// VPMULLQZrmk
    9348U,	// VPMULLQZrmkz
    4U,	// VPMULLQZrr
    0U,	// VPMULLQZrrk
    9348U,	// VPMULLQZrrkz
    4U,	// VPMULLWYrm
    4U,	// VPMULLWYrr
    4U,	// VPMULLWZ128rm
    132U,	// VPMULLWZ128rmk
    9348U,	// VPMULLWZ128rmkz
    4U,	// VPMULLWZ128rr
    0U,	// VPMULLWZ128rrk
    9348U,	// VPMULLWZ128rrkz
    4U,	// VPMULLWZ256rm
    132U,	// VPMULLWZ256rmk
    9348U,	// VPMULLWZ256rmkz
    4U,	// VPMULLWZ256rr
    0U,	// VPMULLWZ256rrk
    9348U,	// VPMULLWZ256rrkz
    4U,	// VPMULLWZrm
    132U,	// VPMULLWZrmk
    9348U,	// VPMULLWZrmkz
    4U,	// VPMULLWZrr
    0U,	// VPMULLWZrrk
    9348U,	// VPMULLWZrrkz
    4U,	// VPMULLWrm
    4U,	// VPMULLWrr
    4U,	// VPMULTISHIFTQBZ128rm
    72U,	// VPMULTISHIFTQBZ128rmb
    133U,	// VPMULTISHIFTQBZ128rmbk
    9348U,	// VPMULTISHIFTQBZ128rmbkz
    132U,	// VPMULTISHIFTQBZ128rmk
    9348U,	// VPMULTISHIFTQBZ128rmkz
    4U,	// VPMULTISHIFTQBZ128rr
    0U,	// VPMULTISHIFTQBZ128rrk
    9348U,	// VPMULTISHIFTQBZ128rrkz
    4U,	// VPMULTISHIFTQBZ256rm
    72U,	// VPMULTISHIFTQBZ256rmb
    133U,	// VPMULTISHIFTQBZ256rmbk
    9348U,	// VPMULTISHIFTQBZ256rmbkz
    132U,	// VPMULTISHIFTQBZ256rmk
    9348U,	// VPMULTISHIFTQBZ256rmkz
    4U,	// VPMULTISHIFTQBZ256rr
    0U,	// VPMULTISHIFTQBZ256rrk
    9348U,	// VPMULTISHIFTQBZ256rrkz
    4U,	// VPMULTISHIFTQBZrm
    72U,	// VPMULTISHIFTQBZrmb
    133U,	// VPMULTISHIFTQBZrmbk
    9348U,	// VPMULTISHIFTQBZrmbkz
    132U,	// VPMULTISHIFTQBZrmk
    9348U,	// VPMULTISHIFTQBZrmkz
    4U,	// VPMULTISHIFTQBZrr
    0U,	// VPMULTISHIFTQBZrrk
    9348U,	// VPMULTISHIFTQBZrrkz
    4U,	// VPMULUDQYrm
    4U,	// VPMULUDQYrr
    4U,	// VPMULUDQZ128rm
    72U,	// VPMULUDQZ128rmb
    133U,	// VPMULUDQZ128rmbk
    9348U,	// VPMULUDQZ128rmbkz
    132U,	// VPMULUDQZ128rmk
    9348U,	// VPMULUDQZ128rmkz
    4U,	// VPMULUDQZ128rr
    0U,	// VPMULUDQZ128rrk
    9348U,	// VPMULUDQZ128rrkz
    4U,	// VPMULUDQZ256rm
    72U,	// VPMULUDQZ256rmb
    133U,	// VPMULUDQZ256rmbk
    9348U,	// VPMULUDQZ256rmbkz
    132U,	// VPMULUDQZ256rmk
    9348U,	// VPMULUDQZ256rmkz
    4U,	// VPMULUDQZ256rr
    0U,	// VPMULUDQZ256rrk
    9348U,	// VPMULUDQZ256rrkz
    4U,	// VPMULUDQZrm
    72U,	// VPMULUDQZrmb
    133U,	// VPMULUDQZrmbk
    9348U,	// VPMULUDQZrmbkz
    132U,	// VPMULUDQZrmk
    9348U,	// VPMULUDQZrmkz
    4U,	// VPMULUDQZrr
    0U,	// VPMULUDQZrrk
    9348U,	// VPMULUDQZrrkz
    4U,	// VPMULUDQrm
    4U,	// VPMULUDQrr
    0U,	// VPOPCNTBZ128rm
    405U,	// VPOPCNTBZ128rmk
    461U,	// VPOPCNTBZ128rmkz
    0U,	// VPOPCNTBZ128rr
    405U,	// VPOPCNTBZ128rrk
    461U,	// VPOPCNTBZ128rrkz
    0U,	// VPOPCNTBZ256rm
    405U,	// VPOPCNTBZ256rmk
    461U,	// VPOPCNTBZ256rmkz
    0U,	// VPOPCNTBZ256rr
    405U,	// VPOPCNTBZ256rrk
    461U,	// VPOPCNTBZ256rrkz
    0U,	// VPOPCNTBZrm
    405U,	// VPOPCNTBZrmk
    461U,	// VPOPCNTBZrmkz
    0U,	// VPOPCNTBZrr
    405U,	// VPOPCNTBZrrk
    461U,	// VPOPCNTBZrrkz
    0U,	// VPOPCNTDZ128rm
    0U,	// VPOPCNTDZ128rmb
    3356U,	// VPOPCNTDZ128rmbk
    4444U,	// VPOPCNTDZ128rmbkz
    405U,	// VPOPCNTDZ128rmk
    461U,	// VPOPCNTDZ128rmkz
    0U,	// VPOPCNTDZ128rr
    405U,	// VPOPCNTDZ128rrk
    461U,	// VPOPCNTDZ128rrkz
    0U,	// VPOPCNTDZ256rm
    0U,	// VPOPCNTDZ256rmb
    3356U,	// VPOPCNTDZ256rmbk
    4444U,	// VPOPCNTDZ256rmbkz
    405U,	// VPOPCNTDZ256rmk
    461U,	// VPOPCNTDZ256rmkz
    0U,	// VPOPCNTDZ256rr
    405U,	// VPOPCNTDZ256rrk
    461U,	// VPOPCNTDZ256rrkz
    0U,	// VPOPCNTDZrm
    0U,	// VPOPCNTDZrmb
    3356U,	// VPOPCNTDZrmbk
    4444U,	// VPOPCNTDZrmbkz
    405U,	// VPOPCNTDZrmk
    461U,	// VPOPCNTDZrmkz
    0U,	// VPOPCNTDZrr
    405U,	// VPOPCNTDZrrk
    461U,	// VPOPCNTDZrrkz
    0U,	// VPOPCNTQZ128rm
    0U,	// VPOPCNTQZ128rmb
    3356U,	// VPOPCNTQZ128rmbk
    4444U,	// VPOPCNTQZ128rmbkz
    405U,	// VPOPCNTQZ128rmk
    461U,	// VPOPCNTQZ128rmkz
    0U,	// VPOPCNTQZ128rr
    405U,	// VPOPCNTQZ128rrk
    461U,	// VPOPCNTQZ128rrkz
    0U,	// VPOPCNTQZ256rm
    0U,	// VPOPCNTQZ256rmb
    3356U,	// VPOPCNTQZ256rmbk
    4444U,	// VPOPCNTQZ256rmbkz
    405U,	// VPOPCNTQZ256rmk
    461U,	// VPOPCNTQZ256rmkz
    0U,	// VPOPCNTQZ256rr
    405U,	// VPOPCNTQZ256rrk
    461U,	// VPOPCNTQZ256rrkz
    0U,	// VPOPCNTQZrm
    0U,	// VPOPCNTQZrmb
    3356U,	// VPOPCNTQZrmbk
    4444U,	// VPOPCNTQZrmbkz
    405U,	// VPOPCNTQZrmk
    461U,	// VPOPCNTQZrmkz
    0U,	// VPOPCNTQZrr
    405U,	// VPOPCNTQZrrk
    461U,	// VPOPCNTQZrrkz
    0U,	// VPOPCNTWZ128rm
    405U,	// VPOPCNTWZ128rmk
    461U,	// VPOPCNTWZ128rmkz
    0U,	// VPOPCNTWZ128rr
    405U,	// VPOPCNTWZ128rrk
    461U,	// VPOPCNTWZ128rrkz
    0U,	// VPOPCNTWZ256rm
    405U,	// VPOPCNTWZ256rmk
    461U,	// VPOPCNTWZ256rmkz
    0U,	// VPOPCNTWZ256rr
    405U,	// VPOPCNTWZ256rrk
    461U,	// VPOPCNTWZ256rrkz
    0U,	// VPOPCNTWZrm
    405U,	// VPOPCNTWZrmk
    461U,	// VPOPCNTWZrmkz
    0U,	// VPOPCNTWZrr
    405U,	// VPOPCNTWZrrk
    461U,	// VPOPCNTWZrrkz
    4U,	// VPORDZ128rm
    72U,	// VPORDZ128rmb
    133U,	// VPORDZ128rmbk
    9348U,	// VPORDZ128rmbkz
    132U,	// VPORDZ128rmk
    9348U,	// VPORDZ128rmkz
    4U,	// VPORDZ128rr
    0U,	// VPORDZ128rrk
    9348U,	// VPORDZ128rrkz
    4U,	// VPORDZ256rm
    72U,	// VPORDZ256rmb
    133U,	// VPORDZ256rmbk
    9348U,	// VPORDZ256rmbkz
    132U,	// VPORDZ256rmk
    9348U,	// VPORDZ256rmkz
    4U,	// VPORDZ256rr
    0U,	// VPORDZ256rrk
    9348U,	// VPORDZ256rrkz
    4U,	// VPORDZrm
    72U,	// VPORDZrmb
    133U,	// VPORDZrmbk
    9348U,	// VPORDZrmbkz
    132U,	// VPORDZrmk
    9348U,	// VPORDZrmkz
    4U,	// VPORDZrr
    0U,	// VPORDZrrk
    9348U,	// VPORDZrrkz
    4U,	// VPORQZ128rm
    72U,	// VPORQZ128rmb
    133U,	// VPORQZ128rmbk
    9348U,	// VPORQZ128rmbkz
    132U,	// VPORQZ128rmk
    9348U,	// VPORQZ128rmkz
    4U,	// VPORQZ128rr
    0U,	// VPORQZ128rrk
    9348U,	// VPORQZ128rrkz
    4U,	// VPORQZ256rm
    72U,	// VPORQZ256rmb
    133U,	// VPORQZ256rmbk
    9348U,	// VPORQZ256rmbkz
    132U,	// VPORQZ256rmk
    9348U,	// VPORQZ256rmkz
    4U,	// VPORQZ256rr
    0U,	// VPORQZ256rrk
    9348U,	// VPORQZ256rrkz
    4U,	// VPORQZrm
    72U,	// VPORQZrmb
    133U,	// VPORQZrmbk
    9348U,	// VPORQZrmbkz
    132U,	// VPORQZrmk
    9348U,	// VPORQZrmkz
    4U,	// VPORQZrr
    0U,	// VPORQZrrk
    9348U,	// VPORQZrrkz
    4U,	// VPORYrm
    4U,	// VPORYrr
    4U,	// VPORrm
    4U,	// VPORrr
    72U,	// VPPERMrmr
    18636U,	// VPPERMrrm
    18636U,	// VPPERMrrr
    18636U,	// VPPERMrrr_REV
    5U,	// VPROLDZ128mbi
    133U,	// VPROLDZ128mbik
    9349U,	// VPROLDZ128mbikz
    4U,	// VPROLDZ128mi
    3356U,	// VPROLDZ128mik
    4444U,	// VPROLDZ128mikz
    72U,	// VPROLDZ128ri
    133U,	// VPROLDZ128rik
    9348U,	// VPROLDZ128rikz
    5U,	// VPROLDZ256mbi
    133U,	// VPROLDZ256mbik
    9349U,	// VPROLDZ256mbikz
    4U,	// VPROLDZ256mi
    3356U,	// VPROLDZ256mik
    4444U,	// VPROLDZ256mikz
    72U,	// VPROLDZ256ri
    133U,	// VPROLDZ256rik
    9348U,	// VPROLDZ256rikz
    5U,	// VPROLDZmbi
    133U,	// VPROLDZmbik
    9349U,	// VPROLDZmbikz
    4U,	// VPROLDZmi
    3356U,	// VPROLDZmik
    4444U,	// VPROLDZmikz
    72U,	// VPROLDZri
    133U,	// VPROLDZrik
    9348U,	// VPROLDZrikz
    5U,	// VPROLQZ128mbi
    133U,	// VPROLQZ128mbik
    9349U,	// VPROLQZ128mbikz
    4U,	// VPROLQZ128mi
    3356U,	// VPROLQZ128mik
    4444U,	// VPROLQZ128mikz
    72U,	// VPROLQZ128ri
    133U,	// VPROLQZ128rik
    9348U,	// VPROLQZ128rikz
    5U,	// VPROLQZ256mbi
    133U,	// VPROLQZ256mbik
    9349U,	// VPROLQZ256mbikz
    4U,	// VPROLQZ256mi
    3356U,	// VPROLQZ256mik
    4444U,	// VPROLQZ256mikz
    72U,	// VPROLQZ256ri
    133U,	// VPROLQZ256rik
    9348U,	// VPROLQZ256rikz
    5U,	// VPROLQZmbi
    133U,	// VPROLQZmbik
    9349U,	// VPROLQZmbikz
    4U,	// VPROLQZmi
    3356U,	// VPROLQZmik
    4444U,	// VPROLQZmikz
    72U,	// VPROLQZri
    133U,	// VPROLQZrik
    9348U,	// VPROLQZrikz
    4U,	// VPROLVDZ128rm
    72U,	// VPROLVDZ128rmb
    133U,	// VPROLVDZ128rmbk
    9348U,	// VPROLVDZ128rmbkz
    132U,	// VPROLVDZ128rmk
    9348U,	// VPROLVDZ128rmkz
    4U,	// VPROLVDZ128rr
    0U,	// VPROLVDZ128rrk
    9348U,	// VPROLVDZ128rrkz
    4U,	// VPROLVDZ256rm
    72U,	// VPROLVDZ256rmb
    133U,	// VPROLVDZ256rmbk
    9348U,	// VPROLVDZ256rmbkz
    132U,	// VPROLVDZ256rmk
    9348U,	// VPROLVDZ256rmkz
    4U,	// VPROLVDZ256rr
    0U,	// VPROLVDZ256rrk
    9348U,	// VPROLVDZ256rrkz
    4U,	// VPROLVDZrm
    72U,	// VPROLVDZrmb
    133U,	// VPROLVDZrmbk
    9348U,	// VPROLVDZrmbkz
    132U,	// VPROLVDZrmk
    9348U,	// VPROLVDZrmkz
    4U,	// VPROLVDZrr
    0U,	// VPROLVDZrrk
    9348U,	// VPROLVDZrrkz
    4U,	// VPROLVQZ128rm
    72U,	// VPROLVQZ128rmb
    133U,	// VPROLVQZ128rmbk
    9348U,	// VPROLVQZ128rmbkz
    132U,	// VPROLVQZ128rmk
    9348U,	// VPROLVQZ128rmkz
    4U,	// VPROLVQZ128rr
    0U,	// VPROLVQZ128rrk
    9348U,	// VPROLVQZ128rrkz
    4U,	// VPROLVQZ256rm
    72U,	// VPROLVQZ256rmb
    133U,	// VPROLVQZ256rmbk
    9348U,	// VPROLVQZ256rmbkz
    132U,	// VPROLVQZ256rmk
    9348U,	// VPROLVQZ256rmkz
    4U,	// VPROLVQZ256rr
    0U,	// VPROLVQZ256rrk
    9348U,	// VPROLVQZ256rrkz
    4U,	// VPROLVQZrm
    72U,	// VPROLVQZrmb
    133U,	// VPROLVQZrmbk
    9348U,	// VPROLVQZrmbkz
    132U,	// VPROLVQZrmk
    9348U,	// VPROLVQZrmkz
    4U,	// VPROLVQZrr
    0U,	// VPROLVQZrrk
    9348U,	// VPROLVQZrrkz
    5U,	// VPRORDZ128mbi
    133U,	// VPRORDZ128mbik
    9349U,	// VPRORDZ128mbikz
    4U,	// VPRORDZ128mi
    3356U,	// VPRORDZ128mik
    4444U,	// VPRORDZ128mikz
    72U,	// VPRORDZ128ri
    133U,	// VPRORDZ128rik
    9348U,	// VPRORDZ128rikz
    5U,	// VPRORDZ256mbi
    133U,	// VPRORDZ256mbik
    9349U,	// VPRORDZ256mbikz
    4U,	// VPRORDZ256mi
    3356U,	// VPRORDZ256mik
    4444U,	// VPRORDZ256mikz
    72U,	// VPRORDZ256ri
    133U,	// VPRORDZ256rik
    9348U,	// VPRORDZ256rikz
    5U,	// VPRORDZmbi
    133U,	// VPRORDZmbik
    9349U,	// VPRORDZmbikz
    4U,	// VPRORDZmi
    3356U,	// VPRORDZmik
    4444U,	// VPRORDZmikz
    72U,	// VPRORDZri
    133U,	// VPRORDZrik
    9348U,	// VPRORDZrikz
    5U,	// VPRORQZ128mbi
    133U,	// VPRORQZ128mbik
    9349U,	// VPRORQZ128mbikz
    4U,	// VPRORQZ128mi
    3356U,	// VPRORQZ128mik
    4444U,	// VPRORQZ128mikz
    72U,	// VPRORQZ128ri
    133U,	// VPRORQZ128rik
    9348U,	// VPRORQZ128rikz
    5U,	// VPRORQZ256mbi
    133U,	// VPRORQZ256mbik
    9349U,	// VPRORQZ256mbikz
    4U,	// VPRORQZ256mi
    3356U,	// VPRORQZ256mik
    4444U,	// VPRORQZ256mikz
    72U,	// VPRORQZ256ri
    133U,	// VPRORQZ256rik
    9348U,	// VPRORQZ256rikz
    5U,	// VPRORQZmbi
    133U,	// VPRORQZmbik
    9349U,	// VPRORQZmbikz
    4U,	// VPRORQZmi
    3356U,	// VPRORQZmik
    4444U,	// VPRORQZmikz
    72U,	// VPRORQZri
    133U,	// VPRORQZrik
    9348U,	// VPRORQZrikz
    4U,	// VPRORVDZ128rm
    72U,	// VPRORVDZ128rmb
    133U,	// VPRORVDZ128rmbk
    9348U,	// VPRORVDZ128rmbkz
    132U,	// VPRORVDZ128rmk
    9348U,	// VPRORVDZ128rmkz
    4U,	// VPRORVDZ128rr
    0U,	// VPRORVDZ128rrk
    9348U,	// VPRORVDZ128rrkz
    4U,	// VPRORVDZ256rm
    72U,	// VPRORVDZ256rmb
    133U,	// VPRORVDZ256rmbk
    9348U,	// VPRORVDZ256rmbkz
    132U,	// VPRORVDZ256rmk
    9348U,	// VPRORVDZ256rmkz
    4U,	// VPRORVDZ256rr
    0U,	// VPRORVDZ256rrk
    9348U,	// VPRORVDZ256rrkz
    4U,	// VPRORVDZrm
    72U,	// VPRORVDZrmb
    133U,	// VPRORVDZrmbk
    9348U,	// VPRORVDZrmbkz
    132U,	// VPRORVDZrmk
    9348U,	// VPRORVDZrmkz
    4U,	// VPRORVDZrr
    0U,	// VPRORVDZrrk
    9348U,	// VPRORVDZrrkz
    4U,	// VPRORVQZ128rm
    72U,	// VPRORVQZ128rmb
    133U,	// VPRORVQZ128rmbk
    9348U,	// VPRORVQZ128rmbkz
    132U,	// VPRORVQZ128rmk
    9348U,	// VPRORVQZ128rmkz
    4U,	// VPRORVQZ128rr
    0U,	// VPRORVQZ128rrk
    9348U,	// VPRORVQZ128rrkz
    4U,	// VPRORVQZ256rm
    72U,	// VPRORVQZ256rmb
    133U,	// VPRORVQZ256rmbk
    9348U,	// VPRORVQZ256rmbkz
    132U,	// VPRORVQZ256rmk
    9348U,	// VPRORVQZ256rmkz
    4U,	// VPRORVQZ256rr
    0U,	// VPRORVQZ256rrk
    9348U,	// VPRORVQZ256rrkz
    4U,	// VPRORVQZrm
    72U,	// VPRORVQZrmb
    133U,	// VPRORVQZrmbk
    9348U,	// VPRORVQZrmbkz
    132U,	// VPRORVQZrmk
    9348U,	// VPRORVQZrmkz
    4U,	// VPRORVQZrr
    0U,	// VPRORVQZrrk
    9348U,	// VPRORVQZrrkz
    4U,	// VPROTBmi
    4U,	// VPROTBmr
    72U,	// VPROTBri
    4U,	// VPROTBrm
    4U,	// VPROTBrr
    4U,	// VPROTBrr_REV
    4U,	// VPROTDmi
    4U,	// VPROTDmr
    72U,	// VPROTDri
    4U,	// VPROTDrm
    4U,	// VPROTDrr
    4U,	// VPROTDrr_REV
    4U,	// VPROTQmi
    4U,	// VPROTQmr
    72U,	// VPROTQri
    4U,	// VPROTQrm
    4U,	// VPROTQrr
    4U,	// VPROTQrr_REV
    4U,	// VPROTWmi
    4U,	// VPROTWmr
    72U,	// VPROTWri
    4U,	// VPROTWrm
    4U,	// VPROTWrr
    4U,	// VPROTWrr_REV
    4U,	// VPSADBWYrm
    4U,	// VPSADBWYrr
    4U,	// VPSADBWZ128rm
    4U,	// VPSADBWZ128rr
    4U,	// VPSADBWZ256rm
    4U,	// VPSADBWZ256rr
    4U,	// VPSADBWZrm
    4U,	// VPSADBWZrr
    4U,	// VPSADBWrm
    4U,	// VPSADBWrr
    57U,	// VPSCATTERDDZ128mr
    57U,	// VPSCATTERDDZ256mr
    57U,	// VPSCATTERDDZmr
    57U,	// VPSCATTERDQZ128mr
    57U,	// VPSCATTERDQZ256mr
    57U,	// VPSCATTERDQZmr
    57U,	// VPSCATTERQDZ128mr
    57U,	// VPSCATTERQDZ256mr
    57U,	// VPSCATTERQDZmr
    57U,	// VPSCATTERQQZ128mr
    57U,	// VPSCATTERQQZ256mr
    57U,	// VPSCATTERQQZmr
    4U,	// VPSHABmr
    4U,	// VPSHABrm
    4U,	// VPSHABrr
    4U,	// VPSHABrr_REV
    4U,	// VPSHADmr
    4U,	// VPSHADrm
    4U,	// VPSHADrr
    4U,	// VPSHADrr_REV
    4U,	// VPSHAQmr
    4U,	// VPSHAQrm
    4U,	// VPSHAQrr
    4U,	// VPSHAQrr_REV
    4U,	// VPSHAWmr
    4U,	// VPSHAWrm
    4U,	// VPSHAWrr
    4U,	// VPSHAWrr_REV
    4U,	// VPSHLBmr
    4U,	// VPSHLBrm
    4U,	// VPSHLBrr
    4U,	// VPSHLBrr_REV
    18637U,	// VPSHLDDZ128rmbi
    26833U,	// VPSHLDDZ128rmbik
    26837U,	// VPSHLDDZ128rmbikz
    72U,	// VPSHLDDZ128rmi
    1U,	// VPSHLDDZ128rmik
    9348U,	// VPSHLDDZ128rmikz
    18636U,	// VPSHLDDZ128rri
    25U,	// VPSHLDDZ128rrik
    26837U,	// VPSHLDDZ128rrikz
    18637U,	// VPSHLDDZ256rmbi
    26833U,	// VPSHLDDZ256rmbik
    26837U,	// VPSHLDDZ256rmbikz
    72U,	// VPSHLDDZ256rmi
    1U,	// VPSHLDDZ256rmik
    9348U,	// VPSHLDDZ256rmikz
    18636U,	// VPSHLDDZ256rri
    25U,	// VPSHLDDZ256rrik
    26837U,	// VPSHLDDZ256rrikz
    18637U,	// VPSHLDDZrmbi
    26833U,	// VPSHLDDZrmbik
    26837U,	// VPSHLDDZrmbikz
    72U,	// VPSHLDDZrmi
    1U,	// VPSHLDDZrmik
    9348U,	// VPSHLDDZrmikz
    18636U,	// VPSHLDDZrri
    25U,	// VPSHLDDZrrik
    26837U,	// VPSHLDDZrrikz
    18637U,	// VPSHLDQZ128rmbi
    26833U,	// VPSHLDQZ128rmbik
    26837U,	// VPSHLDQZ128rmbikz
    72U,	// VPSHLDQZ128rmi
    1U,	// VPSHLDQZ128rmik
    9348U,	// VPSHLDQZ128rmikz
    18636U,	// VPSHLDQZ128rri
    25U,	// VPSHLDQZ128rrik
    26837U,	// VPSHLDQZ128rrikz
    18637U,	// VPSHLDQZ256rmbi
    26833U,	// VPSHLDQZ256rmbik
    26837U,	// VPSHLDQZ256rmbikz
    72U,	// VPSHLDQZ256rmi
    1U,	// VPSHLDQZ256rmik
    9348U,	// VPSHLDQZ256rmikz
    18636U,	// VPSHLDQZ256rri
    25U,	// VPSHLDQZ256rrik
    26837U,	// VPSHLDQZ256rrikz
    18637U,	// VPSHLDQZrmbi
    26833U,	// VPSHLDQZrmbik
    26837U,	// VPSHLDQZrmbikz
    72U,	// VPSHLDQZrmi
    1U,	// VPSHLDQZrmik
    9348U,	// VPSHLDQZrmikz
    18636U,	// VPSHLDQZrri
    25U,	// VPSHLDQZrrik
    26837U,	// VPSHLDQZrrikz
    4U,	// VPSHLDVDZ128m
    4U,	// VPSHLDVDZ128mb
    133U,	// VPSHLDVDZ128mbk
    8325U,	// VPSHLDVDZ128mbkz
    132U,	// VPSHLDVDZ128mk
    8324U,	// VPSHLDVDZ128mkz
    4U,	// VPSHLDVDZ128r
    0U,	// VPSHLDVDZ128rk
    0U,	// VPSHLDVDZ128rkz
    4U,	// VPSHLDVDZ256m
    4U,	// VPSHLDVDZ256mb
    133U,	// VPSHLDVDZ256mbk
    8325U,	// VPSHLDVDZ256mbkz
    132U,	// VPSHLDVDZ256mk
    8324U,	// VPSHLDVDZ256mkz
    4U,	// VPSHLDVDZ256r
    0U,	// VPSHLDVDZ256rk
    0U,	// VPSHLDVDZ256rkz
    4U,	// VPSHLDVDZm
    4U,	// VPSHLDVDZmb
    133U,	// VPSHLDVDZmbk
    8325U,	// VPSHLDVDZmbkz
    132U,	// VPSHLDVDZmk
    8324U,	// VPSHLDVDZmkz
    4U,	// VPSHLDVDZr
    0U,	// VPSHLDVDZrk
    0U,	// VPSHLDVDZrkz
    4U,	// VPSHLDVQZ128m
    4U,	// VPSHLDVQZ128mb
    133U,	// VPSHLDVQZ128mbk
    8325U,	// VPSHLDVQZ128mbkz
    132U,	// VPSHLDVQZ128mk
    8324U,	// VPSHLDVQZ128mkz
    4U,	// VPSHLDVQZ128r
    0U,	// VPSHLDVQZ128rk
    0U,	// VPSHLDVQZ128rkz
    4U,	// VPSHLDVQZ256m
    4U,	// VPSHLDVQZ256mb
    133U,	// VPSHLDVQZ256mbk
    8325U,	// VPSHLDVQZ256mbkz
    132U,	// VPSHLDVQZ256mk
    8324U,	// VPSHLDVQZ256mkz
    4U,	// VPSHLDVQZ256r
    0U,	// VPSHLDVQZ256rk
    0U,	// VPSHLDVQZ256rkz
    4U,	// VPSHLDVQZm
    4U,	// VPSHLDVQZmb
    133U,	// VPSHLDVQZmbk
    8325U,	// VPSHLDVQZmbkz
    132U,	// VPSHLDVQZmk
    8324U,	// VPSHLDVQZmkz
    4U,	// VPSHLDVQZr
    0U,	// VPSHLDVQZrk
    0U,	// VPSHLDVQZrkz
    4U,	// VPSHLDVWZ128m
    132U,	// VPSHLDVWZ128mk
    8324U,	// VPSHLDVWZ128mkz
    4U,	// VPSHLDVWZ128r
    0U,	// VPSHLDVWZ128rk
    0U,	// VPSHLDVWZ128rkz
    4U,	// VPSHLDVWZ256m
    132U,	// VPSHLDVWZ256mk
    8324U,	// VPSHLDVWZ256mkz
    4U,	// VPSHLDVWZ256r
    0U,	// VPSHLDVWZ256rk
    0U,	// VPSHLDVWZ256rkz
    4U,	// VPSHLDVWZm
    132U,	// VPSHLDVWZmk
    8324U,	// VPSHLDVWZmkz
    4U,	// VPSHLDVWZr
    0U,	// VPSHLDVWZrk
    0U,	// VPSHLDVWZrkz
    72U,	// VPSHLDWZ128rmi
    1U,	// VPSHLDWZ128rmik
    9348U,	// VPSHLDWZ128rmikz
    18636U,	// VPSHLDWZ128rri
    25U,	// VPSHLDWZ128rrik
    26837U,	// VPSHLDWZ128rrikz
    72U,	// VPSHLDWZ256rmi
    1U,	// VPSHLDWZ256rmik
    9348U,	// VPSHLDWZ256rmikz
    18636U,	// VPSHLDWZ256rri
    25U,	// VPSHLDWZ256rrik
    26837U,	// VPSHLDWZ256rrikz
    72U,	// VPSHLDWZrmi
    1U,	// VPSHLDWZrmik
    9348U,	// VPSHLDWZrmikz
    18636U,	// VPSHLDWZrri
    25U,	// VPSHLDWZrrik
    26837U,	// VPSHLDWZrrikz
    4U,	// VPSHLDmr
    4U,	// VPSHLDrm
    4U,	// VPSHLDrr
    4U,	// VPSHLDrr_REV
    4U,	// VPSHLQmr
    4U,	// VPSHLQrm
    4U,	// VPSHLQrr
    4U,	// VPSHLQrr_REV
    4U,	// VPSHLWmr
    4U,	// VPSHLWrm
    4U,	// VPSHLWrr
    4U,	// VPSHLWrr_REV
    18637U,	// VPSHRDDZ128rmbi
    26833U,	// VPSHRDDZ128rmbik
    26837U,	// VPSHRDDZ128rmbikz
    72U,	// VPSHRDDZ128rmi
    1U,	// VPSHRDDZ128rmik
    9348U,	// VPSHRDDZ128rmikz
    18636U,	// VPSHRDDZ128rri
    25U,	// VPSHRDDZ128rrik
    26837U,	// VPSHRDDZ128rrikz
    18637U,	// VPSHRDDZ256rmbi
    26833U,	// VPSHRDDZ256rmbik
    26837U,	// VPSHRDDZ256rmbikz
    72U,	// VPSHRDDZ256rmi
    1U,	// VPSHRDDZ256rmik
    9348U,	// VPSHRDDZ256rmikz
    18636U,	// VPSHRDDZ256rri
    25U,	// VPSHRDDZ256rrik
    26837U,	// VPSHRDDZ256rrikz
    18637U,	// VPSHRDDZrmbi
    26833U,	// VPSHRDDZrmbik
    26837U,	// VPSHRDDZrmbikz
    72U,	// VPSHRDDZrmi
    1U,	// VPSHRDDZrmik
    9348U,	// VPSHRDDZrmikz
    18636U,	// VPSHRDDZrri
    25U,	// VPSHRDDZrrik
    26837U,	// VPSHRDDZrrikz
    18637U,	// VPSHRDQZ128rmbi
    26833U,	// VPSHRDQZ128rmbik
    26837U,	// VPSHRDQZ128rmbikz
    72U,	// VPSHRDQZ128rmi
    1U,	// VPSHRDQZ128rmik
    9348U,	// VPSHRDQZ128rmikz
    18636U,	// VPSHRDQZ128rri
    25U,	// VPSHRDQZ128rrik
    26837U,	// VPSHRDQZ128rrikz
    18637U,	// VPSHRDQZ256rmbi
    26833U,	// VPSHRDQZ256rmbik
    26837U,	// VPSHRDQZ256rmbikz
    72U,	// VPSHRDQZ256rmi
    1U,	// VPSHRDQZ256rmik
    9348U,	// VPSHRDQZ256rmikz
    18636U,	// VPSHRDQZ256rri
    25U,	// VPSHRDQZ256rrik
    26837U,	// VPSHRDQZ256rrikz
    18637U,	// VPSHRDQZrmbi
    26833U,	// VPSHRDQZrmbik
    26837U,	// VPSHRDQZrmbikz
    72U,	// VPSHRDQZrmi
    1U,	// VPSHRDQZrmik
    9348U,	// VPSHRDQZrmikz
    18636U,	// VPSHRDQZrri
    25U,	// VPSHRDQZrrik
    26837U,	// VPSHRDQZrrikz
    4U,	// VPSHRDVDZ128m
    4U,	// VPSHRDVDZ128mb
    133U,	// VPSHRDVDZ128mbk
    8325U,	// VPSHRDVDZ128mbkz
    132U,	// VPSHRDVDZ128mk
    8324U,	// VPSHRDVDZ128mkz
    4U,	// VPSHRDVDZ128r
    0U,	// VPSHRDVDZ128rk
    0U,	// VPSHRDVDZ128rkz
    4U,	// VPSHRDVDZ256m
    4U,	// VPSHRDVDZ256mb
    133U,	// VPSHRDVDZ256mbk
    8325U,	// VPSHRDVDZ256mbkz
    132U,	// VPSHRDVDZ256mk
    8324U,	// VPSHRDVDZ256mkz
    4U,	// VPSHRDVDZ256r
    0U,	// VPSHRDVDZ256rk
    0U,	// VPSHRDVDZ256rkz
    4U,	// VPSHRDVDZm
    4U,	// VPSHRDVDZmb
    133U,	// VPSHRDVDZmbk
    8325U,	// VPSHRDVDZmbkz
    132U,	// VPSHRDVDZmk
    8324U,	// VPSHRDVDZmkz
    4U,	// VPSHRDVDZr
    0U,	// VPSHRDVDZrk
    0U,	// VPSHRDVDZrkz
    4U,	// VPSHRDVQZ128m
    4U,	// VPSHRDVQZ128mb
    133U,	// VPSHRDVQZ128mbk
    8325U,	// VPSHRDVQZ128mbkz
    132U,	// VPSHRDVQZ128mk
    8324U,	// VPSHRDVQZ128mkz
    4U,	// VPSHRDVQZ128r
    0U,	// VPSHRDVQZ128rk
    0U,	// VPSHRDVQZ128rkz
    4U,	// VPSHRDVQZ256m
    4U,	// VPSHRDVQZ256mb
    133U,	// VPSHRDVQZ256mbk
    8325U,	// VPSHRDVQZ256mbkz
    132U,	// VPSHRDVQZ256mk
    8324U,	// VPSHRDVQZ256mkz
    4U,	// VPSHRDVQZ256r
    0U,	// VPSHRDVQZ256rk
    0U,	// VPSHRDVQZ256rkz
    4U,	// VPSHRDVQZm
    4U,	// VPSHRDVQZmb
    133U,	// VPSHRDVQZmbk
    8325U,	// VPSHRDVQZmbkz
    132U,	// VPSHRDVQZmk
    8324U,	// VPSHRDVQZmkz
    4U,	// VPSHRDVQZr
    0U,	// VPSHRDVQZrk
    0U,	// VPSHRDVQZrkz
    4U,	// VPSHRDVWZ128m
    132U,	// VPSHRDVWZ128mk
    8324U,	// VPSHRDVWZ128mkz
    4U,	// VPSHRDVWZ128r
    0U,	// VPSHRDVWZ128rk
    0U,	// VPSHRDVWZ128rkz
    4U,	// VPSHRDVWZ256m
    132U,	// VPSHRDVWZ256mk
    8324U,	// VPSHRDVWZ256mkz
    4U,	// VPSHRDVWZ256r
    0U,	// VPSHRDVWZ256rk
    0U,	// VPSHRDVWZ256rkz
    4U,	// VPSHRDVWZm
    132U,	// VPSHRDVWZmk
    8324U,	// VPSHRDVWZmkz
    4U,	// VPSHRDVWZr
    0U,	// VPSHRDVWZrk
    0U,	// VPSHRDVWZrkz
    72U,	// VPSHRDWZ128rmi
    1U,	// VPSHRDWZ128rmik
    9348U,	// VPSHRDWZ128rmikz
    18636U,	// VPSHRDWZ128rri
    25U,	// VPSHRDWZ128rrik
    26837U,	// VPSHRDWZ128rrikz
    72U,	// VPSHRDWZ256rmi
    1U,	// VPSHRDWZ256rmik
    9348U,	// VPSHRDWZ256rmikz
    18636U,	// VPSHRDWZ256rri
    25U,	// VPSHRDWZ256rrik
    26837U,	// VPSHRDWZ256rrikz
    72U,	// VPSHRDWZrmi
    1U,	// VPSHRDWZrmik
    9348U,	// VPSHRDWZrmikz
    18636U,	// VPSHRDWZrri
    25U,	// VPSHRDWZrrik
    26837U,	// VPSHRDWZrrikz
    4U,	// VPSHUFBITQMBZ128rm
    1156U,	// VPSHUFBITQMBZ128rmk
    4U,	// VPSHUFBITQMBZ128rr
    1156U,	// VPSHUFBITQMBZ128rrk
    4U,	// VPSHUFBITQMBZ256rm
    1156U,	// VPSHUFBITQMBZ256rmk
    4U,	// VPSHUFBITQMBZ256rr
    1156U,	// VPSHUFBITQMBZ256rrk
    4U,	// VPSHUFBITQMBZrm
    1156U,	// VPSHUFBITQMBZrmk
    4U,	// VPSHUFBITQMBZrr
    1156U,	// VPSHUFBITQMBZrrk
    4U,	// VPSHUFBYrm
    4U,	// VPSHUFBYrr
    4U,	// VPSHUFBZ128rm
    132U,	// VPSHUFBZ128rmk
    9348U,	// VPSHUFBZ128rmkz
    4U,	// VPSHUFBZ128rr
    0U,	// VPSHUFBZ128rrk
    9348U,	// VPSHUFBZ128rrkz
    4U,	// VPSHUFBZ256rm
    132U,	// VPSHUFBZ256rmk
    9348U,	// VPSHUFBZ256rmkz
    4U,	// VPSHUFBZ256rr
    0U,	// VPSHUFBZ256rrk
    9348U,	// VPSHUFBZ256rrkz
    4U,	// VPSHUFBZrm
    132U,	// VPSHUFBZrmk
    9348U,	// VPSHUFBZrmkz
    4U,	// VPSHUFBZrr
    0U,	// VPSHUFBZrrk
    9348U,	// VPSHUFBZrrkz
    4U,	// VPSHUFBrm
    4U,	// VPSHUFBrr
    4U,	// VPSHUFDYmi
    72U,	// VPSHUFDYri
    5U,	// VPSHUFDZ128mbi
    133U,	// VPSHUFDZ128mbik
    9349U,	// VPSHUFDZ128mbikz
    4U,	// VPSHUFDZ128mi
    3356U,	// VPSHUFDZ128mik
    4444U,	// VPSHUFDZ128mikz
    72U,	// VPSHUFDZ128ri
    133U,	// VPSHUFDZ128rik
    9348U,	// VPSHUFDZ128rikz
    5U,	// VPSHUFDZ256mbi
    133U,	// VPSHUFDZ256mbik
    9349U,	// VPSHUFDZ256mbikz
    4U,	// VPSHUFDZ256mi
    3356U,	// VPSHUFDZ256mik
    4444U,	// VPSHUFDZ256mikz
    72U,	// VPSHUFDZ256ri
    133U,	// VPSHUFDZ256rik
    9348U,	// VPSHUFDZ256rikz
    5U,	// VPSHUFDZmbi
    133U,	// VPSHUFDZmbik
    9349U,	// VPSHUFDZmbikz
    4U,	// VPSHUFDZmi
    3356U,	// VPSHUFDZmik
    4444U,	// VPSHUFDZmikz
    72U,	// VPSHUFDZri
    133U,	// VPSHUFDZrik
    9348U,	// VPSHUFDZrikz
    4U,	// VPSHUFDmi
    72U,	// VPSHUFDri
    4U,	// VPSHUFHWYmi
    72U,	// VPSHUFHWYri
    4U,	// VPSHUFHWZ128mi
    3356U,	// VPSHUFHWZ128mik
    4444U,	// VPSHUFHWZ128mikz
    72U,	// VPSHUFHWZ128ri
    133U,	// VPSHUFHWZ128rik
    9348U,	// VPSHUFHWZ128rikz
    4U,	// VPSHUFHWZ256mi
    3356U,	// VPSHUFHWZ256mik
    4444U,	// VPSHUFHWZ256mikz
    72U,	// VPSHUFHWZ256ri
    133U,	// VPSHUFHWZ256rik
    9348U,	// VPSHUFHWZ256rikz
    4U,	// VPSHUFHWZmi
    3356U,	// VPSHUFHWZmik
    4444U,	// VPSHUFHWZmikz
    72U,	// VPSHUFHWZri
    133U,	// VPSHUFHWZrik
    9348U,	// VPSHUFHWZrikz
    4U,	// VPSHUFHWmi
    72U,	// VPSHUFHWri
    4U,	// VPSHUFLWYmi
    72U,	// VPSHUFLWYri
    4U,	// VPSHUFLWZ128mi
    3356U,	// VPSHUFLWZ128mik
    4444U,	// VPSHUFLWZ128mikz
    72U,	// VPSHUFLWZ128ri
    133U,	// VPSHUFLWZ128rik
    9348U,	// VPSHUFLWZ128rikz
    4U,	// VPSHUFLWZ256mi
    3356U,	// VPSHUFLWZ256mik
    4444U,	// VPSHUFLWZ256mikz
    72U,	// VPSHUFLWZ256ri
    133U,	// VPSHUFLWZ256rik
    9348U,	// VPSHUFLWZ256rikz
    4U,	// VPSHUFLWZmi
    3356U,	// VPSHUFLWZmik
    4444U,	// VPSHUFLWZmikz
    72U,	// VPSHUFLWZri
    133U,	// VPSHUFLWZrik
    9348U,	// VPSHUFLWZrikz
    4U,	// VPSHUFLWmi
    72U,	// VPSHUFLWri
    4U,	// VPSIGNBYrm
    4U,	// VPSIGNBYrr
    4U,	// VPSIGNBrm
    4U,	// VPSIGNBrr
    4U,	// VPSIGNDYrm
    4U,	// VPSIGNDYrr
    4U,	// VPSIGNDrm
    4U,	// VPSIGNDrr
    4U,	// VPSIGNWYrm
    4U,	// VPSIGNWYrr
    4U,	// VPSIGNWrm
    4U,	// VPSIGNWrr
    72U,	// VPSLLDQYri
    4U,	// VPSLLDQZ128rm
    72U,	// VPSLLDQZ128rr
    4U,	// VPSLLDQZ256rm
    72U,	// VPSLLDQZ256rr
    4U,	// VPSLLDQZrm
    72U,	// VPSLLDQZrr
    72U,	// VPSLLDQri
    72U,	// VPSLLDYri
    4U,	// VPSLLDYrm
    4U,	// VPSLLDYrr
    5U,	// VPSLLDZ128mbi
    133U,	// VPSLLDZ128mbik
    9349U,	// VPSLLDZ128mbikz
    4U,	// VPSLLDZ128mi
    3356U,	// VPSLLDZ128mik
    4444U,	// VPSLLDZ128mikz
    72U,	// VPSLLDZ128ri
    133U,	// VPSLLDZ128rik
    9348U,	// VPSLLDZ128rikz
    4U,	// VPSLLDZ128rm
    132U,	// VPSLLDZ128rmk
    9348U,	// VPSLLDZ128rmkz
    4U,	// VPSLLDZ128rr
    0U,	// VPSLLDZ128rrk
    9348U,	// VPSLLDZ128rrkz
    5U,	// VPSLLDZ256mbi
    133U,	// VPSLLDZ256mbik
    9349U,	// VPSLLDZ256mbikz
    4U,	// VPSLLDZ256mi
    3356U,	// VPSLLDZ256mik
    4444U,	// VPSLLDZ256mikz
    72U,	// VPSLLDZ256ri
    133U,	// VPSLLDZ256rik
    9348U,	// VPSLLDZ256rikz
    4U,	// VPSLLDZ256rm
    132U,	// VPSLLDZ256rmk
    9348U,	// VPSLLDZ256rmkz
    4U,	// VPSLLDZ256rr
    0U,	// VPSLLDZ256rrk
    9348U,	// VPSLLDZ256rrkz
    5U,	// VPSLLDZmbi
    133U,	// VPSLLDZmbik
    9349U,	// VPSLLDZmbikz
    4U,	// VPSLLDZmi
    3356U,	// VPSLLDZmik
    4444U,	// VPSLLDZmikz
    72U,	// VPSLLDZri
    133U,	// VPSLLDZrik
    9348U,	// VPSLLDZrikz
    4U,	// VPSLLDZrm
    132U,	// VPSLLDZrmk
    9348U,	// VPSLLDZrmkz
    4U,	// VPSLLDZrr
    0U,	// VPSLLDZrrk
    9348U,	// VPSLLDZrrkz
    72U,	// VPSLLDri
    4U,	// VPSLLDrm
    4U,	// VPSLLDrr
    72U,	// VPSLLQYri
    4U,	// VPSLLQYrm
    4U,	// VPSLLQYrr
    5U,	// VPSLLQZ128mbi
    133U,	// VPSLLQZ128mbik
    9349U,	// VPSLLQZ128mbikz
    4U,	// VPSLLQZ128mi
    3356U,	// VPSLLQZ128mik
    4444U,	// VPSLLQZ128mikz
    72U,	// VPSLLQZ128ri
    133U,	// VPSLLQZ128rik
    9348U,	// VPSLLQZ128rikz
    4U,	// VPSLLQZ128rm
    132U,	// VPSLLQZ128rmk
    9348U,	// VPSLLQZ128rmkz
    4U,	// VPSLLQZ128rr
    0U,	// VPSLLQZ128rrk
    9348U,	// VPSLLQZ128rrkz
    5U,	// VPSLLQZ256mbi
    133U,	// VPSLLQZ256mbik
    9349U,	// VPSLLQZ256mbikz
    4U,	// VPSLLQZ256mi
    3356U,	// VPSLLQZ256mik
    4444U,	// VPSLLQZ256mikz
    72U,	// VPSLLQZ256ri
    133U,	// VPSLLQZ256rik
    9348U,	// VPSLLQZ256rikz
    4U,	// VPSLLQZ256rm
    132U,	// VPSLLQZ256rmk
    9348U,	// VPSLLQZ256rmkz
    4U,	// VPSLLQZ256rr
    0U,	// VPSLLQZ256rrk
    9348U,	// VPSLLQZ256rrkz
    5U,	// VPSLLQZmbi
    133U,	// VPSLLQZmbik
    9349U,	// VPSLLQZmbikz
    4U,	// VPSLLQZmi
    3356U,	// VPSLLQZmik
    4444U,	// VPSLLQZmikz
    72U,	// VPSLLQZri
    133U,	// VPSLLQZrik
    9348U,	// VPSLLQZrikz
    4U,	// VPSLLQZrm
    132U,	// VPSLLQZrmk
    9348U,	// VPSLLQZrmkz
    4U,	// VPSLLQZrr
    0U,	// VPSLLQZrrk
    9348U,	// VPSLLQZrrkz
    72U,	// VPSLLQri
    4U,	// VPSLLQrm
    4U,	// VPSLLQrr
    4U,	// VPSLLVDYrm
    4U,	// VPSLLVDYrr
    4U,	// VPSLLVDZ128rm
    72U,	// VPSLLVDZ128rmb
    133U,	// VPSLLVDZ128rmbk
    9348U,	// VPSLLVDZ128rmbkz
    132U,	// VPSLLVDZ128rmk
    9348U,	// VPSLLVDZ128rmkz
    4U,	// VPSLLVDZ128rr
    0U,	// VPSLLVDZ128rrk
    9348U,	// VPSLLVDZ128rrkz
    4U,	// VPSLLVDZ256rm
    72U,	// VPSLLVDZ256rmb
    133U,	// VPSLLVDZ256rmbk
    9348U,	// VPSLLVDZ256rmbkz
    132U,	// VPSLLVDZ256rmk
    9348U,	// VPSLLVDZ256rmkz
    4U,	// VPSLLVDZ256rr
    0U,	// VPSLLVDZ256rrk
    9348U,	// VPSLLVDZ256rrkz
    4U,	// VPSLLVDZrm
    72U,	// VPSLLVDZrmb
    133U,	// VPSLLVDZrmbk
    9348U,	// VPSLLVDZrmbkz
    132U,	// VPSLLVDZrmk
    9348U,	// VPSLLVDZrmkz
    4U,	// VPSLLVDZrr
    0U,	// VPSLLVDZrrk
    9348U,	// VPSLLVDZrrkz
    4U,	// VPSLLVDrm
    4U,	// VPSLLVDrr
    4U,	// VPSLLVQYrm
    4U,	// VPSLLVQYrr
    4U,	// VPSLLVQZ128rm
    72U,	// VPSLLVQZ128rmb
    133U,	// VPSLLVQZ128rmbk
    9348U,	// VPSLLVQZ128rmbkz
    132U,	// VPSLLVQZ128rmk
    9348U,	// VPSLLVQZ128rmkz
    4U,	// VPSLLVQZ128rr
    0U,	// VPSLLVQZ128rrk
    9348U,	// VPSLLVQZ128rrkz
    4U,	// VPSLLVQZ256rm
    72U,	// VPSLLVQZ256rmb
    133U,	// VPSLLVQZ256rmbk
    9348U,	// VPSLLVQZ256rmbkz
    132U,	// VPSLLVQZ256rmk
    9348U,	// VPSLLVQZ256rmkz
    4U,	// VPSLLVQZ256rr
    0U,	// VPSLLVQZ256rrk
    9348U,	// VPSLLVQZ256rrkz
    4U,	// VPSLLVQZrm
    72U,	// VPSLLVQZrmb
    133U,	// VPSLLVQZrmbk
    9348U,	// VPSLLVQZrmbkz
    132U,	// VPSLLVQZrmk
    9348U,	// VPSLLVQZrmkz
    4U,	// VPSLLVQZrr
    0U,	// VPSLLVQZrrk
    9348U,	// VPSLLVQZrrkz
    4U,	// VPSLLVQrm
    4U,	// VPSLLVQrr
    4U,	// VPSLLVWZ128rm
    132U,	// VPSLLVWZ128rmk
    9348U,	// VPSLLVWZ128rmkz
    4U,	// VPSLLVWZ128rr
    0U,	// VPSLLVWZ128rrk
    9348U,	// VPSLLVWZ128rrkz
    4U,	// VPSLLVWZ256rm
    132U,	// VPSLLVWZ256rmk
    9348U,	// VPSLLVWZ256rmkz
    4U,	// VPSLLVWZ256rr
    0U,	// VPSLLVWZ256rrk
    9348U,	// VPSLLVWZ256rrkz
    4U,	// VPSLLVWZrm
    132U,	// VPSLLVWZrmk
    9348U,	// VPSLLVWZrmkz
    4U,	// VPSLLVWZrr
    0U,	// VPSLLVWZrrk
    9348U,	// VPSLLVWZrrkz
    72U,	// VPSLLWYri
    4U,	// VPSLLWYrm
    4U,	// VPSLLWYrr
    4U,	// VPSLLWZ128mi
    3356U,	// VPSLLWZ128mik
    4444U,	// VPSLLWZ128mikz
    72U,	// VPSLLWZ128ri
    133U,	// VPSLLWZ128rik
    9348U,	// VPSLLWZ128rikz
    4U,	// VPSLLWZ128rm
    132U,	// VPSLLWZ128rmk
    9348U,	// VPSLLWZ128rmkz
    4U,	// VPSLLWZ128rr
    0U,	// VPSLLWZ128rrk
    9348U,	// VPSLLWZ128rrkz
    4U,	// VPSLLWZ256mi
    3356U,	// VPSLLWZ256mik
    4444U,	// VPSLLWZ256mikz
    72U,	// VPSLLWZ256ri
    133U,	// VPSLLWZ256rik
    9348U,	// VPSLLWZ256rikz
    4U,	// VPSLLWZ256rm
    132U,	// VPSLLWZ256rmk
    9348U,	// VPSLLWZ256rmkz
    4U,	// VPSLLWZ256rr
    0U,	// VPSLLWZ256rrk
    9348U,	// VPSLLWZ256rrkz
    4U,	// VPSLLWZmi
    3356U,	// VPSLLWZmik
    4444U,	// VPSLLWZmikz
    72U,	// VPSLLWZri
    133U,	// VPSLLWZrik
    9348U,	// VPSLLWZrikz
    4U,	// VPSLLWZrm
    132U,	// VPSLLWZrmk
    9348U,	// VPSLLWZrmkz
    4U,	// VPSLLWZrr
    0U,	// VPSLLWZrrk
    9348U,	// VPSLLWZrrkz
    72U,	// VPSLLWri
    4U,	// VPSLLWrm
    4U,	// VPSLLWrr
    72U,	// VPSRADYri
    4U,	// VPSRADYrm
    4U,	// VPSRADYrr
    5U,	// VPSRADZ128mbi
    133U,	// VPSRADZ128mbik
    9349U,	// VPSRADZ128mbikz
    4U,	// VPSRADZ128mi
    3356U,	// VPSRADZ128mik
    4444U,	// VPSRADZ128mikz
    72U,	// VPSRADZ128ri
    133U,	// VPSRADZ128rik
    9348U,	// VPSRADZ128rikz
    4U,	// VPSRADZ128rm
    132U,	// VPSRADZ128rmk
    9348U,	// VPSRADZ128rmkz
    4U,	// VPSRADZ128rr
    0U,	// VPSRADZ128rrk
    9348U,	// VPSRADZ128rrkz
    5U,	// VPSRADZ256mbi
    133U,	// VPSRADZ256mbik
    9349U,	// VPSRADZ256mbikz
    4U,	// VPSRADZ256mi
    3356U,	// VPSRADZ256mik
    4444U,	// VPSRADZ256mikz
    72U,	// VPSRADZ256ri
    133U,	// VPSRADZ256rik
    9348U,	// VPSRADZ256rikz
    4U,	// VPSRADZ256rm
    132U,	// VPSRADZ256rmk
    9348U,	// VPSRADZ256rmkz
    4U,	// VPSRADZ256rr
    0U,	// VPSRADZ256rrk
    9348U,	// VPSRADZ256rrkz
    5U,	// VPSRADZmbi
    133U,	// VPSRADZmbik
    9349U,	// VPSRADZmbikz
    4U,	// VPSRADZmi
    3356U,	// VPSRADZmik
    4444U,	// VPSRADZmikz
    72U,	// VPSRADZri
    133U,	// VPSRADZrik
    9348U,	// VPSRADZrikz
    4U,	// VPSRADZrm
    132U,	// VPSRADZrmk
    9348U,	// VPSRADZrmkz
    4U,	// VPSRADZrr
    0U,	// VPSRADZrrk
    9348U,	// VPSRADZrrkz
    72U,	// VPSRADri
    4U,	// VPSRADrm
    4U,	// VPSRADrr
    5U,	// VPSRAQZ128mbi
    133U,	// VPSRAQZ128mbik
    9349U,	// VPSRAQZ128mbikz
    4U,	// VPSRAQZ128mi
    3356U,	// VPSRAQZ128mik
    4444U,	// VPSRAQZ128mikz
    72U,	// VPSRAQZ128ri
    133U,	// VPSRAQZ128rik
    9348U,	// VPSRAQZ128rikz
    4U,	// VPSRAQZ128rm
    132U,	// VPSRAQZ128rmk
    9348U,	// VPSRAQZ128rmkz
    4U,	// VPSRAQZ128rr
    0U,	// VPSRAQZ128rrk
    9348U,	// VPSRAQZ128rrkz
    5U,	// VPSRAQZ256mbi
    133U,	// VPSRAQZ256mbik
    9349U,	// VPSRAQZ256mbikz
    4U,	// VPSRAQZ256mi
    3356U,	// VPSRAQZ256mik
    4444U,	// VPSRAQZ256mikz
    72U,	// VPSRAQZ256ri
    133U,	// VPSRAQZ256rik
    9348U,	// VPSRAQZ256rikz
    4U,	// VPSRAQZ256rm
    132U,	// VPSRAQZ256rmk
    9348U,	// VPSRAQZ256rmkz
    4U,	// VPSRAQZ256rr
    0U,	// VPSRAQZ256rrk
    9348U,	// VPSRAQZ256rrkz
    5U,	// VPSRAQZmbi
    133U,	// VPSRAQZmbik
    9349U,	// VPSRAQZmbikz
    4U,	// VPSRAQZmi
    3356U,	// VPSRAQZmik
    4444U,	// VPSRAQZmikz
    72U,	// VPSRAQZri
    133U,	// VPSRAQZrik
    9348U,	// VPSRAQZrikz
    4U,	// VPSRAQZrm
    132U,	// VPSRAQZrmk
    9348U,	// VPSRAQZrmkz
    4U,	// VPSRAQZrr
    0U,	// VPSRAQZrrk
    9348U,	// VPSRAQZrrkz
    4U,	// VPSRAVDYrm
    4U,	// VPSRAVDYrr
    4U,	// VPSRAVDZ128rm
    72U,	// VPSRAVDZ128rmb
    133U,	// VPSRAVDZ128rmbk
    9348U,	// VPSRAVDZ128rmbkz
    132U,	// VPSRAVDZ128rmk
    9348U,	// VPSRAVDZ128rmkz
    4U,	// VPSRAVDZ128rr
    0U,	// VPSRAVDZ128rrk
    9348U,	// VPSRAVDZ128rrkz
    4U,	// VPSRAVDZ256rm
    72U,	// VPSRAVDZ256rmb
    133U,	// VPSRAVDZ256rmbk
    9348U,	// VPSRAVDZ256rmbkz
    132U,	// VPSRAVDZ256rmk
    9348U,	// VPSRAVDZ256rmkz
    4U,	// VPSRAVDZ256rr
    0U,	// VPSRAVDZ256rrk
    9348U,	// VPSRAVDZ256rrkz
    4U,	// VPSRAVDZrm
    72U,	// VPSRAVDZrmb
    133U,	// VPSRAVDZrmbk
    9348U,	// VPSRAVDZrmbkz
    132U,	// VPSRAVDZrmk
    9348U,	// VPSRAVDZrmkz
    4U,	// VPSRAVDZrr
    0U,	// VPSRAVDZrrk
    9348U,	// VPSRAVDZrrkz
    4U,	// VPSRAVDrm
    4U,	// VPSRAVDrr
    4U,	// VPSRAVQZ128rm
    72U,	// VPSRAVQZ128rmb
    133U,	// VPSRAVQZ128rmbk
    9348U,	// VPSRAVQZ128rmbkz
    132U,	// VPSRAVQZ128rmk
    9348U,	// VPSRAVQZ128rmkz
    4U,	// VPSRAVQZ128rr
    0U,	// VPSRAVQZ128rrk
    9348U,	// VPSRAVQZ128rrkz
    4U,	// VPSRAVQZ256rm
    72U,	// VPSRAVQZ256rmb
    133U,	// VPSRAVQZ256rmbk
    9348U,	// VPSRAVQZ256rmbkz
    132U,	// VPSRAVQZ256rmk
    9348U,	// VPSRAVQZ256rmkz
    4U,	// VPSRAVQZ256rr
    0U,	// VPSRAVQZ256rrk
    9348U,	// VPSRAVQZ256rrkz
    4U,	// VPSRAVQZrm
    72U,	// VPSRAVQZrmb
    133U,	// VPSRAVQZrmbk
    9348U,	// VPSRAVQZrmbkz
    132U,	// VPSRAVQZrmk
    9348U,	// VPSRAVQZrmkz
    4U,	// VPSRAVQZrr
    0U,	// VPSRAVQZrrk
    9348U,	// VPSRAVQZrrkz
    4U,	// VPSRAVWZ128rm
    132U,	// VPSRAVWZ128rmk
    9348U,	// VPSRAVWZ128rmkz
    4U,	// VPSRAVWZ128rr
    0U,	// VPSRAVWZ128rrk
    9348U,	// VPSRAVWZ128rrkz
    4U,	// VPSRAVWZ256rm
    132U,	// VPSRAVWZ256rmk
    9348U,	// VPSRAVWZ256rmkz
    4U,	// VPSRAVWZ256rr
    0U,	// VPSRAVWZ256rrk
    9348U,	// VPSRAVWZ256rrkz
    4U,	// VPSRAVWZrm
    132U,	// VPSRAVWZrmk
    9348U,	// VPSRAVWZrmkz
    4U,	// VPSRAVWZrr
    0U,	// VPSRAVWZrrk
    9348U,	// VPSRAVWZrrkz
    72U,	// VPSRAWYri
    4U,	// VPSRAWYrm
    4U,	// VPSRAWYrr
    4U,	// VPSRAWZ128mi
    3356U,	// VPSRAWZ128mik
    4444U,	// VPSRAWZ128mikz
    72U,	// VPSRAWZ128ri
    133U,	// VPSRAWZ128rik
    9348U,	// VPSRAWZ128rikz
    4U,	// VPSRAWZ128rm
    132U,	// VPSRAWZ128rmk
    9348U,	// VPSRAWZ128rmkz
    4U,	// VPSRAWZ128rr
    0U,	// VPSRAWZ128rrk
    9348U,	// VPSRAWZ128rrkz
    4U,	// VPSRAWZ256mi
    3356U,	// VPSRAWZ256mik
    4444U,	// VPSRAWZ256mikz
    72U,	// VPSRAWZ256ri
    133U,	// VPSRAWZ256rik
    9348U,	// VPSRAWZ256rikz
    4U,	// VPSRAWZ256rm
    132U,	// VPSRAWZ256rmk
    9348U,	// VPSRAWZ256rmkz
    4U,	// VPSRAWZ256rr
    0U,	// VPSRAWZ256rrk
    9348U,	// VPSRAWZ256rrkz
    4U,	// VPSRAWZmi
    3356U,	// VPSRAWZmik
    4444U,	// VPSRAWZmikz
    72U,	// VPSRAWZri
    133U,	// VPSRAWZrik
    9348U,	// VPSRAWZrikz
    4U,	// VPSRAWZrm
    132U,	// VPSRAWZrmk
    9348U,	// VPSRAWZrmkz
    4U,	// VPSRAWZrr
    0U,	// VPSRAWZrrk
    9348U,	// VPSRAWZrrkz
    72U,	// VPSRAWri
    4U,	// VPSRAWrm
    4U,	// VPSRAWrr
    72U,	// VPSRLDQYri
    4U,	// VPSRLDQZ128rm
    72U,	// VPSRLDQZ128rr
    4U,	// VPSRLDQZ256rm
    72U,	// VPSRLDQZ256rr
    4U,	// VPSRLDQZrm
    72U,	// VPSRLDQZrr
    72U,	// VPSRLDQri
    72U,	// VPSRLDYri
    4U,	// VPSRLDYrm
    4U,	// VPSRLDYrr
    5U,	// VPSRLDZ128mbi
    133U,	// VPSRLDZ128mbik
    9349U,	// VPSRLDZ128mbikz
    4U,	// VPSRLDZ128mi
    3356U,	// VPSRLDZ128mik
    4444U,	// VPSRLDZ128mikz
    72U,	// VPSRLDZ128ri
    133U,	// VPSRLDZ128rik
    9348U,	// VPSRLDZ128rikz
    4U,	// VPSRLDZ128rm
    132U,	// VPSRLDZ128rmk
    9348U,	// VPSRLDZ128rmkz
    4U,	// VPSRLDZ128rr
    0U,	// VPSRLDZ128rrk
    9348U,	// VPSRLDZ128rrkz
    5U,	// VPSRLDZ256mbi
    133U,	// VPSRLDZ256mbik
    9349U,	// VPSRLDZ256mbikz
    4U,	// VPSRLDZ256mi
    3356U,	// VPSRLDZ256mik
    4444U,	// VPSRLDZ256mikz
    72U,	// VPSRLDZ256ri
    133U,	// VPSRLDZ256rik
    9348U,	// VPSRLDZ256rikz
    4U,	// VPSRLDZ256rm
    132U,	// VPSRLDZ256rmk
    9348U,	// VPSRLDZ256rmkz
    4U,	// VPSRLDZ256rr
    0U,	// VPSRLDZ256rrk
    9348U,	// VPSRLDZ256rrkz
    5U,	// VPSRLDZmbi
    133U,	// VPSRLDZmbik
    9349U,	// VPSRLDZmbikz
    4U,	// VPSRLDZmi
    3356U,	// VPSRLDZmik
    4444U,	// VPSRLDZmikz
    72U,	// VPSRLDZri
    133U,	// VPSRLDZrik
    9348U,	// VPSRLDZrikz
    4U,	// VPSRLDZrm
    132U,	// VPSRLDZrmk
    9348U,	// VPSRLDZrmkz
    4U,	// VPSRLDZrr
    0U,	// VPSRLDZrrk
    9348U,	// VPSRLDZrrkz
    72U,	// VPSRLDri
    4U,	// VPSRLDrm
    4U,	// VPSRLDrr
    72U,	// VPSRLQYri
    4U,	// VPSRLQYrm
    4U,	// VPSRLQYrr
    5U,	// VPSRLQZ128mbi
    133U,	// VPSRLQZ128mbik
    9349U,	// VPSRLQZ128mbikz
    4U,	// VPSRLQZ128mi
    3356U,	// VPSRLQZ128mik
    4444U,	// VPSRLQZ128mikz
    72U,	// VPSRLQZ128ri
    133U,	// VPSRLQZ128rik
    9348U,	// VPSRLQZ128rikz
    4U,	// VPSRLQZ128rm
    132U,	// VPSRLQZ128rmk
    9348U,	// VPSRLQZ128rmkz
    4U,	// VPSRLQZ128rr
    0U,	// VPSRLQZ128rrk
    9348U,	// VPSRLQZ128rrkz
    5U,	// VPSRLQZ256mbi
    133U,	// VPSRLQZ256mbik
    9349U,	// VPSRLQZ256mbikz
    4U,	// VPSRLQZ256mi
    3356U,	// VPSRLQZ256mik
    4444U,	// VPSRLQZ256mikz
    72U,	// VPSRLQZ256ri
    133U,	// VPSRLQZ256rik
    9348U,	// VPSRLQZ256rikz
    4U,	// VPSRLQZ256rm
    132U,	// VPSRLQZ256rmk
    9348U,	// VPSRLQZ256rmkz
    4U,	// VPSRLQZ256rr
    0U,	// VPSRLQZ256rrk
    9348U,	// VPSRLQZ256rrkz
    5U,	// VPSRLQZmbi
    133U,	// VPSRLQZmbik
    9349U,	// VPSRLQZmbikz
    4U,	// VPSRLQZmi
    3356U,	// VPSRLQZmik
    4444U,	// VPSRLQZmikz
    72U,	// VPSRLQZri
    133U,	// VPSRLQZrik
    9348U,	// VPSRLQZrikz
    4U,	// VPSRLQZrm
    132U,	// VPSRLQZrmk
    9348U,	// VPSRLQZrmkz
    4U,	// VPSRLQZrr
    0U,	// VPSRLQZrrk
    9348U,	// VPSRLQZrrkz
    72U,	// VPSRLQri
    4U,	// VPSRLQrm
    4U,	// VPSRLQrr
    4U,	// VPSRLVDYrm
    4U,	// VPSRLVDYrr
    4U,	// VPSRLVDZ128rm
    72U,	// VPSRLVDZ128rmb
    133U,	// VPSRLVDZ128rmbk
    9348U,	// VPSRLVDZ128rmbkz
    132U,	// VPSRLVDZ128rmk
    9348U,	// VPSRLVDZ128rmkz
    4U,	// VPSRLVDZ128rr
    0U,	// VPSRLVDZ128rrk
    9348U,	// VPSRLVDZ128rrkz
    4U,	// VPSRLVDZ256rm
    72U,	// VPSRLVDZ256rmb
    133U,	// VPSRLVDZ256rmbk
    9348U,	// VPSRLVDZ256rmbkz
    132U,	// VPSRLVDZ256rmk
    9348U,	// VPSRLVDZ256rmkz
    4U,	// VPSRLVDZ256rr
    0U,	// VPSRLVDZ256rrk
    9348U,	// VPSRLVDZ256rrkz
    4U,	// VPSRLVDZrm
    72U,	// VPSRLVDZrmb
    133U,	// VPSRLVDZrmbk
    9348U,	// VPSRLVDZrmbkz
    132U,	// VPSRLVDZrmk
    9348U,	// VPSRLVDZrmkz
    4U,	// VPSRLVDZrr
    0U,	// VPSRLVDZrrk
    9348U,	// VPSRLVDZrrkz
    4U,	// VPSRLVDrm
    4U,	// VPSRLVDrr
    4U,	// VPSRLVQYrm
    4U,	// VPSRLVQYrr
    4U,	// VPSRLVQZ128rm
    72U,	// VPSRLVQZ128rmb
    133U,	// VPSRLVQZ128rmbk
    9348U,	// VPSRLVQZ128rmbkz
    132U,	// VPSRLVQZ128rmk
    9348U,	// VPSRLVQZ128rmkz
    4U,	// VPSRLVQZ128rr
    0U,	// VPSRLVQZ128rrk
    9348U,	// VPSRLVQZ128rrkz
    4U,	// VPSRLVQZ256rm
    72U,	// VPSRLVQZ256rmb
    133U,	// VPSRLVQZ256rmbk
    9348U,	// VPSRLVQZ256rmbkz
    132U,	// VPSRLVQZ256rmk
    9348U,	// VPSRLVQZ256rmkz
    4U,	// VPSRLVQZ256rr
    0U,	// VPSRLVQZ256rrk
    9348U,	// VPSRLVQZ256rrkz
    4U,	// VPSRLVQZrm
    72U,	// VPSRLVQZrmb
    133U,	// VPSRLVQZrmbk
    9348U,	// VPSRLVQZrmbkz
    132U,	// VPSRLVQZrmk
    9348U,	// VPSRLVQZrmkz
    4U,	// VPSRLVQZrr
    0U,	// VPSRLVQZrrk
    9348U,	// VPSRLVQZrrkz
    4U,	// VPSRLVQrm
    4U,	// VPSRLVQrr
    4U,	// VPSRLVWZ128rm
    132U,	// VPSRLVWZ128rmk
    9348U,	// VPSRLVWZ128rmkz
    4U,	// VPSRLVWZ128rr
    0U,	// VPSRLVWZ128rrk
    9348U,	// VPSRLVWZ128rrkz
    4U,	// VPSRLVWZ256rm
    132U,	// VPSRLVWZ256rmk
    9348U,	// VPSRLVWZ256rmkz
    4U,	// VPSRLVWZ256rr
    0U,	// VPSRLVWZ256rrk
    9348U,	// VPSRLVWZ256rrkz
    4U,	// VPSRLVWZrm
    132U,	// VPSRLVWZrmk
    9348U,	// VPSRLVWZrmkz
    4U,	// VPSRLVWZrr
    0U,	// VPSRLVWZrrk
    9348U,	// VPSRLVWZrrkz
    72U,	// VPSRLWYri
    4U,	// VPSRLWYrm
    4U,	// VPSRLWYrr
    4U,	// VPSRLWZ128mi
    3356U,	// VPSRLWZ128mik
    4444U,	// VPSRLWZ128mikz
    72U,	// VPSRLWZ128ri
    133U,	// VPSRLWZ128rik
    9348U,	// VPSRLWZ128rikz
    4U,	// VPSRLWZ128rm
    132U,	// VPSRLWZ128rmk
    9348U,	// VPSRLWZ128rmkz
    4U,	// VPSRLWZ128rr
    0U,	// VPSRLWZ128rrk
    9348U,	// VPSRLWZ128rrkz
    4U,	// VPSRLWZ256mi
    3356U,	// VPSRLWZ256mik
    4444U,	// VPSRLWZ256mikz
    72U,	// VPSRLWZ256ri
    133U,	// VPSRLWZ256rik
    9348U,	// VPSRLWZ256rikz
    4U,	// VPSRLWZ256rm
    132U,	// VPSRLWZ256rmk
    9348U,	// VPSRLWZ256rmkz
    4U,	// VPSRLWZ256rr
    0U,	// VPSRLWZ256rrk
    9348U,	// VPSRLWZ256rrkz
    4U,	// VPSRLWZmi
    3356U,	// VPSRLWZmik
    4444U,	// VPSRLWZmikz
    72U,	// VPSRLWZri
    133U,	// VPSRLWZrik
    9348U,	// VPSRLWZrikz
    4U,	// VPSRLWZrm
    132U,	// VPSRLWZrmk
    9348U,	// VPSRLWZrmkz
    4U,	// VPSRLWZrr
    0U,	// VPSRLWZrrk
    9348U,	// VPSRLWZrrkz
    72U,	// VPSRLWri
    4U,	// VPSRLWrm
    4U,	// VPSRLWrr
    4U,	// VPSUBBYrm
    4U,	// VPSUBBYrr
    4U,	// VPSUBBZ128rm
    132U,	// VPSUBBZ128rmk
    9348U,	// VPSUBBZ128rmkz
    4U,	// VPSUBBZ128rr
    0U,	// VPSUBBZ128rrk
    9348U,	// VPSUBBZ128rrkz
    4U,	// VPSUBBZ256rm
    132U,	// VPSUBBZ256rmk
    9348U,	// VPSUBBZ256rmkz
    4U,	// VPSUBBZ256rr
    0U,	// VPSUBBZ256rrk
    9348U,	// VPSUBBZ256rrkz
    4U,	// VPSUBBZrm
    132U,	// VPSUBBZrmk
    9348U,	// VPSUBBZrmkz
    4U,	// VPSUBBZrr
    0U,	// VPSUBBZrrk
    9348U,	// VPSUBBZrrkz
    4U,	// VPSUBBrm
    4U,	// VPSUBBrr
    4U,	// VPSUBDYrm
    4U,	// VPSUBDYrr
    4U,	// VPSUBDZ128rm
    72U,	// VPSUBDZ128rmb
    133U,	// VPSUBDZ128rmbk
    9348U,	// VPSUBDZ128rmbkz
    132U,	// VPSUBDZ128rmk
    9348U,	// VPSUBDZ128rmkz
    4U,	// VPSUBDZ128rr
    0U,	// VPSUBDZ128rrk
    9348U,	// VPSUBDZ128rrkz
    4U,	// VPSUBDZ256rm
    72U,	// VPSUBDZ256rmb
    133U,	// VPSUBDZ256rmbk
    9348U,	// VPSUBDZ256rmbkz
    132U,	// VPSUBDZ256rmk
    9348U,	// VPSUBDZ256rmkz
    4U,	// VPSUBDZ256rr
    0U,	// VPSUBDZ256rrk
    9348U,	// VPSUBDZ256rrkz
    4U,	// VPSUBDZrm
    72U,	// VPSUBDZrmb
    133U,	// VPSUBDZrmbk
    9348U,	// VPSUBDZrmbkz
    132U,	// VPSUBDZrmk
    9348U,	// VPSUBDZrmkz
    4U,	// VPSUBDZrr
    0U,	// VPSUBDZrrk
    9348U,	// VPSUBDZrrkz
    4U,	// VPSUBDrm
    4U,	// VPSUBDrr
    4U,	// VPSUBQYrm
    4U,	// VPSUBQYrr
    4U,	// VPSUBQZ128rm
    72U,	// VPSUBQZ128rmb
    133U,	// VPSUBQZ128rmbk
    9348U,	// VPSUBQZ128rmbkz
    132U,	// VPSUBQZ128rmk
    9348U,	// VPSUBQZ128rmkz
    4U,	// VPSUBQZ128rr
    0U,	// VPSUBQZ128rrk
    9348U,	// VPSUBQZ128rrkz
    4U,	// VPSUBQZ256rm
    72U,	// VPSUBQZ256rmb
    133U,	// VPSUBQZ256rmbk
    9348U,	// VPSUBQZ256rmbkz
    132U,	// VPSUBQZ256rmk
    9348U,	// VPSUBQZ256rmkz
    4U,	// VPSUBQZ256rr
    0U,	// VPSUBQZ256rrk
    9348U,	// VPSUBQZ256rrkz
    4U,	// VPSUBQZrm
    72U,	// VPSUBQZrmb
    133U,	// VPSUBQZrmbk
    9348U,	// VPSUBQZrmbkz
    132U,	// VPSUBQZrmk
    9348U,	// VPSUBQZrmkz
    4U,	// VPSUBQZrr
    0U,	// VPSUBQZrrk
    9348U,	// VPSUBQZrrkz
    4U,	// VPSUBQrm
    4U,	// VPSUBQrr
    4U,	// VPSUBSBYrm
    4U,	// VPSUBSBYrr
    4U,	// VPSUBSBZ128rm
    132U,	// VPSUBSBZ128rmk
    9348U,	// VPSUBSBZ128rmkz
    4U,	// VPSUBSBZ128rr
    0U,	// VPSUBSBZ128rrk
    9348U,	// VPSUBSBZ128rrkz
    4U,	// VPSUBSBZ256rm
    132U,	// VPSUBSBZ256rmk
    9348U,	// VPSUBSBZ256rmkz
    4U,	// VPSUBSBZ256rr
    0U,	// VPSUBSBZ256rrk
    9348U,	// VPSUBSBZ256rrkz
    4U,	// VPSUBSBZrm
    132U,	// VPSUBSBZrmk
    9348U,	// VPSUBSBZrmkz
    4U,	// VPSUBSBZrr
    0U,	// VPSUBSBZrrk
    9348U,	// VPSUBSBZrrkz
    4U,	// VPSUBSBrm
    4U,	// VPSUBSBrr
    4U,	// VPSUBSWYrm
    4U,	// VPSUBSWYrr
    4U,	// VPSUBSWZ128rm
    132U,	// VPSUBSWZ128rmk
    9348U,	// VPSUBSWZ128rmkz
    4U,	// VPSUBSWZ128rr
    0U,	// VPSUBSWZ128rrk
    9348U,	// VPSUBSWZ128rrkz
    4U,	// VPSUBSWZ256rm
    132U,	// VPSUBSWZ256rmk
    9348U,	// VPSUBSWZ256rmkz
    4U,	// VPSUBSWZ256rr
    0U,	// VPSUBSWZ256rrk
    9348U,	// VPSUBSWZ256rrkz
    4U,	// VPSUBSWZrm
    132U,	// VPSUBSWZrmk
    9348U,	// VPSUBSWZrmkz
    4U,	// VPSUBSWZrr
    0U,	// VPSUBSWZrrk
    9348U,	// VPSUBSWZrrkz
    4U,	// VPSUBSWrm
    4U,	// VPSUBSWrr
    4U,	// VPSUBUSBYrm
    4U,	// VPSUBUSBYrr
    4U,	// VPSUBUSBZ128rm
    132U,	// VPSUBUSBZ128rmk
    9348U,	// VPSUBUSBZ128rmkz
    4U,	// VPSUBUSBZ128rr
    0U,	// VPSUBUSBZ128rrk
    9348U,	// VPSUBUSBZ128rrkz
    4U,	// VPSUBUSBZ256rm
    132U,	// VPSUBUSBZ256rmk
    9348U,	// VPSUBUSBZ256rmkz
    4U,	// VPSUBUSBZ256rr
    0U,	// VPSUBUSBZ256rrk
    9348U,	// VPSUBUSBZ256rrkz
    4U,	// VPSUBUSBZrm
    132U,	// VPSUBUSBZrmk
    9348U,	// VPSUBUSBZrmkz
    4U,	// VPSUBUSBZrr
    0U,	// VPSUBUSBZrrk
    9348U,	// VPSUBUSBZrrkz
    4U,	// VPSUBUSBrm
    4U,	// VPSUBUSBrr
    4U,	// VPSUBUSWYrm
    4U,	// VPSUBUSWYrr
    4U,	// VPSUBUSWZ128rm
    132U,	// VPSUBUSWZ128rmk
    9348U,	// VPSUBUSWZ128rmkz
    4U,	// VPSUBUSWZ128rr
    0U,	// VPSUBUSWZ128rrk
    9348U,	// VPSUBUSWZ128rrkz
    4U,	// VPSUBUSWZ256rm
    132U,	// VPSUBUSWZ256rmk
    9348U,	// VPSUBUSWZ256rmkz
    4U,	// VPSUBUSWZ256rr
    0U,	// VPSUBUSWZ256rrk
    9348U,	// VPSUBUSWZ256rrkz
    4U,	// VPSUBUSWZrm
    132U,	// VPSUBUSWZrmk
    9348U,	// VPSUBUSWZrmkz
    4U,	// VPSUBUSWZrr
    0U,	// VPSUBUSWZrrk
    9348U,	// VPSUBUSWZrrkz
    4U,	// VPSUBUSWrm
    4U,	// VPSUBUSWrr
    4U,	// VPSUBWYrm
    4U,	// VPSUBWYrr
    4U,	// VPSUBWZ128rm
    132U,	// VPSUBWZ128rmk
    9348U,	// VPSUBWZ128rmkz
    4U,	// VPSUBWZ128rr
    0U,	// VPSUBWZ128rrk
    9348U,	// VPSUBWZ128rrkz
    4U,	// VPSUBWZ256rm
    132U,	// VPSUBWZ256rmk
    9348U,	// VPSUBWZ256rmkz
    4U,	// VPSUBWZ256rr
    0U,	// VPSUBWZ256rrk
    9348U,	// VPSUBWZ256rrkz
    4U,	// VPSUBWZrm
    132U,	// VPSUBWZrmk
    9348U,	// VPSUBWZrmkz
    4U,	// VPSUBWZrr
    0U,	// VPSUBWZrrk
    9348U,	// VPSUBWZrrkz
    4U,	// VPSUBWrm
    4U,	// VPSUBWrr
    18645U,	// VPTERNLOGDZ128rmbi
    26833U,	// VPTERNLOGDZ128rmbik
    26833U,	// VPTERNLOGDZ128rmbikz
    4U,	// VPTERNLOGDZ128rmi
    1U,	// VPTERNLOGDZ128rmik
    2U,	// VPTERNLOGDZ128rmikz
    18645U,	// VPTERNLOGDZ128rri
    25U,	// VPTERNLOGDZ128rrik
    53U,	// VPTERNLOGDZ128rrikz
    18645U,	// VPTERNLOGDZ256rmbi
    26833U,	// VPTERNLOGDZ256rmbik
    26833U,	// VPTERNLOGDZ256rmbikz
    4U,	// VPTERNLOGDZ256rmi
    1U,	// VPTERNLOGDZ256rmik
    2U,	// VPTERNLOGDZ256rmikz
    18645U,	// VPTERNLOGDZ256rri
    25U,	// VPTERNLOGDZ256rrik
    53U,	// VPTERNLOGDZ256rrikz
    18645U,	// VPTERNLOGDZrmbi
    26833U,	// VPTERNLOGDZrmbik
    26833U,	// VPTERNLOGDZrmbikz
    4U,	// VPTERNLOGDZrmi
    1U,	// VPTERNLOGDZrmik
    2U,	// VPTERNLOGDZrmikz
    18645U,	// VPTERNLOGDZrri
    25U,	// VPTERNLOGDZrrik
    53U,	// VPTERNLOGDZrrikz
    18645U,	// VPTERNLOGQZ128rmbi
    26833U,	// VPTERNLOGQZ128rmbik
    26833U,	// VPTERNLOGQZ128rmbikz
    4U,	// VPTERNLOGQZ128rmi
    1U,	// VPTERNLOGQZ128rmik
    2U,	// VPTERNLOGQZ128rmikz
    18645U,	// VPTERNLOGQZ128rri
    25U,	// VPTERNLOGQZ128rrik
    53U,	// VPTERNLOGQZ128rrikz
    18645U,	// VPTERNLOGQZ256rmbi
    26833U,	// VPTERNLOGQZ256rmbik
    26833U,	// VPTERNLOGQZ256rmbikz
    4U,	// VPTERNLOGQZ256rmi
    1U,	// VPTERNLOGQZ256rmik
    2U,	// VPTERNLOGQZ256rmikz
    18645U,	// VPTERNLOGQZ256rri
    25U,	// VPTERNLOGQZ256rrik
    53U,	// VPTERNLOGQZ256rrikz
    18645U,	// VPTERNLOGQZrmbi
    26833U,	// VPTERNLOGQZrmbik
    26833U,	// VPTERNLOGQZrmbikz
    4U,	// VPTERNLOGQZrmi
    1U,	// VPTERNLOGQZrmik
    2U,	// VPTERNLOGQZrmikz
    18645U,	// VPTERNLOGQZrri
    25U,	// VPTERNLOGQZrrik
    53U,	// VPTERNLOGQZrrikz
    4U,	// VPTESTMBZ128rm
    1156U,	// VPTESTMBZ128rmk
    4U,	// VPTESTMBZ128rr
    1156U,	// VPTESTMBZ128rrk
    4U,	// VPTESTMBZ256rm
    1156U,	// VPTESTMBZ256rmk
    4U,	// VPTESTMBZ256rr
    1156U,	// VPTESTMBZ256rrk
    4U,	// VPTESTMBZrm
    1156U,	// VPTESTMBZrmk
    4U,	// VPTESTMBZrr
    1156U,	// VPTESTMBZrrk
    4U,	// VPTESTMDZ128rm
    72U,	// VPTESTMDZ128rmb
    1156U,	// VPTESTMDZ128rmbk
    1156U,	// VPTESTMDZ128rmk
    4U,	// VPTESTMDZ128rr
    1156U,	// VPTESTMDZ128rrk
    4U,	// VPTESTMDZ256rm
    72U,	// VPTESTMDZ256rmb
    1156U,	// VPTESTMDZ256rmbk
    1156U,	// VPTESTMDZ256rmk
    4U,	// VPTESTMDZ256rr
    1156U,	// VPTESTMDZ256rrk
    4U,	// VPTESTMDZrm
    72U,	// VPTESTMDZrmb
    1156U,	// VPTESTMDZrmbk
    1156U,	// VPTESTMDZrmk
    4U,	// VPTESTMDZrr
    1156U,	// VPTESTMDZrrk
    4U,	// VPTESTMQZ128rm
    72U,	// VPTESTMQZ128rmb
    1156U,	// VPTESTMQZ128rmbk
    1156U,	// VPTESTMQZ128rmk
    4U,	// VPTESTMQZ128rr
    1156U,	// VPTESTMQZ128rrk
    4U,	// VPTESTMQZ256rm
    72U,	// VPTESTMQZ256rmb
    1156U,	// VPTESTMQZ256rmbk
    1156U,	// VPTESTMQZ256rmk
    4U,	// VPTESTMQZ256rr
    1156U,	// VPTESTMQZ256rrk
    4U,	// VPTESTMQZrm
    72U,	// VPTESTMQZrmb
    1156U,	// VPTESTMQZrmbk
    1156U,	// VPTESTMQZrmk
    4U,	// VPTESTMQZrr
    1156U,	// VPTESTMQZrrk
    4U,	// VPTESTMWZ128rm
    1156U,	// VPTESTMWZ128rmk
    4U,	// VPTESTMWZ128rr
    1156U,	// VPTESTMWZ128rrk
    4U,	// VPTESTMWZ256rm
    1156U,	// VPTESTMWZ256rmk
    4U,	// VPTESTMWZ256rr
    1156U,	// VPTESTMWZ256rrk
    4U,	// VPTESTMWZrm
    1156U,	// VPTESTMWZrmk
    4U,	// VPTESTMWZrr
    1156U,	// VPTESTMWZrrk
    4U,	// VPTESTNMBZ128rm
    1156U,	// VPTESTNMBZ128rmk
    4U,	// VPTESTNMBZ128rr
    1156U,	// VPTESTNMBZ128rrk
    4U,	// VPTESTNMBZ256rm
    1156U,	// VPTESTNMBZ256rmk
    4U,	// VPTESTNMBZ256rr
    1156U,	// VPTESTNMBZ256rrk
    4U,	// VPTESTNMBZrm
    1156U,	// VPTESTNMBZrmk
    4U,	// VPTESTNMBZrr
    1156U,	// VPTESTNMBZrrk
    4U,	// VPTESTNMDZ128rm
    72U,	// VPTESTNMDZ128rmb
    1156U,	// VPTESTNMDZ128rmbk
    1156U,	// VPTESTNMDZ128rmk
    4U,	// VPTESTNMDZ128rr
    1156U,	// VPTESTNMDZ128rrk
    4U,	// VPTESTNMDZ256rm
    72U,	// VPTESTNMDZ256rmb
    1156U,	// VPTESTNMDZ256rmbk
    1156U,	// VPTESTNMDZ256rmk
    4U,	// VPTESTNMDZ256rr
    1156U,	// VPTESTNMDZ256rrk
    4U,	// VPTESTNMDZrm
    72U,	// VPTESTNMDZrmb
    1156U,	// VPTESTNMDZrmbk
    1156U,	// VPTESTNMDZrmk
    4U,	// VPTESTNMDZrr
    1156U,	// VPTESTNMDZrrk
    4U,	// VPTESTNMQZ128rm
    72U,	// VPTESTNMQZ128rmb
    1156U,	// VPTESTNMQZ128rmbk
    1156U,	// VPTESTNMQZ128rmk
    4U,	// VPTESTNMQZ128rr
    1156U,	// VPTESTNMQZ128rrk
    4U,	// VPTESTNMQZ256rm
    72U,	// VPTESTNMQZ256rmb
    1156U,	// VPTESTNMQZ256rmbk
    1156U,	// VPTESTNMQZ256rmk
    4U,	// VPTESTNMQZ256rr
    1156U,	// VPTESTNMQZ256rrk
    4U,	// VPTESTNMQZrm
    72U,	// VPTESTNMQZrmb
    1156U,	// VPTESTNMQZrmbk
    1156U,	// VPTESTNMQZrmk
    4U,	// VPTESTNMQZrr
    1156U,	// VPTESTNMQZrrk
    4U,	// VPTESTNMWZ128rm
    1156U,	// VPTESTNMWZ128rmk
    4U,	// VPTESTNMWZ128rr
    1156U,	// VPTESTNMWZ128rrk
    4U,	// VPTESTNMWZ256rm
    1156U,	// VPTESTNMWZ256rmk
    4U,	// VPTESTNMWZ256rr
    1156U,	// VPTESTNMWZ256rrk
    4U,	// VPTESTNMWZrm
    1156U,	// VPTESTNMWZrmk
    4U,	// VPTESTNMWZrr
    1156U,	// VPTESTNMWZrrk
    0U,	// VPTESTYrm
    0U,	// VPTESTYrr
    0U,	// VPTESTrm
    0U,	// VPTESTrr
    4U,	// VPUNPCKHBWYrm
    4U,	// VPUNPCKHBWYrr
    4U,	// VPUNPCKHBWZ128rm
    132U,	// VPUNPCKHBWZ128rmk
    9348U,	// VPUNPCKHBWZ128rmkz
    4U,	// VPUNPCKHBWZ128rr
    0U,	// VPUNPCKHBWZ128rrk
    9348U,	// VPUNPCKHBWZ128rrkz
    4U,	// VPUNPCKHBWZ256rm
    132U,	// VPUNPCKHBWZ256rmk
    9348U,	// VPUNPCKHBWZ256rmkz
    4U,	// VPUNPCKHBWZ256rr
    0U,	// VPUNPCKHBWZ256rrk
    9348U,	// VPUNPCKHBWZ256rrkz
    4U,	// VPUNPCKHBWZrm
    132U,	// VPUNPCKHBWZrmk
    9348U,	// VPUNPCKHBWZrmkz
    4U,	// VPUNPCKHBWZrr
    0U,	// VPUNPCKHBWZrrk
    9348U,	// VPUNPCKHBWZrrkz
    4U,	// VPUNPCKHBWrm
    4U,	// VPUNPCKHBWrr
    4U,	// VPUNPCKHDQYrm
    4U,	// VPUNPCKHDQYrr
    4U,	// VPUNPCKHDQZ128rm
    72U,	// VPUNPCKHDQZ128rmb
    133U,	// VPUNPCKHDQZ128rmbk
    9348U,	// VPUNPCKHDQZ128rmbkz
    132U,	// VPUNPCKHDQZ128rmk
    9348U,	// VPUNPCKHDQZ128rmkz
    4U,	// VPUNPCKHDQZ128rr
    0U,	// VPUNPCKHDQZ128rrk
    9348U,	// VPUNPCKHDQZ128rrkz
    4U,	// VPUNPCKHDQZ256rm
    72U,	// VPUNPCKHDQZ256rmb
    133U,	// VPUNPCKHDQZ256rmbk
    9348U,	// VPUNPCKHDQZ256rmbkz
    132U,	// VPUNPCKHDQZ256rmk
    9348U,	// VPUNPCKHDQZ256rmkz
    4U,	// VPUNPCKHDQZ256rr
    0U,	// VPUNPCKHDQZ256rrk
    9348U,	// VPUNPCKHDQZ256rrkz
    4U,	// VPUNPCKHDQZrm
    72U,	// VPUNPCKHDQZrmb
    133U,	// VPUNPCKHDQZrmbk
    9348U,	// VPUNPCKHDQZrmbkz
    132U,	// VPUNPCKHDQZrmk
    9348U,	// VPUNPCKHDQZrmkz
    4U,	// VPUNPCKHDQZrr
    0U,	// VPUNPCKHDQZrrk
    9348U,	// VPUNPCKHDQZrrkz
    4U,	// VPUNPCKHDQrm
    4U,	// VPUNPCKHDQrr
    4U,	// VPUNPCKHQDQYrm
    4U,	// VPUNPCKHQDQYrr
    4U,	// VPUNPCKHQDQZ128rm
    72U,	// VPUNPCKHQDQZ128rmb
    133U,	// VPUNPCKHQDQZ128rmbk
    9348U,	// VPUNPCKHQDQZ128rmbkz
    132U,	// VPUNPCKHQDQZ128rmk
    9348U,	// VPUNPCKHQDQZ128rmkz
    4U,	// VPUNPCKHQDQZ128rr
    0U,	// VPUNPCKHQDQZ128rrk
    9348U,	// VPUNPCKHQDQZ128rrkz
    4U,	// VPUNPCKHQDQZ256rm
    72U,	// VPUNPCKHQDQZ256rmb
    133U,	// VPUNPCKHQDQZ256rmbk
    9348U,	// VPUNPCKHQDQZ256rmbkz
    132U,	// VPUNPCKHQDQZ256rmk
    9348U,	// VPUNPCKHQDQZ256rmkz
    4U,	// VPUNPCKHQDQZ256rr
    0U,	// VPUNPCKHQDQZ256rrk
    9348U,	// VPUNPCKHQDQZ256rrkz
    4U,	// VPUNPCKHQDQZrm
    72U,	// VPUNPCKHQDQZrmb
    133U,	// VPUNPCKHQDQZrmbk
    9348U,	// VPUNPCKHQDQZrmbkz
    132U,	// VPUNPCKHQDQZrmk
    9348U,	// VPUNPCKHQDQZrmkz
    4U,	// VPUNPCKHQDQZrr
    0U,	// VPUNPCKHQDQZrrk
    9348U,	// VPUNPCKHQDQZrrkz
    4U,	// VPUNPCKHQDQrm
    4U,	// VPUNPCKHQDQrr
    4U,	// VPUNPCKHWDYrm
    4U,	// VPUNPCKHWDYrr
    4U,	// VPUNPCKHWDZ128rm
    132U,	// VPUNPCKHWDZ128rmk
    9348U,	// VPUNPCKHWDZ128rmkz
    4U,	// VPUNPCKHWDZ128rr
    0U,	// VPUNPCKHWDZ128rrk
    9348U,	// VPUNPCKHWDZ128rrkz
    4U,	// VPUNPCKHWDZ256rm
    132U,	// VPUNPCKHWDZ256rmk
    9348U,	// VPUNPCKHWDZ256rmkz
    4U,	// VPUNPCKHWDZ256rr
    0U,	// VPUNPCKHWDZ256rrk
    9348U,	// VPUNPCKHWDZ256rrkz
    4U,	// VPUNPCKHWDZrm
    132U,	// VPUNPCKHWDZrmk
    9348U,	// VPUNPCKHWDZrmkz
    4U,	// VPUNPCKHWDZrr
    0U,	// VPUNPCKHWDZrrk
    9348U,	// VPUNPCKHWDZrrkz
    4U,	// VPUNPCKHWDrm
    4U,	// VPUNPCKHWDrr
    4U,	// VPUNPCKLBWYrm
    4U,	// VPUNPCKLBWYrr
    4U,	// VPUNPCKLBWZ128rm
    132U,	// VPUNPCKLBWZ128rmk
    9348U,	// VPUNPCKLBWZ128rmkz
    4U,	// VPUNPCKLBWZ128rr
    0U,	// VPUNPCKLBWZ128rrk
    9348U,	// VPUNPCKLBWZ128rrkz
    4U,	// VPUNPCKLBWZ256rm
    132U,	// VPUNPCKLBWZ256rmk
    9348U,	// VPUNPCKLBWZ256rmkz
    4U,	// VPUNPCKLBWZ256rr
    0U,	// VPUNPCKLBWZ256rrk
    9348U,	// VPUNPCKLBWZ256rrkz
    4U,	// VPUNPCKLBWZrm
    132U,	// VPUNPCKLBWZrmk
    9348U,	// VPUNPCKLBWZrmkz
    4U,	// VPUNPCKLBWZrr
    0U,	// VPUNPCKLBWZrrk
    9348U,	// VPUNPCKLBWZrrkz
    4U,	// VPUNPCKLBWrm
    4U,	// VPUNPCKLBWrr
    4U,	// VPUNPCKLDQYrm
    4U,	// VPUNPCKLDQYrr
    4U,	// VPUNPCKLDQZ128rm
    72U,	// VPUNPCKLDQZ128rmb
    133U,	// VPUNPCKLDQZ128rmbk
    9348U,	// VPUNPCKLDQZ128rmbkz
    132U,	// VPUNPCKLDQZ128rmk
    9348U,	// VPUNPCKLDQZ128rmkz
    4U,	// VPUNPCKLDQZ128rr
    0U,	// VPUNPCKLDQZ128rrk
    9348U,	// VPUNPCKLDQZ128rrkz
    4U,	// VPUNPCKLDQZ256rm
    72U,	// VPUNPCKLDQZ256rmb
    133U,	// VPUNPCKLDQZ256rmbk
    9348U,	// VPUNPCKLDQZ256rmbkz
    132U,	// VPUNPCKLDQZ256rmk
    9348U,	// VPUNPCKLDQZ256rmkz
    4U,	// VPUNPCKLDQZ256rr
    0U,	// VPUNPCKLDQZ256rrk
    9348U,	// VPUNPCKLDQZ256rrkz
    4U,	// VPUNPCKLDQZrm
    72U,	// VPUNPCKLDQZrmb
    133U,	// VPUNPCKLDQZrmbk
    9348U,	// VPUNPCKLDQZrmbkz
    132U,	// VPUNPCKLDQZrmk
    9348U,	// VPUNPCKLDQZrmkz
    4U,	// VPUNPCKLDQZrr
    0U,	// VPUNPCKLDQZrrk
    9348U,	// VPUNPCKLDQZrrkz
    4U,	// VPUNPCKLDQrm
    4U,	// VPUNPCKLDQrr
    4U,	// VPUNPCKLQDQYrm
    4U,	// VPUNPCKLQDQYrr
    4U,	// VPUNPCKLQDQZ128rm
    72U,	// VPUNPCKLQDQZ128rmb
    133U,	// VPUNPCKLQDQZ128rmbk
    9348U,	// VPUNPCKLQDQZ128rmbkz
    132U,	// VPUNPCKLQDQZ128rmk
    9348U,	// VPUNPCKLQDQZ128rmkz
    4U,	// VPUNPCKLQDQZ128rr
    0U,	// VPUNPCKLQDQZ128rrk
    9348U,	// VPUNPCKLQDQZ128rrkz
    4U,	// VPUNPCKLQDQZ256rm
    72U,	// VPUNPCKLQDQZ256rmb
    133U,	// VPUNPCKLQDQZ256rmbk
    9348U,	// VPUNPCKLQDQZ256rmbkz
    132U,	// VPUNPCKLQDQZ256rmk
    9348U,	// VPUNPCKLQDQZ256rmkz
    4U,	// VPUNPCKLQDQZ256rr
    0U,	// VPUNPCKLQDQZ256rrk
    9348U,	// VPUNPCKLQDQZ256rrkz
    4U,	// VPUNPCKLQDQZrm
    72U,	// VPUNPCKLQDQZrmb
    133U,	// VPUNPCKLQDQZrmbk
    9348U,	// VPUNPCKLQDQZrmbkz
    132U,	// VPUNPCKLQDQZrmk
    9348U,	// VPUNPCKLQDQZrmkz
    4U,	// VPUNPCKLQDQZrr
    0U,	// VPUNPCKLQDQZrrk
    9348U,	// VPUNPCKLQDQZrrkz
    4U,	// VPUNPCKLQDQrm
    4U,	// VPUNPCKLQDQrr
    4U,	// VPUNPCKLWDYrm
    4U,	// VPUNPCKLWDYrr
    4U,	// VPUNPCKLWDZ128rm
    132U,	// VPUNPCKLWDZ128rmk
    9348U,	// VPUNPCKLWDZ128rmkz
    4U,	// VPUNPCKLWDZ128rr
    0U,	// VPUNPCKLWDZ128rrk
    9348U,	// VPUNPCKLWDZ128rrkz
    4U,	// VPUNPCKLWDZ256rm
    132U,	// VPUNPCKLWDZ256rmk
    9348U,	// VPUNPCKLWDZ256rmkz
    4U,	// VPUNPCKLWDZ256rr
    0U,	// VPUNPCKLWDZ256rrk
    9348U,	// VPUNPCKLWDZ256rrkz
    4U,	// VPUNPCKLWDZrm
    132U,	// VPUNPCKLWDZrmk
    9348U,	// VPUNPCKLWDZrmkz
    4U,	// VPUNPCKLWDZrr
    0U,	// VPUNPCKLWDZrrk
    9348U,	// VPUNPCKLWDZrrkz
    4U,	// VPUNPCKLWDrm
    4U,	// VPUNPCKLWDrr
    4U,	// VPXORDZ128rm
    72U,	// VPXORDZ128rmb
    133U,	// VPXORDZ128rmbk
    9348U,	// VPXORDZ128rmbkz
    132U,	// VPXORDZ128rmk
    9348U,	// VPXORDZ128rmkz
    4U,	// VPXORDZ128rr
    0U,	// VPXORDZ128rrk
    9348U,	// VPXORDZ128rrkz
    4U,	// VPXORDZ256rm
    72U,	// VPXORDZ256rmb
    133U,	// VPXORDZ256rmbk
    9348U,	// VPXORDZ256rmbkz
    132U,	// VPXORDZ256rmk
    9348U,	// VPXORDZ256rmkz
    4U,	// VPXORDZ256rr
    0U,	// VPXORDZ256rrk
    9348U,	// VPXORDZ256rrkz
    4U,	// VPXORDZrm
    72U,	// VPXORDZrmb
    133U,	// VPXORDZrmbk
    9348U,	// VPXORDZrmbkz
    132U,	// VPXORDZrmk
    9348U,	// VPXORDZrmkz
    4U,	// VPXORDZrr
    0U,	// VPXORDZrrk
    9348U,	// VPXORDZrrkz
    4U,	// VPXORQZ128rm
    72U,	// VPXORQZ128rmb
    133U,	// VPXORQZ128rmbk
    9348U,	// VPXORQZ128rmbkz
    132U,	// VPXORQZ128rmk
    9348U,	// VPXORQZ128rmkz
    4U,	// VPXORQZ128rr
    0U,	// VPXORQZ128rrk
    9348U,	// VPXORQZ128rrkz
    4U,	// VPXORQZ256rm
    72U,	// VPXORQZ256rmb
    133U,	// VPXORQZ256rmbk
    9348U,	// VPXORQZ256rmbkz
    132U,	// VPXORQZ256rmk
    9348U,	// VPXORQZ256rmkz
    4U,	// VPXORQZ256rr
    0U,	// VPXORQZ256rrk
    9348U,	// VPXORQZ256rrkz
    4U,	// VPXORQZrm
    72U,	// VPXORQZrmb
    133U,	// VPXORQZrmbk
    9348U,	// VPXORQZrmbkz
    132U,	// VPXORQZrmk
    9348U,	// VPXORQZrmkz
    4U,	// VPXORQZrr
    0U,	// VPXORQZrrk
    9348U,	// VPXORQZrrkz
    4U,	// VPXORYrm
    4U,	// VPXORYrr
    4U,	// VPXORrm
    4U,	// VPXORrr
    18637U,	// VRANGEPDZ128rmbi
    26833U,	// VRANGEPDZ128rmbik
    26837U,	// VRANGEPDZ128rmbikz
    72U,	// VRANGEPDZ128rmi
    1U,	// VRANGEPDZ128rmik
    9348U,	// VRANGEPDZ128rmikz
    18636U,	// VRANGEPDZ128rri
    25U,	// VRANGEPDZ128rrik
    26837U,	// VRANGEPDZ128rrikz
    18637U,	// VRANGEPDZ256rmbi
    26833U,	// VRANGEPDZ256rmbik
    26837U,	// VRANGEPDZ256rmbikz
    72U,	// VRANGEPDZ256rmi
    1U,	// VRANGEPDZ256rmik
    9348U,	// VRANGEPDZ256rmikz
    18636U,	// VRANGEPDZ256rri
    25U,	// VRANGEPDZ256rrik
    26837U,	// VRANGEPDZ256rrikz
    18637U,	// VRANGEPDZrmbi
    26833U,	// VRANGEPDZrmbik
    26837U,	// VRANGEPDZrmbikz
    72U,	// VRANGEPDZrmi
    1U,	// VRANGEPDZrmik
    9348U,	// VRANGEPDZrmikz
    18636U,	// VRANGEPDZrri
    18636U,	// VRANGEPDZrrib
    25U,	// VRANGEPDZrribk
    26837U,	// VRANGEPDZrribkz
    25U,	// VRANGEPDZrrik
    26837U,	// VRANGEPDZrrikz
    18637U,	// VRANGEPSZ128rmbi
    26833U,	// VRANGEPSZ128rmbik
    26837U,	// VRANGEPSZ128rmbikz
    72U,	// VRANGEPSZ128rmi
    1U,	// VRANGEPSZ128rmik
    9348U,	// VRANGEPSZ128rmikz
    18636U,	// VRANGEPSZ128rri
    25U,	// VRANGEPSZ128rrik
    26837U,	// VRANGEPSZ128rrikz
    18637U,	// VRANGEPSZ256rmbi
    26833U,	// VRANGEPSZ256rmbik
    26837U,	// VRANGEPSZ256rmbikz
    72U,	// VRANGEPSZ256rmi
    1U,	// VRANGEPSZ256rmik
    9348U,	// VRANGEPSZ256rmikz
    18636U,	// VRANGEPSZ256rri
    25U,	// VRANGEPSZ256rrik
    26837U,	// VRANGEPSZ256rrikz
    18637U,	// VRANGEPSZrmbi
    26833U,	// VRANGEPSZrmbik
    26837U,	// VRANGEPSZrmbikz
    72U,	// VRANGEPSZrmi
    1U,	// VRANGEPSZrmik
    9348U,	// VRANGEPSZrmikz
    18636U,	// VRANGEPSZrri
    18636U,	// VRANGEPSZrrib
    25U,	// VRANGEPSZrribk
    26837U,	// VRANGEPSZrribkz
    25U,	// VRANGEPSZrrik
    26837U,	// VRANGEPSZrrikz
    18636U,	// VRANGESDZrmi
    26832U,	// VRANGESDZrmik
    26836U,	// VRANGESDZrmikz
    18636U,	// VRANGESDZrri
    18636U,	// VRANGESDZrrib
    25U,	// VRANGESDZrribk
    26837U,	// VRANGESDZrribkz
    25U,	// VRANGESDZrrik
    26837U,	// VRANGESDZrrikz
    18636U,	// VRANGESSZrmi
    26832U,	// VRANGESSZrmik
    26836U,	// VRANGESSZrmikz
    18636U,	// VRANGESSZrri
    18636U,	// VRANGESSZrrib
    25U,	// VRANGESSZrribk
    26837U,	// VRANGESSZrribkz
    25U,	// VRANGESSZrrik
    26837U,	// VRANGESSZrrikz
    0U,	// VRCP14PDZ128m
    0U,	// VRCP14PDZ128mb
    3356U,	// VRCP14PDZ128mbk
    4444U,	// VRCP14PDZ128mbkz
    405U,	// VRCP14PDZ128mk
    461U,	// VRCP14PDZ128mkz
    0U,	// VRCP14PDZ128r
    405U,	// VRCP14PDZ128rk
    461U,	// VRCP14PDZ128rkz
    0U,	// VRCP14PDZ256m
    0U,	// VRCP14PDZ256mb
    3356U,	// VRCP14PDZ256mbk
    4444U,	// VRCP14PDZ256mbkz
    405U,	// VRCP14PDZ256mk
    461U,	// VRCP14PDZ256mkz
    0U,	// VRCP14PDZ256r
    405U,	// VRCP14PDZ256rk
    461U,	// VRCP14PDZ256rkz
    0U,	// VRCP14PDZm
    0U,	// VRCP14PDZmb
    3356U,	// VRCP14PDZmbk
    4444U,	// VRCP14PDZmbkz
    405U,	// VRCP14PDZmk
    461U,	// VRCP14PDZmkz
    0U,	// VRCP14PDZr
    405U,	// VRCP14PDZrk
    461U,	// VRCP14PDZrkz
    0U,	// VRCP14PSZ128m
    0U,	// VRCP14PSZ128mb
    3356U,	// VRCP14PSZ128mbk
    4444U,	// VRCP14PSZ128mbkz
    405U,	// VRCP14PSZ128mk
    461U,	// VRCP14PSZ128mkz
    0U,	// VRCP14PSZ128r
    405U,	// VRCP14PSZ128rk
    461U,	// VRCP14PSZ128rkz
    0U,	// VRCP14PSZ256m
    0U,	// VRCP14PSZ256mb
    3356U,	// VRCP14PSZ256mbk
    4444U,	// VRCP14PSZ256mbkz
    405U,	// VRCP14PSZ256mk
    461U,	// VRCP14PSZ256mkz
    0U,	// VRCP14PSZ256r
    405U,	// VRCP14PSZ256rk
    461U,	// VRCP14PSZ256rkz
    0U,	// VRCP14PSZm
    0U,	// VRCP14PSZmb
    3356U,	// VRCP14PSZmbk
    4444U,	// VRCP14PSZmbkz
    405U,	// VRCP14PSZmk
    461U,	// VRCP14PSZmkz
    0U,	// VRCP14PSZr
    405U,	// VRCP14PSZrk
    461U,	// VRCP14PSZrkz
    72U,	// VRCP14SDZrm
    133U,	// VRCP14SDZrmk
    9348U,	// VRCP14SDZrmkz
    4U,	// VRCP14SDZrr
    0U,	// VRCP14SDZrrk
    9348U,	// VRCP14SDZrrkz
    72U,	// VRCP14SSZrm
    133U,	// VRCP14SSZrmk
    9348U,	// VRCP14SSZrmkz
    4U,	// VRCP14SSZrr
    0U,	// VRCP14SSZrrk
    9348U,	// VRCP14SSZrrkz
    0U,	// VRCP28PDZm
    0U,	// VRCP28PDZmb
    3356U,	// VRCP28PDZmbk
    4444U,	// VRCP28PDZmbkz
    405U,	// VRCP28PDZmk
    461U,	// VRCP28PDZmkz
    0U,	// VRCP28PDZr
    0U,	// VRCP28PDZrb
    405U,	// VRCP28PDZrbk
    461U,	// VRCP28PDZrbkz
    405U,	// VRCP28PDZrk
    461U,	// VRCP28PDZrkz
    0U,	// VRCP28PSZm
    0U,	// VRCP28PSZmb
    3356U,	// VRCP28PSZmbk
    4444U,	// VRCP28PSZmbkz
    405U,	// VRCP28PSZmk
    461U,	// VRCP28PSZmkz
    0U,	// VRCP28PSZr
    0U,	// VRCP28PSZrb
    405U,	// VRCP28PSZrbk
    461U,	// VRCP28PSZrbkz
    405U,	// VRCP28PSZrk
    461U,	// VRCP28PSZrkz
    72U,	// VRCP28SDZm
    133U,	// VRCP28SDZmk
    9348U,	// VRCP28SDZmkz
    4U,	// VRCP28SDZr
    4U,	// VRCP28SDZrb
    0U,	// VRCP28SDZrbk
    9348U,	// VRCP28SDZrbkz
    0U,	// VRCP28SDZrk
    9348U,	// VRCP28SDZrkz
    72U,	// VRCP28SSZm
    133U,	// VRCP28SSZmk
    9348U,	// VRCP28SSZmkz
    4U,	// VRCP28SSZr
    4U,	// VRCP28SSZrb
    0U,	// VRCP28SSZrbk
    9348U,	// VRCP28SSZrbkz
    0U,	// VRCP28SSZrk
    9348U,	// VRCP28SSZrkz
    0U,	// VRCPPSYm
    0U,	// VRCPPSYr
    0U,	// VRCPPSm
    0U,	// VRCPPSr
    72U,	// VRCPSSm
    72U,	// VRCPSSm_Int
    4U,	// VRCPSSr
    4U,	// VRCPSSr_Int
    5U,	// VREDUCEPDZ128rmbi
    133U,	// VREDUCEPDZ128rmbik
    9349U,	// VREDUCEPDZ128rmbikz
    0U,	// VREDUCEPDZ128rmi
    3356U,	// VREDUCEPDZ128rmik
    4444U,	// VREDUCEPDZ128rmikz
    72U,	// VREDUCEPDZ128rri
    133U,	// VREDUCEPDZ128rrik
    9348U,	// VREDUCEPDZ128rrikz
    5U,	// VREDUCEPDZ256rmbi
    133U,	// VREDUCEPDZ256rmbik
    9349U,	// VREDUCEPDZ256rmbikz
    0U,	// VREDUCEPDZ256rmi
    3356U,	// VREDUCEPDZ256rmik
    4444U,	// VREDUCEPDZ256rmikz
    72U,	// VREDUCEPDZ256rri
    133U,	// VREDUCEPDZ256rrik
    9348U,	// VREDUCEPDZ256rrikz
    5U,	// VREDUCEPDZrmbi
    133U,	// VREDUCEPDZrmbik
    9349U,	// VREDUCEPDZrmbikz
    0U,	// VREDUCEPDZrmi
    3356U,	// VREDUCEPDZrmik
    4444U,	// VREDUCEPDZrmikz
    72U,	// VREDUCEPDZrri
    72U,	// VREDUCEPDZrrib
    133U,	// VREDUCEPDZrribk
    9348U,	// VREDUCEPDZrribkz
    133U,	// VREDUCEPDZrrik
    9348U,	// VREDUCEPDZrrikz
    5U,	// VREDUCEPSZ128rmbi
    133U,	// VREDUCEPSZ128rmbik
    9349U,	// VREDUCEPSZ128rmbikz
    0U,	// VREDUCEPSZ128rmi
    3356U,	// VREDUCEPSZ128rmik
    4444U,	// VREDUCEPSZ128rmikz
    72U,	// VREDUCEPSZ128rri
    133U,	// VREDUCEPSZ128rrik
    9348U,	// VREDUCEPSZ128rrikz
    5U,	// VREDUCEPSZ256rmbi
    133U,	// VREDUCEPSZ256rmbik
    9349U,	// VREDUCEPSZ256rmbikz
    0U,	// VREDUCEPSZ256rmi
    3356U,	// VREDUCEPSZ256rmik
    4444U,	// VREDUCEPSZ256rmikz
    72U,	// VREDUCEPSZ256rri
    133U,	// VREDUCEPSZ256rrik
    9348U,	// VREDUCEPSZ256rrikz
    5U,	// VREDUCEPSZrmbi
    133U,	// VREDUCEPSZrmbik
    9349U,	// VREDUCEPSZrmbikz
    0U,	// VREDUCEPSZrmi
    3356U,	// VREDUCEPSZrmik
    4444U,	// VREDUCEPSZrmikz
    72U,	// VREDUCEPSZrri
    72U,	// VREDUCEPSZrrib
    133U,	// VREDUCEPSZrribk
    9348U,	// VREDUCEPSZrribkz
    133U,	// VREDUCEPSZrrik
    9348U,	// VREDUCEPSZrrikz
    18636U,	// VREDUCESDZrmi
    26832U,	// VREDUCESDZrmik
    26836U,	// VREDUCESDZrmikz
    18636U,	// VREDUCESDZrri
    18636U,	// VREDUCESDZrrib
    25U,	// VREDUCESDZrribk
    26837U,	// VREDUCESDZrribkz
    25U,	// VREDUCESDZrrik
    26837U,	// VREDUCESDZrrikz
    18636U,	// VREDUCESSZrmi
    26832U,	// VREDUCESSZrmik
    26836U,	// VREDUCESSZrmikz
    18636U,	// VREDUCESSZrri
    18636U,	// VREDUCESSZrrib
    25U,	// VREDUCESSZrribk
    26837U,	// VREDUCESSZrribkz
    25U,	// VREDUCESSZrrik
    26837U,	// VREDUCESSZrrikz
    5U,	// VRNDSCALEPDZ128rmbi
    133U,	// VRNDSCALEPDZ128rmbik
    9349U,	// VRNDSCALEPDZ128rmbikz
    0U,	// VRNDSCALEPDZ128rmi
    3356U,	// VRNDSCALEPDZ128rmik
    4444U,	// VRNDSCALEPDZ128rmikz
    72U,	// VRNDSCALEPDZ128rri
    133U,	// VRNDSCALEPDZ128rrik
    9348U,	// VRNDSCALEPDZ128rrikz
    5U,	// VRNDSCALEPDZ256rmbi
    133U,	// VRNDSCALEPDZ256rmbik
    9349U,	// VRNDSCALEPDZ256rmbikz
    0U,	// VRNDSCALEPDZ256rmi
    3356U,	// VRNDSCALEPDZ256rmik
    4444U,	// VRNDSCALEPDZ256rmikz
    72U,	// VRNDSCALEPDZ256rri
    133U,	// VRNDSCALEPDZ256rrik
    9348U,	// VRNDSCALEPDZ256rrikz
    5U,	// VRNDSCALEPDZrmbi
    133U,	// VRNDSCALEPDZrmbik
    9349U,	// VRNDSCALEPDZrmbikz
    0U,	// VRNDSCALEPDZrmi
    3356U,	// VRNDSCALEPDZrmik
    4444U,	// VRNDSCALEPDZrmikz
    72U,	// VRNDSCALEPDZrri
    72U,	// VRNDSCALEPDZrrib
    133U,	// VRNDSCALEPDZrribk
    9348U,	// VRNDSCALEPDZrribkz
    133U,	// VRNDSCALEPDZrrik
    9348U,	// VRNDSCALEPDZrrikz
    5U,	// VRNDSCALEPSZ128rmbi
    133U,	// VRNDSCALEPSZ128rmbik
    9349U,	// VRNDSCALEPSZ128rmbikz
    0U,	// VRNDSCALEPSZ128rmi
    3356U,	// VRNDSCALEPSZ128rmik
    4444U,	// VRNDSCALEPSZ128rmikz
    72U,	// VRNDSCALEPSZ128rri
    133U,	// VRNDSCALEPSZ128rrik
    9348U,	// VRNDSCALEPSZ128rrikz
    5U,	// VRNDSCALEPSZ256rmbi
    133U,	// VRNDSCALEPSZ256rmbik
    9349U,	// VRNDSCALEPSZ256rmbikz
    0U,	// VRNDSCALEPSZ256rmi
    3356U,	// VRNDSCALEPSZ256rmik
    4444U,	// VRNDSCALEPSZ256rmikz
    72U,	// VRNDSCALEPSZ256rri
    133U,	// VRNDSCALEPSZ256rrik
    9348U,	// VRNDSCALEPSZ256rrikz
    5U,	// VRNDSCALEPSZrmbi
    133U,	// VRNDSCALEPSZrmbik
    9349U,	// VRNDSCALEPSZrmbikz
    0U,	// VRNDSCALEPSZrmi
    3356U,	// VRNDSCALEPSZrmik
    4444U,	// VRNDSCALEPSZrmikz
    72U,	// VRNDSCALEPSZrri
    72U,	// VRNDSCALEPSZrrib
    133U,	// VRNDSCALEPSZrribk
    9348U,	// VRNDSCALEPSZrribkz
    133U,	// VRNDSCALEPSZrrik
    9348U,	// VRNDSCALEPSZrrikz
    18636U,	// VRNDSCALESDZm
    18636U,	// VRNDSCALESDZm_Int
    26832U,	// VRNDSCALESDZm_Intk
    26836U,	// VRNDSCALESDZm_Intkz
    18636U,	// VRNDSCALESDZr
    18636U,	// VRNDSCALESDZr_Int
    25U,	// VRNDSCALESDZr_Intk
    26837U,	// VRNDSCALESDZr_Intkz
    18636U,	// VRNDSCALESDZrb_Int
    25U,	// VRNDSCALESDZrb_Intk
    26837U,	// VRNDSCALESDZrb_Intkz
    18636U,	// VRNDSCALESSZm
    18636U,	// VRNDSCALESSZm_Int
    26832U,	// VRNDSCALESSZm_Intk
    26836U,	// VRNDSCALESSZm_Intkz
    18636U,	// VRNDSCALESSZr
    18636U,	// VRNDSCALESSZr_Int
    25U,	// VRNDSCALESSZr_Intk
    26837U,	// VRNDSCALESSZr_Intkz
    18636U,	// VRNDSCALESSZrb_Int
    25U,	// VRNDSCALESSZrb_Intk
    26837U,	// VRNDSCALESSZrb_Intkz
    0U,	// VROUNDPDYm
    72U,	// VROUNDPDYr
    0U,	// VROUNDPDm
    72U,	// VROUNDPDr
    0U,	// VROUNDPSYm
    72U,	// VROUNDPSYr
    0U,	// VROUNDPSm
    72U,	// VROUNDPSr
    18636U,	// VROUNDSDm
    18636U,	// VROUNDSDm_Int
    18636U,	// VROUNDSDr
    18636U,	// VROUNDSDr_Int
    18636U,	// VROUNDSSm
    18636U,	// VROUNDSSm_Int
    18636U,	// VROUNDSSr
    18636U,	// VROUNDSSr_Int
    0U,	// VRSQRT14PDZ128m
    0U,	// VRSQRT14PDZ128mb
    3356U,	// VRSQRT14PDZ128mbk
    4444U,	// VRSQRT14PDZ128mbkz
    405U,	// VRSQRT14PDZ128mk
    461U,	// VRSQRT14PDZ128mkz
    0U,	// VRSQRT14PDZ128r
    405U,	// VRSQRT14PDZ128rk
    461U,	// VRSQRT14PDZ128rkz
    0U,	// VRSQRT14PDZ256m
    0U,	// VRSQRT14PDZ256mb
    3356U,	// VRSQRT14PDZ256mbk
    4444U,	// VRSQRT14PDZ256mbkz
    405U,	// VRSQRT14PDZ256mk
    461U,	// VRSQRT14PDZ256mkz
    0U,	// VRSQRT14PDZ256r
    405U,	// VRSQRT14PDZ256rk
    461U,	// VRSQRT14PDZ256rkz
    0U,	// VRSQRT14PDZm
    0U,	// VRSQRT14PDZmb
    3356U,	// VRSQRT14PDZmbk
    4444U,	// VRSQRT14PDZmbkz
    405U,	// VRSQRT14PDZmk
    461U,	// VRSQRT14PDZmkz
    0U,	// VRSQRT14PDZr
    405U,	// VRSQRT14PDZrk
    461U,	// VRSQRT14PDZrkz
    0U,	// VRSQRT14PSZ128m
    0U,	// VRSQRT14PSZ128mb
    3356U,	// VRSQRT14PSZ128mbk
    4444U,	// VRSQRT14PSZ128mbkz
    405U,	// VRSQRT14PSZ128mk
    461U,	// VRSQRT14PSZ128mkz
    0U,	// VRSQRT14PSZ128r
    405U,	// VRSQRT14PSZ128rk
    461U,	// VRSQRT14PSZ128rkz
    0U,	// VRSQRT14PSZ256m
    0U,	// VRSQRT14PSZ256mb
    3356U,	// VRSQRT14PSZ256mbk
    4444U,	// VRSQRT14PSZ256mbkz
    405U,	// VRSQRT14PSZ256mk
    461U,	// VRSQRT14PSZ256mkz
    0U,	// VRSQRT14PSZ256r
    405U,	// VRSQRT14PSZ256rk
    461U,	// VRSQRT14PSZ256rkz
    0U,	// VRSQRT14PSZm
    0U,	// VRSQRT14PSZmb
    3356U,	// VRSQRT14PSZmbk
    4444U,	// VRSQRT14PSZmbkz
    405U,	// VRSQRT14PSZmk
    461U,	// VRSQRT14PSZmkz
    0U,	// VRSQRT14PSZr
    405U,	// VRSQRT14PSZrk
    461U,	// VRSQRT14PSZrkz
    72U,	// VRSQRT14SDZrm
    133U,	// VRSQRT14SDZrmk
    9348U,	// VRSQRT14SDZrmkz
    4U,	// VRSQRT14SDZrr
    0U,	// VRSQRT14SDZrrk
    9348U,	// VRSQRT14SDZrrkz
    72U,	// VRSQRT14SSZrm
    133U,	// VRSQRT14SSZrmk
    9348U,	// VRSQRT14SSZrmkz
    4U,	// VRSQRT14SSZrr
    0U,	// VRSQRT14SSZrrk
    9348U,	// VRSQRT14SSZrrkz
    0U,	// VRSQRT28PDZm
    0U,	// VRSQRT28PDZmb
    3356U,	// VRSQRT28PDZmbk
    4444U,	// VRSQRT28PDZmbkz
    405U,	// VRSQRT28PDZmk
    461U,	// VRSQRT28PDZmkz
    0U,	// VRSQRT28PDZr
    0U,	// VRSQRT28PDZrb
    405U,	// VRSQRT28PDZrbk
    461U,	// VRSQRT28PDZrbkz
    405U,	// VRSQRT28PDZrk
    461U,	// VRSQRT28PDZrkz
    0U,	// VRSQRT28PSZm
    0U,	// VRSQRT28PSZmb
    3356U,	// VRSQRT28PSZmbk
    4444U,	// VRSQRT28PSZmbkz
    405U,	// VRSQRT28PSZmk
    461U,	// VRSQRT28PSZmkz
    0U,	// VRSQRT28PSZr
    0U,	// VRSQRT28PSZrb
    405U,	// VRSQRT28PSZrbk
    461U,	// VRSQRT28PSZrbkz
    405U,	// VRSQRT28PSZrk
    461U,	// VRSQRT28PSZrkz
    72U,	// VRSQRT28SDZm
    133U,	// VRSQRT28SDZmk
    9348U,	// VRSQRT28SDZmkz
    4U,	// VRSQRT28SDZr
    4U,	// VRSQRT28SDZrb
    0U,	// VRSQRT28SDZrbk
    9348U,	// VRSQRT28SDZrbkz
    0U,	// VRSQRT28SDZrk
    9348U,	// VRSQRT28SDZrkz
    72U,	// VRSQRT28SSZm
    133U,	// VRSQRT28SSZmk
    9348U,	// VRSQRT28SSZmkz
    4U,	// VRSQRT28SSZr
    4U,	// VRSQRT28SSZrb
    0U,	// VRSQRT28SSZrbk
    9348U,	// VRSQRT28SSZrbkz
    0U,	// VRSQRT28SSZrk
    9348U,	// VRSQRT28SSZrkz
    0U,	// VRSQRTPSYm
    0U,	// VRSQRTPSYr
    0U,	// VRSQRTPSm
    0U,	// VRSQRTPSr
    72U,	// VRSQRTSSm
    72U,	// VRSQRTSSm_Int
    4U,	// VRSQRTSSr
    4U,	// VRSQRTSSr_Int
    4U,	// VSCALEFPDZ128rm
    72U,	// VSCALEFPDZ128rmb
    133U,	// VSCALEFPDZ128rmbk
    9348U,	// VSCALEFPDZ128rmbkz
    0U,	// VSCALEFPDZ128rmk
    9348U,	// VSCALEFPDZ128rmkz
    4U,	// VSCALEFPDZ128rr
    0U,	// VSCALEFPDZ128rrk
    9348U,	// VSCALEFPDZ128rrkz
    4U,	// VSCALEFPDZ256rm
    72U,	// VSCALEFPDZ256rmb
    133U,	// VSCALEFPDZ256rmbk
    9348U,	// VSCALEFPDZ256rmbkz
    0U,	// VSCALEFPDZ256rmk
    9348U,	// VSCALEFPDZ256rmkz
    4U,	// VSCALEFPDZ256rr
    0U,	// VSCALEFPDZ256rrk
    9348U,	// VSCALEFPDZ256rrkz
    4U,	// VSCALEFPDZrm
    72U,	// VSCALEFPDZrmb
    133U,	// VSCALEFPDZrmbk
    9348U,	// VSCALEFPDZrmbkz
    0U,	// VSCALEFPDZrmk
    9348U,	// VSCALEFPDZrmkz
    4U,	// VSCALEFPDZrr
    4U,	// VSCALEFPDZrrb
    0U,	// VSCALEFPDZrrbk
    9348U,	// VSCALEFPDZrrbkz
    0U,	// VSCALEFPDZrrk
    9348U,	// VSCALEFPDZrrkz
    4U,	// VSCALEFPSZ128rm
    72U,	// VSCALEFPSZ128rmb
    133U,	// VSCALEFPSZ128rmbk
    9348U,	// VSCALEFPSZ128rmbkz
    0U,	// VSCALEFPSZ128rmk
    9348U,	// VSCALEFPSZ128rmkz
    4U,	// VSCALEFPSZ128rr
    0U,	// VSCALEFPSZ128rrk
    9348U,	// VSCALEFPSZ128rrkz
    4U,	// VSCALEFPSZ256rm
    72U,	// VSCALEFPSZ256rmb
    133U,	// VSCALEFPSZ256rmbk
    9348U,	// VSCALEFPSZ256rmbkz
    0U,	// VSCALEFPSZ256rmk
    9348U,	// VSCALEFPSZ256rmkz
    4U,	// VSCALEFPSZ256rr
    0U,	// VSCALEFPSZ256rrk
    9348U,	// VSCALEFPSZ256rrkz
    4U,	// VSCALEFPSZrm
    72U,	// VSCALEFPSZrmb
    133U,	// VSCALEFPSZrmbk
    9348U,	// VSCALEFPSZrmbkz
    0U,	// VSCALEFPSZrmk
    9348U,	// VSCALEFPSZrmkz
    4U,	// VSCALEFPSZrr
    4U,	// VSCALEFPSZrrb
    0U,	// VSCALEFPSZrrbk
    9348U,	// VSCALEFPSZrrbkz
    0U,	// VSCALEFPSZrrk
    9348U,	// VSCALEFPSZrrkz
    72U,	// VSCALEFSDZrm
    133U,	// VSCALEFSDZrmk
    9348U,	// VSCALEFSDZrmkz
    4U,	// VSCALEFSDZrr
    4U,	// VSCALEFSDZrrb_Int
    0U,	// VSCALEFSDZrrb_Intk
    9348U,	// VSCALEFSDZrrb_Intkz
    0U,	// VSCALEFSDZrrk
    9348U,	// VSCALEFSDZrrkz
    72U,	// VSCALEFSSZrm
    133U,	// VSCALEFSSZrmk
    9348U,	// VSCALEFSSZrmkz
    4U,	// VSCALEFSSZrr
    4U,	// VSCALEFSSZrrb_Int
    0U,	// VSCALEFSSZrrb_Intk
    9348U,	// VSCALEFSSZrrb_Intkz
    0U,	// VSCALEFSSZrrk
    9348U,	// VSCALEFSSZrrkz
    57U,	// VSCATTERDPDZ128mr
    57U,	// VSCATTERDPDZ256mr
    57U,	// VSCATTERDPDZmr
    57U,	// VSCATTERDPSZ128mr
    57U,	// VSCATTERDPSZ256mr
    57U,	// VSCATTERDPSZmr
    0U,	// VSCATTERPF0DPDm
    0U,	// VSCATTERPF0DPSm
    0U,	// VSCATTERPF0QPDm
    0U,	// VSCATTERPF0QPSm
    0U,	// VSCATTERPF1DPDm
    0U,	// VSCATTERPF1DPSm
    0U,	// VSCATTERPF1QPDm
    0U,	// VSCATTERPF1QPSm
    57U,	// VSCATTERQPDZ128mr
    57U,	// VSCATTERQPDZ256mr
    57U,	// VSCATTERQPDZmr
    57U,	// VSCATTERQPSZ128mr
    57U,	// VSCATTERQPSZ256mr
    57U,	// VSCATTERQPSZmr
    18637U,	// VSHUFF32X4Z256rmbi
    26833U,	// VSHUFF32X4Z256rmbik
    26837U,	// VSHUFF32X4Z256rmbikz
    72U,	// VSHUFF32X4Z256rmi
    1U,	// VSHUFF32X4Z256rmik
    9348U,	// VSHUFF32X4Z256rmikz
    18636U,	// VSHUFF32X4Z256rri
    25U,	// VSHUFF32X4Z256rrik
    26837U,	// VSHUFF32X4Z256rrikz
    18637U,	// VSHUFF32X4Zrmbi
    26833U,	// VSHUFF32X4Zrmbik
    26837U,	// VSHUFF32X4Zrmbikz
    72U,	// VSHUFF32X4Zrmi
    1U,	// VSHUFF32X4Zrmik
    9348U,	// VSHUFF32X4Zrmikz
    18636U,	// VSHUFF32X4Zrri
    25U,	// VSHUFF32X4Zrrik
    26837U,	// VSHUFF32X4Zrrikz
    18637U,	// VSHUFF64X2Z256rmbi
    26833U,	// VSHUFF64X2Z256rmbik
    26837U,	// VSHUFF64X2Z256rmbikz
    72U,	// VSHUFF64X2Z256rmi
    1U,	// VSHUFF64X2Z256rmik
    9348U,	// VSHUFF64X2Z256rmikz
    18636U,	// VSHUFF64X2Z256rri
    25U,	// VSHUFF64X2Z256rrik
    26837U,	// VSHUFF64X2Z256rrikz
    18637U,	// VSHUFF64X2Zrmbi
    26833U,	// VSHUFF64X2Zrmbik
    26837U,	// VSHUFF64X2Zrmbikz
    72U,	// VSHUFF64X2Zrmi
    1U,	// VSHUFF64X2Zrmik
    9348U,	// VSHUFF64X2Zrmikz
    18636U,	// VSHUFF64X2Zrri
    25U,	// VSHUFF64X2Zrrik
    26837U,	// VSHUFF64X2Zrrikz
    18637U,	// VSHUFI32X4Z256rmbi
    26833U,	// VSHUFI32X4Z256rmbik
    26837U,	// VSHUFI32X4Z256rmbikz
    72U,	// VSHUFI32X4Z256rmi
    1U,	// VSHUFI32X4Z256rmik
    9348U,	// VSHUFI32X4Z256rmikz
    18636U,	// VSHUFI32X4Z256rri
    25U,	// VSHUFI32X4Z256rrik
    26837U,	// VSHUFI32X4Z256rrikz
    18637U,	// VSHUFI32X4Zrmbi
    26833U,	// VSHUFI32X4Zrmbik
    26837U,	// VSHUFI32X4Zrmbikz
    72U,	// VSHUFI32X4Zrmi
    1U,	// VSHUFI32X4Zrmik
    9348U,	// VSHUFI32X4Zrmikz
    18636U,	// VSHUFI32X4Zrri
    25U,	// VSHUFI32X4Zrrik
    26837U,	// VSHUFI32X4Zrrikz
    18637U,	// VSHUFI64X2Z256rmbi
    26833U,	// VSHUFI64X2Z256rmbik
    26837U,	// VSHUFI64X2Z256rmbikz
    72U,	// VSHUFI64X2Z256rmi
    1U,	// VSHUFI64X2Z256rmik
    9348U,	// VSHUFI64X2Z256rmikz
    18636U,	// VSHUFI64X2Z256rri
    25U,	// VSHUFI64X2Z256rrik
    26837U,	// VSHUFI64X2Z256rrikz
    18637U,	// VSHUFI64X2Zrmbi
    26833U,	// VSHUFI64X2Zrmbik
    26837U,	// VSHUFI64X2Zrmbikz
    72U,	// VSHUFI64X2Zrmi
    1U,	// VSHUFI64X2Zrmik
    9348U,	// VSHUFI64X2Zrmikz
    18636U,	// VSHUFI64X2Zrri
    25U,	// VSHUFI64X2Zrrik
    26837U,	// VSHUFI64X2Zrrikz
    72U,	// VSHUFPDYrmi
    18636U,	// VSHUFPDYrri
    18637U,	// VSHUFPDZ128rmbi
    26833U,	// VSHUFPDZ128rmbik
    26837U,	// VSHUFPDZ128rmbikz
    72U,	// VSHUFPDZ128rmi
    1U,	// VSHUFPDZ128rmik
    9348U,	// VSHUFPDZ128rmikz
    18636U,	// VSHUFPDZ128rri
    25U,	// VSHUFPDZ128rrik
    26837U,	// VSHUFPDZ128rrikz
    18637U,	// VSHUFPDZ256rmbi
    26833U,	// VSHUFPDZ256rmbik
    26837U,	// VSHUFPDZ256rmbikz
    72U,	// VSHUFPDZ256rmi
    1U,	// VSHUFPDZ256rmik
    9348U,	// VSHUFPDZ256rmikz
    18636U,	// VSHUFPDZ256rri
    25U,	// VSHUFPDZ256rrik
    26837U,	// VSHUFPDZ256rrikz
    18637U,	// VSHUFPDZrmbi
    26833U,	// VSHUFPDZrmbik
    26837U,	// VSHUFPDZrmbikz
    72U,	// VSHUFPDZrmi
    1U,	// VSHUFPDZrmik
    9348U,	// VSHUFPDZrmikz
    18636U,	// VSHUFPDZrri
    25U,	// VSHUFPDZrrik
    26837U,	// VSHUFPDZrrikz
    72U,	// VSHUFPDrmi
    18636U,	// VSHUFPDrri
    72U,	// VSHUFPSYrmi
    18636U,	// VSHUFPSYrri
    18637U,	// VSHUFPSZ128rmbi
    26833U,	// VSHUFPSZ128rmbik
    26837U,	// VSHUFPSZ128rmbikz
    72U,	// VSHUFPSZ128rmi
    1U,	// VSHUFPSZ128rmik
    9348U,	// VSHUFPSZ128rmikz
    18636U,	// VSHUFPSZ128rri
    25U,	// VSHUFPSZ128rrik
    26837U,	// VSHUFPSZ128rrikz
    18637U,	// VSHUFPSZ256rmbi
    26833U,	// VSHUFPSZ256rmbik
    26837U,	// VSHUFPSZ256rmbikz
    72U,	// VSHUFPSZ256rmi
    1U,	// VSHUFPSZ256rmik
    9348U,	// VSHUFPSZ256rmikz
    18636U,	// VSHUFPSZ256rri
    25U,	// VSHUFPSZ256rrik
    26837U,	// VSHUFPSZ256rrikz
    18637U,	// VSHUFPSZrmbi
    26833U,	// VSHUFPSZrmbik
    26837U,	// VSHUFPSZrmbikz
    72U,	// VSHUFPSZrmi
    1U,	// VSHUFPSZrmik
    9348U,	// VSHUFPSZrmikz
    18636U,	// VSHUFPSZrri
    25U,	// VSHUFPSZrrik
    26837U,	// VSHUFPSZrrikz
    72U,	// VSHUFPSrmi
    18636U,	// VSHUFPSrri
    0U,	// VSQRTPDYm
    0U,	// VSQRTPDYr
    0U,	// VSQRTPDZ128m
    0U,	// VSQRTPDZ128mb
    3356U,	// VSQRTPDZ128mbk
    4444U,	// VSQRTPDZ128mbkz
    405U,	// VSQRTPDZ128mk
    461U,	// VSQRTPDZ128mkz
    0U,	// VSQRTPDZ128r
    405U,	// VSQRTPDZ128rk
    461U,	// VSQRTPDZ128rkz
    0U,	// VSQRTPDZ256m
    0U,	// VSQRTPDZ256mb
    3356U,	// VSQRTPDZ256mbk
    4444U,	// VSQRTPDZ256mbkz
    405U,	// VSQRTPDZ256mk
    461U,	// VSQRTPDZ256mkz
    0U,	// VSQRTPDZ256r
    405U,	// VSQRTPDZ256rk
    461U,	// VSQRTPDZ256rkz
    0U,	// VSQRTPDZm
    0U,	// VSQRTPDZmb
    3356U,	// VSQRTPDZmbk
    4444U,	// VSQRTPDZmbkz
    405U,	// VSQRTPDZmk
    461U,	// VSQRTPDZmkz
    0U,	// VSQRTPDZr
    0U,	// VSQRTPDZrb
    405U,	// VSQRTPDZrbk
    461U,	// VSQRTPDZrbkz
    405U,	// VSQRTPDZrk
    461U,	// VSQRTPDZrkz
    0U,	// VSQRTPDm
    0U,	// VSQRTPDr
    0U,	// VSQRTPSYm
    0U,	// VSQRTPSYr
    0U,	// VSQRTPSZ128m
    0U,	// VSQRTPSZ128mb
    3356U,	// VSQRTPSZ128mbk
    4444U,	// VSQRTPSZ128mbkz
    405U,	// VSQRTPSZ128mk
    461U,	// VSQRTPSZ128mkz
    0U,	// VSQRTPSZ128r
    405U,	// VSQRTPSZ128rk
    461U,	// VSQRTPSZ128rkz
    0U,	// VSQRTPSZ256m
    0U,	// VSQRTPSZ256mb
    3356U,	// VSQRTPSZ256mbk
    4444U,	// VSQRTPSZ256mbkz
    405U,	// VSQRTPSZ256mk
    461U,	// VSQRTPSZ256mkz
    0U,	// VSQRTPSZ256r
    405U,	// VSQRTPSZ256rk
    461U,	// VSQRTPSZ256rkz
    0U,	// VSQRTPSZm
    0U,	// VSQRTPSZmb
    3356U,	// VSQRTPSZmbk
    4444U,	// VSQRTPSZmbkz
    405U,	// VSQRTPSZmk
    461U,	// VSQRTPSZmkz
    0U,	// VSQRTPSZr
    0U,	// VSQRTPSZrb
    405U,	// VSQRTPSZrbk
    461U,	// VSQRTPSZrbkz
    405U,	// VSQRTPSZrk
    461U,	// VSQRTPSZrkz
    0U,	// VSQRTPSm
    0U,	// VSQRTPSr
    72U,	// VSQRTSDZm
    72U,	// VSQRTSDZm_Int
    133U,	// VSQRTSDZm_Intk
    9348U,	// VSQRTSDZm_Intkz
    4U,	// VSQRTSDZr
    4U,	// VSQRTSDZr_Int
    0U,	// VSQRTSDZr_Intk
    9348U,	// VSQRTSDZr_Intkz
    4U,	// VSQRTSDZrb_Int
    0U,	// VSQRTSDZrb_Intk
    9348U,	// VSQRTSDZrb_Intkz
    72U,	// VSQRTSDm
    72U,	// VSQRTSDm_Int
    4U,	// VSQRTSDr
    4U,	// VSQRTSDr_Int
    72U,	// VSQRTSSZm
    72U,	// VSQRTSSZm_Int
    133U,	// VSQRTSSZm_Intk
    9348U,	// VSQRTSSZm_Intkz
    4U,	// VSQRTSSZr
    4U,	// VSQRTSSZr_Int
    0U,	// VSQRTSSZr_Intk
    9348U,	// VSQRTSSZr_Intkz
    4U,	// VSQRTSSZrb_Int
    0U,	// VSQRTSSZrb_Intk
    9348U,	// VSQRTSSZrb_Intkz
    72U,	// VSQRTSSm
    72U,	// VSQRTSSm_Int
    4U,	// VSQRTSSr
    4U,	// VSQRTSSr_Int
    0U,	// VSTMXCSR
    4U,	// VSUBPDYrm
    4U,	// VSUBPDYrr
    4U,	// VSUBPDZ128rm
    72U,	// VSUBPDZ128rmb
    133U,	// VSUBPDZ128rmbk
    9348U,	// VSUBPDZ128rmbkz
    0U,	// VSUBPDZ128rmk
    9348U,	// VSUBPDZ128rmkz
    4U,	// VSUBPDZ128rr
    0U,	// VSUBPDZ128rrk
    9348U,	// VSUBPDZ128rrkz
    4U,	// VSUBPDZ256rm
    72U,	// VSUBPDZ256rmb
    133U,	// VSUBPDZ256rmbk
    9348U,	// VSUBPDZ256rmbkz
    0U,	// VSUBPDZ256rmk
    9348U,	// VSUBPDZ256rmkz
    4U,	// VSUBPDZ256rr
    0U,	// VSUBPDZ256rrk
    9348U,	// VSUBPDZ256rrkz
    4U,	// VSUBPDZrm
    72U,	// VSUBPDZrmb
    133U,	// VSUBPDZrmbk
    9348U,	// VSUBPDZrmbkz
    0U,	// VSUBPDZrmk
    9348U,	// VSUBPDZrmkz
    4U,	// VSUBPDZrr
    4U,	// VSUBPDZrrb
    0U,	// VSUBPDZrrbk
    9348U,	// VSUBPDZrrbkz
    0U,	// VSUBPDZrrk
    9348U,	// VSUBPDZrrkz
    4U,	// VSUBPDrm
    4U,	// VSUBPDrr
    4U,	// VSUBPSYrm
    4U,	// VSUBPSYrr
    4U,	// VSUBPSZ128rm
    72U,	// VSUBPSZ128rmb
    133U,	// VSUBPSZ128rmbk
    9348U,	// VSUBPSZ128rmbkz
    0U,	// VSUBPSZ128rmk
    9348U,	// VSUBPSZ128rmkz
    4U,	// VSUBPSZ128rr
    0U,	// VSUBPSZ128rrk
    9348U,	// VSUBPSZ128rrkz
    4U,	// VSUBPSZ256rm
    72U,	// VSUBPSZ256rmb
    133U,	// VSUBPSZ256rmbk
    9348U,	// VSUBPSZ256rmbkz
    0U,	// VSUBPSZ256rmk
    9348U,	// VSUBPSZ256rmkz
    4U,	// VSUBPSZ256rr
    0U,	// VSUBPSZ256rrk
    9348U,	// VSUBPSZ256rrkz
    4U,	// VSUBPSZrm
    72U,	// VSUBPSZrmb
    133U,	// VSUBPSZrmbk
    9348U,	// VSUBPSZrmbkz
    0U,	// VSUBPSZrmk
    9348U,	// VSUBPSZrmkz
    4U,	// VSUBPSZrr
    4U,	// VSUBPSZrrb
    0U,	// VSUBPSZrrbk
    9348U,	// VSUBPSZrrbkz
    0U,	// VSUBPSZrrk
    9348U,	// VSUBPSZrrkz
    4U,	// VSUBPSrm
    4U,	// VSUBPSrr
    72U,	// VSUBSDZrm
    72U,	// VSUBSDZrm_Int
    133U,	// VSUBSDZrm_Intk
    9348U,	// VSUBSDZrm_Intkz
    4U,	// VSUBSDZrr
    4U,	// VSUBSDZrr_Int
    0U,	// VSUBSDZrr_Intk
    9348U,	// VSUBSDZrr_Intkz
    4U,	// VSUBSDZrrb_Int
    0U,	// VSUBSDZrrb_Intk
    9348U,	// VSUBSDZrrb_Intkz
    72U,	// VSUBSDrm
    72U,	// VSUBSDrm_Int
    4U,	// VSUBSDrr
    4U,	// VSUBSDrr_Int
    72U,	// VSUBSSZrm
    72U,	// VSUBSSZrm_Int
    133U,	// VSUBSSZrm_Intk
    9348U,	// VSUBSSZrm_Intkz
    4U,	// VSUBSSZrr
    4U,	// VSUBSSZrr_Int
    0U,	// VSUBSSZrr_Intk
    9348U,	// VSUBSSZrr_Intkz
    4U,	// VSUBSSZrrb_Int
    0U,	// VSUBSSZrrb_Intk
    9348U,	// VSUBSSZrrb_Intkz
    72U,	// VSUBSSrm
    72U,	// VSUBSSrm_Int
    4U,	// VSUBSSrr
    4U,	// VSUBSSrr_Int
    0U,	// VTESTPDYrm
    0U,	// VTESTPDYrr
    0U,	// VTESTPDrm
    0U,	// VTESTPDrr
    0U,	// VTESTPSYrm
    0U,	// VTESTPSYrr
    0U,	// VTESTPSrm
    0U,	// VTESTPSrr
    0U,	// VUCOMISDZrm
    0U,	// VUCOMISDZrm_Int
    0U,	// VUCOMISDZrr
    0U,	// VUCOMISDZrr_Int
    0U,	// VUCOMISDZrrb
    0U,	// VUCOMISDrm
    0U,	// VUCOMISDrm_Int
    0U,	// VUCOMISDrr
    0U,	// VUCOMISDrr_Int
    0U,	// VUCOMISSZrm
    0U,	// VUCOMISSZrm_Int
    0U,	// VUCOMISSZrr
    0U,	// VUCOMISSZrr_Int
    0U,	// VUCOMISSZrrb
    0U,	// VUCOMISSrm
    0U,	// VUCOMISSrm_Int
    0U,	// VUCOMISSrr
    0U,	// VUCOMISSrr_Int
    4U,	// VUNPCKHPDYrm
    4U,	// VUNPCKHPDYrr
    4U,	// VUNPCKHPDZ128rm
    72U,	// VUNPCKHPDZ128rmb
    133U,	// VUNPCKHPDZ128rmbk
    9348U,	// VUNPCKHPDZ128rmbkz
    0U,	// VUNPCKHPDZ128rmk
    9348U,	// VUNPCKHPDZ128rmkz
    4U,	// VUNPCKHPDZ128rr
    0U,	// VUNPCKHPDZ128rrk
    9348U,	// VUNPCKHPDZ128rrkz
    4U,	// VUNPCKHPDZ256rm
    72U,	// VUNPCKHPDZ256rmb
    133U,	// VUNPCKHPDZ256rmbk
    9348U,	// VUNPCKHPDZ256rmbkz
    0U,	// VUNPCKHPDZ256rmk
    9348U,	// VUNPCKHPDZ256rmkz
    4U,	// VUNPCKHPDZ256rr
    0U,	// VUNPCKHPDZ256rrk
    9348U,	// VUNPCKHPDZ256rrkz
    4U,	// VUNPCKHPDZrm
    72U,	// VUNPCKHPDZrmb
    133U,	// VUNPCKHPDZrmbk
    9348U,	// VUNPCKHPDZrmbkz
    0U,	// VUNPCKHPDZrmk
    9348U,	// VUNPCKHPDZrmkz
    4U,	// VUNPCKHPDZrr
    0U,	// VUNPCKHPDZrrk
    9348U,	// VUNPCKHPDZrrkz
    4U,	// VUNPCKHPDrm
    4U,	// VUNPCKHPDrr
    4U,	// VUNPCKHPSYrm
    4U,	// VUNPCKHPSYrr
    4U,	// VUNPCKHPSZ128rm
    72U,	// VUNPCKHPSZ128rmb
    133U,	// VUNPCKHPSZ128rmbk
    9348U,	// VUNPCKHPSZ128rmbkz
    0U,	// VUNPCKHPSZ128rmk
    9348U,	// VUNPCKHPSZ128rmkz
    4U,	// VUNPCKHPSZ128rr
    0U,	// VUNPCKHPSZ128rrk
    9348U,	// VUNPCKHPSZ128rrkz
    4U,	// VUNPCKHPSZ256rm
    72U,	// VUNPCKHPSZ256rmb
    133U,	// VUNPCKHPSZ256rmbk
    9348U,	// VUNPCKHPSZ256rmbkz
    0U,	// VUNPCKHPSZ256rmk
    9348U,	// VUNPCKHPSZ256rmkz
    4U,	// VUNPCKHPSZ256rr
    0U,	// VUNPCKHPSZ256rrk
    9348U,	// VUNPCKHPSZ256rrkz
    4U,	// VUNPCKHPSZrm
    72U,	// VUNPCKHPSZrmb
    133U,	// VUNPCKHPSZrmbk
    9348U,	// VUNPCKHPSZrmbkz
    0U,	// VUNPCKHPSZrmk
    9348U,	// VUNPCKHPSZrmkz
    4U,	// VUNPCKHPSZrr
    0U,	// VUNPCKHPSZrrk
    9348U,	// VUNPCKHPSZrrkz
    4U,	// VUNPCKHPSrm
    4U,	// VUNPCKHPSrr
    4U,	// VUNPCKLPDYrm
    4U,	// VUNPCKLPDYrr
    4U,	// VUNPCKLPDZ128rm
    72U,	// VUNPCKLPDZ128rmb
    133U,	// VUNPCKLPDZ128rmbk
    9348U,	// VUNPCKLPDZ128rmbkz
    0U,	// VUNPCKLPDZ128rmk
    9348U,	// VUNPCKLPDZ128rmkz
    4U,	// VUNPCKLPDZ128rr
    0U,	// VUNPCKLPDZ128rrk
    9348U,	// VUNPCKLPDZ128rrkz
    4U,	// VUNPCKLPDZ256rm
    72U,	// VUNPCKLPDZ256rmb
    133U,	// VUNPCKLPDZ256rmbk
    9348U,	// VUNPCKLPDZ256rmbkz
    0U,	// VUNPCKLPDZ256rmk
    9348U,	// VUNPCKLPDZ256rmkz
    4U,	// VUNPCKLPDZ256rr
    0U,	// VUNPCKLPDZ256rrk
    9348U,	// VUNPCKLPDZ256rrkz
    4U,	// VUNPCKLPDZrm
    72U,	// VUNPCKLPDZrmb
    133U,	// VUNPCKLPDZrmbk
    9348U,	// VUNPCKLPDZrmbkz
    0U,	// VUNPCKLPDZrmk
    9348U,	// VUNPCKLPDZrmkz
    4U,	// VUNPCKLPDZrr
    0U,	// VUNPCKLPDZrrk
    9348U,	// VUNPCKLPDZrrkz
    4U,	// VUNPCKLPDrm
    4U,	// VUNPCKLPDrr
    4U,	// VUNPCKLPSYrm
    4U,	// VUNPCKLPSYrr
    4U,	// VUNPCKLPSZ128rm
    72U,	// VUNPCKLPSZ128rmb
    133U,	// VUNPCKLPSZ128rmbk
    9348U,	// VUNPCKLPSZ128rmbkz
    0U,	// VUNPCKLPSZ128rmk
    9348U,	// VUNPCKLPSZ128rmkz
    4U,	// VUNPCKLPSZ128rr
    0U,	// VUNPCKLPSZ128rrk
    9348U,	// VUNPCKLPSZ128rrkz
    4U,	// VUNPCKLPSZ256rm
    72U,	// VUNPCKLPSZ256rmb
    133U,	// VUNPCKLPSZ256rmbk
    9348U,	// VUNPCKLPSZ256rmbkz
    0U,	// VUNPCKLPSZ256rmk
    9348U,	// VUNPCKLPSZ256rmkz
    4U,	// VUNPCKLPSZ256rr
    0U,	// VUNPCKLPSZ256rrk
    9348U,	// VUNPCKLPSZ256rrkz
    4U,	// VUNPCKLPSZrm
    72U,	// VUNPCKLPSZrmb
    133U,	// VUNPCKLPSZrmbk
    9348U,	// VUNPCKLPSZrmbkz
    0U,	// VUNPCKLPSZrmk
    9348U,	// VUNPCKLPSZrmkz
    4U,	// VUNPCKLPSZrr
    0U,	// VUNPCKLPSZrrk
    9348U,	// VUNPCKLPSZrrkz
    4U,	// VUNPCKLPSrm
    4U,	// VUNPCKLPSrr
    4U,	// VXORPDYrm
    4U,	// VXORPDYrr
    4U,	// VXORPDZ128rm
    72U,	// VXORPDZ128rmb
    133U,	// VXORPDZ128rmbk
    9348U,	// VXORPDZ128rmbkz
    0U,	// VXORPDZ128rmk
    9348U,	// VXORPDZ128rmkz
    4U,	// VXORPDZ128rr
    0U,	// VXORPDZ128rrk
    9348U,	// VXORPDZ128rrkz
    4U,	// VXORPDZ256rm
    72U,	// VXORPDZ256rmb
    133U,	// VXORPDZ256rmbk
    9348U,	// VXORPDZ256rmbkz
    0U,	// VXORPDZ256rmk
    9348U,	// VXORPDZ256rmkz
    4U,	// VXORPDZ256rr
    0U,	// VXORPDZ256rrk
    9348U,	// VXORPDZ256rrkz
    4U,	// VXORPDZrm
    72U,	// VXORPDZrmb
    133U,	// VXORPDZrmbk
    9348U,	// VXORPDZrmbkz
    0U,	// VXORPDZrmk
    9348U,	// VXORPDZrmkz
    4U,	// VXORPDZrr
    0U,	// VXORPDZrrk
    9348U,	// VXORPDZrrkz
    4U,	// VXORPDrm
    4U,	// VXORPDrr
    4U,	// VXORPSYrm
    4U,	// VXORPSYrr
    4U,	// VXORPSZ128rm
    72U,	// VXORPSZ128rmb
    133U,	// VXORPSZ128rmbk
    9348U,	// VXORPSZ128rmbkz
    0U,	// VXORPSZ128rmk
    9348U,	// VXORPSZ128rmkz
    4U,	// VXORPSZ128rr
    0U,	// VXORPSZ128rrk
    9348U,	// VXORPSZ128rrkz
    4U,	// VXORPSZ256rm
    72U,	// VXORPSZ256rmb
    133U,	// VXORPSZ256rmbk
    9348U,	// VXORPSZ256rmbkz
    0U,	// VXORPSZ256rmk
    9348U,	// VXORPSZ256rmkz
    4U,	// VXORPSZ256rr
    0U,	// VXORPSZ256rrk
    9348U,	// VXORPSZ256rrkz
    4U,	// VXORPSZrm
    72U,	// VXORPSZrmb
    133U,	// VXORPSZrmbk
    9348U,	// VXORPSZrmbkz
    0U,	// VXORPSZrmk
    9348U,	// VXORPSZrmkz
    4U,	// VXORPSZrr
    0U,	// VXORPSZrrk
    9348U,	// VXORPSZrrkz
    4U,	// VXORPSrm
    4U,	// VXORPSrr
    0U,	// VZEROALL
    0U,	// VZEROUPPER
    0U,	// WAIT
    0U,	// WBINVD
    0U,	// WBNOINVD
    0U,	// WRFSBASE
    0U,	// WRFSBASE64
    0U,	// WRGSBASE
    0U,	// WRGSBASE64
    0U,	// WRMSR
    0U,	// WRPKRUr
    0U,	// WRSSD
    0U,	// WRSSQ
    0U,	// WRUSSD
    0U,	// WRUSSQ
    0U,	// XABORT
    0U,	// XACQUIRE_PREFIX
    3U,	// XADD16rm
    0U,	// XADD16rr
    3U,	// XADD32rm
    0U,	// XADD32rr
    3U,	// XADD64rm
    0U,	// XADD64rr
    3U,	// XADD8rm
    0U,	// XADD8rr
    0U,	// XBEGIN_2
    0U,	// XBEGIN_4
    0U,	// XCHG16ar
    3U,	// XCHG16rm
    0U,	// XCHG16rr
    0U,	// XCHG32ar
    3U,	// XCHG32rm
    0U,	// XCHG32rr
    0U,	// XCHG64ar
    3U,	// XCHG64rm
    0U,	// XCHG64rr
    3U,	// XCHG8rm
    0U,	// XCHG8rr
    0U,	// XCH_F
    0U,	// XCRYPTCBC
    0U,	// XCRYPTCFB
    0U,	// XCRYPTCTR
    0U,	// XCRYPTECB
    0U,	// XCRYPTOFB
    0U,	// XEND
    0U,	// XGETBV
    0U,	// XLAT
    0U,	// XOR16i16
    0U,	// XOR16mi
    0U,	// XOR16mi8
    0U,	// XOR16mr
    0U,	// XOR16ri
    0U,	// XOR16ri8
    0U,	// XOR16rm
    0U,	// XOR16rr
    0U,	// XOR16rr_REV
    0U,	// XOR32i32
    0U,	// XOR32mi
    0U,	// XOR32mi8
    0U,	// XOR32mr
    0U,	// XOR32ri
    0U,	// XOR32ri8
    0U,	// XOR32rm
    0U,	// XOR32rr
    0U,	// XOR32rr_REV
    0U,	// XOR64i32
    0U,	// XOR64mi32
    0U,	// XOR64mi8
    0U,	// XOR64mr
    0U,	// XOR64ri32
    0U,	// XOR64ri8
    0U,	// XOR64rm
    0U,	// XOR64rr
    0U,	// XOR64rr_REV
    0U,	// XOR8i8
    0U,	// XOR8mi
    0U,	// XOR8mi8
    0U,	// XOR8mr
    0U,	// XOR8ri
    0U,	// XOR8ri8
    0U,	// XOR8rm
    0U,	// XOR8rr
    0U,	// XOR8rr_REV
    0U,	// XORPDrm
    0U,	// XORPDrr
    0U,	// XORPSrm
    0U,	// XORPSrr
    0U,	// XRELEASE_PREFIX
    0U,	// XRSTOR
    0U,	// XRSTOR64
    0U,	// XRSTORS
    0U,	// XRSTORS64
    0U,	// XSAVE
    0U,	// XSAVE64
    0U,	// XSAVEC
    0U,	// XSAVEC64
    0U,	// XSAVEOPT
    0U,	// XSAVEOPT64
    0U,	// XSAVES
    0U,	// XSAVES64
    0U,	// XSETBV
    0U,	// XSHA1
    0U,	// XSHA256
    0U,	// XSTORE
    0U,	// XTEST
  };

  static const uint8_t OpInfo2[] = {
    0U,	// PHI
    0U,	// INLINEASM
    0U,	// CFI_INSTRUCTION
    0U,	// EH_LABEL
    0U,	// GC_LABEL
    0U,	// ANNOTATION_LABEL
    0U,	// KILL
    0U,	// EXTRACT_SUBREG
    0U,	// INSERT_SUBREG
    0U,	// IMPLICIT_DEF
    0U,	// SUBREG_TO_REG
    0U,	// COPY_TO_REGCLASS
    0U,	// DBG_VALUE
    0U,	// DBG_LABEL
    0U,	// REG_SEQUENCE
    0U,	// COPY
    0U,	// BUNDLE
    0U,	// LIFETIME_START
    0U,	// LIFETIME_END
    0U,	// STACKMAP
    0U,	// FENTRY_CALL
    0U,	// PATCHPOINT
    0U,	// LOAD_STACK_GUARD
    0U,	// STATEPOINT
    0U,	// LOCAL_ESCAPE
    0U,	// FAULTING_OP
    0U,	// PATCHABLE_OP
    0U,	// PATCHABLE_FUNCTION_ENTER
    0U,	// PATCHABLE_RET
    0U,	// PATCHABLE_FUNCTION_EXIT
    0U,	// PATCHABLE_TAIL_CALL
    0U,	// PATCHABLE_EVENT_CALL
    0U,	// PATCHABLE_TYPED_EVENT_CALL
    0U,	// ICALL_BRANCH_FUNNEL
    0U,	// G_ADD
    0U,	// G_SUB
    0U,	// G_MUL
    0U,	// G_SDIV
    0U,	// G_UDIV
    0U,	// G_SREM
    0U,	// G_UREM
    0U,	// G_AND
    0U,	// G_OR
    0U,	// G_XOR
    0U,	// G_IMPLICIT_DEF
    0U,	// G_PHI
    0U,	// G_FRAME_INDEX
    0U,	// G_GLOBAL_VALUE
    0U,	// G_EXTRACT
    0U,	// G_UNMERGE_VALUES
    0U,	// G_INSERT
    0U,	// G_MERGE_VALUES
    0U,	// G_PTRTOINT
    0U,	// G_INTTOPTR
    0U,	// G_BITCAST
    0U,	// G_LOAD
    0U,	// G_SEXTLOAD
    0U,	// G_ZEXTLOAD
    0U,	// G_STORE
    0U,	// G_ATOMIC_CMPXCHG_WITH_SUCCESS
    0U,	// G_ATOMIC_CMPXCHG
    0U,	// G_ATOMICRMW_XCHG
    0U,	// G_ATOMICRMW_ADD
    0U,	// G_ATOMICRMW_SUB
    0U,	// G_ATOMICRMW_AND
    0U,	// G_ATOMICRMW_NAND
    0U,	// G_ATOMICRMW_OR
    0U,	// G_ATOMICRMW_XOR
    0U,	// G_ATOMICRMW_MAX
    0U,	// G_ATOMICRMW_MIN
    0U,	// G_ATOMICRMW_UMAX
    0U,	// G_ATOMICRMW_UMIN
    0U,	// G_BRCOND
    0U,	// G_BRINDIRECT
    0U,	// G_INTRINSIC
    0U,	// G_INTRINSIC_W_SIDE_EFFECTS
    0U,	// G_ANYEXT
    0U,	// G_TRUNC
    0U,	// G_CONSTANT
    0U,	// G_FCONSTANT
    0U,	// G_VASTART
    0U,	// G_VAARG
    0U,	// G_SEXT
    0U,	// G_ZEXT
    0U,	// G_SHL
    0U,	// G_LSHR
    0U,	// G_ASHR
    0U,	// G_ICMP
    0U,	// G_FCMP
    0U,	// G_SELECT
    0U,	// G_UADDE
    0U,	// G_USUBE
    0U,	// G_SADDO
    0U,	// G_SSUBO
    0U,	// G_UMULO
    0U,	// G_SMULO
    0U,	// G_UMULH
    0U,	// G_SMULH
    0U,	// G_FADD
    0U,	// G_FSUB
    0U,	// G_FMUL
    0U,	// G_FMA
    0U,	// G_FDIV
    0U,	// G_FREM
    0U,	// G_FPOW
    0U,	// G_FEXP
    0U,	// G_FEXP2
    0U,	// G_FLOG
    0U,	// G_FLOG2
    0U,	// G_FNEG
    0U,	// G_FPEXT
    0U,	// G_FPTRUNC
    0U,	// G_FPTOSI
    0U,	// G_FPTOUI
    0U,	// G_SITOFP
    0U,	// G_UITOFP
    0U,	// G_FABS
    0U,	// G_GEP
    0U,	// G_PTR_MASK
    0U,	// G_BR
    0U,	// G_INSERT_VECTOR_ELT
    0U,	// G_EXTRACT_VECTOR_ELT
    0U,	// G_SHUFFLE_VECTOR
    0U,	// G_BSWAP
    0U,	// G_ADDRSPACE_CAST
    0U,	// G_BLOCK_ADDR
    0U,	// AVX1_SETALLONES
    0U,	// AVX2_SETALLONES
    0U,	// AVX512_128_SET0
    0U,	// AVX512_256_SET0
    0U,	// AVX512_512_SET0
    0U,	// AVX512_512_SETALLONES
    0U,	// AVX512_512_SEXT_MASK_32
    0U,	// AVX512_512_SEXT_MASK_64
    0U,	// AVX512_FsFLD0SD
    0U,	// AVX512_FsFLD0SS
    0U,	// AVX_SET0
    0U,	// KSET0D
    0U,	// KSET0Q
    0U,	// KSET0W
    0U,	// KSET1D
    0U,	// KSET1Q
    0U,	// KSET1W
    0U,	// MMX_SET0
    0U,	// V_SET0
    0U,	// V_SETALLONES
    0U,	// AAA
    0U,	// AAD8i8
    0U,	// AAM8i8
    0U,	// AAS
    0U,	// ABS_F
    0U,	// ABS_Fp32
    0U,	// ABS_Fp64
    0U,	// ABS_Fp80
    0U,	// ADC16i16
    0U,	// ADC16mi
    0U,	// ADC16mi8
    0U,	// ADC16mr
    0U,	// ADC16ri
    0U,	// ADC16ri8
    0U,	// ADC16rm
    0U,	// ADC16rr
    0U,	// ADC16rr_REV
    0U,	// ADC32i32
    0U,	// ADC32mi
    0U,	// ADC32mi8
    0U,	// ADC32mr
    0U,	// ADC32ri
    0U,	// ADC32ri8
    0U,	// ADC32rm
    0U,	// ADC32rr
    0U,	// ADC32rr_REV
    0U,	// ADC64i32
    0U,	// ADC64mi32
    0U,	// ADC64mi8
    0U,	// ADC64mr
    0U,	// ADC64ri32
    0U,	// ADC64ri8
    0U,	// ADC64rm
    0U,	// ADC64rr
    0U,	// ADC64rr_REV
    0U,	// ADC8i8
    0U,	// ADC8mi
    0U,	// ADC8mi8
    0U,	// ADC8mr
    0U,	// ADC8ri
    0U,	// ADC8ri8
    0U,	// ADC8rm
    0U,	// ADC8rr
    0U,	// ADC8rr_REV
    0U,	// ADCX32rm
    0U,	// ADCX32rr
    0U,	// ADCX64rm
    0U,	// ADCX64rr
    0U,	// ADD16i16
    0U,	// ADD16mi
    0U,	// ADD16mi8
    0U,	// ADD16mr
    0U,	// ADD16ri
    0U,	// ADD16ri8
    0U,	// ADD16rm
    0U,	// ADD16rr
    0U,	// ADD16rr_REV
    0U,	// ADD32i32
    0U,	// ADD32mi
    0U,	// ADD32mi8
    0U,	// ADD32mr
    0U,	// ADD32ri
    0U,	// ADD32ri8
    0U,	// ADD32rm
    0U,	// ADD32rr
    0U,	// ADD32rr_REV
    0U,	// ADD64i32
    0U,	// ADD64mi32
    0U,	// ADD64mi8
    0U,	// ADD64mr
    0U,	// ADD64ri32
    0U,	// ADD64ri8
    0U,	// ADD64rm
    0U,	// ADD64rr
    0U,	// ADD64rr_REV
    0U,	// ADD8i8
    0U,	// ADD8mi
    0U,	// ADD8mi8
    0U,	// ADD8mr
    0U,	// ADD8ri
    0U,	// ADD8ri8
    0U,	// ADD8rm
    0U,	// ADD8rr
    0U,	// ADD8rr_REV
    0U,	// ADDPDrm
    0U,	// ADDPDrr
    0U,	// ADDPSrm
    0U,	// ADDPSrr
    0U,	// ADDSDrm
    0U,	// ADDSDrm_Int
    0U,	// ADDSDrr
    0U,	// ADDSDrr_Int
    0U,	// ADDSSrm
    0U,	// ADDSSrm_Int
    0U,	// ADDSSrr
    0U,	// ADDSSrr_Int
    0U,	// ADDSUBPDrm
    0U,	// ADDSUBPDrr
    0U,	// ADDSUBPSrm
    0U,	// ADDSUBPSrr
    0U,	// ADD_F32m
    0U,	// ADD_F64m
    0U,	// ADD_FI16m
    0U,	// ADD_FI32m
    0U,	// ADD_FPrST0
    0U,	// ADD_FST0r
    0U,	// ADD_Fp32
    0U,	// ADD_Fp32m
    0U,	// ADD_Fp64
    0U,	// ADD_Fp64m
    0U,	// ADD_Fp64m32
    0U,	// ADD_Fp80
    0U,	// ADD_Fp80m32
    0U,	// ADD_Fp80m64
    0U,	// ADD_FpI16m32
    0U,	// ADD_FpI16m64
    0U,	// ADD_FpI16m80
    0U,	// ADD_FpI32m32
    0U,	// ADD_FpI32m64
    0U,	// ADD_FpI32m80
    0U,	// ADD_FrST0
    0U,	// ADOX32rm
    0U,	// ADOX32rr
    0U,	// ADOX64rm
    0U,	// ADOX64rr
    0U,	// AESDECLASTrm
    0U,	// AESDECLASTrr
    0U,	// AESDECrm
    0U,	// AESDECrr
    0U,	// AESENCLASTrm
    0U,	// AESENCLASTrr
    0U,	// AESENCrm
    0U,	// AESENCrr
    0U,	// AESIMCrm
    0U,	// AESIMCrr
    0U,	// AESKEYGENASSIST128rm
    0U,	// AESKEYGENASSIST128rr
    0U,	// AND16i16
    0U,	// AND16mi
    0U,	// AND16mi8
    0U,	// AND16mr
    0U,	// AND16ri
    0U,	// AND16ri8
    0U,	// AND16rm
    0U,	// AND16rr
    0U,	// AND16rr_REV
    0U,	// AND32i32
    0U,	// AND32mi
    0U,	// AND32mi8
    0U,	// AND32mr
    0U,	// AND32ri
    0U,	// AND32ri8
    0U,	// AND32rm
    0U,	// AND32rr
    0U,	// AND32rr_REV
    0U,	// AND64i32
    0U,	// AND64mi32
    0U,	// AND64mi8
    0U,	// AND64mr
    0U,	// AND64ri32
    0U,	// AND64ri8
    0U,	// AND64rm
    0U,	// AND64rr
    0U,	// AND64rr_REV
    0U,	// AND8i8
    0U,	// AND8mi
    0U,	// AND8mi8
    0U,	// AND8mr
    0U,	// AND8ri
    0U,	// AND8ri8
    0U,	// AND8rm
    0U,	// AND8rr
    0U,	// AND8rr_REV
    0U,	// ANDN32rm
    0U,	// ANDN32rr
    0U,	// ANDN64rm
    0U,	// ANDN64rr
    0U,	// ANDNPDrm
    0U,	// ANDNPDrr
    0U,	// ANDNPSrm
    0U,	// ANDNPSrr
    0U,	// ANDPDrm
    0U,	// ANDPDrr
    0U,	// ANDPSrm
    0U,	// ANDPSrr
    0U,	// ARPL16mr
    0U,	// ARPL16rr
    0U,	// BEXTR32rm
    0U,	// BEXTR32rr
    0U,	// BEXTR64rm
    0U,	// BEXTR64rr
    0U,	// BEXTRI32mi
    0U,	// BEXTRI32ri
    0U,	// BEXTRI64mi
    0U,	// BEXTRI64ri
    0U,	// BLCFILL32rm
    0U,	// BLCFILL32rr
    0U,	// BLCFILL64rm
    0U,	// BLCFILL64rr
    0U,	// BLCI32rm
    0U,	// BLCI32rr
    0U,	// BLCI64rm
    0U,	// BLCI64rr
    0U,	// BLCIC32rm
    0U,	// BLCIC32rr
    0U,	// BLCIC64rm
    0U,	// BLCIC64rr
    0U,	// BLCMSK32rm
    0U,	// BLCMSK32rr
    0U,	// BLCMSK64rm
    0U,	// BLCMSK64rr
    0U,	// BLCS32rm
    0U,	// BLCS32rr
    0U,	// BLCS64rm
    0U,	// BLCS64rr
    0U,	// BLENDPDrmi
    0U,	// BLENDPDrri
    0U,	// BLENDPSrmi
    0U,	// BLENDPSrri
    0U,	// BLENDVPDrm0
    0U,	// BLENDVPDrr0
    0U,	// BLENDVPSrm0
    0U,	// BLENDVPSrr0
    0U,	// BLSFILL32rm
    0U,	// BLSFILL32rr
    0U,	// BLSFILL64rm
    0U,	// BLSFILL64rr
    0U,	// BLSI32rm
    0U,	// BLSI32rr
    0U,	// BLSI64rm
    0U,	// BLSI64rr
    0U,	// BLSIC32rm
    0U,	// BLSIC32rr
    0U,	// BLSIC64rm
    0U,	// BLSIC64rr
    0U,	// BLSMSK32rm
    0U,	// BLSMSK32rr
    0U,	// BLSMSK64rm
    0U,	// BLSMSK64rr
    0U,	// BLSR32rm
    0U,	// BLSR32rr
    0U,	// BLSR64rm
    0U,	// BLSR64rr
    0U,	// BNDCL32rm
    0U,	// BNDCL32rr
    0U,	// BNDCL64rm
    0U,	// BNDCL64rr
    0U,	// BNDCN32rm
    0U,	// BNDCN32rr
    0U,	// BNDCN64rm
    0U,	// BNDCN64rr
    0U,	// BNDCU32rm
    0U,	// BNDCU32rr
    0U,	// BNDCU64rm
    0U,	// BNDCU64rr
    0U,	// BNDLDXrm
    0U,	// BNDMK32rm
    0U,	// BNDMK64rm
    0U,	// BNDMOV32mr
    0U,	// BNDMOV32rm
    0U,	// BNDMOV64mr
    0U,	// BNDMOV64rm
    0U,	// BNDMOVrr
    0U,	// BNDMOVrr_REV
    0U,	// BNDSTXmr
    0U,	// BOUNDS16rm
    0U,	// BOUNDS32rm
    0U,	// BSF16rm
    0U,	// BSF16rr
    0U,	// BSF32rm
    0U,	// BSF32rr
    0U,	// BSF64rm
    0U,	// BSF64rr
    0U,	// BSR16rm
    0U,	// BSR16rr
    0U,	// BSR32rm
    0U,	// BSR32rr
    0U,	// BSR64rm
    0U,	// BSR64rr
    0U,	// BSWAP16r_BAD
    0U,	// BSWAP32r
    0U,	// BSWAP64r
    0U,	// BT16mi8
    0U,	// BT16mr
    0U,	// BT16ri8
    0U,	// BT16rr
    0U,	// BT32mi8
    0U,	// BT32mr
    0U,	// BT32ri8
    0U,	// BT32rr
    0U,	// BT64mi8
    0U,	// BT64mr
    0U,	// BT64ri8
    0U,	// BT64rr
    0U,	// BTC16mi8
    0U,	// BTC16mr
    0U,	// BTC16ri8
    0U,	// BTC16rr
    0U,	// BTC32mi8
    0U,	// BTC32mr
    0U,	// BTC32ri8
    0U,	// BTC32rr
    0U,	// BTC64mi8
    0U,	// BTC64mr
    0U,	// BTC64ri8
    0U,	// BTC64rr
    0U,	// BTR16mi8
    0U,	// BTR16mr
    0U,	// BTR16ri8
    0U,	// BTR16rr
    0U,	// BTR32mi8
    0U,	// BTR32mr
    0U,	// BTR32ri8
    0U,	// BTR32rr
    0U,	// BTR64mi8
    0U,	// BTR64mr
    0U,	// BTR64ri8
    0U,	// BTR64rr
    0U,	// BTS16mi8
    0U,	// BTS16mr
    0U,	// BTS16ri8
    0U,	// BTS16rr
    0U,	// BTS32mi8
    0U,	// BTS32mr
    0U,	// BTS32ri8
    0U,	// BTS32rr
    0U,	// BTS64mi8
    0U,	// BTS64mr
    0U,	// BTS64ri8
    0U,	// BTS64rr
    0U,	// BZHI32rm
    0U,	// BZHI32rr
    0U,	// BZHI64rm
    0U,	// BZHI64rr
    0U,	// CALL16m
    0U,	// CALL16m_NT
    0U,	// CALL16r
    0U,	// CALL16r_NT
    0U,	// CALL32m
    0U,	// CALL32m_NT
    0U,	// CALL32r
    0U,	// CALL32r_NT
    0U,	// CALL64m
    0U,	// CALL64m_NT
    0U,	// CALL64pcrel32
    0U,	// CALL64r
    0U,	// CALL64r_NT
    0U,	// CALLpcrel16
    0U,	// CALLpcrel32
    0U,	// CBW
    0U,	// CDQ
    0U,	// CDQE
    0U,	// CHS_F
    0U,	// CHS_Fp32
    0U,	// CHS_Fp64
    0U,	// CHS_Fp80
    0U,	// CLAC
    0U,	// CLC
    0U,	// CLD
    0U,	// CLDEMOTE
    0U,	// CLFLUSH
    0U,	// CLFLUSHOPT
    0U,	// CLGI
    0U,	// CLI
    0U,	// CLRSSBSY
    0U,	// CLTS
    0U,	// CLWB
    0U,	// CLZEROr
    0U,	// CMC
    0U,	// CMOVA16rm
    0U,	// CMOVA16rr
    0U,	// CMOVA32rm
    0U,	// CMOVA32rr
    0U,	// CMOVA64rm
    0U,	// CMOVA64rr
    0U,	// CMOVAE16rm
    0U,	// CMOVAE16rr
    0U,	// CMOVAE32rm
    0U,	// CMOVAE32rr
    0U,	// CMOVAE64rm
    0U,	// CMOVAE64rr
    0U,	// CMOVB16rm
    0U,	// CMOVB16rr
    0U,	// CMOVB32rm
    0U,	// CMOVB32rr
    0U,	// CMOVB64rm
    0U,	// CMOVB64rr
    0U,	// CMOVBE16rm
    0U,	// CMOVBE16rr
    0U,	// CMOVBE32rm
    0U,	// CMOVBE32rr
    0U,	// CMOVBE64rm
    0U,	// CMOVBE64rr
    0U,	// CMOVBE_F
    0U,	// CMOVBE_Fp32
    0U,	// CMOVBE_Fp64
    0U,	// CMOVBE_Fp80
    0U,	// CMOVB_F
    0U,	// CMOVB_Fp32
    0U,	// CMOVB_Fp64
    0U,	// CMOVB_Fp80
    0U,	// CMOVE16rm
    0U,	// CMOVE16rr
    0U,	// CMOVE32rm
    0U,	// CMOVE32rr
    0U,	// CMOVE64rm
    0U,	// CMOVE64rr
    0U,	// CMOVE_F
    0U,	// CMOVE_Fp32
    0U,	// CMOVE_Fp64
    0U,	// CMOVE_Fp80
    0U,	// CMOVG16rm
    0U,	// CMOVG16rr
    0U,	// CMOVG32rm
    0U,	// CMOVG32rr
    0U,	// CMOVG64rm
    0U,	// CMOVG64rr
    0U,	// CMOVGE16rm
    0U,	// CMOVGE16rr
    0U,	// CMOVGE32rm
    0U,	// CMOVGE32rr
    0U,	// CMOVGE64rm
    0U,	// CMOVGE64rr
    0U,	// CMOVL16rm
    0U,	// CMOVL16rr
    0U,	// CMOVL32rm
    0U,	// CMOVL32rr
    0U,	// CMOVL64rm
    0U,	// CMOVL64rr
    0U,	// CMOVLE16rm
    0U,	// CMOVLE16rr
    0U,	// CMOVLE32rm
    0U,	// CMOVLE32rr
    0U,	// CMOVLE64rm
    0U,	// CMOVLE64rr
    0U,	// CMOVNBE_F
    0U,	// CMOVNBE_Fp32
    0U,	// CMOVNBE_Fp64
    0U,	// CMOVNBE_Fp80
    0U,	// CMOVNB_F
    0U,	// CMOVNB_Fp32
    0U,	// CMOVNB_Fp64
    0U,	// CMOVNB_Fp80
    0U,	// CMOVNE16rm
    0U,	// CMOVNE16rr
    0U,	// CMOVNE32rm
    0U,	// CMOVNE32rr
    0U,	// CMOVNE64rm
    0U,	// CMOVNE64rr
    0U,	// CMOVNE_F
    0U,	// CMOVNE_Fp32
    0U,	// CMOVNE_Fp64
    0U,	// CMOVNE_Fp80
    0U,	// CMOVNO16rm
    0U,	// CMOVNO16rr
    0U,	// CMOVNO32rm
    0U,	// CMOVNO32rr
    0U,	// CMOVNO64rm
    0U,	// CMOVNO64rr
    0U,	// CMOVNP16rm
    0U,	// CMOVNP16rr
    0U,	// CMOVNP32rm
    0U,	// CMOVNP32rr
    0U,	// CMOVNP64rm
    0U,	// CMOVNP64rr
    0U,	// CMOVNP_F
    0U,	// CMOVNP_Fp32
    0U,	// CMOVNP_Fp64
    0U,	// CMOVNP_Fp80
    0U,	// CMOVNS16rm
    0U,	// CMOVNS16rr
    0U,	// CMOVNS32rm
    0U,	// CMOVNS32rr
    0U,	// CMOVNS64rm
    0U,	// CMOVNS64rr
    0U,	// CMOVO16rm
    0U,	// CMOVO16rr
    0U,	// CMOVO32rm
    0U,	// CMOVO32rr
    0U,	// CMOVO64rm
    0U,	// CMOVO64rr
    0U,	// CMOVP16rm
    0U,	// CMOVP16rr
    0U,	// CMOVP32rm
    0U,	// CMOVP32rr
    0U,	// CMOVP64rm
    0U,	// CMOVP64rr
    0U,	// CMOVP_F
    0U,	// CMOVP_Fp32
    0U,	// CMOVP_Fp64
    0U,	// CMOVP_Fp80
    0U,	// CMOVS16rm
    0U,	// CMOVS16rr
    0U,	// CMOVS32rm
    0U,	// CMOVS32rr
    0U,	// CMOVS64rm
    0U,	// CMOVS64rr
    0U,	// CMP16i16
    0U,	// CMP16mi
    0U,	// CMP16mi8
    0U,	// CMP16mr
    0U,	// CMP16ri
    0U,	// CMP16ri8
    0U,	// CMP16rm
    0U,	// CMP16rr
    0U,	// CMP16rr_REV
    0U,	// CMP32i32
    0U,	// CMP32mi
    0U,	// CMP32mi8
    0U,	// CMP32mr
    0U,	// CMP32ri
    0U,	// CMP32ri8
    0U,	// CMP32rm
    0U,	// CMP32rr
    0U,	// CMP32rr_REV
    0U,	// CMP64i32
    0U,	// CMP64mi32
    0U,	// CMP64mi8
    0U,	// CMP64mr
    0U,	// CMP64ri32
    0U,	// CMP64ri8
    0U,	// CMP64rm
    0U,	// CMP64rr
    0U,	// CMP64rr_REV
    0U,	// CMP8i8
    0U,	// CMP8mi
    0U,	// CMP8mi8
    0U,	// CMP8mr
    0U,	// CMP8ri
    0U,	// CMP8ri8
    0U,	// CMP8rm
    0U,	// CMP8rr
    0U,	// CMP8rr_REV
    0U,	// CMPPDrmi
    0U,	// CMPPDrmi_alt
    0U,	// CMPPDrri
    0U,	// CMPPDrri_alt
    0U,	// CMPPSrmi
    0U,	// CMPPSrmi_alt
    0U,	// CMPPSrri
    0U,	// CMPPSrri_alt
    0U,	// CMPSB
    0U,	// CMPSDrm
    0U,	// CMPSDrm_Int
    0U,	// CMPSDrm_alt
    0U,	// CMPSDrr
    0U,	// CMPSDrr_Int
    0U,	// CMPSDrr_alt
    0U,	// CMPSL
    0U,	// CMPSQ
    0U,	// CMPSSrm
    0U,	// CMPSSrm_Int
    0U,	// CMPSSrm_alt
    0U,	// CMPSSrr
    0U,	// CMPSSrr_Int
    0U,	// CMPSSrr_alt
    0U,	// CMPSW
    0U,	// CMPXCHG16B
    0U,	// CMPXCHG16rm
    0U,	// CMPXCHG16rr
    0U,	// CMPXCHG32rm
    0U,	// CMPXCHG32rr
    0U,	// CMPXCHG64rm
    0U,	// CMPXCHG64rr
    0U,	// CMPXCHG8B
    0U,	// CMPXCHG8rm
    0U,	// CMPXCHG8rr
    0U,	// COMISDrm
    0U,	// COMISDrm_Int
    0U,	// COMISDrr
    0U,	// COMISDrr_Int
    0U,	// COMISSrm
    0U,	// COMISSrm_Int
    0U,	// COMISSrr
    0U,	// COMISSrr_Int
    0U,	// COMP_FST0r
    0U,	// COM_FIPr
    0U,	// COM_FIr
    0U,	// COM_FST0r
    0U,	// COS_F
    0U,	// COS_Fp32
    0U,	// COS_Fp64
    0U,	// COS_Fp80
    0U,	// CPUID
    0U,	// CQO
    0U,	// CRC32r32m16
    0U,	// CRC32r32m32
    0U,	// CRC32r32m8
    0U,	// CRC32r32r16
    0U,	// CRC32r32r32
    0U,	// CRC32r32r8
    0U,	// CRC32r64m64
    0U,	// CRC32r64m8
    0U,	// CRC32r64r64
    0U,	// CRC32r64r8
    0U,	// CVTDQ2PDrm
    0U,	// CVTDQ2PDrr
    0U,	// CVTDQ2PSrm
    0U,	// CVTDQ2PSrr
    0U,	// CVTPD2DQrm
    0U,	// CVTPD2DQrr
    0U,	// CVTPD2PSrm
    0U,	// CVTPD2PSrr
    0U,	// CVTPS2DQrm
    0U,	// CVTPS2DQrr
    0U,	// CVTPS2PDrm
    0U,	// CVTPS2PDrr
    0U,	// CVTSD2SI64rm_Int
    0U,	// CVTSD2SI64rr_Int
    0U,	// CVTSD2SIrm_Int
    0U,	// CVTSD2SIrr_Int
    0U,	// CVTSD2SSrm
    0U,	// CVTSD2SSrm_Int
    0U,	// CVTSD2SSrr
    0U,	// CVTSD2SSrr_Int
    0U,	// CVTSI2SDrm
    0U,	// CVTSI2SDrm_Int
    0U,	// CVTSI2SDrr
    0U,	// CVTSI2SDrr_Int
    0U,	// CVTSI2SSrm
    0U,	// CVTSI2SSrm_Int
    0U,	// CVTSI2SSrr
    0U,	// CVTSI2SSrr_Int
    0U,	// CVTSI642SDrm
    0U,	// CVTSI642SDrm_Int
    0U,	// CVTSI642SDrr
    0U,	// CVTSI642SDrr_Int
    0U,	// CVTSI642SSrm
    0U,	// CVTSI642SSrm_Int
    0U,	// CVTSI642SSrr
    0U,	// CVTSI642SSrr_Int
    0U,	// CVTSS2SDrm
    0U,	// CVTSS2SDrm_Int
    0U,	// CVTSS2SDrr
    0U,	// CVTSS2SDrr_Int
    0U,	// CVTSS2SI64rm_Int
    0U,	// CVTSS2SI64rr_Int
    0U,	// CVTSS2SIrm_Int
    0U,	// CVTSS2SIrr_Int
    0U,	// CVTTPD2DQrm
    0U,	// CVTTPD2DQrr
    0U,	// CVTTPS2DQrm
    0U,	// CVTTPS2DQrr
    0U,	// CVTTSD2SI64rm
    0U,	// CVTTSD2SI64rm_Int
    0U,	// CVTTSD2SI64rr
    0U,	// CVTTSD2SI64rr_Int
    0U,	// CVTTSD2SIrm
    0U,	// CVTTSD2SIrm_Int
    0U,	// CVTTSD2SIrr
    0U,	// CVTTSD2SIrr_Int
    0U,	// CVTTSS2SI64rm
    0U,	// CVTTSS2SI64rm_Int
    0U,	// CVTTSS2SI64rr
    0U,	// CVTTSS2SI64rr_Int
    0U,	// CVTTSS2SIrm
    0U,	// CVTTSS2SIrm_Int
    0U,	// CVTTSS2SIrr
    0U,	// CVTTSS2SIrr_Int
    0U,	// CWD
    0U,	// CWDE
    0U,	// DAA
    0U,	// DAS
    0U,	// DATA16_PREFIX
    0U,	// DEC16m
    0U,	// DEC16r
    0U,	// DEC16r_alt
    0U,	// DEC32m
    0U,	// DEC32r
    0U,	// DEC32r_alt
    0U,	// DEC64m
    0U,	// DEC64r
    0U,	// DEC8m
    0U,	// DEC8r
    0U,	// DIV16m
    0U,	// DIV16r
    0U,	// DIV32m
    0U,	// DIV32r
    0U,	// DIV64m
    0U,	// DIV64r
    0U,	// DIV8m
    0U,	// DIV8r
    0U,	// DIVPDrm
    0U,	// DIVPDrr
    0U,	// DIVPSrm
    0U,	// DIVPSrr
    0U,	// DIVR_F32m
    0U,	// DIVR_F64m
    0U,	// DIVR_FI16m
    0U,	// DIVR_FI32m
    0U,	// DIVR_FPrST0
    0U,	// DIVR_FST0r
    0U,	// DIVR_Fp32m
    0U,	// DIVR_Fp64m
    0U,	// DIVR_Fp64m32
    0U,	// DIVR_Fp80m32
    0U,	// DIVR_Fp80m64
    0U,	// DIVR_FpI16m32
    0U,	// DIVR_FpI16m64
    0U,	// DIVR_FpI16m80
    0U,	// DIVR_FpI32m32
    0U,	// DIVR_FpI32m64
    0U,	// DIVR_FpI32m80
    0U,	// DIVR_FrST0
    0U,	// DIVSDrm
    0U,	// DIVSDrm_Int
    0U,	// DIVSDrr
    0U,	// DIVSDrr_Int
    0U,	// DIVSSrm
    0U,	// DIVSSrm_Int
    0U,	// DIVSSrr
    0U,	// DIVSSrr_Int
    0U,	// DIV_F32m
    0U,	// DIV_F64m
    0U,	// DIV_FI16m
    0U,	// DIV_FI32m
    0U,	// DIV_FPrST0
    0U,	// DIV_FST0r
    0U,	// DIV_Fp32
    0U,	// DIV_Fp32m
    0U,	// DIV_Fp64
    0U,	// DIV_Fp64m
    0U,	// DIV_Fp64m32
    0U,	// DIV_Fp80
    0U,	// DIV_Fp80m32
    0U,	// DIV_Fp80m64
    0U,	// DIV_FpI16m32
    0U,	// DIV_FpI16m64
    0U,	// DIV_FpI16m80
    0U,	// DIV_FpI32m32
    0U,	// DIV_FpI32m64
    0U,	// DIV_FpI32m80
    0U,	// DIV_FrST0
    0U,	// DPPDrmi
    0U,	// DPPDrri
    0U,	// DPPSrmi
    0U,	// DPPSrri
    0U,	// ENCLS
    0U,	// ENCLU
    0U,	// ENCLV
    0U,	// ENDBR32
    0U,	// ENDBR64
    0U,	// ENTER
    0U,	// EXTRACTPSmr
    0U,	// EXTRACTPSrr
    0U,	// EXTRQ
    0U,	// EXTRQI
    0U,	// F2XM1
    0U,	// FARCALL16i
    0U,	// FARCALL16m
    0U,	// FARCALL32i
    0U,	// FARCALL32m
    0U,	// FARCALL64
    0U,	// FARJMP16i
    0U,	// FARJMP16m
    0U,	// FARJMP32i
    0U,	// FARJMP32m
    0U,	// FARJMP64
    0U,	// FBLDm
    0U,	// FBSTPm
    0U,	// FCOM32m
    0U,	// FCOM64m
    0U,	// FCOMP32m
    0U,	// FCOMP64m
    0U,	// FCOMPP
    0U,	// FDECSTP
    0U,	// FDISI8087_NOP
    0U,	// FEMMS
    0U,	// FENI8087_NOP
    0U,	// FFREE
    0U,	// FFREEP
    0U,	// FICOM16m
    0U,	// FICOM32m
    0U,	// FICOMP16m
    0U,	// FICOMP32m
    0U,	// FINCSTP
    0U,	// FLDCW16m
    0U,	// FLDENVm
    0U,	// FLDL2E
    0U,	// FLDL2T
    0U,	// FLDLG2
    0U,	// FLDLN2
    0U,	// FLDPI
    0U,	// FNCLEX
    0U,	// FNINIT
    0U,	// FNOP
    0U,	// FNSTCW16m
    0U,	// FNSTSW16r
    0U,	// FNSTSWm
    0U,	// FPATAN
    0U,	// FPNCEST0r
    0U,	// FPREM
    0U,	// FPREM1
    0U,	// FPTAN
    0U,	// FRNDINT
    0U,	// FRSTORm
    0U,	// FSAVEm
    0U,	// FSCALE
    0U,	// FSETPM
    0U,	// FSINCOS
    0U,	// FSTENVm
    0U,	// FXAM
    0U,	// FXRSTOR
    0U,	// FXRSTOR64
    0U,	// FXSAVE
    0U,	// FXSAVE64
    0U,	// FXTRACT
    0U,	// FYL2X
    0U,	// FYL2XP1
    0U,	// GETSEC
    0U,	// GF2P8AFFINEINVQBrmi
    0U,	// GF2P8AFFINEINVQBrri
    0U,	// GF2P8AFFINEQBrmi
    0U,	// GF2P8AFFINEQBrri
    0U,	// GF2P8MULBrm
    0U,	// GF2P8MULBrr
    0U,	// HADDPDrm
    0U,	// HADDPDrr
    0U,	// HADDPSrm
    0U,	// HADDPSrr
    0U,	// HLT
    0U,	// HSUBPDrm
    0U,	// HSUBPDrr
    0U,	// HSUBPSrm
    0U,	// HSUBPSrr
    0U,	// IDIV16m
    0U,	// IDIV16r
    0U,	// IDIV32m
    0U,	// IDIV32r
    0U,	// IDIV64m
    0U,	// IDIV64r
    0U,	// IDIV8m
    0U,	// IDIV8r
    0U,	// ILD_F16m
    0U,	// ILD_F32m
    0U,	// ILD_F64m
    0U,	// ILD_Fp16m32
    0U,	// ILD_Fp16m64
    0U,	// ILD_Fp16m80
    0U,	// ILD_Fp32m32
    0U,	// ILD_Fp32m64
    0U,	// ILD_Fp32m80
    0U,	// ILD_Fp64m32
    0U,	// ILD_Fp64m64
    0U,	// ILD_Fp64m80
    0U,	// IMUL16m
    0U,	// IMUL16r
    0U,	// IMUL16rm
    0U,	// IMUL16rmi
    0U,	// IMUL16rmi8
    0U,	// IMUL16rr
    0U,	// IMUL16rri
    0U,	// IMUL16rri8
    0U,	// IMUL32m
    0U,	// IMUL32r
    0U,	// IMUL32rm
    0U,	// IMUL32rmi
    0U,	// IMUL32rmi8
    0U,	// IMUL32rr
    0U,	// IMUL32rri
    0U,	// IMUL32rri8
    0U,	// IMUL64m
    0U,	// IMUL64r
    0U,	// IMUL64rm
    0U,	// IMUL64rmi32
    0U,	// IMUL64rmi8
    0U,	// IMUL64rr
    0U,	// IMUL64rri32
    0U,	// IMUL64rri8
    0U,	// IMUL8m
    0U,	// IMUL8r
    0U,	// IN16ri
    0U,	// IN16rr
    0U,	// IN32ri
    0U,	// IN32rr
    0U,	// IN8ri
    0U,	// IN8rr
    0U,	// INC16m
    0U,	// INC16r
    0U,	// INC16r_alt
    0U,	// INC32m
    0U,	// INC32r
    0U,	// INC32r_alt
    0U,	// INC64m
    0U,	// INC64r
    0U,	// INC8m
    0U,	// INC8r
    0U,	// INCSSPD
    0U,	// INCSSPQ
    0U,	// INSB
    0U,	// INSERTPSrm
    0U,	// INSERTPSrr
    0U,	// INSERTQ
    0U,	// INSERTQI
    0U,	// INSL
    0U,	// INSW
    0U,	// INT
    0U,	// INT1
    0U,	// INT3
    0U,	// INTO
    0U,	// INVD
    0U,	// INVEPT32
    0U,	// INVEPT64
    0U,	// INVLPG
    0U,	// INVLPGA32
    0U,	// INVLPGA64
    0U,	// INVPCID32
    0U,	// INVPCID64
    0U,	// INVVPID32
    0U,	// INVVPID64
    0U,	// IRET16
    0U,	// IRET32
    0U,	// IRET64
    0U,	// ISTT_FP16m
    0U,	// ISTT_FP32m
    0U,	// ISTT_FP64m
    0U,	// ISTT_Fp16m32
    0U,	// ISTT_Fp16m64
    0U,	// ISTT_Fp16m80
    0U,	// ISTT_Fp32m32
    0U,	// ISTT_Fp32m64
    0U,	// ISTT_Fp32m80
    0U,	// ISTT_Fp64m32
    0U,	// ISTT_Fp64m64
    0U,	// ISTT_Fp64m80
    0U,	// IST_F16m
    0U,	// IST_F32m
    0U,	// IST_FP16m
    0U,	// IST_FP32m
    0U,	// IST_FP64m
    0U,	// IST_Fp16m32
    0U,	// IST_Fp16m64
    0U,	// IST_Fp16m80
    0U,	// IST_Fp32m32
    0U,	// IST_Fp32m64
    0U,	// IST_Fp32m80
    0U,	// IST_Fp64m32
    0U,	// IST_Fp64m64
    0U,	// IST_Fp64m80
    0U,	// JAE_1
    0U,	// JAE_2
    0U,	// JAE_4
    0U,	// JA_1
    0U,	// JA_2
    0U,	// JA_4
    0U,	// JBE_1
    0U,	// JBE_2
    0U,	// JBE_4
    0U,	// JB_1
    0U,	// JB_2
    0U,	// JB_4
    0U,	// JCXZ
    0U,	// JECXZ
    0U,	// JE_1
    0U,	// JE_2
    0U,	// JE_4
    0U,	// JGE_1
    0U,	// JGE_2
    0U,	// JGE_4
    0U,	// JG_1
    0U,	// JG_2
    0U,	// JG_4
    0U,	// JLE_1
    0U,	// JLE_2
    0U,	// JLE_4
    0U,	// JL_1
    0U,	// JL_2
    0U,	// JL_4
    0U,	// JMP16m
    0U,	// JMP16m_NT
    0U,	// JMP16r
    0U,	// JMP16r_NT
    0U,	// JMP32m
    0U,	// JMP32m_NT
    0U,	// JMP32r
    0U,	// JMP32r_NT
    0U,	// JMP64m
    0U,	// JMP64m_NT
    0U,	// JMP64r
    0U,	// JMP64r_NT
    0U,	// JMP_1
    0U,	// JMP_2
    0U,	// JMP_4
    0U,	// JNE_1
    0U,	// JNE_2
    0U,	// JNE_4
    0U,	// JNO_1
    0U,	// JNO_2
    0U,	// JNO_4
    0U,	// JNP_1
    0U,	// JNP_2
    0U,	// JNP_4
    0U,	// JNS_1
    0U,	// JNS_2
    0U,	// JNS_4
    0U,	// JO_1
    0U,	// JO_2
    0U,	// JO_4
    0U,	// JP_1
    0U,	// JP_2
    0U,	// JP_4
    0U,	// JRCXZ
    0U,	// JS_1
    0U,	// JS_2
    0U,	// JS_4
    0U,	// KADDBrr
    0U,	// KADDDrr
    0U,	// KADDQrr
    0U,	// KADDWrr
    0U,	// KANDBrr
    0U,	// KANDDrr
    0U,	// KANDNBrr
    0U,	// KANDNDrr
    0U,	// KANDNQrr
    0U,	// KANDNWrr
    0U,	// KANDQrr
    0U,	// KANDWrr
    0U,	// KMOVBkk
    0U,	// KMOVBkm
    0U,	// KMOVBkr
    0U,	// KMOVBmk
    0U,	// KMOVBrk
    0U,	// KMOVDkk
    0U,	// KMOVDkm
    0U,	// KMOVDkr
    0U,	// KMOVDmk
    0U,	// KMOVDrk
    0U,	// KMOVQkk
    0U,	// KMOVQkm
    0U,	// KMOVQkr
    0U,	// KMOVQmk
    0U,	// KMOVQrk
    0U,	// KMOVWkk
    0U,	// KMOVWkm
    0U,	// KMOVWkr
    0U,	// KMOVWmk
    0U,	// KMOVWrk
    0U,	// KNOTBrr
    0U,	// KNOTDrr
    0U,	// KNOTQrr
    0U,	// KNOTWrr
    0U,	// KORBrr
    0U,	// KORDrr
    0U,	// KORQrr
    0U,	// KORTESTBrr
    0U,	// KORTESTDrr
    0U,	// KORTESTQrr
    0U,	// KORTESTWrr
    0U,	// KORWrr
    0U,	// KSHIFTLBri
    0U,	// KSHIFTLDri
    0U,	// KSHIFTLQri
    0U,	// KSHIFTLWri
    0U,	// KSHIFTRBri
    0U,	// KSHIFTRDri
    0U,	// KSHIFTRQri
    0U,	// KSHIFTRWri
    0U,	// KTESTBrr
    0U,	// KTESTDrr
    0U,	// KTESTQrr
    0U,	// KTESTWrr
    0U,	// KUNPCKBWrr
    0U,	// KUNPCKDQrr
    0U,	// KUNPCKWDrr
    0U,	// KXNORBrr
    0U,	// KXNORDrr
    0U,	// KXNORQrr
    0U,	// KXNORWrr
    0U,	// KXORBrr
    0U,	// KXORDrr
    0U,	// KXORQrr
    0U,	// KXORWrr
    0U,	// LAHF
    0U,	// LAR16rm
    0U,	// LAR16rr
    0U,	// LAR32rm
    0U,	// LAR32rr
    0U,	// LAR64rm
    0U,	// LAR64rr
    0U,	// LDDQUrm
    0U,	// LDMXCSR
    0U,	// LDS16rm
    0U,	// LDS32rm
    0U,	// LD_F0
    0U,	// LD_F1
    0U,	// LD_F32m
    0U,	// LD_F64m
    0U,	// LD_F80m
    0U,	// LD_Fp032
    0U,	// LD_Fp064
    0U,	// LD_Fp080
    0U,	// LD_Fp132
    0U,	// LD_Fp164
    0U,	// LD_Fp180
    0U,	// LD_Fp32m
    0U,	// LD_Fp32m64
    0U,	// LD_Fp32m80
    0U,	// LD_Fp64m
    0U,	// LD_Fp64m80
    0U,	// LD_Fp80m
    0U,	// LD_Frr
    0U,	// LEA16r
    0U,	// LEA32r
    0U,	// LEA64_32r
    0U,	// LEA64r
    0U,	// LEAVE
    0U,	// LEAVE64
    0U,	// LES16rm
    0U,	// LES32rm
    0U,	// LFENCE
    0U,	// LFS16rm
    0U,	// LFS32rm
    0U,	// LFS64rm
    0U,	// LGDT16m
    0U,	// LGDT32m
    0U,	// LGDT64m
    0U,	// LGS16rm
    0U,	// LGS32rm
    0U,	// LGS64rm
    0U,	// LIDT16m
    0U,	// LIDT32m
    0U,	// LIDT64m
    0U,	// LLDT16m
    0U,	// LLDT16r
    0U,	// LLWPCB
    0U,	// LLWPCB64
    0U,	// LMSW16m
    0U,	// LMSW16r
    0U,	// LOCK_PREFIX
    0U,	// LODSB
    0U,	// LODSL
    0U,	// LODSQ
    0U,	// LODSW
    0U,	// LOOP
    0U,	// LOOPE
    0U,	// LOOPNE
    0U,	// LRETIL
    0U,	// LRETIQ
    0U,	// LRETIW
    0U,	// LRETL
    0U,	// LRETQ
    0U,	// LRETW
    0U,	// LSL16rm
    0U,	// LSL16rr
    0U,	// LSL32rm
    0U,	// LSL32rr
    0U,	// LSL64rm
    0U,	// LSL64rr
    0U,	// LSS16rm
    0U,	// LSS32rm
    0U,	// LSS64rm
    0U,	// LTRm
    0U,	// LTRr
    0U,	// LWPINS32rmi
    0U,	// LWPINS32rri
    0U,	// LWPINS64rmi
    0U,	// LWPINS64rri
    0U,	// LWPVAL32rmi
    0U,	// LWPVAL32rri
    0U,	// LWPVAL64rmi
    0U,	// LWPVAL64rri
    0U,	// LZCNT16rm
    0U,	// LZCNT16rr
    0U,	// LZCNT32rm
    0U,	// LZCNT32rr
    0U,	// LZCNT64rm
    0U,	// LZCNT64rr
    0U,	// MASKMOVDQU
    0U,	// MASKMOVDQU64
    0U,	// MAXCPDrm
    0U,	// MAXCPDrr
    0U,	// MAXCPSrm
    0U,	// MAXCPSrr
    0U,	// MAXCSDrm
    0U,	// MAXCSDrr
    0U,	// MAXCSSrm
    0U,	// MAXCSSrr
    0U,	// MAXPDrm
    0U,	// MAXPDrr
    0U,	// MAXPSrm
    0U,	// MAXPSrr
    0U,	// MAXSDrm
    0U,	// MAXSDrm_Int
    0U,	// MAXSDrr
    0U,	// MAXSDrr_Int
    0U,	// MAXSSrm
    0U,	// MAXSSrm_Int
    0U,	// MAXSSrr
    0U,	// MAXSSrr_Int
    0U,	// MFENCE
    0U,	// MINCPDrm
    0U,	// MINCPDrr
    0U,	// MINCPSrm
    0U,	// MINCPSrr
    0U,	// MINCSDrm
    0U,	// MINCSDrr
    0U,	// MINCSSrm
    0U,	// MINCSSrr
    0U,	// MINPDrm
    0U,	// MINPDrr
    0U,	// MINPSrm
    0U,	// MINPSrr
    0U,	// MINSDrm
    0U,	// MINSDrm_Int
    0U,	// MINSDrr
    0U,	// MINSDrr_Int
    0U,	// MINSSrm
    0U,	// MINSSrm_Int
    0U,	// MINSSrr
    0U,	// MINSSrr_Int
    0U,	// MMX_CVTPD2PIirm
    0U,	// MMX_CVTPD2PIirr
    0U,	// MMX_CVTPI2PDirm
    0U,	// MMX_CVTPI2PDirr
    0U,	// MMX_CVTPI2PSirm
    0U,	// MMX_CVTPI2PSirr
    0U,	// MMX_CVTPS2PIirm
    0U,	// MMX_CVTPS2PIirr
    0U,	// MMX_CVTTPD2PIirm
    0U,	// MMX_CVTTPD2PIirr
    0U,	// MMX_CVTTPS2PIirm
    0U,	// MMX_CVTTPS2PIirr
    0U,	// MMX_EMMS
    0U,	// MMX_MASKMOVQ
    0U,	// MMX_MASKMOVQ64
    0U,	// MMX_MOVD64from64rm
    0U,	// MMX_MOVD64from64rr
    0U,	// MMX_MOVD64grr
    0U,	// MMX_MOVD64mr
    0U,	// MMX_MOVD64rm
    0U,	// MMX_MOVD64rr
    0U,	// MMX_MOVD64to64rm
    0U,	// MMX_MOVD64to64rr
    0U,	// MMX_MOVDQ2Qrr
    0U,	// MMX_MOVFR642Qrr
    0U,	// MMX_MOVNTQmr
    0U,	// MMX_MOVQ2DQrr
    0U,	// MMX_MOVQ2FR64rr
    0U,	// MMX_MOVQ64mr
    0U,	// MMX_MOVQ64rm
    0U,	// MMX_MOVQ64rr
    0U,	// MMX_MOVQ64rr_REV
    0U,	// MMX_PABSBrm
    0U,	// MMX_PABSBrr
    0U,	// MMX_PABSDrm
    0U,	// MMX_PABSDrr
    0U,	// MMX_PABSWrm
    0U,	// MMX_PABSWrr
    0U,	// MMX_PACKSSDWirm
    0U,	// MMX_PACKSSDWirr
    0U,	// MMX_PACKSSWBirm
    0U,	// MMX_PACKSSWBirr
    0U,	// MMX_PACKUSWBirm
    0U,	// MMX_PACKUSWBirr
    0U,	// MMX_PADDBirm
    0U,	// MMX_PADDBirr
    0U,	// MMX_PADDDirm
    0U,	// MMX_PADDDirr
    0U,	// MMX_PADDQirm
    0U,	// MMX_PADDQirr
    0U,	// MMX_PADDSBirm
    0U,	// MMX_PADDSBirr
    0U,	// MMX_PADDSWirm
    0U,	// MMX_PADDSWirr
    0U,	// MMX_PADDUSBirm
    0U,	// MMX_PADDUSBirr
    0U,	// MMX_PADDUSWirm
    0U,	// MMX_PADDUSWirr
    0U,	// MMX_PADDWirm
    0U,	// MMX_PADDWirr
    0U,	// MMX_PALIGNRrmi
    0U,	// MMX_PALIGNRrri
    0U,	// MMX_PANDNirm
    0U,	// MMX_PANDNirr
    0U,	// MMX_PANDirm
    0U,	// MMX_PANDirr
    0U,	// MMX_PAVGBirm
    0U,	// MMX_PAVGBirr
    0U,	// MMX_PAVGWirm
    0U,	// MMX_PAVGWirr
    0U,	// MMX_PCMPEQBirm
    0U,	// MMX_PCMPEQBirr
    0U,	// MMX_PCMPEQDirm
    0U,	// MMX_PCMPEQDirr
    0U,	// MMX_PCMPEQWirm
    0U,	// MMX_PCMPEQWirr
    0U,	// MMX_PCMPGTBirm
    0U,	// MMX_PCMPGTBirr
    0U,	// MMX_PCMPGTDirm
    0U,	// MMX_PCMPGTDirr
    0U,	// MMX_PCMPGTWirm
    0U,	// MMX_PCMPGTWirr
    0U,	// MMX_PEXTRWrr
    0U,	// MMX_PHADDDrm
    0U,	// MMX_PHADDDrr
    0U,	// MMX_PHADDSWrm
    0U,	// MMX_PHADDSWrr
    0U,	// MMX_PHADDWrm
    0U,	// MMX_PHADDWrr
    0U,	// MMX_PHSUBDrm
    0U,	// MMX_PHSUBDrr
    0U,	// MMX_PHSUBSWrm
    0U,	// MMX_PHSUBSWrr
    0U,	// MMX_PHSUBWrm
    0U,	// MMX_PHSUBWrr
    0U,	// MMX_PINSRWrm
    0U,	// MMX_PINSRWrr
    0U,	// MMX_PMADDUBSWrm
    0U,	// MMX_PMADDUBSWrr
    0U,	// MMX_PMADDWDirm
    0U,	// MMX_PMADDWDirr
    0U,	// MMX_PMAXSWirm
    0U,	// MMX_PMAXSWirr
    0U,	// MMX_PMAXUBirm
    0U,	// MMX_PMAXUBirr
    0U,	// MMX_PMINSWirm
    0U,	// MMX_PMINSWirr
    0U,	// MMX_PMINUBirm
    0U,	// MMX_PMINUBirr
    0U,	// MMX_PMOVMSKBrr
    0U,	// MMX_PMULHRSWrm
    0U,	// MMX_PMULHRSWrr
    0U,	// MMX_PMULHUWirm
    0U,	// MMX_PMULHUWirr
    0U,	// MMX_PMULHWirm
    0U,	// MMX_PMULHWirr
    0U,	// MMX_PMULLWirm
    0U,	// MMX_PMULLWirr
    0U,	// MMX_PMULUDQirm
    0U,	// MMX_PMULUDQirr
    0U,	// MMX_PORirm
    0U,	// MMX_PORirr
    0U,	// MMX_PSADBWirm
    0U,	// MMX_PSADBWirr
    0U,	// MMX_PSHUFBrm
    0U,	// MMX_PSHUFBrr
    0U,	// MMX_PSHUFWmi
    0U,	// MMX_PSHUFWri
    0U,	// MMX_PSIGNBrm
    0U,	// MMX_PSIGNBrr
    0U,	// MMX_PSIGNDrm
    0U,	// MMX_PSIGNDrr
    0U,	// MMX_PSIGNWrm
    0U,	// MMX_PSIGNWrr
    0U,	// MMX_PSLLDri
    0U,	// MMX_PSLLDrm
    0U,	// MMX_PSLLDrr
    0U,	// MMX_PSLLQri
    0U,	// MMX_PSLLQrm
    0U,	// MMX_PSLLQrr
    0U,	// MMX_PSLLWri
    0U,	// MMX_PSLLWrm
    0U,	// MMX_PSLLWrr
    0U,	// MMX_PSRADri
    0U,	// MMX_PSRADrm
    0U,	// MMX_PSRADrr
    0U,	// MMX_PSRAWri
    0U,	// MMX_PSRAWrm
    0U,	// MMX_PSRAWrr
    0U,	// MMX_PSRLDri
    0U,	// MMX_PSRLDrm
    0U,	// MMX_PSRLDrr
    0U,	// MMX_PSRLQri
    0U,	// MMX_PSRLQrm
    0U,	// MMX_PSRLQrr
    0U,	// MMX_PSRLWri
    0U,	// MMX_PSRLWrm
    0U,	// MMX_PSRLWrr
    0U,	// MMX_PSUBBirm
    0U,	// MMX_PSUBBirr
    0U,	// MMX_PSUBDirm
    0U,	// MMX_PSUBDirr
    0U,	// MMX_PSUBQirm
    0U,	// MMX_PSUBQirr
    0U,	// MMX_PSUBSBirm
    0U,	// MMX_PSUBSBirr
    0U,	// MMX_PSUBSWirm
    0U,	// MMX_PSUBSWirr
    0U,	// MMX_PSUBUSBirm
    0U,	// MMX_PSUBUSBirr
    0U,	// MMX_PSUBUSWirm
    0U,	// MMX_PSUBUSWirr
    0U,	// MMX_PSUBWirm
    0U,	// MMX_PSUBWirr
    0U,	// MMX_PUNPCKHBWirm
    0U,	// MMX_PUNPCKHBWirr
    0U,	// MMX_PUNPCKHDQirm
    0U,	// MMX_PUNPCKHDQirr
    0U,	// MMX_PUNPCKHWDirm
    0U,	// MMX_PUNPCKHWDirr
    0U,	// MMX_PUNPCKLBWirm
    0U,	// MMX_PUNPCKLBWirr
    0U,	// MMX_PUNPCKLDQirm
    0U,	// MMX_PUNPCKLDQirr
    0U,	// MMX_PUNPCKLWDirm
    0U,	// MMX_PUNPCKLWDirr
    0U,	// MMX_PXORirm
    0U,	// MMX_PXORirr
    0U,	// MONITORXrrr
    0U,	// MONITORrrr
    0U,	// MONTMUL
    0U,	// MOV16ao16
    0U,	// MOV16ao32
    0U,	// MOV16ao64
    0U,	// MOV16mi
    0U,	// MOV16mr
    0U,	// MOV16ms
    0U,	// MOV16o16a
    0U,	// MOV16o32a
    0U,	// MOV16o64a
    0U,	// MOV16ri
    0U,	// MOV16ri_alt
    0U,	// MOV16rm
    0U,	// MOV16rr
    0U,	// MOV16rr_REV
    0U,	// MOV16rs
    0U,	// MOV16sm
    0U,	// MOV16sr
    0U,	// MOV32ao16
    0U,	// MOV32ao32
    0U,	// MOV32ao64
    0U,	// MOV32cr
    0U,	// MOV32dr
    0U,	// MOV32mi
    0U,	// MOV32mr
    0U,	// MOV32o16a
    0U,	// MOV32o32a
    0U,	// MOV32o64a
    0U,	// MOV32rc
    0U,	// MOV32rd
    0U,	// MOV32ri
    0U,	// MOV32ri_alt
    0U,	// MOV32rm
    0U,	// MOV32rr
    0U,	// MOV32rr_REV
    0U,	// MOV32rs
    0U,	// MOV32sr
    0U,	// MOV64ao32
    0U,	// MOV64ao64
    0U,	// MOV64cr
    0U,	// MOV64dr
    0U,	// MOV64mi32
    0U,	// MOV64mr
    0U,	// MOV64o32a
    0U,	// MOV64o64a
    0U,	// MOV64rc
    0U,	// MOV64rd
    0U,	// MOV64ri
    0U,	// MOV64ri32
    0U,	// MOV64rm
    0U,	// MOV64rr
    0U,	// MOV64rr_REV
    0U,	// MOV64rs
    0U,	// MOV64sr
    0U,	// MOV64toPQIrm
    0U,	// MOV64toPQIrr
    0U,	// MOV64toSDrm
    0U,	// MOV64toSDrr
    0U,	// MOV8ao16
    0U,	// MOV8ao32
    0U,	// MOV8ao64
    0U,	// MOV8mi
    0U,	// MOV8mr
    0U,	// MOV8mr_NOREX
    0U,	// MOV8o16a
    0U,	// MOV8o32a
    0U,	// MOV8o64a
    0U,	// MOV8ri
    0U,	// MOV8ri_alt
    0U,	// MOV8rm
    0U,	// MOV8rm_NOREX
    0U,	// MOV8rr
    0U,	// MOV8rr_NOREX
    0U,	// MOV8rr_REV
    0U,	// MOVAPDmr
    0U,	// MOVAPDrm
    0U,	// MOVAPDrr
    0U,	// MOVAPDrr_REV
    0U,	// MOVAPSmr
    0U,	// MOVAPSrm
    0U,	// MOVAPSrr
    0U,	// MOVAPSrr_REV
    0U,	// MOVBE16mr
    0U,	// MOVBE16rm
    0U,	// MOVBE32mr
    0U,	// MOVBE32rm
    0U,	// MOVBE64mr
    0U,	// MOVBE64rm
    0U,	// MOVDDUPrm
    0U,	// MOVDDUPrr
    0U,	// MOVDI2PDIrm
    0U,	// MOVDI2PDIrr
    0U,	// MOVDI2SSrm
    0U,	// MOVDI2SSrr
    0U,	// MOVDIR64B16
    0U,	// MOVDIR64B32
    0U,	// MOVDIR64B64
    0U,	// MOVDIRI32
    0U,	// MOVDIRI64
    0U,	// MOVDQAmr
    0U,	// MOVDQArm
    0U,	// MOVDQArr
    0U,	// MOVDQArr_REV
    0U,	// MOVDQUmr
    0U,	// MOVDQUrm
    0U,	// MOVDQUrr
    0U,	// MOVDQUrr_REV
    0U,	// MOVHLPSrr
    0U,	// MOVHPDmr
    0U,	// MOVHPDrm
    0U,	// MOVHPSmr
    0U,	// MOVHPSrm
    0U,	// MOVLHPSrr
    0U,	// MOVLPDmr
    0U,	// MOVLPDrm
    0U,	// MOVLPSmr
    0U,	// MOVLPSrm
    0U,	// MOVMSKPDrr
    0U,	// MOVMSKPSrr
    0U,	// MOVNTDQArm
    0U,	// MOVNTDQmr
    0U,	// MOVNTI_64mr
    0U,	// MOVNTImr
    0U,	// MOVNTPDmr
    0U,	// MOVNTPSmr
    0U,	// MOVNTSD
    0U,	// MOVNTSS
    0U,	// MOVPDI2DImr
    0U,	// MOVPDI2DIrr
    0U,	// MOVPQI2QImr
    0U,	// MOVPQI2QIrr
    0U,	// MOVPQIto64mr
    0U,	// MOVPQIto64rr
    0U,	// MOVQI2PQIrm
    0U,	// MOVSB
    0U,	// MOVSDmr
    0U,	// MOVSDrm
    0U,	// MOVSDrr
    0U,	// MOVSDrr_REV
    0U,	// MOVSDto64mr
    0U,	// MOVSDto64rr
    0U,	// MOVSHDUPrm
    0U,	// MOVSHDUPrr
    0U,	// MOVSL
    0U,	// MOVSLDUPrm
    0U,	// MOVSLDUPrr
    0U,	// MOVSQ
    0U,	// MOVSS2DImr
    0U,	// MOVSS2DIrr
    0U,	// MOVSSmr
    0U,	// MOVSSrm
    0U,	// MOVSSrr
    0U,	// MOVSSrr_REV
    0U,	// MOVSW
    0U,	// MOVSX16rm16
    0U,	// MOVSX16rm8
    0U,	// MOVSX16rr16
    0U,	// MOVSX16rr8
    0U,	// MOVSX32rm16
    0U,	// MOVSX32rm8
    0U,	// MOVSX32rm8_NOREX
    0U,	// MOVSX32rr16
    0U,	// MOVSX32rr8
    0U,	// MOVSX32rr8_NOREX
    0U,	// MOVSX64rm16
    0U,	// MOVSX64rm32
    0U,	// MOVSX64rm8
    0U,	// MOVSX64rr16
    0U,	// MOVSX64rr32
    0U,	// MOVSX64rr8
    0U,	// MOVUPDmr
    0U,	// MOVUPDrm
    0U,	// MOVUPDrr
    0U,	// MOVUPDrr_REV
    0U,	// MOVUPSmr
    0U,	// MOVUPSrm
    0U,	// MOVUPSrr
    0U,	// MOVUPSrr_REV
    0U,	// MOVZPQILo2PQIrr
    0U,	// MOVZX16rm16
    0U,	// MOVZX16rm8
    0U,	// MOVZX16rr16
    0U,	// MOVZX16rr8
    0U,	// MOVZX32rm16
    0U,	// MOVZX32rm8
    0U,	// MOVZX32rm8_NOREX
    0U,	// MOVZX32rr16
    0U,	// MOVZX32rr8
    0U,	// MOVZX32rr8_NOREX
    0U,	// MOVZX64rm16
    0U,	// MOVZX64rm8
    0U,	// MOVZX64rr16
    0U,	// MOVZX64rr8
    0U,	// MPSADBWrmi
    0U,	// MPSADBWrri
    0U,	// MUL16m
    0U,	// MUL16r
    0U,	// MUL32m
    0U,	// MUL32r
    0U,	// MUL64m
    0U,	// MUL64r
    0U,	// MUL8m
    0U,	// MUL8r
    0U,	// MULPDrm
    0U,	// MULPDrr
    0U,	// MULPSrm
    0U,	// MULPSrr
    0U,	// MULSDrm
    0U,	// MULSDrm_Int
    0U,	// MULSDrr
    0U,	// MULSDrr_Int
    0U,	// MULSSrm
    0U,	// MULSSrm_Int
    0U,	// MULSSrr
    0U,	// MULSSrr_Int
    0U,	// MULX32rm
    0U,	// MULX32rr
    0U,	// MULX64rm
    0U,	// MULX64rr
    0U,	// MUL_F32m
    0U,	// MUL_F64m
    0U,	// MUL_FI16m
    0U,	// MUL_FI32m
    0U,	// MUL_FPrST0
    0U,	// MUL_FST0r
    0U,	// MUL_Fp32
    0U,	// MUL_Fp32m
    0U,	// MUL_Fp64
    0U,	// MUL_Fp64m
    0U,	// MUL_Fp64m32
    0U,	// MUL_Fp80
    0U,	// MUL_Fp80m32
    0U,	// MUL_Fp80m64
    0U,	// MUL_FpI16m32
    0U,	// MUL_FpI16m64
    0U,	// MUL_FpI16m80
    0U,	// MUL_FpI32m32
    0U,	// MUL_FpI32m64
    0U,	// MUL_FpI32m80
    0U,	// MUL_FrST0
    0U,	// MWAITXrrr
    0U,	// MWAITrr
    0U,	// NEG16m
    0U,	// NEG16r
    0U,	// NEG32m
    0U,	// NEG32r
    0U,	// NEG64m
    0U,	// NEG64r
    0U,	// NEG8m
    0U,	// NEG8r
    0U,	// NOOP
    0U,	// NOOP18_16m4
    0U,	// NOOP18_16m5
    0U,	// NOOP18_16m6
    0U,	// NOOP18_16m7
    0U,	// NOOP18_16r4
    0U,	// NOOP18_16r5
    0U,	// NOOP18_16r6
    0U,	// NOOP18_16r7
    0U,	// NOOP18_m4
    0U,	// NOOP18_m5
    0U,	// NOOP18_m6
    0U,	// NOOP18_m7
    0U,	// NOOP18_r4
    0U,	// NOOP18_r5
    0U,	// NOOP18_r6
    0U,	// NOOP18_r7
    0U,	// NOOP19rr
    0U,	// NOOPL
    0U,	// NOOPL_19
    0U,	// NOOPL_1d
    0U,	// NOOPL_1e
    0U,	// NOOPLr
    0U,	// NOOPQ
    0U,	// NOOPQr
    0U,	// NOOPW
    0U,	// NOOPW_19
    0U,	// NOOPW_1c
    0U,	// NOOPW_1d
    0U,	// NOOPW_1e
    0U,	// NOOPWr
    0U,	// NOT16m
    0U,	// NOT16r
    0U,	// NOT32m
    0U,	// NOT32r
    0U,	// NOT64m
    0U,	// NOT64r
    0U,	// NOT8m
    0U,	// NOT8r
    0U,	// OR16i16
    0U,	// OR16mi
    0U,	// OR16mi8
    0U,	// OR16mr
    0U,	// OR16ri
    0U,	// OR16ri8
    0U,	// OR16rm
    0U,	// OR16rr
    0U,	// OR16rr_REV
    0U,	// OR32i32
    0U,	// OR32mi
    0U,	// OR32mi8
    0U,	// OR32mr
    0U,	// OR32ri
    0U,	// OR32ri8
    0U,	// OR32rm
    0U,	// OR32rr
    0U,	// OR32rr_REV
    0U,	// OR64i32
    0U,	// OR64mi32
    0U,	// OR64mi8
    0U,	// OR64mr
    0U,	// OR64ri32
    0U,	// OR64ri8
    0U,	// OR64rm
    0U,	// OR64rr
    0U,	// OR64rr_REV
    0U,	// OR8i8
    0U,	// OR8mi
    0U,	// OR8mi8
    0U,	// OR8mr
    0U,	// OR8ri
    0U,	// OR8ri8
    0U,	// OR8rm
    0U,	// OR8rr
    0U,	// OR8rr_REV
    0U,	// ORPDrm
    0U,	// ORPDrr
    0U,	// ORPSrm
    0U,	// ORPSrr
    0U,	// OUT16ir
    0U,	// OUT16rr
    0U,	// OUT32ir
    0U,	// OUT32rr
    0U,	// OUT8ir
    0U,	// OUT8rr
    0U,	// OUTSB
    0U,	// OUTSL
    0U,	// OUTSW
    0U,	// PABSBrm
    0U,	// PABSBrr
    0U,	// PABSDrm
    0U,	// PABSDrr
    0U,	// PABSWrm
    0U,	// PABSWrr
    0U,	// PACKSSDWrm
    0U,	// PACKSSDWrr
    0U,	// PACKSSWBrm
    0U,	// PACKSSWBrr
    0U,	// PACKUSDWrm
    0U,	// PACKUSDWrr
    0U,	// PACKUSWBrm
    0U,	// PACKUSWBrr
    0U,	// PADDBrm
    0U,	// PADDBrr
    0U,	// PADDDrm
    0U,	// PADDDrr
    0U,	// PADDQrm
    0U,	// PADDQrr
    0U,	// PADDSBrm
    0U,	// PADDSBrr
    0U,	// PADDSWrm
    0U,	// PADDSWrr
    0U,	// PADDUSBrm
    0U,	// PADDUSBrr
    0U,	// PADDUSWrm
    0U,	// PADDUSWrr
    0U,	// PADDWrm
    0U,	// PADDWrr
    0U,	// PALIGNRrmi
    0U,	// PALIGNRrri
    0U,	// PANDNrm
    0U,	// PANDNrr
    0U,	// PANDrm
    0U,	// PANDrr
    0U,	// PAUSE
    0U,	// PAVGBrm
    0U,	// PAVGBrr
    0U,	// PAVGUSBrm
    0U,	// PAVGUSBrr
    0U,	// PAVGWrm
    0U,	// PAVGWrr
    0U,	// PBLENDVBrm0
    0U,	// PBLENDVBrr0
    0U,	// PBLENDWrmi
    0U,	// PBLENDWrri
    0U,	// PCLMULQDQrm
    0U,	// PCLMULQDQrr
    0U,	// PCMPEQBrm
    0U,	// PCMPEQBrr
    0U,	// PCMPEQDrm
    0U,	// PCMPEQDrr
    0U,	// PCMPEQQrm
    0U,	// PCMPEQQrr
    0U,	// PCMPEQWrm
    0U,	// PCMPEQWrr
    0U,	// PCMPESTRIrm
    0U,	// PCMPESTRIrr
    0U,	// PCMPESTRMrm
    0U,	// PCMPESTRMrr
    0U,	// PCMPGTBrm
    0U,	// PCMPGTBrr
    0U,	// PCMPGTDrm
    0U,	// PCMPGTDrr
    0U,	// PCMPGTQrm
    0U,	// PCMPGTQrr
    0U,	// PCMPGTWrm
    0U,	// PCMPGTWrr
    0U,	// PCMPISTRIrm
    0U,	// PCMPISTRIrr
    0U,	// PCMPISTRMrm
    0U,	// PCMPISTRMrr
    0U,	// PCONFIG
    0U,	// PDEP32rm
    0U,	// PDEP32rr
    0U,	// PDEP64rm
    0U,	// PDEP64rr
    0U,	// PEXT32rm
    0U,	// PEXT32rr
    0U,	// PEXT64rm
    0U,	// PEXT64rr
    0U,	// PEXTRBmr
    0U,	// PEXTRBrr
    0U,	// PEXTRDmr
    0U,	// PEXTRDrr
    0U,	// PEXTRQmr
    0U,	// PEXTRQrr
    0U,	// PEXTRWmr
    0U,	// PEXTRWrr
    0U,	// PEXTRWrr_REV
    0U,	// PF2IDrm
    0U,	// PF2IDrr
    0U,	// PF2IWrm
    0U,	// PF2IWrr
    0U,	// PFACCrm
    0U,	// PFACCrr
    0U,	// PFADDrm
    0U,	// PFADDrr
    0U,	// PFCMPEQrm
    0U,	// PFCMPEQrr
    0U,	// PFCMPGErm
    0U,	// PFCMPGErr
    0U,	// PFCMPGTrm
    0U,	// PFCMPGTrr
    0U,	// PFMAXrm
    0U,	// PFMAXrr
    0U,	// PFMINrm
    0U,	// PFMINrr
    0U,	// PFMULrm
    0U,	// PFMULrr
    0U,	// PFNACCrm
    0U,	// PFNACCrr
    0U,	// PFPNACCrm
    0U,	// PFPNACCrr
    0U,	// PFRCPIT1rm
    0U,	// PFRCPIT1rr
    0U,	// PFRCPIT2rm
    0U,	// PFRCPIT2rr
    0U,	// PFRCPrm
    0U,	// PFRCPrr
    0U,	// PFRSQIT1rm
    0U,	// PFRSQIT1rr
    0U,	// PFRSQRTrm
    0U,	// PFRSQRTrr
    0U,	// PFSUBRrm
    0U,	// PFSUBRrr
    0U,	// PFSUBrm
    0U,	// PFSUBrr
    0U,	// PHADDDrm
    0U,	// PHADDDrr
    0U,	// PHADDSWrm
    0U,	// PHADDSWrr
    0U,	// PHADDWrm
    0U,	// PHADDWrr
    0U,	// PHMINPOSUWrm
    0U,	// PHMINPOSUWrr
    0U,	// PHSUBDrm
    0U,	// PHSUBDrr
    0U,	// PHSUBSWrm
    0U,	// PHSUBSWrr
    0U,	// PHSUBWrm
    0U,	// PHSUBWrr
    0U,	// PI2FDrm
    0U,	// PI2FDrr
    0U,	// PI2FWrm
    0U,	// PI2FWrr
    0U,	// PINSRBrm
    0U,	// PINSRBrr
    0U,	// PINSRDrm
    0U,	// PINSRDrr
    0U,	// PINSRQrm
    0U,	// PINSRQrr
    0U,	// PINSRWrm
    0U,	// PINSRWrr
    0U,	// PMADDUBSWrm
    0U,	// PMADDUBSWrr
    0U,	// PMADDWDrm
    0U,	// PMADDWDrr
    0U,	// PMAXSBrm
    0U,	// PMAXSBrr
    0U,	// PMAXSDrm
    0U,	// PMAXSDrr
    0U,	// PMAXSWrm
    0U,	// PMAXSWrr
    0U,	// PMAXUBrm
    0U,	// PMAXUBrr
    0U,	// PMAXUDrm
    0U,	// PMAXUDrr
    0U,	// PMAXUWrm
    0U,	// PMAXUWrr
    0U,	// PMINSBrm
    0U,	// PMINSBrr
    0U,	// PMINSDrm
    0U,	// PMINSDrr
    0U,	// PMINSWrm
    0U,	// PMINSWrr
    0U,	// PMINUBrm
    0U,	// PMINUBrr
    0U,	// PMINUDrm
    0U,	// PMINUDrr
    0U,	// PMINUWrm
    0U,	// PMINUWrr
    0U,	// PMOVMSKBrr
    0U,	// PMOVSXBDrm
    0U,	// PMOVSXBDrr
    0U,	// PMOVSXBQrm
    0U,	// PMOVSXBQrr
    0U,	// PMOVSXBWrm
    0U,	// PMOVSXBWrr
    0U,	// PMOVSXDQrm
    0U,	// PMOVSXDQrr
    0U,	// PMOVSXWDrm
    0U,	// PMOVSXWDrr
    0U,	// PMOVSXWQrm
    0U,	// PMOVSXWQrr
    0U,	// PMOVZXBDrm
    0U,	// PMOVZXBDrr
    0U,	// PMOVZXBQrm
    0U,	// PMOVZXBQrr
    0U,	// PMOVZXBWrm
    0U,	// PMOVZXBWrr
    0U,	// PMOVZXDQrm
    0U,	// PMOVZXDQrr
    0U,	// PMOVZXWDrm
    0U,	// PMOVZXWDrr
    0U,	// PMOVZXWQrm
    0U,	// PMOVZXWQrr
    0U,	// PMULDQrm
    0U,	// PMULDQrr
    0U,	// PMULHRSWrm
    0U,	// PMULHRSWrr
    0U,	// PMULHRWrm
    0U,	// PMULHRWrr
    0U,	// PMULHUWrm
    0U,	// PMULHUWrr
    0U,	// PMULHWrm
    0U,	// PMULHWrr
    0U,	// PMULLDrm
    0U,	// PMULLDrr
    0U,	// PMULLWrm
    0U,	// PMULLWrr
    0U,	// PMULUDQrm
    0U,	// PMULUDQrr
    0U,	// POP16r
    0U,	// POP16rmm
    0U,	// POP16rmr
    0U,	// POP32r
    0U,	// POP32rmm
    0U,	// POP32rmr
    0U,	// POP64r
    0U,	// POP64rmm
    0U,	// POP64rmr
    0U,	// POPA16
    0U,	// POPA32
    0U,	// POPCNT16rm
    0U,	// POPCNT16rr
    0U,	// POPCNT32rm
    0U,	// POPCNT32rr
    0U,	// POPCNT64rm
    0U,	// POPCNT64rr
    0U,	// POPDS16
    0U,	// POPDS32
    0U,	// POPES16
    0U,	// POPES32
    0U,	// POPF16
    0U,	// POPF32
    0U,	// POPF64
    0U,	// POPFS16
    0U,	// POPFS32
    0U,	// POPFS64
    0U,	// POPGS16
    0U,	// POPGS32
    0U,	// POPGS64
    0U,	// POPSS16
    0U,	// POPSS32
    0U,	// PORrm
    0U,	// PORrr
    0U,	// PREFETCH
    0U,	// PREFETCHNTA
    0U,	// PREFETCHT0
    0U,	// PREFETCHT1
    0U,	// PREFETCHT2
    0U,	// PREFETCHW
    0U,	// PREFETCHWT1
    0U,	// PSADBWrm
    0U,	// PSADBWrr
    0U,	// PSHUFBrm
    0U,	// PSHUFBrr
    0U,	// PSHUFDmi
    0U,	// PSHUFDri
    0U,	// PSHUFHWmi
    0U,	// PSHUFHWri
    0U,	// PSHUFLWmi
    0U,	// PSHUFLWri
    0U,	// PSIGNBrm
    0U,	// PSIGNBrr
    0U,	// PSIGNDrm
    0U,	// PSIGNDrr
    0U,	// PSIGNWrm
    0U,	// PSIGNWrr
    0U,	// PSLLDQri
    0U,	// PSLLDri
    0U,	// PSLLDrm
    0U,	// PSLLDrr
    0U,	// PSLLQri
    0U,	// PSLLQrm
    0U,	// PSLLQrr
    0U,	// PSLLWri
    0U,	// PSLLWrm
    0U,	// PSLLWrr
    0U,	// PSRADri
    0U,	// PSRADrm
    0U,	// PSRADrr
    0U,	// PSRAWri
    0U,	// PSRAWrm
    0U,	// PSRAWrr
    0U,	// PSRLDQri
    0U,	// PSRLDri
    0U,	// PSRLDrm
    0U,	// PSRLDrr
    0U,	// PSRLQri
    0U,	// PSRLQrm
    0U,	// PSRLQrr
    0U,	// PSRLWri
    0U,	// PSRLWrm
    0U,	// PSRLWrr
    0U,	// PSUBBrm
    0U,	// PSUBBrr
    0U,	// PSUBDrm
    0U,	// PSUBDrr
    0U,	// PSUBQrm
    0U,	// PSUBQrr
    0U,	// PSUBSBrm
    0U,	// PSUBSBrr
    0U,	// PSUBSWrm
    0U,	// PSUBSWrr
    0U,	// PSUBUSBrm
    0U,	// PSUBUSBrr
    0U,	// PSUBUSWrm
    0U,	// PSUBUSWrr
    0U,	// PSUBWrm
    0U,	// PSUBWrr
    0U,	// PSWAPDrm
    0U,	// PSWAPDrr
    0U,	// PTESTrm
    0U,	// PTESTrr
    0U,	// PTWRITE64m
    0U,	// PTWRITE64r
    0U,	// PTWRITEm
    0U,	// PTWRITEr
    0U,	// PUNPCKHBWrm
    0U,	// PUNPCKHBWrr
    0U,	// PUNPCKHDQrm
    0U,	// PUNPCKHDQrr
    0U,	// PUNPCKHQDQrm
    0U,	// PUNPCKHQDQrr
    0U,	// PUNPCKHWDrm
    0U,	// PUNPCKHWDrr
    0U,	// PUNPCKLBWrm
    0U,	// PUNPCKLBWrr
    0U,	// PUNPCKLDQrm
    0U,	// PUNPCKLDQrr
    0U,	// PUNPCKLQDQrm
    0U,	// PUNPCKLQDQrr
    0U,	// PUNPCKLWDrm
    0U,	// PUNPCKLWDrr
    0U,	// PUSH16i8
    0U,	// PUSH16r
    0U,	// PUSH16rmm
    0U,	// PUSH16rmr
    0U,	// PUSH32i8
    0U,	// PUSH32r
    0U,	// PUSH32rmm
    0U,	// PUSH32rmr
    0U,	// PUSH64i32
    0U,	// PUSH64i8
    0U,	// PUSH64r
    0U,	// PUSH64rmm
    0U,	// PUSH64rmr
    0U,	// PUSHA16
    0U,	// PUSHA32
    0U,	// PUSHCS16
    0U,	// PUSHCS32
    0U,	// PUSHDS16
    0U,	// PUSHDS32
    0U,	// PUSHES16
    0U,	// PUSHES32
    0U,	// PUSHF16
    0U,	// PUSHF32
    0U,	// PUSHF64
    0U,	// PUSHFS16
    0U,	// PUSHFS32
    0U,	// PUSHFS64
    0U,	// PUSHGS16
    0U,	// PUSHGS32
    0U,	// PUSHGS64
    0U,	// PUSHSS16
    0U,	// PUSHSS32
    0U,	// PUSHi16
    0U,	// PUSHi32
    0U,	// PXORrm
    0U,	// PXORrr
    0U,	// RCL16m1
    0U,	// RCL16mCL
    0U,	// RCL16mi
    0U,	// RCL16r1
    0U,	// RCL16rCL
    0U,	// RCL16ri
    0U,	// RCL32m1
    0U,	// RCL32mCL
    0U,	// RCL32mi
    0U,	// RCL32r1
    0U,	// RCL32rCL
    0U,	// RCL32ri
    0U,	// RCL64m1
    0U,	// RCL64mCL
    0U,	// RCL64mi
    0U,	// RCL64r1
    0U,	// RCL64rCL
    0U,	// RCL64ri
    0U,	// RCL8m1
    0U,	// RCL8mCL
    0U,	// RCL8mi
    0U,	// RCL8r1
    0U,	// RCL8rCL
    0U,	// RCL8ri
    0U,	// RCPPSm
    0U,	// RCPPSr
    0U,	// RCPSSm
    0U,	// RCPSSm_Int
    0U,	// RCPSSr
    0U,	// RCPSSr_Int
    0U,	// RCR16m1
    0U,	// RCR16mCL
    0U,	// RCR16mi
    0U,	// RCR16r1
    0U,	// RCR16rCL
    0U,	// RCR16ri
    0U,	// RCR32m1
    0U,	// RCR32mCL
    0U,	// RCR32mi
    0U,	// RCR32r1
    0U,	// RCR32rCL
    0U,	// RCR32ri
    0U,	// RCR64m1
    0U,	// RCR64mCL
    0U,	// RCR64mi
    0U,	// RCR64r1
    0U,	// RCR64rCL
    0U,	// RCR64ri
    0U,	// RCR8m1
    0U,	// RCR8mCL
    0U,	// RCR8mi
    0U,	// RCR8r1
    0U,	// RCR8rCL
    0U,	// RCR8ri
    0U,	// RDFSBASE
    0U,	// RDFSBASE64
    0U,	// RDGSBASE
    0U,	// RDGSBASE64
    0U,	// RDMSR
    0U,	// RDPID32
    0U,	// RDPID64
    0U,	// RDPKRUr
    0U,	// RDPMC
    0U,	// RDRAND16r
    0U,	// RDRAND32r
    0U,	// RDRAND64r
    0U,	// RDSEED16r
    0U,	// RDSEED32r
    0U,	// RDSEED64r
    0U,	// RDSSPD
    0U,	// RDSSPQ
    0U,	// RDTSC
    0U,	// RDTSCP
    0U,	// REPNE_PREFIX
    0U,	// REP_PREFIX
    0U,	// RETIL
    0U,	// RETIQ
    0U,	// RETIW
    0U,	// RETL
    0U,	// RETQ
    0U,	// RETW
    0U,	// REX64_PREFIX
    0U,	// ROL16m1
    0U,	// ROL16mCL
    0U,	// ROL16mi
    0U,	// ROL16r1
    0U,	// ROL16rCL
    0U,	// ROL16ri
    0U,	// ROL32m1
    0U,	// ROL32mCL
    0U,	// ROL32mi
    0U,	// ROL32r1
    0U,	// ROL32rCL
    0U,	// ROL32ri
    0U,	// ROL64m1
    0U,	// ROL64mCL
    0U,	// ROL64mi
    0U,	// ROL64r1
    0U,	// ROL64rCL
    0U,	// ROL64ri
    0U,	// ROL8m1
    0U,	// ROL8mCL
    0U,	// ROL8mi
    0U,	// ROL8r1
    0U,	// ROL8rCL
    0U,	// ROL8ri
    0U,	// ROR16m1
    0U,	// ROR16mCL
    0U,	// ROR16mi
    0U,	// ROR16r1
    0U,	// ROR16rCL
    0U,	// ROR16ri
    0U,	// ROR32m1
    0U,	// ROR32mCL
    0U,	// ROR32mi
    0U,	// ROR32r1
    0U,	// ROR32rCL
    0U,	// ROR32ri
    0U,	// ROR64m1
    0U,	// ROR64mCL
    0U,	// ROR64mi
    0U,	// ROR64r1
    0U,	// ROR64rCL
    0U,	// ROR64ri
    0U,	// ROR8m1
    0U,	// ROR8mCL
    0U,	// ROR8mi
    0U,	// ROR8r1
    0U,	// ROR8rCL
    0U,	// ROR8ri
    0U,	// RORX32mi
    0U,	// RORX32ri
    0U,	// RORX64mi
    0U,	// RORX64ri
    0U,	// ROUNDPDm
    0U,	// ROUNDPDr
    0U,	// ROUNDPSm
    0U,	// ROUNDPSr
    0U,	// ROUNDSDm
    0U,	// ROUNDSDm_Int
    0U,	// ROUNDSDr
    0U,	// ROUNDSDr_Int
    0U,	// ROUNDSSm
    0U,	// ROUNDSSm_Int
    0U,	// ROUNDSSr
    0U,	// ROUNDSSr_Int
    0U,	// RSM
    0U,	// RSQRTPSm
    0U,	// RSQRTPSr
    0U,	// RSQRTSSm
    0U,	// RSQRTSSm_Int
    0U,	// RSQRTSSr
    0U,	// RSQRTSSr_Int
    0U,	// RSTORSSP
    0U,	// SAHF
    0U,	// SAL16m1
    0U,	// SAL16mCL
    0U,	// SAL16mi
    0U,	// SAL16r1
    0U,	// SAL16rCL
    0U,	// SAL16ri
    0U,	// SAL32m1
    0U,	// SAL32mCL
    0U,	// SAL32mi
    0U,	// SAL32r1
    0U,	// SAL32rCL
    0U,	// SAL32ri
    0U,	// SAL64m1
    0U,	// SAL64mCL
    0U,	// SAL64mi
    0U,	// SAL64r1
    0U,	// SAL64rCL
    0U,	// SAL64ri
    0U,	// SAL8m1
    0U,	// SAL8mCL
    0U,	// SAL8mi
    0U,	// SAL8r1
    0U,	// SAL8rCL
    0U,	// SAL8ri
    0U,	// SALC
    0U,	// SAR16m1
    0U,	// SAR16mCL
    0U,	// SAR16mi
    0U,	// SAR16r1
    0U,	// SAR16rCL
    0U,	// SAR16ri
    0U,	// SAR32m1
    0U,	// SAR32mCL
    0U,	// SAR32mi
    0U,	// SAR32r1
    0U,	// SAR32rCL
    0U,	// SAR32ri
    0U,	// SAR64m1
    0U,	// SAR64mCL
    0U,	// SAR64mi
    0U,	// SAR64r1
    0U,	// SAR64rCL
    0U,	// SAR64ri
    0U,	// SAR8m1
    0U,	// SAR8mCL
    0U,	// SAR8mi
    0U,	// SAR8r1
    0U,	// SAR8rCL
    0U,	// SAR8ri
    0U,	// SARX32rm
    0U,	// SARX32rr
    0U,	// SARX64rm
    0U,	// SARX64rr
    0U,	// SAVEPREVSSP
    0U,	// SBB16i16
    0U,	// SBB16mi
    0U,	// SBB16mi8
    0U,	// SBB16mr
    0U,	// SBB16ri
    0U,	// SBB16ri8
    0U,	// SBB16rm
    0U,	// SBB16rr
    0U,	// SBB16rr_REV
    0U,	// SBB32i32
    0U,	// SBB32mi
    0U,	// SBB32mi8
    0U,	// SBB32mr
    0U,	// SBB32ri
    0U,	// SBB32ri8
    0U,	// SBB32rm
    0U,	// SBB32rr
    0U,	// SBB32rr_REV
    0U,	// SBB64i32
    0U,	// SBB64mi32
    0U,	// SBB64mi8
    0U,	// SBB64mr
    0U,	// SBB64ri32
    0U,	// SBB64ri8
    0U,	// SBB64rm
    0U,	// SBB64rr
    0U,	// SBB64rr_REV
    0U,	// SBB8i8
    0U,	// SBB8mi
    0U,	// SBB8mi8
    0U,	// SBB8mr
    0U,	// SBB8ri
    0U,	// SBB8ri8
    0U,	// SBB8rm
    0U,	// SBB8rr
    0U,	// SBB8rr_REV
    0U,	// SCASB
    0U,	// SCASL
    0U,	// SCASQ
    0U,	// SCASW
    0U,	// SETAEm
    0U,	// SETAEr
    0U,	// SETAm
    0U,	// SETAr
    0U,	// SETBEm
    0U,	// SETBEr
    0U,	// SETBm
    0U,	// SETBr
    0U,	// SETEm
    0U,	// SETEr
    0U,	// SETGEm
    0U,	// SETGEr
    0U,	// SETGm
    0U,	// SETGr
    0U,	// SETLEm
    0U,	// SETLEr
    0U,	// SETLm
    0U,	// SETLr
    0U,	// SETNEm
    0U,	// SETNEr
    0U,	// SETNOm
    0U,	// SETNOr
    0U,	// SETNPm
    0U,	// SETNPr
    0U,	// SETNSm
    0U,	// SETNSr
    0U,	// SETOm
    0U,	// SETOr
    0U,	// SETPm
    0U,	// SETPr
    0U,	// SETSSBSY
    0U,	// SETSm
    0U,	// SETSr
    0U,	// SFENCE
    0U,	// SGDT16m
    0U,	// SGDT32m
    0U,	// SGDT64m
    0U,	// SHA1MSG1rm
    0U,	// SHA1MSG1rr
    0U,	// SHA1MSG2rm
    0U,	// SHA1MSG2rr
    0U,	// SHA1NEXTErm
    0U,	// SHA1NEXTErr
    0U,	// SHA1RNDS4rmi
    0U,	// SHA1RNDS4rri
    0U,	// SHA256MSG1rm
    0U,	// SHA256MSG1rr
    0U,	// SHA256MSG2rm
    0U,	// SHA256MSG2rr
    0U,	// SHA256RNDS2rm
    0U,	// SHA256RNDS2rr
    0U,	// SHL16m1
    0U,	// SHL16mCL
    0U,	// SHL16mi
    0U,	// SHL16r1
    0U,	// SHL16rCL
    0U,	// SHL16ri
    0U,	// SHL32m1
    0U,	// SHL32mCL
    0U,	// SHL32mi
    0U,	// SHL32r1
    0U,	// SHL32rCL
    0U,	// SHL32ri
    0U,	// SHL64m1
    0U,	// SHL64mCL
    0U,	// SHL64mi
    0U,	// SHL64r1
    0U,	// SHL64rCL
    0U,	// SHL64ri
    0U,	// SHL8m1
    0U,	// SHL8mCL
    0U,	// SHL8mi
    0U,	// SHL8r1
    0U,	// SHL8rCL
    0U,	// SHL8ri
    0U,	// SHLD16mrCL
    0U,	// SHLD16mri8
    0U,	// SHLD16rrCL
    0U,	// SHLD16rri8
    0U,	// SHLD32mrCL
    0U,	// SHLD32mri8
    0U,	// SHLD32rrCL
    0U,	// SHLD32rri8
    0U,	// SHLD64mrCL
    0U,	// SHLD64mri8
    0U,	// SHLD64rrCL
    0U,	// SHLD64rri8
    0U,	// SHLX32rm
    0U,	// SHLX32rr
    0U,	// SHLX64rm
    0U,	// SHLX64rr
    0U,	// SHR16m1
    0U,	// SHR16mCL
    0U,	// SHR16mi
    0U,	// SHR16r1
    0U,	// SHR16rCL
    0U,	// SHR16ri
    0U,	// SHR32m1
    0U,	// SHR32mCL
    0U,	// SHR32mi
    0U,	// SHR32r1
    0U,	// SHR32rCL
    0U,	// SHR32ri
    0U,	// SHR64m1
    0U,	// SHR64mCL
    0U,	// SHR64mi
    0U,	// SHR64r1
    0U,	// SHR64rCL
    0U,	// SHR64ri
    0U,	// SHR8m1
    0U,	// SHR8mCL
    0U,	// SHR8mi
    0U,	// SHR8r1
    0U,	// SHR8rCL
    0U,	// SHR8ri
    0U,	// SHRD16mrCL
    0U,	// SHRD16mri8
    0U,	// SHRD16rrCL
    0U,	// SHRD16rri8
    0U,	// SHRD32mrCL
    0U,	// SHRD32mri8
    0U,	// SHRD32rrCL
    0U,	// SHRD32rri8
    0U,	// SHRD64mrCL
    0U,	// SHRD64mri8
    0U,	// SHRD64rrCL
    0U,	// SHRD64rri8
    0U,	// SHRX32rm
    0U,	// SHRX32rr
    0U,	// SHRX64rm
    0U,	// SHRX64rr
    0U,	// SHUFPDrmi
    0U,	// SHUFPDrri
    0U,	// SHUFPSrmi
    0U,	// SHUFPSrri
    0U,	// SIDT16m
    0U,	// SIDT32m
    0U,	// SIDT64m
    0U,	// SIN_F
    0U,	// SIN_Fp32
    0U,	// SIN_Fp64
    0U,	// SIN_Fp80
    0U,	// SKINIT
    0U,	// SLDT16m
    0U,	// SLDT16r
    0U,	// SLDT32r
    0U,	// SLDT64r
    0U,	// SLWPCB
    0U,	// SLWPCB64
    0U,	// SMSW16m
    0U,	// SMSW16r
    0U,	// SMSW32r
    0U,	// SMSW64r
    0U,	// SQRTPDm
    0U,	// SQRTPDr
    0U,	// SQRTPSm
    0U,	// SQRTPSr
    0U,	// SQRTSDm
    0U,	// SQRTSDm_Int
    0U,	// SQRTSDr
    0U,	// SQRTSDr_Int
    0U,	// SQRTSSm
    0U,	// SQRTSSm_Int
    0U,	// SQRTSSr
    0U,	// SQRTSSr_Int
    0U,	// SQRT_F
    0U,	// SQRT_Fp32
    0U,	// SQRT_Fp64
    0U,	// SQRT_Fp80
    0U,	// STAC
    0U,	// STC
    0U,	// STD
    0U,	// STGI
    0U,	// STI
    0U,	// STMXCSR
    0U,	// STOSB
    0U,	// STOSL
    0U,	// STOSQ
    0U,	// STOSW
    0U,	// STR16r
    0U,	// STR32r
    0U,	// STR64r
    0U,	// STRm
    0U,	// ST_F32m
    0U,	// ST_F64m
    0U,	// ST_FP32m
    0U,	// ST_FP64m
    0U,	// ST_FP80m
    0U,	// ST_FPrr
    0U,	// ST_Fp32m
    0U,	// ST_Fp64m
    0U,	// ST_Fp64m32
    0U,	// ST_Fp80m32
    0U,	// ST_Fp80m64
    0U,	// ST_FpP32m
    0U,	// ST_FpP64m
    0U,	// ST_FpP64m32
    0U,	// ST_FpP80m
    0U,	// ST_FpP80m32
    0U,	// ST_FpP80m64
    0U,	// ST_Frr
    0U,	// SUB16i16
    0U,	// SUB16mi
    0U,	// SUB16mi8
    0U,	// SUB16mr
    0U,	// SUB16ri
    0U,	// SUB16ri8
    0U,	// SUB16rm
    0U,	// SUB16rr
    0U,	// SUB16rr_REV
    0U,	// SUB32i32
    0U,	// SUB32mi
    0U,	// SUB32mi8
    0U,	// SUB32mr
    0U,	// SUB32ri
    0U,	// SUB32ri8
    0U,	// SUB32rm
    0U,	// SUB32rr
    0U,	// SUB32rr_REV
    0U,	// SUB64i32
    0U,	// SUB64mi32
    0U,	// SUB64mi8
    0U,	// SUB64mr
    0U,	// SUB64ri32
    0U,	// SUB64ri8
    0U,	// SUB64rm
    0U,	// SUB64rr
    0U,	// SUB64rr_REV
    0U,	// SUB8i8
    0U,	// SUB8mi
    0U,	// SUB8mi8
    0U,	// SUB8mr
    0U,	// SUB8ri
    0U,	// SUB8ri8
    0U,	// SUB8rm
    0U,	// SUB8rr
    0U,	// SUB8rr_REV
    0U,	// SUBPDrm
    0U,	// SUBPDrr
    0U,	// SUBPSrm
    0U,	// SUBPSrr
    0U,	// SUBR_F32m
    0U,	// SUBR_F64m
    0U,	// SUBR_FI16m
    0U,	// SUBR_FI32m
    0U,	// SUBR_FPrST0
    0U,	// SUBR_FST0r
    0U,	// SUBR_Fp32m
    0U,	// SUBR_Fp64m
    0U,	// SUBR_Fp64m32
    0U,	// SUBR_Fp80m32
    0U,	// SUBR_Fp80m64
    0U,	// SUBR_FpI16m32
    0U,	// SUBR_FpI16m64
    0U,	// SUBR_FpI16m80
    0U,	// SUBR_FpI32m32
    0U,	// SUBR_FpI32m64
    0U,	// SUBR_FpI32m80
    0U,	// SUBR_FrST0
    0U,	// SUBSDrm
    0U,	// SUBSDrm_Int
    0U,	// SUBSDrr
    0U,	// SUBSDrr_Int
    0U,	// SUBSSrm
    0U,	// SUBSSrm_Int
    0U,	// SUBSSrr
    0U,	// SUBSSrr_Int
    0U,	// SUB_F32m
    0U,	// SUB_F64m
    0U,	// SUB_FI16m
    0U,	// SUB_FI32m
    0U,	// SUB_FPrST0
    0U,	// SUB_FST0r
    0U,	// SUB_Fp32
    0U,	// SUB_Fp32m
    0U,	// SUB_Fp64
    0U,	// SUB_Fp64m
    0U,	// SUB_Fp64m32
    0U,	// SUB_Fp80
    0U,	// SUB_Fp80m32
    0U,	// SUB_Fp80m64
    0U,	// SUB_FpI16m32
    0U,	// SUB_FpI16m64
    0U,	// SUB_FpI16m80
    0U,	// SUB_FpI32m32
    0U,	// SUB_FpI32m64
    0U,	// SUB_FpI32m80
    0U,	// SUB_FrST0
    0U,	// SWAPGS
    0U,	// SYSCALL
    0U,	// SYSENTER
    0U,	// SYSEXIT
    0U,	// SYSEXIT64
    0U,	// SYSRET
    0U,	// SYSRET64
    0U,	// T1MSKC32rm
    0U,	// T1MSKC32rr
    0U,	// T1MSKC64rm
    0U,	// T1MSKC64rr
    0U,	// TEST16i16
    0U,	// TEST16mi
    0U,	// TEST16mi_alt
    0U,	// TEST16mr
    0U,	// TEST16ri
    0U,	// TEST16ri_alt
    0U,	// TEST16rr
    0U,	// TEST32i32
    0U,	// TEST32mi
    0U,	// TEST32mi_alt
    0U,	// TEST32mr
    0U,	// TEST32ri
    0U,	// TEST32ri_alt
    0U,	// TEST32rr
    0U,	// TEST64i32
    0U,	// TEST64mi32
    0U,	// TEST64mi32_alt
    0U,	// TEST64mr
    0U,	// TEST64ri32
    0U,	// TEST64ri32_alt
    0U,	// TEST64rr
    0U,	// TEST8i8
    0U,	// TEST8mi
    0U,	// TEST8mi_alt
    0U,	// TEST8mr
    0U,	// TEST8ri
    0U,	// TEST8ri_alt
    0U,	// TEST8rr
    0U,	// TPAUSE
    0U,	// TST_F
    0U,	// TST_Fp32
    0U,	// TST_Fp64
    0U,	// TST_Fp80
    0U,	// TZCNT16rm
    0U,	// TZCNT16rr
    0U,	// TZCNT32rm
    0U,	// TZCNT32rr
    0U,	// TZCNT64rm
    0U,	// TZCNT64rr
    0U,	// TZMSK32rm
    0U,	// TZMSK32rr
    0U,	// TZMSK64rm
    0U,	// TZMSK64rr
    0U,	// UCOMISDrm
    0U,	// UCOMISDrm_Int
    0U,	// UCOMISDrr
    0U,	// UCOMISDrr_Int
    0U,	// UCOMISSrm
    0U,	// UCOMISSrm_Int
    0U,	// UCOMISSrr
    0U,	// UCOMISSrr_Int
    0U,	// UCOM_FIPr
    0U,	// UCOM_FIr
    0U,	// UCOM_FPPr
    0U,	// UCOM_FPr
    0U,	// UCOM_FpIr32
    0U,	// UCOM_FpIr64
    0U,	// UCOM_FpIr80
    0U,	// UCOM_Fpr32
    0U,	// UCOM_Fpr64
    0U,	// UCOM_Fpr80
    0U,	// UCOM_Fr
    0U,	// UD0
    0U,	// UD1
    0U,	// UD2
    0U,	// UMONITOR16
    0U,	// UMONITOR32
    0U,	// UMONITOR64
    0U,	// UMWAIT
    0U,	// UNPCKHPDrm
    0U,	// UNPCKHPDrr
    0U,	// UNPCKHPSrm
    0U,	// UNPCKHPSrr
    0U,	// UNPCKLPDrm
    0U,	// UNPCKLPDrr
    0U,	// UNPCKLPSrm
    0U,	// UNPCKLPSrr
    0U,	// V4FMADDPSrm
    0U,	// V4FMADDPSrmk
    0U,	// V4FMADDPSrmkz
    0U,	// V4FMADDSSrm
    0U,	// V4FMADDSSrmk
    0U,	// V4FMADDSSrmkz
    0U,	// V4FNMADDPSrm
    0U,	// V4FNMADDPSrmk
    0U,	// V4FNMADDPSrmkz
    0U,	// V4FNMADDSSrm
    0U,	// V4FNMADDSSrmk
    0U,	// V4FNMADDSSrmkz
    0U,	// VADDPDYrm
    0U,	// VADDPDYrr
    0U,	// VADDPDZ128rm
    0U,	// VADDPDZ128rmb
    0U,	// VADDPDZ128rmbk
    0U,	// VADDPDZ128rmbkz
    0U,	// VADDPDZ128rmk
    0U,	// VADDPDZ128rmkz
    0U,	// VADDPDZ128rr
    0U,	// VADDPDZ128rrk
    0U,	// VADDPDZ128rrkz
    0U,	// VADDPDZ256rm
    0U,	// VADDPDZ256rmb
    0U,	// VADDPDZ256rmbk
    0U,	// VADDPDZ256rmbkz
    0U,	// VADDPDZ256rmk
    0U,	// VADDPDZ256rmkz
    0U,	// VADDPDZ256rr
    0U,	// VADDPDZ256rrk
    0U,	// VADDPDZ256rrkz
    0U,	// VADDPDZrm
    0U,	// VADDPDZrmb
    0U,	// VADDPDZrmbk
    0U,	// VADDPDZrmbkz
    0U,	// VADDPDZrmk
    0U,	// VADDPDZrmkz
    0U,	// VADDPDZrr
    0U,	// VADDPDZrrb
    0U,	// VADDPDZrrbk
    0U,	// VADDPDZrrbkz
    0U,	// VADDPDZrrk
    0U,	// VADDPDZrrkz
    0U,	// VADDPDrm
    0U,	// VADDPDrr
    0U,	// VADDPSYrm
    0U,	// VADDPSYrr
    0U,	// VADDPSZ128rm
    0U,	// VADDPSZ128rmb
    0U,	// VADDPSZ128rmbk
    0U,	// VADDPSZ128rmbkz
    0U,	// VADDPSZ128rmk
    0U,	// VADDPSZ128rmkz
    0U,	// VADDPSZ128rr
    0U,	// VADDPSZ128rrk
    0U,	// VADDPSZ128rrkz
    0U,	// VADDPSZ256rm
    0U,	// VADDPSZ256rmb
    0U,	// VADDPSZ256rmbk
    0U,	// VADDPSZ256rmbkz
    0U,	// VADDPSZ256rmk
    0U,	// VADDPSZ256rmkz
    0U,	// VADDPSZ256rr
    0U,	// VADDPSZ256rrk
    0U,	// VADDPSZ256rrkz
    0U,	// VADDPSZrm
    0U,	// VADDPSZrmb
    0U,	// VADDPSZrmbk
    0U,	// VADDPSZrmbkz
    0U,	// VADDPSZrmk
    0U,	// VADDPSZrmkz
    0U,	// VADDPSZrr
    0U,	// VADDPSZrrb
    0U,	// VADDPSZrrbk
    0U,	// VADDPSZrrbkz
    0U,	// VADDPSZrrk
    0U,	// VADDPSZrrkz
    0U,	// VADDPSrm
    0U,	// VADDPSrr
    0U,	// VADDSDZrm
    0U,	// VADDSDZrm_Int
    0U,	// VADDSDZrm_Intk
    0U,	// VADDSDZrm_Intkz
    0U,	// VADDSDZrr
    0U,	// VADDSDZrr_Int
    0U,	// VADDSDZrr_Intk
    0U,	// VADDSDZrr_Intkz
    0U,	// VADDSDZrrb_Int
    0U,	// VADDSDZrrb_Intk
    0U,	// VADDSDZrrb_Intkz
    0U,	// VADDSDrm
    0U,	// VADDSDrm_Int
    0U,	// VADDSDrr
    0U,	// VADDSDrr_Int
    0U,	// VADDSSZrm
    0U,	// VADDSSZrm_Int
    0U,	// VADDSSZrm_Intk
    0U,	// VADDSSZrm_Intkz
    0U,	// VADDSSZrr
    0U,	// VADDSSZrr_Int
    0U,	// VADDSSZrr_Intk
    0U,	// VADDSSZrr_Intkz
    0U,	// VADDSSZrrb_Int
    0U,	// VADDSSZrrb_Intk
    0U,	// VADDSSZrrb_Intkz
    0U,	// VADDSSrm
    0U,	// VADDSSrm_Int
    0U,	// VADDSSrr
    0U,	// VADDSSrr_Int
    0U,	// VADDSUBPDYrm
    0U,	// VADDSUBPDYrr
    0U,	// VADDSUBPDrm
    0U,	// VADDSUBPDrr
    0U,	// VADDSUBPSYrm
    0U,	// VADDSUBPSYrr
    0U,	// VADDSUBPSrm
    0U,	// VADDSUBPSrr
    0U,	// VAESDECLASTYrm
    0U,	// VAESDECLASTYrr
    0U,	// VAESDECLASTZ128rm
    0U,	// VAESDECLASTZ128rr
    0U,	// VAESDECLASTZ256rm
    0U,	// VAESDECLASTZ256rr
    0U,	// VAESDECLASTZrm
    0U,	// VAESDECLASTZrr
    0U,	// VAESDECLASTrm
    0U,	// VAESDECLASTrr
    0U,	// VAESDECYrm
    0U,	// VAESDECYrr
    0U,	// VAESDECZ128rm
    0U,	// VAESDECZ128rr
    0U,	// VAESDECZ256rm
    0U,	// VAESDECZ256rr
    0U,	// VAESDECZrm
    0U,	// VAESDECZrr
    0U,	// VAESDECrm
    0U,	// VAESDECrr
    0U,	// VAESENCLASTYrm
    0U,	// VAESENCLASTYrr
    0U,	// VAESENCLASTZ128rm
    0U,	// VAESENCLASTZ128rr
    0U,	// VAESENCLASTZ256rm
    0U,	// VAESENCLASTZ256rr
    0U,	// VAESENCLASTZrm
    0U,	// VAESENCLASTZrr
    0U,	// VAESENCLASTrm
    0U,	// VAESENCLASTrr
    0U,	// VAESENCYrm
    0U,	// VAESENCYrr
    0U,	// VAESENCZ128rm
    0U,	// VAESENCZ128rr
    0U,	// VAESENCZ256rm
    0U,	// VAESENCZ256rr
    0U,	// VAESENCZrm
    0U,	// VAESENCZrr
    0U,	// VAESENCrm
    0U,	// VAESENCrr
    0U,	// VAESIMCrm
    0U,	// VAESIMCrr
    0U,	// VAESKEYGENASSIST128rm
    0U,	// VAESKEYGENASSIST128rr
    0U,	// VALIGNDZ128rmbi
    0U,	// VALIGNDZ128rmbik
    3U,	// VALIGNDZ128rmbikz
    0U,	// VALIGNDZ128rmi
    0U,	// VALIGNDZ128rmik
    0U,	// VALIGNDZ128rmikz
    0U,	// VALIGNDZ128rri
    0U,	// VALIGNDZ128rrik
    3U,	// VALIGNDZ128rrikz
    0U,	// VALIGNDZ256rmbi
    0U,	// VALIGNDZ256rmbik
    3U,	// VALIGNDZ256rmbikz
    0U,	// VALIGNDZ256rmi
    0U,	// VALIGNDZ256rmik
    0U,	// VALIGNDZ256rmikz
    0U,	// VALIGNDZ256rri
    0U,	// VALIGNDZ256rrik
    3U,	// VALIGNDZ256rrikz
    0U,	// VALIGNDZrmbi
    0U,	// VALIGNDZrmbik
    3U,	// VALIGNDZrmbikz
    0U,	// VALIGNDZrmi
    0U,	// VALIGNDZrmik
    0U,	// VALIGNDZrmikz
    0U,	// VALIGNDZrri
    0U,	// VALIGNDZrrik
    3U,	// VALIGNDZrrikz
    0U,	// VALIGNQZ128rmbi
    0U,	// VALIGNQZ128rmbik
    3U,	// VALIGNQZ128rmbikz
    0U,	// VALIGNQZ128rmi
    0U,	// VALIGNQZ128rmik
    0U,	// VALIGNQZ128rmikz
    0U,	// VALIGNQZ128rri
    0U,	// VALIGNQZ128rrik
    3U,	// VALIGNQZ128rrikz
    0U,	// VALIGNQZ256rmbi
    0U,	// VALIGNQZ256rmbik
    3U,	// VALIGNQZ256rmbikz
    0U,	// VALIGNQZ256rmi
    0U,	// VALIGNQZ256rmik
    0U,	// VALIGNQZ256rmikz
    0U,	// VALIGNQZ256rri
    0U,	// VALIGNQZ256rrik
    3U,	// VALIGNQZ256rrikz
    0U,	// VALIGNQZrmbi
    0U,	// VALIGNQZrmbik
    3U,	// VALIGNQZrmbikz
    0U,	// VALIGNQZrmi
    0U,	// VALIGNQZrmik
    0U,	// VALIGNQZrmikz
    0U,	// VALIGNQZrri
    0U,	// VALIGNQZrrik
    3U,	// VALIGNQZrrikz
    0U,	// VANDNPDYrm
    0U,	// VANDNPDYrr
    0U,	// VANDNPDZ128rm
    0U,	// VANDNPDZ128rmb
    0U,	// VANDNPDZ128rmbk
    0U,	// VANDNPDZ128rmbkz
    0U,	// VANDNPDZ128rmk
    0U,	// VANDNPDZ128rmkz
    0U,	// VANDNPDZ128rr
    0U,	// VANDNPDZ128rrk
    0U,	// VANDNPDZ128rrkz
    0U,	// VANDNPDZ256rm
    0U,	// VANDNPDZ256rmb
    0U,	// VANDNPDZ256rmbk
    0U,	// VANDNPDZ256rmbkz
    0U,	// VANDNPDZ256rmk
    0U,	// VANDNPDZ256rmkz
    0U,	// VANDNPDZ256rr
    0U,	// VANDNPDZ256rrk
    0U,	// VANDNPDZ256rrkz
    0U,	// VANDNPDZrm
    0U,	// VANDNPDZrmb
    0U,	// VANDNPDZrmbk
    0U,	// VANDNPDZrmbkz
    0U,	// VANDNPDZrmk
    0U,	// VANDNPDZrmkz
    0U,	// VANDNPDZrr
    0U,	// VANDNPDZrrk
    0U,	// VANDNPDZrrkz
    0U,	// VANDNPDrm
    0U,	// VANDNPDrr
    0U,	// VANDNPSYrm
    0U,	// VANDNPSYrr
    0U,	// VANDNPSZ128rm
    0U,	// VANDNPSZ128rmb
    0U,	// VANDNPSZ128rmbk
    0U,	// VANDNPSZ128rmbkz
    0U,	// VANDNPSZ128rmk
    0U,	// VANDNPSZ128rmkz
    0U,	// VANDNPSZ128rr
    0U,	// VANDNPSZ128rrk
    0U,	// VANDNPSZ128rrkz
    0U,	// VANDNPSZ256rm
    0U,	// VANDNPSZ256rmb
    0U,	// VANDNPSZ256rmbk
    0U,	// VANDNPSZ256rmbkz
    0U,	// VANDNPSZ256rmk
    0U,	// VANDNPSZ256rmkz
    0U,	// VANDNPSZ256rr
    0U,	// VANDNPSZ256rrk
    0U,	// VANDNPSZ256rrkz
    0U,	// VANDNPSZrm
    0U,	// VANDNPSZrmb
    0U,	// VANDNPSZrmbk
    0U,	// VANDNPSZrmbkz
    0U,	// VANDNPSZrmk
    0U,	// VANDNPSZrmkz
    0U,	// VANDNPSZrr
    0U,	// VANDNPSZrrk
    0U,	// VANDNPSZrrkz
    0U,	// VANDNPSrm
    0U,	// VANDNPSrr
    0U,	// VANDPDYrm
    0U,	// VANDPDYrr
    0U,	// VANDPDZ128rm
    0U,	// VANDPDZ128rmb
    0U,	// VANDPDZ128rmbk
    0U,	// VANDPDZ128rmbkz
    0U,	// VANDPDZ128rmk
    0U,	// VANDPDZ128rmkz
    0U,	// VANDPDZ128rr
    0U,	// VANDPDZ128rrk
    0U,	// VANDPDZ128rrkz
    0U,	// VANDPDZ256rm
    0U,	// VANDPDZ256rmb
    0U,	// VANDPDZ256rmbk
    0U,	// VANDPDZ256rmbkz
    0U,	// VANDPDZ256rmk
    0U,	// VANDPDZ256rmkz
    0U,	// VANDPDZ256rr
    0U,	// VANDPDZ256rrk
    0U,	// VANDPDZ256rrkz
    0U,	// VANDPDZrm
    0U,	// VANDPDZrmb
    0U,	// VANDPDZrmbk
    0U,	// VANDPDZrmbkz
    0U,	// VANDPDZrmk
    0U,	// VANDPDZrmkz
    0U,	// VANDPDZrr
    0U,	// VANDPDZrrk
    0U,	// VANDPDZrrkz
    0U,	// VANDPDrm
    0U,	// VANDPDrr
    0U,	// VANDPSYrm
    0U,	// VANDPSYrr
    0U,	// VANDPSZ128rm
    0U,	// VANDPSZ128rmb
    0U,	// VANDPSZ128rmbk
    0U,	// VANDPSZ128rmbkz
    0U,	// VANDPSZ128rmk
    0U,	// VANDPSZ128rmkz
    0U,	// VANDPSZ128rr
    0U,	// VANDPSZ128rrk
    0U,	// VANDPSZ128rrkz
    0U,	// VANDPSZ256rm
    0U,	// VANDPSZ256rmb
    0U,	// VANDPSZ256rmbk
    0U,	// VANDPSZ256rmbkz
    0U,	// VANDPSZ256rmk
    0U,	// VANDPSZ256rmkz
    0U,	// VANDPSZ256rr
    0U,	// VANDPSZ256rrk
    0U,	// VANDPSZ256rrkz
    0U,	// VANDPSZrm
    0U,	// VANDPSZrmb
    0U,	// VANDPSZrmbk
    0U,	// VANDPSZrmbkz
    0U,	// VANDPSZrmk
    0U,	// VANDPSZrmkz
    0U,	// VANDPSZrr
    0U,	// VANDPSZrrk
    0U,	// VANDPSZrrkz
    0U,	// VANDPSrm
    0U,	// VANDPSrr
    0U,	// VBLENDMPDZ128rm
    0U,	// VBLENDMPDZ128rmb
    0U,	// VBLENDMPDZ128rmbk
    0U,	// VBLENDMPDZ128rmbkz
    0U,	// VBLENDMPDZ128rmk
    0U,	// VBLENDMPDZ128rmkz
    0U,	// VBLENDMPDZ128rr
    0U,	// VBLENDMPDZ128rrk
    0U,	// VBLENDMPDZ128rrkz
    0U,	// VBLENDMPDZ256rm
    0U,	// VBLENDMPDZ256rmb
    0U,	// VBLENDMPDZ256rmbk
    0U,	// VBLENDMPDZ256rmbkz
    0U,	// VBLENDMPDZ256rmk
    0U,	// VBLENDMPDZ256rmkz
    0U,	// VBLENDMPDZ256rr
    0U,	// VBLENDMPDZ256rrk
    0U,	// VBLENDMPDZ256rrkz
    0U,	// VBLENDMPDZrm
    0U,	// VBLENDMPDZrmb
    0U,	// VBLENDMPDZrmbk
    0U,	// VBLENDMPDZrmbkz
    0U,	// VBLENDMPDZrmk
    0U,	// VBLENDMPDZrmkz
    0U,	// VBLENDMPDZrr
    0U,	// VBLENDMPDZrrk
    0U,	// VBLENDMPDZrrkz
    0U,	// VBLENDMPSZ128rm
    0U,	// VBLENDMPSZ128rmb
    0U,	// VBLENDMPSZ128rmbk
    0U,	// VBLENDMPSZ128rmbkz
    0U,	// VBLENDMPSZ128rmk
    0U,	// VBLENDMPSZ128rmkz
    0U,	// VBLENDMPSZ128rr
    0U,	// VBLENDMPSZ128rrk
    0U,	// VBLENDMPSZ128rrkz
    0U,	// VBLENDMPSZ256rm
    0U,	// VBLENDMPSZ256rmb
    0U,	// VBLENDMPSZ256rmbk
    0U,	// VBLENDMPSZ256rmbkz
    0U,	// VBLENDMPSZ256rmk
    0U,	// VBLENDMPSZ256rmkz
    0U,	// VBLENDMPSZ256rr
    0U,	// VBLENDMPSZ256rrk
    0U,	// VBLENDMPSZ256rrkz
    0U,	// VBLENDMPSZrm
    0U,	// VBLENDMPSZrmb
    0U,	// VBLENDMPSZrmbk
    0U,	// VBLENDMPSZrmbkz
    0U,	// VBLENDMPSZrmk
    0U,	// VBLENDMPSZrmkz
    0U,	// VBLENDMPSZrr
    0U,	// VBLENDMPSZrrk
    0U,	// VBLENDMPSZrrkz
    0U,	// VBLENDPDYrmi
    0U,	// VBLENDPDYrri
    0U,	// VBLENDPDrmi
    0U,	// VBLENDPDrri
    0U,	// VBLENDPSYrmi
    0U,	// VBLENDPSYrri
    0U,	// VBLENDPSrmi
    0U,	// VBLENDPSrri
    0U,	// VBLENDVPDYrm
    0U,	// VBLENDVPDYrr
    0U,	// VBLENDVPDrm
    0U,	// VBLENDVPDrr
    0U,	// VBLENDVPSYrm
    0U,	// VBLENDVPSYrr
    0U,	// VBLENDVPSrm
    0U,	// VBLENDVPSrr
    0U,	// VBROADCASTF128
    0U,	// VBROADCASTF32X2Z256m
    0U,	// VBROADCASTF32X2Z256mk
    0U,	// VBROADCASTF32X2Z256mkz
    0U,	// VBROADCASTF32X2Z256r
    0U,	// VBROADCASTF32X2Z256rk
    0U,	// VBROADCASTF32X2Z256rkz
    0U,	// VBROADCASTF32X2Zm
    0U,	// VBROADCASTF32X2Zmk
    0U,	// VBROADCASTF32X2Zmkz
    0U,	// VBROADCASTF32X2Zr
    0U,	// VBROADCASTF32X2Zrk
    0U,	// VBROADCASTF32X2Zrkz
    0U,	// VBROADCASTF32X4Z256rm
    0U,	// VBROADCASTF32X4Z256rmk
    0U,	// VBROADCASTF32X4Z256rmkz
    0U,	// VBROADCASTF32X4rm
    0U,	// VBROADCASTF32X4rmk
    0U,	// VBROADCASTF32X4rmkz
    0U,	// VBROADCASTF32X8rm
    0U,	// VBROADCASTF32X8rmk
    0U,	// VBROADCASTF32X8rmkz
    0U,	// VBROADCASTF64X2Z128rm
    0U,	// VBROADCASTF64X2Z128rmk
    0U,	// VBROADCASTF64X2Z128rmkz
    0U,	// VBROADCASTF64X2rm
    0U,	// VBROADCASTF64X2rmk
    0U,	// VBROADCASTF64X2rmkz
    0U,	// VBROADCASTF64X4rm
    0U,	// VBROADCASTF64X4rmk
    0U,	// VBROADCASTF64X4rmkz
    0U,	// VBROADCASTI128
    0U,	// VBROADCASTI32X2Z128m
    0U,	// VBROADCASTI32X2Z128mk
    0U,	// VBROADCASTI32X2Z128mkz
    0U,	// VBROADCASTI32X2Z128r
    0U,	// VBROADCASTI32X2Z128rk
    0U,	// VBROADCASTI32X2Z128rkz
    0U,	// VBROADCASTI32X2Z256m
    0U,	// VBROADCASTI32X2Z256mk
    0U,	// VBROADCASTI32X2Z256mkz
    0U,	// VBROADCASTI32X2Z256r
    0U,	// VBROADCASTI32X2Z256rk
    0U,	// VBROADCASTI32X2Z256rkz
    0U,	// VBROADCASTI32X2Zm
    0U,	// VBROADCASTI32X2Zmk
    0U,	// VBROADCASTI32X2Zmkz
    0U,	// VBROADCASTI32X2Zr
    0U,	// VBROADCASTI32X2Zrk
    0U,	// VBROADCASTI32X2Zrkz
    0U,	// VBROADCASTI32X4Z256rm
    0U,	// VBROADCASTI32X4Z256rmk
    0U,	// VBROADCASTI32X4Z256rmkz
    0U,	// VBROADCASTI32X4rm
    0U,	// VBROADCASTI32X4rmk
    0U,	// VBROADCASTI32X4rmkz
    0U,	// VBROADCASTI32X8rm
    0U,	// VBROADCASTI32X8rmk
    0U,	// VBROADCASTI32X8rmkz
    0U,	// VBROADCASTI64X2Z128rm
    0U,	// VBROADCASTI64X2Z128rmk
    0U,	// VBROADCASTI64X2Z128rmkz
    0U,	// VBROADCASTI64X2rm
    0U,	// VBROADCASTI64X2rmk
    0U,	// VBROADCASTI64X2rmkz
    0U,	// VBROADCASTI64X4rm
    0U,	// VBROADCASTI64X4rmk
    0U,	// VBROADCASTI64X4rmkz
    0U,	// VBROADCASTSDYrm
    0U,	// VBROADCASTSDYrr
    0U,	// VBROADCASTSDZ256m
    0U,	// VBROADCASTSDZ256mk
    0U,	// VBROADCASTSDZ256mkz
    0U,	// VBROADCASTSDZ256r
    0U,	// VBROADCASTSDZ256rk
    0U,	// VBROADCASTSDZ256rkz
    0U,	// VBROADCASTSDZm
    0U,	// VBROADCASTSDZmk
    0U,	// VBROADCASTSDZmkz
    0U,	// VBROADCASTSDZr
    0U,	// VBROADCASTSDZrk
    0U,	// VBROADCASTSDZrkz
    0U,	// VBROADCASTSSYrm
    0U,	// VBROADCASTSSYrr
    0U,	// VBROADCASTSSZ128m
    0U,	// VBROADCASTSSZ128mk
    0U,	// VBROADCASTSSZ128mkz
    0U,	// VBROADCASTSSZ128r
    0U,	// VBROADCASTSSZ128rk
    0U,	// VBROADCASTSSZ128rkz
    0U,	// VBROADCASTSSZ256m
    0U,	// VBROADCASTSSZ256mk
    0U,	// VBROADCASTSSZ256mkz
    0U,	// VBROADCASTSSZ256r
    0U,	// VBROADCASTSSZ256rk
    0U,	// VBROADCASTSSZ256rkz
    0U,	// VBROADCASTSSZm
    0U,	// VBROADCASTSSZmk
    0U,	// VBROADCASTSSZmkz
    0U,	// VBROADCASTSSZr
    0U,	// VBROADCASTSSZrk
    0U,	// VBROADCASTSSZrkz
    0U,	// VBROADCASTSSrm
    0U,	// VBROADCASTSSrr
    0U,	// VCMPPDYrmi
    0U,	// VCMPPDYrmi_alt
    0U,	// VCMPPDYrri
    0U,	// VCMPPDYrri_alt
    0U,	// VCMPPDZ128rmbi
    0U,	// VCMPPDZ128rmbi_alt
    1U,	// VCMPPDZ128rmbi_altk
    1U,	// VCMPPDZ128rmbik
    0U,	// VCMPPDZ128rmi
    0U,	// VCMPPDZ128rmi_alt
    0U,	// VCMPPDZ128rmi_altk
    0U,	// VCMPPDZ128rmik
    0U,	// VCMPPDZ128rri
    0U,	// VCMPPDZ128rri_alt
    1U,	// VCMPPDZ128rri_altk
    1U,	// VCMPPDZ128rrik
    0U,	// VCMPPDZ256rmbi
    0U,	// VCMPPDZ256rmbi_alt
    1U,	// VCMPPDZ256rmbi_altk
    1U,	// VCMPPDZ256rmbik
    0U,	// VCMPPDZ256rmi
    0U,	// VCMPPDZ256rmi_alt
    0U,	// VCMPPDZ256rmi_altk
    0U,	// VCMPPDZ256rmik
    0U,	// VCMPPDZ256rri
    0U,	// VCMPPDZ256rri_alt
    1U,	// VCMPPDZ256rri_altk
    1U,	// VCMPPDZ256rrik
    0U,	// VCMPPDZrmbi
    0U,	// VCMPPDZrmbi_alt
    1U,	// VCMPPDZrmbi_altk
    1U,	// VCMPPDZrmbik
    0U,	// VCMPPDZrmi
    0U,	// VCMPPDZrmi_alt
    0U,	// VCMPPDZrmi_altk
    0U,	// VCMPPDZrmik
    0U,	// VCMPPDZrri
    0U,	// VCMPPDZrri_alt
    1U,	// VCMPPDZrri_altk
    0U,	// VCMPPDZrrib
    0U,	// VCMPPDZrrib_alt
    1U,	// VCMPPDZrrib_altk
    1U,	// VCMPPDZrribk
    1U,	// VCMPPDZrrik
    0U,	// VCMPPDrmi
    0U,	// VCMPPDrmi_alt
    0U,	// VCMPPDrri
    0U,	// VCMPPDrri_alt
    0U,	// VCMPPSYrmi
    0U,	// VCMPPSYrmi_alt
    0U,	// VCMPPSYrri
    0U,	// VCMPPSYrri_alt
    0U,	// VCMPPSZ128rmbi
    0U,	// VCMPPSZ128rmbi_alt
    1U,	// VCMPPSZ128rmbi_altk
    1U,	// VCMPPSZ128rmbik
    0U,	// VCMPPSZ128rmi
    0U,	// VCMPPSZ128rmi_alt
    0U,	// VCMPPSZ128rmi_altk
    0U,	// VCMPPSZ128rmik
    0U,	// VCMPPSZ128rri
    0U,	// VCMPPSZ128rri_alt
    1U,	// VCMPPSZ128rri_altk
    1U,	// VCMPPSZ128rrik
    0U,	// VCMPPSZ256rmbi
    0U,	// VCMPPSZ256rmbi_alt
    1U,	// VCMPPSZ256rmbi_altk
    1U,	// VCMPPSZ256rmbik
    0U,	// VCMPPSZ256rmi
    0U,	// VCMPPSZ256rmi_alt
    0U,	// VCMPPSZ256rmi_altk
    0U,	// VCMPPSZ256rmik
    0U,	// VCMPPSZ256rri
    0U,	// VCMPPSZ256rri_alt
    1U,	// VCMPPSZ256rri_altk
    1U,	// VCMPPSZ256rrik
    0U,	// VCMPPSZrmbi
    0U,	// VCMPPSZrmbi_alt
    1U,	// VCMPPSZrmbi_altk
    1U,	// VCMPPSZrmbik
    0U,	// VCMPPSZrmi
    0U,	// VCMPPSZrmi_alt
    0U,	// VCMPPSZrmi_altk
    0U,	// VCMPPSZrmik
    0U,	// VCMPPSZrri
    0U,	// VCMPPSZrri_alt
    1U,	// VCMPPSZrri_altk
    0U,	// VCMPPSZrrib
    0U,	// VCMPPSZrrib_alt
    1U,	// VCMPPSZrrib_altk
    1U,	// VCMPPSZrribk
    1U,	// VCMPPSZrrik
    0U,	// VCMPPSrmi
    0U,	// VCMPPSrmi_alt
    0U,	// VCMPPSrri
    0U,	// VCMPPSrri_alt
    0U,	// VCMPSDZrm
    0U,	// VCMPSDZrm_Int
    1U,	// VCMPSDZrm_Intk
    0U,	// VCMPSDZrmi_alt
    1U,	// VCMPSDZrmi_altk
    0U,	// VCMPSDZrr
    0U,	// VCMPSDZrr_Int
    1U,	// VCMPSDZrr_Intk
    0U,	// VCMPSDZrrb_Int
    1U,	// VCMPSDZrrb_Intk
    0U,	// VCMPSDZrrb_alt
    1U,	// VCMPSDZrrb_altk
    0U,	// VCMPSDZrri_alt
    1U,	// VCMPSDZrri_altk
    0U,	// VCMPSDrm
    0U,	// VCMPSDrm_Int
    0U,	// VCMPSDrm_alt
    0U,	// VCMPSDrr
    0U,	// VCMPSDrr_Int
    0U,	// VCMPSDrr_alt
    0U,	// VCMPSSZrm
    0U,	// VCMPSSZrm_Int
    1U,	// VCMPSSZrm_Intk
    0U,	// VCMPSSZrmi_alt
    1U,	// VCMPSSZrmi_altk
    0U,	// VCMPSSZrr
    0U,	// VCMPSSZrr_Int
    1U,	// VCMPSSZrr_Intk
    0U,	// VCMPSSZrrb_Int
    1U,	// VCMPSSZrrb_Intk
    0U,	// VCMPSSZrrb_alt
    1U,	// VCMPSSZrrb_altk
    0U,	// VCMPSSZrri_alt
    1U,	// VCMPSSZrri_altk
    0U,	// VCMPSSrm
    0U,	// VCMPSSrm_Int
    0U,	// VCMPSSrm_alt
    0U,	// VCMPSSrr
    0U,	// VCMPSSrr_Int
    0U,	// VCMPSSrr_alt
    0U,	// VCOMISDZrm
    0U,	// VCOMISDZrm_Int
    0U,	// VCOMISDZrr
    0U,	// VCOMISDZrr_Int
    0U,	// VCOMISDZrrb
    0U,	// VCOMISDrm
    0U,	// VCOMISDrm_Int
    0U,	// VCOMISDrr
    0U,	// VCOMISDrr_Int
    0U,	// VCOMISSZrm
    0U,	// VCOMISSZrm_Int
    0U,	// VCOMISSZrr
    0U,	// VCOMISSZrr_Int
    0U,	// VCOMISSZrrb
    0U,	// VCOMISSrm
    0U,	// VCOMISSrm_Int
    0U,	// VCOMISSrr
    0U,	// VCOMISSrr_Int
    0U,	// VCOMPRESSPDZ128mr
    0U,	// VCOMPRESSPDZ128mrk
    0U,	// VCOMPRESSPDZ128rr
    0U,	// VCOMPRESSPDZ128rrk
    0U,	// VCOMPRESSPDZ128rrkz
    0U,	// VCOMPRESSPDZ256mr
    0U,	// VCOMPRESSPDZ256mrk
    0U,	// VCOMPRESSPDZ256rr
    0U,	// VCOMPRESSPDZ256rrk
    0U,	// VCOMPRESSPDZ256rrkz
    0U,	// VCOMPRESSPDZmr
    0U,	// VCOMPRESSPDZmrk
    0U,	// VCOMPRESSPDZrr
    0U,	// VCOMPRESSPDZrrk
    0U,	// VCOMPRESSPDZrrkz
    0U,	// VCOMPRESSPSZ128mr
    0U,	// VCOMPRESSPSZ128mrk
    0U,	// VCOMPRESSPSZ128rr
    0U,	// VCOMPRESSPSZ128rrk
    0U,	// VCOMPRESSPSZ128rrkz
    0U,	// VCOMPRESSPSZ256mr
    0U,	// VCOMPRESSPSZ256mrk
    0U,	// VCOMPRESSPSZ256rr
    0U,	// VCOMPRESSPSZ256rrk
    0U,	// VCOMPRESSPSZ256rrkz
    0U,	// VCOMPRESSPSZmr
    0U,	// VCOMPRESSPSZmrk
    0U,	// VCOMPRESSPSZrr
    0U,	// VCOMPRESSPSZrrk
    0U,	// VCOMPRESSPSZrrkz
    0U,	// VCVTDQ2PDYrm
    0U,	// VCVTDQ2PDYrr
    0U,	// VCVTDQ2PDZ128rm
    0U,	// VCVTDQ2PDZ128rmb
    0U,	// VCVTDQ2PDZ128rmbk
    0U,	// VCVTDQ2PDZ128rmbkz
    0U,	// VCVTDQ2PDZ128rmk
    0U,	// VCVTDQ2PDZ128rmkz
    0U,	// VCVTDQ2PDZ128rr
    0U,	// VCVTDQ2PDZ128rrk
    0U,	// VCVTDQ2PDZ128rrkz
    0U,	// VCVTDQ2PDZ256rm
    0U,	// VCVTDQ2PDZ256rmb
    0U,	// VCVTDQ2PDZ256rmbk
    0U,	// VCVTDQ2PDZ256rmbkz
    0U,	// VCVTDQ2PDZ256rmk
    0U,	// VCVTDQ2PDZ256rmkz
    0U,	// VCVTDQ2PDZ256rr
    0U,	// VCVTDQ2PDZ256rrk
    0U,	// VCVTDQ2PDZ256rrkz
    0U,	// VCVTDQ2PDZrm
    0U,	// VCVTDQ2PDZrmb
    0U,	// VCVTDQ2PDZrmbk
    0U,	// VCVTDQ2PDZrmbkz
    0U,	// VCVTDQ2PDZrmk
    0U,	// VCVTDQ2PDZrmkz
    0U,	// VCVTDQ2PDZrr
    0U,	// VCVTDQ2PDZrrk
    0U,	// VCVTDQ2PDZrrkz
    0U,	// VCVTDQ2PDrm
    0U,	// VCVTDQ2PDrr
    0U,	// VCVTDQ2PSYrm
    0U,	// VCVTDQ2PSYrr
    0U,	// VCVTDQ2PSZ128rm
    0U,	// VCVTDQ2PSZ128rmb
    0U,	// VCVTDQ2PSZ128rmbk
    0U,	// VCVTDQ2PSZ128rmbkz
    0U,	// VCVTDQ2PSZ128rmk
    0U,	// VCVTDQ2PSZ128rmkz
    0U,	// VCVTDQ2PSZ128rr
    0U,	// VCVTDQ2PSZ128rrk
    0U,	// VCVTDQ2PSZ128rrkz
    0U,	// VCVTDQ2PSZ256rm
    0U,	// VCVTDQ2PSZ256rmb
    0U,	// VCVTDQ2PSZ256rmbk
    0U,	// VCVTDQ2PSZ256rmbkz
    0U,	// VCVTDQ2PSZ256rmk
    0U,	// VCVTDQ2PSZ256rmkz
    0U,	// VCVTDQ2PSZ256rr
    0U,	// VCVTDQ2PSZ256rrk
    0U,	// VCVTDQ2PSZ256rrkz
    0U,	// VCVTDQ2PSZrm
    0U,	// VCVTDQ2PSZrmb
    0U,	// VCVTDQ2PSZrmbk
    0U,	// VCVTDQ2PSZrmbkz
    0U,	// VCVTDQ2PSZrmk
    0U,	// VCVTDQ2PSZrmkz
    0U,	// VCVTDQ2PSZrr
    0U,	// VCVTDQ2PSZrrb
    0U,	// VCVTDQ2PSZrrbk
    0U,	// VCVTDQ2PSZrrbkz
    0U,	// VCVTDQ2PSZrrk
    0U,	// VCVTDQ2PSZrrkz
    0U,	// VCVTDQ2PSrm
    0U,	// VCVTDQ2PSrr
    0U,	// VCVTPD2DQYrm
    0U,	// VCVTPD2DQYrr
    0U,	// VCVTPD2DQZ128rm
    0U,	// VCVTPD2DQZ128rmb
    0U,	// VCVTPD2DQZ128rmbk
    0U,	// VCVTPD2DQZ128rmbkz
    0U,	// VCVTPD2DQZ128rmk
    0U,	// VCVTPD2DQZ128rmkz
    0U,	// VCVTPD2DQZ128rr
    0U,	// VCVTPD2DQZ128rrk
    0U,	// VCVTPD2DQZ128rrkz
    0U,	// VCVTPD2DQZ256rm
    0U,	// VCVTPD2DQZ256rmb
    0U,	// VCVTPD2DQZ256rmbk
    0U,	// VCVTPD2DQZ256rmbkz
    0U,	// VCVTPD2DQZ256rmk
    0U,	// VCVTPD2DQZ256rmkz
    0U,	// VCVTPD2DQZ256rr
    0U,	// VCVTPD2DQZ256rrk
    0U,	// VCVTPD2DQZ256rrkz
    0U,	// VCVTPD2DQZrm
    0U,	// VCVTPD2DQZrmb
    0U,	// VCVTPD2DQZrmbk
    0U,	// VCVTPD2DQZrmbkz
    0U,	// VCVTPD2DQZrmk
    0U,	// VCVTPD2DQZrmkz
    0U,	// VCVTPD2DQZrr
    0U,	// VCVTPD2DQZrrb
    0U,	// VCVTPD2DQZrrbk
    0U,	// VCVTPD2DQZrrbkz
    0U,	// VCVTPD2DQZrrk
    0U,	// VCVTPD2DQZrrkz
    0U,	// VCVTPD2DQrm
    0U,	// VCVTPD2DQrr
    0U,	// VCVTPD2PSYrm
    0U,	// VCVTPD2PSYrr
    0U,	// VCVTPD2PSZ128rm
    0U,	// VCVTPD2PSZ128rmb
    0U,	// VCVTPD2PSZ128rmbk
    0U,	// VCVTPD2PSZ128rmbkz
    0U,	// VCVTPD2PSZ128rmk
    0U,	// VCVTPD2PSZ128rmkz
    0U,	// VCVTPD2PSZ128rr
    0U,	// VCVTPD2PSZ128rrk
    0U,	// VCVTPD2PSZ128rrkz
    0U,	// VCVTPD2PSZ256rm
    0U,	// VCVTPD2PSZ256rmb
    0U,	// VCVTPD2PSZ256rmbk
    0U,	// VCVTPD2PSZ256rmbkz
    0U,	// VCVTPD2PSZ256rmk
    0U,	// VCVTPD2PSZ256rmkz
    0U,	// VCVTPD2PSZ256rr
    0U,	// VCVTPD2PSZ256rrk
    0U,	// VCVTPD2PSZ256rrkz
    0U,	// VCVTPD2PSZrm
    0U,	// VCVTPD2PSZrmb
    0U,	// VCVTPD2PSZrmbk
    0U,	// VCVTPD2PSZrmbkz
    0U,	// VCVTPD2PSZrmk
    0U,	// VCVTPD2PSZrmkz
    0U,	// VCVTPD2PSZrr
    0U,	// VCVTPD2PSZrrb
    0U,	// VCVTPD2PSZrrbk
    0U,	// VCVTPD2PSZrrbkz
    0U,	// VCVTPD2PSZrrk
    0U,	// VCVTPD2PSZrrkz
    0U,	// VCVTPD2PSrm
    0U,	// VCVTPD2PSrr
    0U,	// VCVTPD2QQZ128rm
    0U,	// VCVTPD2QQZ128rmb
    0U,	// VCVTPD2QQZ128rmbk
    0U,	// VCVTPD2QQZ128rmbkz
    0U,	// VCVTPD2QQZ128rmk
    0U,	// VCVTPD2QQZ128rmkz
    0U,	// VCVTPD2QQZ128rr
    0U,	// VCVTPD2QQZ128rrk
    0U,	// VCVTPD2QQZ128rrkz
    0U,	// VCVTPD2QQZ256rm
    0U,	// VCVTPD2QQZ256rmb
    0U,	// VCVTPD2QQZ256rmbk
    0U,	// VCVTPD2QQZ256rmbkz
    0U,	// VCVTPD2QQZ256rmk
    0U,	// VCVTPD2QQZ256rmkz
    0U,	// VCVTPD2QQZ256rr
    0U,	// VCVTPD2QQZ256rrk
    0U,	// VCVTPD2QQZ256rrkz
    0U,	// VCVTPD2QQZrm
    0U,	// VCVTPD2QQZrmb
    0U,	// VCVTPD2QQZrmbk
    0U,	// VCVTPD2QQZrmbkz
    0U,	// VCVTPD2QQZrmk
    0U,	// VCVTPD2QQZrmkz
    0U,	// VCVTPD2QQZrr
    0U,	// VCVTPD2QQZrrb
    0U,	// VCVTPD2QQZrrbk
    0U,	// VCVTPD2QQZrrbkz
    0U,	// VCVTPD2QQZrrk
    0U,	// VCVTPD2QQZrrkz
    0U,	// VCVTPD2UDQZ128rm
    0U,	// VCVTPD2UDQZ128rmb
    0U,	// VCVTPD2UDQZ128rmbk
    0U,	// VCVTPD2UDQZ128rmbkz
    0U,	// VCVTPD2UDQZ128rmk
    0U,	// VCVTPD2UDQZ128rmkz
    0U,	// VCVTPD2UDQZ128rr
    0U,	// VCVTPD2UDQZ128rrk
    0U,	// VCVTPD2UDQZ128rrkz
    0U,	// VCVTPD2UDQZ256rm
    0U,	// VCVTPD2UDQZ256rmb
    0U,	// VCVTPD2UDQZ256rmbk
    0U,	// VCVTPD2UDQZ256rmbkz
    0U,	// VCVTPD2UDQZ256rmk
    0U,	// VCVTPD2UDQZ256rmkz
    0U,	// VCVTPD2UDQZ256rr
    0U,	// VCVTPD2UDQZ256rrk
    0U,	// VCVTPD2UDQZ256rrkz
    0U,	// VCVTPD2UDQZrm
    0U,	// VCVTPD2UDQZrmb
    0U,	// VCVTPD2UDQZrmbk
    0U,	// VCVTPD2UDQZrmbkz
    0U,	// VCVTPD2UDQZrmk
    0U,	// VCVTPD2UDQZrmkz
    0U,	// VCVTPD2UDQZrr
    0U,	// VCVTPD2UDQZrrb
    0U,	// VCVTPD2UDQZrrbk
    0U,	// VCVTPD2UDQZrrbkz
    0U,	// VCVTPD2UDQZrrk
    0U,	// VCVTPD2UDQZrrkz
    0U,	// VCVTPD2UQQZ128rm
    0U,	// VCVTPD2UQQZ128rmb
    0U,	// VCVTPD2UQQZ128rmbk
    0U,	// VCVTPD2UQQZ128rmbkz
    0U,	// VCVTPD2UQQZ128rmk
    0U,	// VCVTPD2UQQZ128rmkz
    0U,	// VCVTPD2UQQZ128rr
    0U,	// VCVTPD2UQQZ128rrk
    0U,	// VCVTPD2UQQZ128rrkz
    0U,	// VCVTPD2UQQZ256rm
    0U,	// VCVTPD2UQQZ256rmb
    0U,	// VCVTPD2UQQZ256rmbk
    0U,	// VCVTPD2UQQZ256rmbkz
    0U,	// VCVTPD2UQQZ256rmk
    0U,	// VCVTPD2UQQZ256rmkz
    0U,	// VCVTPD2UQQZ256rr
    0U,	// VCVTPD2UQQZ256rrk
    0U,	// VCVTPD2UQQZ256rrkz
    0U,	// VCVTPD2UQQZrm
    0U,	// VCVTPD2UQQZrmb
    0U,	// VCVTPD2UQQZrmbk
    0U,	// VCVTPD2UQQZrmbkz
    0U,	// VCVTPD2UQQZrmk
    0U,	// VCVTPD2UQQZrmkz
    0U,	// VCVTPD2UQQZrr
    0U,	// VCVTPD2UQQZrrb
    0U,	// VCVTPD2UQQZrrbk
    0U,	// VCVTPD2UQQZrrbkz
    0U,	// VCVTPD2UQQZrrk
    0U,	// VCVTPD2UQQZrrkz
    0U,	// VCVTPH2PSYrm
    0U,	// VCVTPH2PSYrr
    0U,	// VCVTPH2PSZ128rm
    0U,	// VCVTPH2PSZ128rmk
    0U,	// VCVTPH2PSZ128rmkz
    0U,	// VCVTPH2PSZ128rr
    0U,	// VCVTPH2PSZ128rrk
    0U,	// VCVTPH2PSZ128rrkz
    0U,	// VCVTPH2PSZ256rm
    0U,	// VCVTPH2PSZ256rmk
    0U,	// VCVTPH2PSZ256rmkz
    0U,	// VCVTPH2PSZ256rr
    0U,	// VCVTPH2PSZ256rrk
    0U,	// VCVTPH2PSZ256rrkz
    0U,	// VCVTPH2PSZrm
    0U,	// VCVTPH2PSZrmk
    0U,	// VCVTPH2PSZrmkz
    0U,	// VCVTPH2PSZrr
    0U,	// VCVTPH2PSZrrb
    0U,	// VCVTPH2PSZrrbk
    0U,	// VCVTPH2PSZrrbkz
    0U,	// VCVTPH2PSZrrk
    0U,	// VCVTPH2PSZrrkz
    0U,	// VCVTPH2PSrm
    0U,	// VCVTPH2PSrr
    0U,	// VCVTPS2DQYrm
    0U,	// VCVTPS2DQYrr
    0U,	// VCVTPS2DQZ128rm
    0U,	// VCVTPS2DQZ128rmb
    0U,	// VCVTPS2DQZ128rmbk
    0U,	// VCVTPS2DQZ128rmbkz
    0U,	// VCVTPS2DQZ128rmk
    0U,	// VCVTPS2DQZ128rmkz
    0U,	// VCVTPS2DQZ128rr
    0U,	// VCVTPS2DQZ128rrk
    0U,	// VCVTPS2DQZ128rrkz
    0U,	// VCVTPS2DQZ256rm
    0U,	// VCVTPS2DQZ256rmb
    0U,	// VCVTPS2DQZ256rmbk
    0U,	// VCVTPS2DQZ256rmbkz
    0U,	// VCVTPS2DQZ256rmk
    0U,	// VCVTPS2DQZ256rmkz
    0U,	// VCVTPS2DQZ256rr
    0U,	// VCVTPS2DQZ256rrk
    0U,	// VCVTPS2DQZ256rrkz
    0U,	// VCVTPS2DQZrm
    0U,	// VCVTPS2DQZrmb
    0U,	// VCVTPS2DQZrmbk
    0U,	// VCVTPS2DQZrmbkz
    0U,	// VCVTPS2DQZrmk
    0U,	// VCVTPS2DQZrmkz
    0U,	// VCVTPS2DQZrr
    0U,	// VCVTPS2DQZrrb
    0U,	// VCVTPS2DQZrrbk
    0U,	// VCVTPS2DQZrrbkz
    0U,	// VCVTPS2DQZrrk
    0U,	// VCVTPS2DQZrrkz
    0U,	// VCVTPS2DQrm
    0U,	// VCVTPS2DQrr
    0U,	// VCVTPS2PDYrm
    0U,	// VCVTPS2PDYrr
    0U,	// VCVTPS2PDZ128rm
    0U,	// VCVTPS2PDZ128rmb
    0U,	// VCVTPS2PDZ128rmbk
    0U,	// VCVTPS2PDZ128rmbkz
    0U,	// VCVTPS2PDZ128rmk
    0U,	// VCVTPS2PDZ128rmkz
    0U,	// VCVTPS2PDZ128rr
    0U,	// VCVTPS2PDZ128rrk
    0U,	// VCVTPS2PDZ128rrkz
    0U,	// VCVTPS2PDZ256rm
    0U,	// VCVTPS2PDZ256rmb
    0U,	// VCVTPS2PDZ256rmbk
    0U,	// VCVTPS2PDZ256rmbkz
    0U,	// VCVTPS2PDZ256rmk
    0U,	// VCVTPS2PDZ256rmkz
    0U,	// VCVTPS2PDZ256rr
    0U,	// VCVTPS2PDZ256rrk
    0U,	// VCVTPS2PDZ256rrkz
    0U,	// VCVTPS2PDZrm
    0U,	// VCVTPS2PDZrmb
    0U,	// VCVTPS2PDZrmbk
    0U,	// VCVTPS2PDZrmbkz
    0U,	// VCVTPS2PDZrmk
    0U,	// VCVTPS2PDZrmkz
    0U,	// VCVTPS2PDZrr
    0U,	// VCVTPS2PDZrrb
    0U,	// VCVTPS2PDZrrbk
    0U,	// VCVTPS2PDZrrbkz
    0U,	// VCVTPS2PDZrrk
    0U,	// VCVTPS2PDZrrkz
    0U,	// VCVTPS2PDrm
    0U,	// VCVTPS2PDrr
    0U,	// VCVTPS2PHYmr
    0U,	// VCVTPS2PHYrr
    0U,	// VCVTPS2PHZ128mr
    0U,	// VCVTPS2PHZ128mrk
    0U,	// VCVTPS2PHZ128rr
    0U,	// VCVTPS2PHZ128rrk
    0U,	// VCVTPS2PHZ128rrkz
    0U,	// VCVTPS2PHZ256mr
    0U,	// VCVTPS2PHZ256mrk
    0U,	// VCVTPS2PHZ256rr
    0U,	// VCVTPS2PHZ256rrk
    0U,	// VCVTPS2PHZ256rrkz
    0U,	// VCVTPS2PHZmr
    0U,	// VCVTPS2PHZmrk
    0U,	// VCVTPS2PHZrr
    0U,	// VCVTPS2PHZrrb
    0U,	// VCVTPS2PHZrrbk
    0U,	// VCVTPS2PHZrrbkz
    0U,	// VCVTPS2PHZrrk
    0U,	// VCVTPS2PHZrrkz
    0U,	// VCVTPS2PHmr
    0U,	// VCVTPS2PHrr
    0U,	// VCVTPS2QQZ128rm
    0U,	// VCVTPS2QQZ128rmb
    0U,	// VCVTPS2QQZ128rmbk
    0U,	// VCVTPS2QQZ128rmbkz
    0U,	// VCVTPS2QQZ128rmk
    0U,	// VCVTPS2QQZ128rmkz
    0U,	// VCVTPS2QQZ128rr
    0U,	// VCVTPS2QQZ128rrk
    0U,	// VCVTPS2QQZ128rrkz
    0U,	// VCVTPS2QQZ256rm
    0U,	// VCVTPS2QQZ256rmb
    0U,	// VCVTPS2QQZ256rmbk
    0U,	// VCVTPS2QQZ256rmbkz
    0U,	// VCVTPS2QQZ256rmk
    0U,	// VCVTPS2QQZ256rmkz
    0U,	// VCVTPS2QQZ256rr
    0U,	// VCVTPS2QQZ256rrk
    0U,	// VCVTPS2QQZ256rrkz
    0U,	// VCVTPS2QQZrm
    0U,	// VCVTPS2QQZrmb
    0U,	// VCVTPS2QQZrmbk
    0U,	// VCVTPS2QQZrmbkz
    0U,	// VCVTPS2QQZrmk
    0U,	// VCVTPS2QQZrmkz
    0U,	// VCVTPS2QQZrr
    0U,	// VCVTPS2QQZrrb
    0U,	// VCVTPS2QQZrrbk
    0U,	// VCVTPS2QQZrrbkz
    0U,	// VCVTPS2QQZrrk
    0U,	// VCVTPS2QQZrrkz
    0U,	// VCVTPS2UDQZ128rm
    0U,	// VCVTPS2UDQZ128rmb
    0U,	// VCVTPS2UDQZ128rmbk
    0U,	// VCVTPS2UDQZ128rmbkz
    0U,	// VCVTPS2UDQZ128rmk
    0U,	// VCVTPS2UDQZ128rmkz
    0U,	// VCVTPS2UDQZ128rr
    0U,	// VCVTPS2UDQZ128rrk
    0U,	// VCVTPS2UDQZ128rrkz
    0U,	// VCVTPS2UDQZ256rm
    0U,	// VCVTPS2UDQZ256rmb
    0U,	// VCVTPS2UDQZ256rmbk
    0U,	// VCVTPS2UDQZ256rmbkz
    0U,	// VCVTPS2UDQZ256rmk
    0U,	// VCVTPS2UDQZ256rmkz
    0U,	// VCVTPS2UDQZ256rr
    0U,	// VCVTPS2UDQZ256rrk
    0U,	// VCVTPS2UDQZ256rrkz
    0U,	// VCVTPS2UDQZrm
    0U,	// VCVTPS2UDQZrmb
    0U,	// VCVTPS2UDQZrmbk
    0U,	// VCVTPS2UDQZrmbkz
    0U,	// VCVTPS2UDQZrmk
    0U,	// VCVTPS2UDQZrmkz
    0U,	// VCVTPS2UDQZrr
    0U,	// VCVTPS2UDQZrrb
    0U,	// VCVTPS2UDQZrrbk
    0U,	// VCVTPS2UDQZrrbkz
    0U,	// VCVTPS2UDQZrrk
    0U,	// VCVTPS2UDQZrrkz
    0U,	// VCVTPS2UQQZ128rm
    0U,	// VCVTPS2UQQZ128rmb
    0U,	// VCVTPS2UQQZ128rmbk
    0U,	// VCVTPS2UQQZ128rmbkz
    0U,	// VCVTPS2UQQZ128rmk
    0U,	// VCVTPS2UQQZ128rmkz
    0U,	// VCVTPS2UQQZ128rr
    0U,	// VCVTPS2UQQZ128rrk
    0U,	// VCVTPS2UQQZ128rrkz
    0U,	// VCVTPS2UQQZ256rm
    0U,	// VCVTPS2UQQZ256rmb
    0U,	// VCVTPS2UQQZ256rmbk
    0U,	// VCVTPS2UQQZ256rmbkz
    0U,	// VCVTPS2UQQZ256rmk
    0U,	// VCVTPS2UQQZ256rmkz
    0U,	// VCVTPS2UQQZ256rr
    0U,	// VCVTPS2UQQZ256rrk
    0U,	// VCVTPS2UQQZ256rrkz
    0U,	// VCVTPS2UQQZrm
    0U,	// VCVTPS2UQQZrmb
    0U,	// VCVTPS2UQQZrmbk
    0U,	// VCVTPS2UQQZrmbkz
    0U,	// VCVTPS2UQQZrmk
    0U,	// VCVTPS2UQQZrmkz
    0U,	// VCVTPS2UQQZrr
    0U,	// VCVTPS2UQQZrrb
    0U,	// VCVTPS2UQQZrrbk
    0U,	// VCVTPS2UQQZrrbkz
    0U,	// VCVTPS2UQQZrrk
    0U,	// VCVTPS2UQQZrrkz
    0U,	// VCVTQQ2PDZ128rm
    0U,	// VCVTQQ2PDZ128rmb
    0U,	// VCVTQQ2PDZ128rmbk
    0U,	// VCVTQQ2PDZ128rmbkz
    0U,	// VCVTQQ2PDZ128rmk
    0U,	// VCVTQQ2PDZ128rmkz
    0U,	// VCVTQQ2PDZ128rr
    0U,	// VCVTQQ2PDZ128rrk
    0U,	// VCVTQQ2PDZ128rrkz
    0U,	// VCVTQQ2PDZ256rm
    0U,	// VCVTQQ2PDZ256rmb
    0U,	// VCVTQQ2PDZ256rmbk
    0U,	// VCVTQQ2PDZ256rmbkz
    0U,	// VCVTQQ2PDZ256rmk
    0U,	// VCVTQQ2PDZ256rmkz
    0U,	// VCVTQQ2PDZ256rr
    0U,	// VCVTQQ2PDZ256rrk
    0U,	// VCVTQQ2PDZ256rrkz
    0U,	// VCVTQQ2PDZrm
    0U,	// VCVTQQ2PDZrmb
    0U,	// VCVTQQ2PDZrmbk
    0U,	// VCVTQQ2PDZrmbkz
    0U,	// VCVTQQ2PDZrmk
    0U,	// VCVTQQ2PDZrmkz
    0U,	// VCVTQQ2PDZrr
    0U,	// VCVTQQ2PDZrrb
    0U,	// VCVTQQ2PDZrrbk
    0U,	// VCVTQQ2PDZrrbkz
    0U,	// VCVTQQ2PDZrrk
    0U,	// VCVTQQ2PDZrrkz
    0U,	// VCVTQQ2PSZ128rm
    0U,	// VCVTQQ2PSZ128rmb
    0U,	// VCVTQQ2PSZ128rmbk
    0U,	// VCVTQQ2PSZ128rmbkz
    0U,	// VCVTQQ2PSZ128rmk
    0U,	// VCVTQQ2PSZ128rmkz
    0U,	// VCVTQQ2PSZ128rr
    0U,	// VCVTQQ2PSZ128rrk
    0U,	// VCVTQQ2PSZ128rrkz
    0U,	// VCVTQQ2PSZ256rm
    0U,	// VCVTQQ2PSZ256rmb
    0U,	// VCVTQQ2PSZ256rmbk
    0U,	// VCVTQQ2PSZ256rmbkz
    0U,	// VCVTQQ2PSZ256rmk
    0U,	// VCVTQQ2PSZ256rmkz
    0U,	// VCVTQQ2PSZ256rr
    0U,	// VCVTQQ2PSZ256rrk
    0U,	// VCVTQQ2PSZ256rrkz
    0U,	// VCVTQQ2PSZrm
    0U,	// VCVTQQ2PSZrmb
    0U,	// VCVTQQ2PSZrmbk
    0U,	// VCVTQQ2PSZrmbkz
    0U,	// VCVTQQ2PSZrmk
    0U,	// VCVTQQ2PSZrmkz
    0U,	// VCVTQQ2PSZrr
    0U,	// VCVTQQ2PSZrrb
    0U,	// VCVTQQ2PSZrrbk
    0U,	// VCVTQQ2PSZrrbkz
    0U,	// VCVTQQ2PSZrrk
    0U,	// VCVTQQ2PSZrrkz
    0U,	// VCVTSD2SI64Zrm_Int
    0U,	// VCVTSD2SI64Zrr_Int
    0U,	// VCVTSD2SI64Zrrb_Int
    0U,	// VCVTSD2SI64rm_Int
    0U,	// VCVTSD2SI64rr_Int
    0U,	// VCVTSD2SIZrm_Int
    0U,	// VCVTSD2SIZrr_Int
    0U,	// VCVTSD2SIZrrb_Int
    0U,	// VCVTSD2SIrm_Int
    0U,	// VCVTSD2SIrr_Int
    0U,	// VCVTSD2SSZrm
    0U,	// VCVTSD2SSZrm_Int
    0U,	// VCVTSD2SSZrm_Intk
    0U,	// VCVTSD2SSZrm_Intkz
    0U,	// VCVTSD2SSZrr
    0U,	// VCVTSD2SSZrr_Int
    0U,	// VCVTSD2SSZrr_Intk
    0U,	// VCVTSD2SSZrr_Intkz
    0U,	// VCVTSD2SSZrrb_Int
    0U,	// VCVTSD2SSZrrb_Intk
    0U,	// VCVTSD2SSZrrb_Intkz
    0U,	// VCVTSD2SSrm
    0U,	// VCVTSD2SSrm_Int
    0U,	// VCVTSD2SSrr
    0U,	// VCVTSD2SSrr_Int
    0U,	// VCVTSD2USI64Zrm_Int
    0U,	// VCVTSD2USI64Zrr_Int
    0U,	// VCVTSD2USI64Zrrb_Int
    0U,	// VCVTSD2USIZrm_Int
    0U,	// VCVTSD2USIZrr_Int
    0U,	// VCVTSD2USIZrrb_Int
    0U,	// VCVTSI2SDZrm
    0U,	// VCVTSI2SDZrm_Int
    0U,	// VCVTSI2SDZrr
    0U,	// VCVTSI2SDZrr_Int
    0U,	// VCVTSI2SDZrrb_Int
    0U,	// VCVTSI2SDrm
    0U,	// VCVTSI2SDrm_Int
    0U,	// VCVTSI2SDrr
    0U,	// VCVTSI2SDrr_Int
    0U,	// VCVTSI2SSZrm
    0U,	// VCVTSI2SSZrm_Int
    0U,	// VCVTSI2SSZrr
    0U,	// VCVTSI2SSZrr_Int
    0U,	// VCVTSI2SSZrrb_Int
    0U,	// VCVTSI2SSrm
    0U,	// VCVTSI2SSrm_Int
    0U,	// VCVTSI2SSrr
    0U,	// VCVTSI2SSrr_Int
    0U,	// VCVTSI642SDZrm
    0U,	// VCVTSI642SDZrm_Int
    0U,	// VCVTSI642SDZrr
    0U,	// VCVTSI642SDZrr_Int
    0U,	// VCVTSI642SDZrrb_Int
    0U,	// VCVTSI642SDrm
    0U,	// VCVTSI642SDrm_Int
    0U,	// VCVTSI642SDrr
    0U,	// VCVTSI642SDrr_Int
    0U,	// VCVTSI642SSZrm
    0U,	// VCVTSI642SSZrm_Int
    0U,	// VCVTSI642SSZrr
    0U,	// VCVTSI642SSZrr_Int
    0U,	// VCVTSI642SSZrrb_Int
    0U,	// VCVTSI642SSrm
    0U,	// VCVTSI642SSrm_Int
    0U,	// VCVTSI642SSrr
    0U,	// VCVTSI642SSrr_Int
    0U,	// VCVTSS2SDZrm
    0U,	// VCVTSS2SDZrm_Int
    0U,	// VCVTSS2SDZrm_Intk
    0U,	// VCVTSS2SDZrm_Intkz
    0U,	// VCVTSS2SDZrr
    0U,	// VCVTSS2SDZrr_Int
    0U,	// VCVTSS2SDZrr_Intk
    0U,	// VCVTSS2SDZrr_Intkz
    0U,	// VCVTSS2SDZrrb_Int
    0U,	// VCVTSS2SDZrrb_Intk
    0U,	// VCVTSS2SDZrrb_Intkz
    0U,	// VCVTSS2SDrm
    0U,	// VCVTSS2SDrm_Int
    0U,	// VCVTSS2SDrr
    0U,	// VCVTSS2SDrr_Int
    0U,	// VCVTSS2SI64Zrm_Int
    0U,	// VCVTSS2SI64Zrr_Int
    0U,	// VCVTSS2SI64Zrrb_Int
    0U,	// VCVTSS2SI64rm_Int
    0U,	// VCVTSS2SI64rr_Int
    0U,	// VCVTSS2SIZrm_Int
    0U,	// VCVTSS2SIZrr_Int
    0U,	// VCVTSS2SIZrrb_Int
    0U,	// VCVTSS2SIrm_Int
    0U,	// VCVTSS2SIrr_Int
    0U,	// VCVTSS2USI64Zrm_Int
    0U,	// VCVTSS2USI64Zrr_Int
    0U,	// VCVTSS2USI64Zrrb_Int
    0U,	// VCVTSS2USIZrm_Int
    0U,	// VCVTSS2USIZrr_Int
    0U,	// VCVTSS2USIZrrb_Int
    0U,	// VCVTTPD2DQYrm
    0U,	// VCVTTPD2DQYrr
    0U,	// VCVTTPD2DQZ128rm
    0U,	// VCVTTPD2DQZ128rmb
    0U,	// VCVTTPD2DQZ128rmbk
    0U,	// VCVTTPD2DQZ128rmbkz
    0U,	// VCVTTPD2DQZ128rmk
    0U,	// VCVTTPD2DQZ128rmkz
    0U,	// VCVTTPD2DQZ128rr
    0U,	// VCVTTPD2DQZ128rrk
    0U,	// VCVTTPD2DQZ128rrkz
    0U,	// VCVTTPD2DQZ256rm
    0U,	// VCVTTPD2DQZ256rmb
    0U,	// VCVTTPD2DQZ256rmbk
    0U,	// VCVTTPD2DQZ256rmbkz
    0U,	// VCVTTPD2DQZ256rmk
    0U,	// VCVTTPD2DQZ256rmkz
    0U,	// VCVTTPD2DQZ256rr
    0U,	// VCVTTPD2DQZ256rrk
    0U,	// VCVTTPD2DQZ256rrkz
    0U,	// VCVTTPD2DQZrm
    0U,	// VCVTTPD2DQZrmb
    0U,	// VCVTTPD2DQZrmbk
    0U,	// VCVTTPD2DQZrmbkz
    0U,	// VCVTTPD2DQZrmk
    0U,	// VCVTTPD2DQZrmkz
    0U,	// VCVTTPD2DQZrr
    0U,	// VCVTTPD2DQZrrb
    0U,	// VCVTTPD2DQZrrbk
    0U,	// VCVTTPD2DQZrrbkz
    0U,	// VCVTTPD2DQZrrk
    0U,	// VCVTTPD2DQZrrkz
    0U,	// VCVTTPD2DQrm
    0U,	// VCVTTPD2DQrr
    0U,	// VCVTTPD2QQZ128rm
    0U,	// VCVTTPD2QQZ128rmb
    0U,	// VCVTTPD2QQZ128rmbk
    0U,	// VCVTTPD2QQZ128rmbkz
    0U,	// VCVTTPD2QQZ128rmk
    0U,	// VCVTTPD2QQZ128rmkz
    0U,	// VCVTTPD2QQZ128rr
    0U,	// VCVTTPD2QQZ128rrk
    0U,	// VCVTTPD2QQZ128rrkz
    0U,	// VCVTTPD2QQZ256rm
    0U,	// VCVTTPD2QQZ256rmb
    0U,	// VCVTTPD2QQZ256rmbk
    0U,	// VCVTTPD2QQZ256rmbkz
    0U,	// VCVTTPD2QQZ256rmk
    0U,	// VCVTTPD2QQZ256rmkz
    0U,	// VCVTTPD2QQZ256rr
    0U,	// VCVTTPD2QQZ256rrk
    0U,	// VCVTTPD2QQZ256rrkz
    0U,	// VCVTTPD2QQZrm
    0U,	// VCVTTPD2QQZrmb
    0U,	// VCVTTPD2QQZrmbk
    0U,	// VCVTTPD2QQZrmbkz
    0U,	// VCVTTPD2QQZrmk
    0U,	// VCVTTPD2QQZrmkz
    0U,	// VCVTTPD2QQZrr
    0U,	// VCVTTPD2QQZrrb
    0U,	// VCVTTPD2QQZrrbk
    0U,	// VCVTTPD2QQZrrbkz
    0U,	// VCVTTPD2QQZrrk
    0U,	// VCVTTPD2QQZrrkz
    0U,	// VCVTTPD2UDQZ128rm
    0U,	// VCVTTPD2UDQZ128rmb
    0U,	// VCVTTPD2UDQZ128rmbk
    0U,	// VCVTTPD2UDQZ128rmbkz
    0U,	// VCVTTPD2UDQZ128rmk
    0U,	// VCVTTPD2UDQZ128rmkz
    0U,	// VCVTTPD2UDQZ128rr
    0U,	// VCVTTPD2UDQZ128rrk
    0U,	// VCVTTPD2UDQZ128rrkz
    0U,	// VCVTTPD2UDQZ256rm
    0U,	// VCVTTPD2UDQZ256rmb
    0U,	// VCVTTPD2UDQZ256rmbk
    0U,	// VCVTTPD2UDQZ256rmbkz
    0U,	// VCVTTPD2UDQZ256rmk
    0U,	// VCVTTPD2UDQZ256rmkz
    0U,	// VCVTTPD2UDQZ256rr
    0U,	// VCVTTPD2UDQZ256rrk
    0U,	// VCVTTPD2UDQZ256rrkz
    0U,	// VCVTTPD2UDQZrm
    0U,	// VCVTTPD2UDQZrmb
    0U,	// VCVTTPD2UDQZrmbk
    0U,	// VCVTTPD2UDQZrmbkz
    0U,	// VCVTTPD2UDQZrmk
    0U,	// VCVTTPD2UDQZrmkz
    0U,	// VCVTTPD2UDQZrr
    0U,	// VCVTTPD2UDQZrrb
    0U,	// VCVTTPD2UDQZrrbk
    0U,	// VCVTTPD2UDQZrrbkz
    0U,	// VCVTTPD2UDQZrrk
    0U,	// VCVTTPD2UDQZrrkz
    0U,	// VCVTTPD2UQQZ128rm
    0U,	// VCVTTPD2UQQZ128rmb
    0U,	// VCVTTPD2UQQZ128rmbk
    0U,	// VCVTTPD2UQQZ128rmbkz
    0U,	// VCVTTPD2UQQZ128rmk
    0U,	// VCVTTPD2UQQZ128rmkz
    0U,	// VCVTTPD2UQQZ128rr
    0U,	// VCVTTPD2UQQZ128rrk
    0U,	// VCVTTPD2UQQZ128rrkz
    0U,	// VCVTTPD2UQQZ256rm
    0U,	// VCVTTPD2UQQZ256rmb
    0U,	// VCVTTPD2UQQZ256rmbk
    0U,	// VCVTTPD2UQQZ256rmbkz
    0U,	// VCVTTPD2UQQZ256rmk
    0U,	// VCVTTPD2UQQZ256rmkz
    0U,	// VCVTTPD2UQQZ256rr
    0U,	// VCVTTPD2UQQZ256rrk
    0U,	// VCVTTPD2UQQZ256rrkz
    0U,	// VCVTTPD2UQQZrm
    0U,	// VCVTTPD2UQQZrmb
    0U,	// VCVTTPD2UQQZrmbk
    0U,	// VCVTTPD2UQQZrmbkz
    0U,	// VCVTTPD2UQQZrmk
    0U,	// VCVTTPD2UQQZrmkz
    0U,	// VCVTTPD2UQQZrr
    0U,	// VCVTTPD2UQQZrrb
    0U,	// VCVTTPD2UQQZrrbk
    0U,	// VCVTTPD2UQQZrrbkz
    0U,	// VCVTTPD2UQQZrrk
    0U,	// VCVTTPD2UQQZrrkz
    0U,	// VCVTTPS2DQYrm
    0U,	// VCVTTPS2DQYrr
    0U,	// VCVTTPS2DQZ128rm
    0U,	// VCVTTPS2DQZ128rmb
    0U,	// VCVTTPS2DQZ128rmbk
    0U,	// VCVTTPS2DQZ128rmbkz
    0U,	// VCVTTPS2DQZ128rmk
    0U,	// VCVTTPS2DQZ128rmkz
    0U,	// VCVTTPS2DQZ128rr
    0U,	// VCVTTPS2DQZ128rrk
    0U,	// VCVTTPS2DQZ128rrkz
    0U,	// VCVTTPS2DQZ256rm
    0U,	// VCVTTPS2DQZ256rmb
    0U,	// VCVTTPS2DQZ256rmbk
    0U,	// VCVTTPS2DQZ256rmbkz
    0U,	// VCVTTPS2DQZ256rmk
    0U,	// VCVTTPS2DQZ256rmkz
    0U,	// VCVTTPS2DQZ256rr
    0U,	// VCVTTPS2DQZ256rrk
    0U,	// VCVTTPS2DQZ256rrkz
    0U,	// VCVTTPS2DQZrm
    0U,	// VCVTTPS2DQZrmb
    0U,	// VCVTTPS2DQZrmbk
    0U,	// VCVTTPS2DQZrmbkz
    0U,	// VCVTTPS2DQZrmk
    0U,	// VCVTTPS2DQZrmkz
    0U,	// VCVTTPS2DQZrr
    0U,	// VCVTTPS2DQZrrb
    0U,	// VCVTTPS2DQZrrbk
    0U,	// VCVTTPS2DQZrrbkz
    0U,	// VCVTTPS2DQZrrk
    0U,	// VCVTTPS2DQZrrkz
    0U,	// VCVTTPS2DQrm
    0U,	// VCVTTPS2DQrr
    0U,	// VCVTTPS2QQZ128rm
    0U,	// VCVTTPS2QQZ128rmb
    0U,	// VCVTTPS2QQZ128rmbk
    0U,	// VCVTTPS2QQZ128rmbkz
    0U,	// VCVTTPS2QQZ128rmk
    0U,	// VCVTTPS2QQZ128rmkz
    0U,	// VCVTTPS2QQZ128rr
    0U,	// VCVTTPS2QQZ128rrk
    0U,	// VCVTTPS2QQZ128rrkz
    0U,	// VCVTTPS2QQZ256rm
    0U,	// VCVTTPS2QQZ256rmb
    0U,	// VCVTTPS2QQZ256rmbk
    0U,	// VCVTTPS2QQZ256rmbkz
    0U,	// VCVTTPS2QQZ256rmk
    0U,	// VCVTTPS2QQZ256rmkz
    0U,	// VCVTTPS2QQZ256rr
    0U,	// VCVTTPS2QQZ256rrk
    0U,	// VCVTTPS2QQZ256rrkz
    0U,	// VCVTTPS2QQZrm
    0U,	// VCVTTPS2QQZrmb
    0U,	// VCVTTPS2QQZrmbk
    0U,	// VCVTTPS2QQZrmbkz
    0U,	// VCVTTPS2QQZrmk
    0U,	// VCVTTPS2QQZrmkz
    0U,	// VCVTTPS2QQZrr
    0U,	// VCVTTPS2QQZrrb
    0U,	// VCVTTPS2QQZrrbk
    0U,	// VCVTTPS2QQZrrbkz
    0U,	// VCVTTPS2QQZrrk
    0U,	// VCVTTPS2QQZrrkz
    0U,	// VCVTTPS2UDQZ128rm
    0U,	// VCVTTPS2UDQZ128rmb
    0U,	// VCVTTPS2UDQZ128rmbk
    0U,	// VCVTTPS2UDQZ128rmbkz
    0U,	// VCVTTPS2UDQZ128rmk
    0U,	// VCVTTPS2UDQZ128rmkz
    0U,	// VCVTTPS2UDQZ128rr
    0U,	// VCVTTPS2UDQZ128rrk
    0U,	// VCVTTPS2UDQZ128rrkz
    0U,	// VCVTTPS2UDQZ256rm
    0U,	// VCVTTPS2UDQZ256rmb
    0U,	// VCVTTPS2UDQZ256rmbk
    0U,	// VCVTTPS2UDQZ256rmbkz
    0U,	// VCVTTPS2UDQZ256rmk
    0U,	// VCVTTPS2UDQZ256rmkz
    0U,	// VCVTTPS2UDQZ256rr
    0U,	// VCVTTPS2UDQZ256rrk
    0U,	// VCVTTPS2UDQZ256rrkz
    0U,	// VCVTTPS2UDQZrm
    0U,	// VCVTTPS2UDQZrmb
    0U,	// VCVTTPS2UDQZrmbk
    0U,	// VCVTTPS2UDQZrmbkz
    0U,	// VCVTTPS2UDQZrmk
    0U,	// VCVTTPS2UDQZrmkz
    0U,	// VCVTTPS2UDQZrr
    0U,	// VCVTTPS2UDQZrrb
    0U,	// VCVTTPS2UDQZrrbk
    0U,	// VCVTTPS2UDQZrrbkz
    0U,	// VCVTTPS2UDQZrrk
    0U,	// VCVTTPS2UDQZrrkz
    0U,	// VCVTTPS2UQQZ128rm
    0U,	// VCVTTPS2UQQZ128rmb
    0U,	// VCVTTPS2UQQZ128rmbk
    0U,	// VCVTTPS2UQQZ128rmbkz
    0U,	// VCVTTPS2UQQZ128rmk
    0U,	// VCVTTPS2UQQZ128rmkz
    0U,	// VCVTTPS2UQQZ128rr
    0U,	// VCVTTPS2UQQZ128rrk
    0U,	// VCVTTPS2UQQZ128rrkz
    0U,	// VCVTTPS2UQQZ256rm
    0U,	// VCVTTPS2UQQZ256rmb
    0U,	// VCVTTPS2UQQZ256rmbk
    0U,	// VCVTTPS2UQQZ256rmbkz
    0U,	// VCVTTPS2UQQZ256rmk
    0U,	// VCVTTPS2UQQZ256rmkz
    0U,	// VCVTTPS2UQQZ256rr
    0U,	// VCVTTPS2UQQZ256rrk
    0U,	// VCVTTPS2UQQZ256rrkz
    0U,	// VCVTTPS2UQQZrm
    0U,	// VCVTTPS2UQQZrmb
    0U,	// VCVTTPS2UQQZrmbk
    0U,	// VCVTTPS2UQQZrmbkz
    0U,	// VCVTTPS2UQQZrmk
    0U,	// VCVTTPS2UQQZrmkz
    0U,	// VCVTTPS2UQQZrr
    0U,	// VCVTTPS2UQQZrrb
    0U,	// VCVTTPS2UQQZrrbk
    0U,	// VCVTTPS2UQQZrrbkz
    0U,	// VCVTTPS2UQQZrrk
    0U,	// VCVTTPS2UQQZrrkz
    0U,	// VCVTTSD2SI64Zrm
    0U,	// VCVTTSD2SI64Zrm_Int
    0U,	// VCVTTSD2SI64Zrr
    0U,	// VCVTTSD2SI64Zrr_Int
    0U,	// VCVTTSD2SI64Zrrb_Int
    0U,	// VCVTTSD2SI64rm
    0U,	// VCVTTSD2SI64rm_Int
    0U,	// VCVTTSD2SI64rr
    0U,	// VCVTTSD2SI64rr_Int
    0U,	// VCVTTSD2SIZrm
    0U,	// VCVTTSD2SIZrm_Int
    0U,	// VCVTTSD2SIZrr
    0U,	// VCVTTSD2SIZrr_Int
    0U,	// VCVTTSD2SIZrrb_Int
    0U,	// VCVTTSD2SIrm
    0U,	// VCVTTSD2SIrm_Int
    0U,	// VCVTTSD2SIrr
    0U,	// VCVTTSD2SIrr_Int
    0U,	// VCVTTSD2USI64Zrm
    0U,	// VCVTTSD2USI64Zrm_Int
    0U,	// VCVTTSD2USI64Zrr
    0U,	// VCVTTSD2USI64Zrr_Int
    0U,	// VCVTTSD2USI64Zrrb_Int
    0U,	// VCVTTSD2USIZrm
    0U,	// VCVTTSD2USIZrm_Int
    0U,	// VCVTTSD2USIZrr
    0U,	// VCVTTSD2USIZrr_Int
    0U,	// VCVTTSD2USIZrrb_Int
    0U,	// VCVTTSS2SI64Zrm
    0U,	// VCVTTSS2SI64Zrm_Int
    0U,	// VCVTTSS2SI64Zrr
    0U,	// VCVTTSS2SI64Zrr_Int
    0U,	// VCVTTSS2SI64Zrrb_Int
    0U,	// VCVTTSS2SI64rm
    0U,	// VCVTTSS2SI64rm_Int
    0U,	// VCVTTSS2SI64rr
    0U,	// VCVTTSS2SI64rr_Int
    0U,	// VCVTTSS2SIZrm
    0U,	// VCVTTSS2SIZrm_Int
    0U,	// VCVTTSS2SIZrr
    0U,	// VCVTTSS2SIZrr_Int
    0U,	// VCVTTSS2SIZrrb_Int
    0U,	// VCVTTSS2SIrm
    0U,	// VCVTTSS2SIrm_Int
    0U,	// VCVTTSS2SIrr
    0U,	// VCVTTSS2SIrr_Int
    0U,	// VCVTTSS2USI64Zrm
    0U,	// VCVTTSS2USI64Zrm_Int
    0U,	// VCVTTSS2USI64Zrr
    0U,	// VCVTTSS2USI64Zrr_Int
    0U,	// VCVTTSS2USI64Zrrb_Int
    0U,	// VCVTTSS2USIZrm
    0U,	// VCVTTSS2USIZrm_Int
    0U,	// VCVTTSS2USIZrr
    0U,	// VCVTTSS2USIZrr_Int
    0U,	// VCVTTSS2USIZrrb_Int
    0U,	// VCVTUDQ2PDZ128rm
    0U,	// VCVTUDQ2PDZ128rmb
    0U,	// VCVTUDQ2PDZ128rmbk
    0U,	// VCVTUDQ2PDZ128rmbkz
    0U,	// VCVTUDQ2PDZ128rmk
    0U,	// VCVTUDQ2PDZ128rmkz
    0U,	// VCVTUDQ2PDZ128rr
    0U,	// VCVTUDQ2PDZ128rrk
    0U,	// VCVTUDQ2PDZ128rrkz
    0U,	// VCVTUDQ2PDZ256rm
    0U,	// VCVTUDQ2PDZ256rmb
    0U,	// VCVTUDQ2PDZ256rmbk
    0U,	// VCVTUDQ2PDZ256rmbkz
    0U,	// VCVTUDQ2PDZ256rmk
    0U,	// VCVTUDQ2PDZ256rmkz
    0U,	// VCVTUDQ2PDZ256rr
    0U,	// VCVTUDQ2PDZ256rrk
    0U,	// VCVTUDQ2PDZ256rrkz
    0U,	// VCVTUDQ2PDZrm
    0U,	// VCVTUDQ2PDZrmb
    0U,	// VCVTUDQ2PDZrmbk
    0U,	// VCVTUDQ2PDZrmbkz
    0U,	// VCVTUDQ2PDZrmk
    0U,	// VCVTUDQ2PDZrmkz
    0U,	// VCVTUDQ2PDZrr
    0U,	// VCVTUDQ2PDZrrk
    0U,	// VCVTUDQ2PDZrrkz
    0U,	// VCVTUDQ2PSZ128rm
    0U,	// VCVTUDQ2PSZ128rmb
    0U,	// VCVTUDQ2PSZ128rmbk
    0U,	// VCVTUDQ2PSZ128rmbkz
    0U,	// VCVTUDQ2PSZ128rmk
    0U,	// VCVTUDQ2PSZ128rmkz
    0U,	// VCVTUDQ2PSZ128rr
    0U,	// VCVTUDQ2PSZ128rrk
    0U,	// VCVTUDQ2PSZ128rrkz
    0U,	// VCVTUDQ2PSZ256rm
    0U,	// VCVTUDQ2PSZ256rmb
    0U,	// VCVTUDQ2PSZ256rmbk
    0U,	// VCVTUDQ2PSZ256rmbkz
    0U,	// VCVTUDQ2PSZ256rmk
    0U,	// VCVTUDQ2PSZ256rmkz
    0U,	// VCVTUDQ2PSZ256rr
    0U,	// VCVTUDQ2PSZ256rrk
    0U,	// VCVTUDQ2PSZ256rrkz
    0U,	// VCVTUDQ2PSZrm
    0U,	// VCVTUDQ2PSZrmb
    0U,	// VCVTUDQ2PSZrmbk
    0U,	// VCVTUDQ2PSZrmbkz
    0U,	// VCVTUDQ2PSZrmk
    0U,	// VCVTUDQ2PSZrmkz
    0U,	// VCVTUDQ2PSZrr
    0U,	// VCVTUDQ2PSZrrb
    0U,	// VCVTUDQ2PSZrrbk
    0U,	// VCVTUDQ2PSZrrbkz
    0U,	// VCVTUDQ2PSZrrk
    0U,	// VCVTUDQ2PSZrrkz
    0U,	// VCVTUQQ2PDZ128rm
    0U,	// VCVTUQQ2PDZ128rmb
    0U,	// VCVTUQQ2PDZ128rmbk
    0U,	// VCVTUQQ2PDZ128rmbkz
    0U,	// VCVTUQQ2PDZ128rmk
    0U,	// VCVTUQQ2PDZ128rmkz
    0U,	// VCVTUQQ2PDZ128rr
    0U,	// VCVTUQQ2PDZ128rrk
    0U,	// VCVTUQQ2PDZ128rrkz
    0U,	// VCVTUQQ2PDZ256rm
    0U,	// VCVTUQQ2PDZ256rmb
    0U,	// VCVTUQQ2PDZ256rmbk
    0U,	// VCVTUQQ2PDZ256rmbkz
    0U,	// VCVTUQQ2PDZ256rmk
    0U,	// VCVTUQQ2PDZ256rmkz
    0U,	// VCVTUQQ2PDZ256rr
    0U,	// VCVTUQQ2PDZ256rrk
    0U,	// VCVTUQQ2PDZ256rrkz
    0U,	// VCVTUQQ2PDZrm
    0U,	// VCVTUQQ2PDZrmb
    0U,	// VCVTUQQ2PDZrmbk
    0U,	// VCVTUQQ2PDZrmbkz
    0U,	// VCVTUQQ2PDZrmk
    0U,	// VCVTUQQ2PDZrmkz
    0U,	// VCVTUQQ2PDZrr
    0U,	// VCVTUQQ2PDZrrb
    0U,	// VCVTUQQ2PDZrrbk
    0U,	// VCVTUQQ2PDZrrbkz
    0U,	// VCVTUQQ2PDZrrk
    0U,	// VCVTUQQ2PDZrrkz
    0U,	// VCVTUQQ2PSZ128rm
    0U,	// VCVTUQQ2PSZ128rmb
    0U,	// VCVTUQQ2PSZ128rmbk
    0U,	// VCVTUQQ2PSZ128rmbkz
    0U,	// VCVTUQQ2PSZ128rmk
    0U,	// VCVTUQQ2PSZ128rmkz
    0U,	// VCVTUQQ2PSZ128rr
    0U,	// VCVTUQQ2PSZ128rrk
    0U,	// VCVTUQQ2PSZ128rrkz
    0U,	// VCVTUQQ2PSZ256rm
    0U,	// VCVTUQQ2PSZ256rmb
    0U,	// VCVTUQQ2PSZ256rmbk
    0U,	// VCVTUQQ2PSZ256rmbkz
    0U,	// VCVTUQQ2PSZ256rmk
    0U,	// VCVTUQQ2PSZ256rmkz
    0U,	// VCVTUQQ2PSZ256rr
    0U,	// VCVTUQQ2PSZ256rrk
    0U,	// VCVTUQQ2PSZ256rrkz
    0U,	// VCVTUQQ2PSZrm
    0U,	// VCVTUQQ2PSZrmb
    0U,	// VCVTUQQ2PSZrmbk
    0U,	// VCVTUQQ2PSZrmbkz
    0U,	// VCVTUQQ2PSZrmk
    0U,	// VCVTUQQ2PSZrmkz
    0U,	// VCVTUQQ2PSZrr
    0U,	// VCVTUQQ2PSZrrb
    0U,	// VCVTUQQ2PSZrrbk
    0U,	// VCVTUQQ2PSZrrbkz
    0U,	// VCVTUQQ2PSZrrk
    0U,	// VCVTUQQ2PSZrrkz
    0U,	// VCVTUSI2SDZrm
    0U,	// VCVTUSI2SDZrm_Int
    0U,	// VCVTUSI2SDZrr
    0U,	// VCVTUSI2SDZrr_Int
    0U,	// VCVTUSI2SSZrm
    0U,	// VCVTUSI2SSZrm_Int
    0U,	// VCVTUSI2SSZrr
    0U,	// VCVTUSI2SSZrr_Int
    0U,	// VCVTUSI2SSZrrb_Int
    0U,	// VCVTUSI642SDZrm
    0U,	// VCVTUSI642SDZrm_Int
    0U,	// VCVTUSI642SDZrr
    0U,	// VCVTUSI642SDZrr_Int
    0U,	// VCVTUSI642SDZrrb_Int
    0U,	// VCVTUSI642SSZrm
    0U,	// VCVTUSI642SSZrm_Int
    0U,	// VCVTUSI642SSZrr
    0U,	// VCVTUSI642SSZrr_Int
    0U,	// VCVTUSI642SSZrrb_Int
    0U,	// VDBPSADBWZ128rmi
    0U,	// VDBPSADBWZ128rmik
    0U,	// VDBPSADBWZ128rmikz
    0U,	// VDBPSADBWZ128rri
    0U,	// VDBPSADBWZ128rrik
    3U,	// VDBPSADBWZ128rrikz
    0U,	// VDBPSADBWZ256rmi
    0U,	// VDBPSADBWZ256rmik
    0U,	// VDBPSADBWZ256rmikz
    0U,	// VDBPSADBWZ256rri
    0U,	// VDBPSADBWZ256rrik
    3U,	// VDBPSADBWZ256rrikz
    0U,	// VDBPSADBWZrmi
    0U,	// VDBPSADBWZrmik
    0U,	// VDBPSADBWZrmikz
    0U,	// VDBPSADBWZrri
    0U,	// VDBPSADBWZrrik
    3U,	// VDBPSADBWZrrikz
    0U,	// VDIVPDYrm
    0U,	// VDIVPDYrr
    0U,	// VDIVPDZ128rm
    0U,	// VDIVPDZ128rmb
    0U,	// VDIVPDZ128rmbk
    0U,	// VDIVPDZ128rmbkz
    0U,	// VDIVPDZ128rmk
    0U,	// VDIVPDZ128rmkz
    0U,	// VDIVPDZ128rr
    0U,	// VDIVPDZ128rrk
    0U,	// VDIVPDZ128rrkz
    0U,	// VDIVPDZ256rm
    0U,	// VDIVPDZ256rmb
    0U,	// VDIVPDZ256rmbk
    0U,	// VDIVPDZ256rmbkz
    0U,	// VDIVPDZ256rmk
    0U,	// VDIVPDZ256rmkz
    0U,	// VDIVPDZ256rr
    0U,	// VDIVPDZ256rrk
    0U,	// VDIVPDZ256rrkz
    0U,	// VDIVPDZrm
    0U,	// VDIVPDZrmb
    0U,	// VDIVPDZrmbk
    0U,	// VDIVPDZrmbkz
    0U,	// VDIVPDZrmk
    0U,	// VDIVPDZrmkz
    0U,	// VDIVPDZrr
    0U,	// VDIVPDZrrb
    0U,	// VDIVPDZrrbk
    0U,	// VDIVPDZrrbkz
    0U,	// VDIVPDZrrk
    0U,	// VDIVPDZrrkz
    0U,	// VDIVPDrm
    0U,	// VDIVPDrr
    0U,	// VDIVPSYrm
    0U,	// VDIVPSYrr
    0U,	// VDIVPSZ128rm
    0U,	// VDIVPSZ128rmb
    0U,	// VDIVPSZ128rmbk
    0U,	// VDIVPSZ128rmbkz
    0U,	// VDIVPSZ128rmk
    0U,	// VDIVPSZ128rmkz
    0U,	// VDIVPSZ128rr
    0U,	// VDIVPSZ128rrk
    0U,	// VDIVPSZ128rrkz
    0U,	// VDIVPSZ256rm
    0U,	// VDIVPSZ256rmb
    0U,	// VDIVPSZ256rmbk
    0U,	// VDIVPSZ256rmbkz
    0U,	// VDIVPSZ256rmk
    0U,	// VDIVPSZ256rmkz
    0U,	// VDIVPSZ256rr
    0U,	// VDIVPSZ256rrk
    0U,	// VDIVPSZ256rrkz
    0U,	// VDIVPSZrm
    0U,	// VDIVPSZrmb
    0U,	// VDIVPSZrmbk
    0U,	// VDIVPSZrmbkz
    0U,	// VDIVPSZrmk
    0U,	// VDIVPSZrmkz
    0U,	// VDIVPSZrr
    0U,	// VDIVPSZrrb
    0U,	// VDIVPSZrrbk
    0U,	// VDIVPSZrrbkz
    0U,	// VDIVPSZrrk
    0U,	// VDIVPSZrrkz
    0U,	// VDIVPSrm
    0U,	// VDIVPSrr
    0U,	// VDIVSDZrm
    0U,	// VDIVSDZrm_Int
    0U,	// VDIVSDZrm_Intk
    0U,	// VDIVSDZrm_Intkz
    0U,	// VDIVSDZrr
    0U,	// VDIVSDZrr_Int
    0U,	// VDIVSDZrr_Intk
    0U,	// VDIVSDZrr_Intkz
    0U,	// VDIVSDZrrb_Int
    0U,	// VDIVSDZrrb_Intk
    0U,	// VDIVSDZrrb_Intkz
    0U,	// VDIVSDrm
    0U,	// VDIVSDrm_Int
    0U,	// VDIVSDrr
    0U,	// VDIVSDrr_Int
    0U,	// VDIVSSZrm
    0U,	// VDIVSSZrm_Int
    0U,	// VDIVSSZrm_Intk
    0U,	// VDIVSSZrm_Intkz
    0U,	// VDIVSSZrr
    0U,	// VDIVSSZrr_Int
    0U,	// VDIVSSZrr_Intk
    0U,	// VDIVSSZrr_Intkz
    0U,	// VDIVSSZrrb_Int
    0U,	// VDIVSSZrrb_Intk
    0U,	// VDIVSSZrrb_Intkz
    0U,	// VDIVSSrm
    0U,	// VDIVSSrm_Int
    0U,	// VDIVSSrr
    0U,	// VDIVSSrr_Int
    0U,	// VDPPDrmi
    0U,	// VDPPDrri
    0U,	// VDPPSYrmi
    0U,	// VDPPSYrri
    0U,	// VDPPSrmi
    0U,	// VDPPSrri
    0U,	// VERRm
    0U,	// VERRr
    0U,	// VERWm
    0U,	// VERWr
    0U,	// VEXP2PDZm
    0U,	// VEXP2PDZmb
    0U,	// VEXP2PDZmbk
    0U,	// VEXP2PDZmbkz
    0U,	// VEXP2PDZmk
    0U,	// VEXP2PDZmkz
    0U,	// VEXP2PDZr
    0U,	// VEXP2PDZrb
    0U,	// VEXP2PDZrbk
    0U,	// VEXP2PDZrbkz
    0U,	// VEXP2PDZrk
    0U,	// VEXP2PDZrkz
    0U,	// VEXP2PSZm
    0U,	// VEXP2PSZmb
    0U,	// VEXP2PSZmbk
    0U,	// VEXP2PSZmbkz
    0U,	// VEXP2PSZmk
    0U,	// VEXP2PSZmkz
    0U,	// VEXP2PSZr
    0U,	// VEXP2PSZrb
    0U,	// VEXP2PSZrbk
    0U,	// VEXP2PSZrbkz
    0U,	// VEXP2PSZrk
    0U,	// VEXP2PSZrkz
    0U,	// VEXPANDPDZ128rm
    0U,	// VEXPANDPDZ128rmk
    0U,	// VEXPANDPDZ128rmkz
    0U,	// VEXPANDPDZ128rr
    0U,	// VEXPANDPDZ128rrk
    0U,	// VEXPANDPDZ128rrkz
    0U,	// VEXPANDPDZ256rm
    0U,	// VEXPANDPDZ256rmk
    0U,	// VEXPANDPDZ256rmkz
    0U,	// VEXPANDPDZ256rr
    0U,	// VEXPANDPDZ256rrk
    0U,	// VEXPANDPDZ256rrkz
    0U,	// VEXPANDPDZrm
    0U,	// VEXPANDPDZrmk
    0U,	// VEXPANDPDZrmkz
    0U,	// VEXPANDPDZrr
    0U,	// VEXPANDPDZrrk
    0U,	// VEXPANDPDZrrkz
    0U,	// VEXPANDPSZ128rm
    0U,	// VEXPANDPSZ128rmk
    0U,	// VEXPANDPSZ128rmkz
    0U,	// VEXPANDPSZ128rr
    0U,	// VEXPANDPSZ128rrk
    0U,	// VEXPANDPSZ128rrkz
    0U,	// VEXPANDPSZ256rm
    0U,	// VEXPANDPSZ256rmk
    0U,	// VEXPANDPSZ256rmkz
    0U,	// VEXPANDPSZ256rr
    0U,	// VEXPANDPSZ256rrk
    0U,	// VEXPANDPSZ256rrkz
    0U,	// VEXPANDPSZrm
    0U,	// VEXPANDPSZrmk
    0U,	// VEXPANDPSZrmkz
    0U,	// VEXPANDPSZrr
    0U,	// VEXPANDPSZrrk
    0U,	// VEXPANDPSZrrkz
    0U,	// VEXTRACTF128mr
    0U,	// VEXTRACTF128rr
    0U,	// VEXTRACTF32x4Z256mr
    0U,	// VEXTRACTF32x4Z256mrk
    0U,	// VEXTRACTF32x4Z256rr
    0U,	// VEXTRACTF32x4Z256rrk
    0U,	// VEXTRACTF32x4Z256rrkz
    0U,	// VEXTRACTF32x4Zmr
    0U,	// VEXTRACTF32x4Zmrk
    0U,	// VEXTRACTF32x4Zrr
    0U,	// VEXTRACTF32x4Zrrk
    0U,	// VEXTRACTF32x4Zrrkz
    0U,	// VEXTRACTF32x8Zmr
    0U,	// VEXTRACTF32x8Zmrk
    0U,	// VEXTRACTF32x8Zrr
    0U,	// VEXTRACTF32x8Zrrk
    0U,	// VEXTRACTF32x8Zrrkz
    0U,	// VEXTRACTF64x2Z256mr
    0U,	// VEXTRACTF64x2Z256mrk
    0U,	// VEXTRACTF64x2Z256rr
    0U,	// VEXTRACTF64x2Z256rrk
    0U,	// VEXTRACTF64x2Z256rrkz
    0U,	// VEXTRACTF64x2Zmr
    0U,	// VEXTRACTF64x2Zmrk
    0U,	// VEXTRACTF64x2Zrr
    0U,	// VEXTRACTF64x2Zrrk
    0U,	// VEXTRACTF64x2Zrrkz
    0U,	// VEXTRACTF64x4Zmr
    0U,	// VEXTRACTF64x4Zmrk
    0U,	// VEXTRACTF64x4Zrr
    0U,	// VEXTRACTF64x4Zrrk
    0U,	// VEXTRACTF64x4Zrrkz
    0U,	// VEXTRACTI128mr
    0U,	// VEXTRACTI128rr
    0U,	// VEXTRACTI32x4Z256mr
    0U,	// VEXTRACTI32x4Z256mrk
    0U,	// VEXTRACTI32x4Z256rr
    0U,	// VEXTRACTI32x4Z256rrk
    0U,	// VEXTRACTI32x4Z256rrkz
    0U,	// VEXTRACTI32x4Zmr
    0U,	// VEXTRACTI32x4Zmrk
    0U,	// VEXTRACTI32x4Zrr
    0U,	// VEXTRACTI32x4Zrrk
    0U,	// VEXTRACTI32x4Zrrkz
    0U,	// VEXTRACTI32x8Zmr
    0U,	// VEXTRACTI32x8Zmrk
    0U,	// VEXTRACTI32x8Zrr
    0U,	// VEXTRACTI32x8Zrrk
    0U,	// VEXTRACTI32x8Zrrkz
    0U,	// VEXTRACTI64x2Z256mr
    0U,	// VEXTRACTI64x2Z256mrk
    0U,	// VEXTRACTI64x2Z256rr
    0U,	// VEXTRACTI64x2Z256rrk
    0U,	// VEXTRACTI64x2Z256rrkz
    0U,	// VEXTRACTI64x2Zmr
    0U,	// VEXTRACTI64x2Zmrk
    0U,	// VEXTRACTI64x2Zrr
    0U,	// VEXTRACTI64x2Zrrk
    0U,	// VEXTRACTI64x2Zrrkz
    0U,	// VEXTRACTI64x4Zmr
    0U,	// VEXTRACTI64x4Zmrk
    0U,	// VEXTRACTI64x4Zrr
    0U,	// VEXTRACTI64x4Zrrk
    0U,	// VEXTRACTI64x4Zrrkz
    0U,	// VEXTRACTPSZmr
    0U,	// VEXTRACTPSZrr
    0U,	// VEXTRACTPSmr
    0U,	// VEXTRACTPSrr
    0U,	// VFIXUPIMMPDZ128rmbi
    0U,	// VFIXUPIMMPDZ128rmbik
    2U,	// VFIXUPIMMPDZ128rmbikz
    0U,	// VFIXUPIMMPDZ128rmi
    0U,	// VFIXUPIMMPDZ128rmik
    0U,	// VFIXUPIMMPDZ128rmikz
    0U,	// VFIXUPIMMPDZ128rri
    0U,	// VFIXUPIMMPDZ128rrik
    0U,	// VFIXUPIMMPDZ128rrikz
    0U,	// VFIXUPIMMPDZ256rmbi
    0U,	// VFIXUPIMMPDZ256rmbik
    2U,	// VFIXUPIMMPDZ256rmbikz
    0U,	// VFIXUPIMMPDZ256rmi
    0U,	// VFIXUPIMMPDZ256rmik
    0U,	// VFIXUPIMMPDZ256rmikz
    0U,	// VFIXUPIMMPDZ256rri
    0U,	// VFIXUPIMMPDZ256rrik
    0U,	// VFIXUPIMMPDZ256rrikz
    0U,	// VFIXUPIMMPDZrmbi
    0U,	// VFIXUPIMMPDZrmbik
    2U,	// VFIXUPIMMPDZrmbikz
    0U,	// VFIXUPIMMPDZrmi
    0U,	// VFIXUPIMMPDZrmik
    0U,	// VFIXUPIMMPDZrmikz
    0U,	// VFIXUPIMMPDZrri
    0U,	// VFIXUPIMMPDZrrib
    0U,	// VFIXUPIMMPDZrribk
    0U,	// VFIXUPIMMPDZrribkz
    0U,	// VFIXUPIMMPDZrrik
    0U,	// VFIXUPIMMPDZrrikz
    0U,	// VFIXUPIMMPSZ128rmbi
    0U,	// VFIXUPIMMPSZ128rmbik
    2U,	// VFIXUPIMMPSZ128rmbikz
    0U,	// VFIXUPIMMPSZ128rmi
    0U,	// VFIXUPIMMPSZ128rmik
    0U,	// VFIXUPIMMPSZ128rmikz
    0U,	// VFIXUPIMMPSZ128rri
    0U,	// VFIXUPIMMPSZ128rrik
    0U,	// VFIXUPIMMPSZ128rrikz
    0U,	// VFIXUPIMMPSZ256rmbi
    0U,	// VFIXUPIMMPSZ256rmbik
    2U,	// VFIXUPIMMPSZ256rmbikz
    0U,	// VFIXUPIMMPSZ256rmi
    0U,	// VFIXUPIMMPSZ256rmik
    0U,	// VFIXUPIMMPSZ256rmikz
    0U,	// VFIXUPIMMPSZ256rri
    0U,	// VFIXUPIMMPSZ256rrik
    0U,	// VFIXUPIMMPSZ256rrikz
    0U,	// VFIXUPIMMPSZrmbi
    0U,	// VFIXUPIMMPSZrmbik
    2U,	// VFIXUPIMMPSZrmbikz
    0U,	// VFIXUPIMMPSZrmi
    0U,	// VFIXUPIMMPSZrmik
    0U,	// VFIXUPIMMPSZrmikz
    0U,	// VFIXUPIMMPSZrri
    0U,	// VFIXUPIMMPSZrrib
    0U,	// VFIXUPIMMPSZrribk
    0U,	// VFIXUPIMMPSZrribkz
    0U,	// VFIXUPIMMPSZrrik
    0U,	// VFIXUPIMMPSZrrikz
    0U,	// VFIXUPIMMSDZrmi
    0U,	// VFIXUPIMMSDZrmik
    2U,	// VFIXUPIMMSDZrmikz
    0U,	// VFIXUPIMMSDZrri
    0U,	// VFIXUPIMMSDZrrib
    0U,	// VFIXUPIMMSDZrribk
    0U,	// VFIXUPIMMSDZrribkz
    0U,	// VFIXUPIMMSDZrrik
    0U,	// VFIXUPIMMSDZrrikz
    0U,	// VFIXUPIMMSSZrmi
    0U,	// VFIXUPIMMSSZrmik
    2U,	// VFIXUPIMMSSZrmikz
    0U,	// VFIXUPIMMSSZrri
    0U,	// VFIXUPIMMSSZrrib
    0U,	// VFIXUPIMMSSZrribk
    0U,	// VFIXUPIMMSSZrribkz
    0U,	// VFIXUPIMMSSZrrik
    0U,	// VFIXUPIMMSSZrrikz
    0U,	// VFMADD132PDYm
    0U,	// VFMADD132PDYr
    0U,	// VFMADD132PDZ128m
    0U,	// VFMADD132PDZ128mb
    0U,	// VFMADD132PDZ128mbk
    0U,	// VFMADD132PDZ128mbkz
    0U,	// VFMADD132PDZ128mk
    0U,	// VFMADD132PDZ128mkz
    0U,	// VFMADD132PDZ128r
    0U,	// VFMADD132PDZ128rk
    0U,	// VFMADD132PDZ128rkz
    0U,	// VFMADD132PDZ256m
    0U,	// VFMADD132PDZ256mb
    0U,	// VFMADD132PDZ256mbk
    0U,	// VFMADD132PDZ256mbkz
    0U,	// VFMADD132PDZ256mk
    0U,	// VFMADD132PDZ256mkz
    0U,	// VFMADD132PDZ256r
    0U,	// VFMADD132PDZ256rk
    0U,	// VFMADD132PDZ256rkz
    0U,	// VFMADD132PDZm
    0U,	// VFMADD132PDZmb
    0U,	// VFMADD132PDZmbk
    0U,	// VFMADD132PDZmbkz
    0U,	// VFMADD132PDZmk
    0U,	// VFMADD132PDZmkz
    0U,	// VFMADD132PDZr
    0U,	// VFMADD132PDZrb
    0U,	// VFMADD132PDZrbk
    0U,	// VFMADD132PDZrbkz
    0U,	// VFMADD132PDZrk
    0U,	// VFMADD132PDZrkz
    0U,	// VFMADD132PDm
    0U,	// VFMADD132PDr
    0U,	// VFMADD132PSYm
    0U,	// VFMADD132PSYr
    0U,	// VFMADD132PSZ128m
    0U,	// VFMADD132PSZ128mb
    0U,	// VFMADD132PSZ128mbk
    0U,	// VFMADD132PSZ128mbkz
    0U,	// VFMADD132PSZ128mk
    0U,	// VFMADD132PSZ128mkz
    0U,	// VFMADD132PSZ128r
    0U,	// VFMADD132PSZ128rk
    0U,	// VFMADD132PSZ128rkz
    0U,	// VFMADD132PSZ256m
    0U,	// VFMADD132PSZ256mb
    0U,	// VFMADD132PSZ256mbk
    0U,	// VFMADD132PSZ256mbkz
    0U,	// VFMADD132PSZ256mk
    0U,	// VFMADD132PSZ256mkz
    0U,	// VFMADD132PSZ256r
    0U,	// VFMADD132PSZ256rk
    0U,	// VFMADD132PSZ256rkz
    0U,	// VFMADD132PSZm
    0U,	// VFMADD132PSZmb
    0U,	// VFMADD132PSZmbk
    0U,	// VFMADD132PSZmbkz
    0U,	// VFMADD132PSZmk
    0U,	// VFMADD132PSZmkz
    0U,	// VFMADD132PSZr
    0U,	// VFMADD132PSZrb
    0U,	// VFMADD132PSZrbk
    0U,	// VFMADD132PSZrbkz
    0U,	// VFMADD132PSZrk
    0U,	// VFMADD132PSZrkz
    0U,	// VFMADD132PSm
    0U,	// VFMADD132PSr
    0U,	// VFMADD132SDZm
    0U,	// VFMADD132SDZm_Int
    0U,	// VFMADD132SDZm_Intk
    0U,	// VFMADD132SDZm_Intkz
    0U,	// VFMADD132SDZr
    0U,	// VFMADD132SDZr_Int
    0U,	// VFMADD132SDZr_Intk
    0U,	// VFMADD132SDZr_Intkz
    0U,	// VFMADD132SDZrb
    0U,	// VFMADD132SDZrb_Int
    0U,	// VFMADD132SDZrb_Intk
    0U,	// VFMADD132SDZrb_Intkz
    0U,	// VFMADD132SDm
    0U,	// VFMADD132SDm_Int
    0U,	// VFMADD132SDr
    0U,	// VFMADD132SDr_Int
    0U,	// VFMADD132SSZm
    0U,	// VFMADD132SSZm_Int
    0U,	// VFMADD132SSZm_Intk
    0U,	// VFMADD132SSZm_Intkz
    0U,	// VFMADD132SSZr
    0U,	// VFMADD132SSZr_Int
    0U,	// VFMADD132SSZr_Intk
    0U,	// VFMADD132SSZr_Intkz
    0U,	// VFMADD132SSZrb
    0U,	// VFMADD132SSZrb_Int
    0U,	// VFMADD132SSZrb_Intk
    0U,	// VFMADD132SSZrb_Intkz
    0U,	// VFMADD132SSm
    0U,	// VFMADD132SSm_Int
    0U,	// VFMADD132SSr
    0U,	// VFMADD132SSr_Int
    0U,	// VFMADD213PDYm
    0U,	// VFMADD213PDYr
    0U,	// VFMADD213PDZ128m
    0U,	// VFMADD213PDZ128mb
    0U,	// VFMADD213PDZ128mbk
    0U,	// VFMADD213PDZ128mbkz
    0U,	// VFMADD213PDZ128mk
    0U,	// VFMADD213PDZ128mkz
    0U,	// VFMADD213PDZ128r
    0U,	// VFMADD213PDZ128rk
    0U,	// VFMADD213PDZ128rkz
    0U,	// VFMADD213PDZ256m
    0U,	// VFMADD213PDZ256mb
    0U,	// VFMADD213PDZ256mbk
    0U,	// VFMADD213PDZ256mbkz
    0U,	// VFMADD213PDZ256mk
    0U,	// VFMADD213PDZ256mkz
    0U,	// VFMADD213PDZ256r
    0U,	// VFMADD213PDZ256rk
    0U,	// VFMADD213PDZ256rkz
    0U,	// VFMADD213PDZm
    0U,	// VFMADD213PDZmb
    0U,	// VFMADD213PDZmbk
    0U,	// VFMADD213PDZmbkz
    0U,	// VFMADD213PDZmk
    0U,	// VFMADD213PDZmkz
    0U,	// VFMADD213PDZr
    0U,	// VFMADD213PDZrb
    0U,	// VFMADD213PDZrbk
    0U,	// VFMADD213PDZrbkz
    0U,	// VFMADD213PDZrk
    0U,	// VFMADD213PDZrkz
    0U,	// VFMADD213PDm
    0U,	// VFMADD213PDr
    0U,	// VFMADD213PSYm
    0U,	// VFMADD213PSYr
    0U,	// VFMADD213PSZ128m
    0U,	// VFMADD213PSZ128mb
    0U,	// VFMADD213PSZ128mbk
    0U,	// VFMADD213PSZ128mbkz
    0U,	// VFMADD213PSZ128mk
    0U,	// VFMADD213PSZ128mkz
    0U,	// VFMADD213PSZ128r
    0U,	// VFMADD213PSZ128rk
    0U,	// VFMADD213PSZ128rkz
    0U,	// VFMADD213PSZ256m
    0U,	// VFMADD213PSZ256mb
    0U,	// VFMADD213PSZ256mbk
    0U,	// VFMADD213PSZ256mbkz
    0U,	// VFMADD213PSZ256mk
    0U,	// VFMADD213PSZ256mkz
    0U,	// VFMADD213PSZ256r
    0U,	// VFMADD213PSZ256rk
    0U,	// VFMADD213PSZ256rkz
    0U,	// VFMADD213PSZm
    0U,	// VFMADD213PSZmb
    0U,	// VFMADD213PSZmbk
    0U,	// VFMADD213PSZmbkz
    0U,	// VFMADD213PSZmk
    0U,	// VFMADD213PSZmkz
    0U,	// VFMADD213PSZr
    0U,	// VFMADD213PSZrb
    0U,	// VFMADD213PSZrbk
    0U,	// VFMADD213PSZrbkz
    0U,	// VFMADD213PSZrk
    0U,	// VFMADD213PSZrkz
    0U,	// VFMADD213PSm
    0U,	// VFMADD213PSr
    0U,	// VFMADD213SDZm
    0U,	// VFMADD213SDZm_Int
    0U,	// VFMADD213SDZm_Intk
    0U,	// VFMADD213SDZm_Intkz
    0U,	// VFMADD213SDZr
    0U,	// VFMADD213SDZr_Int
    0U,	// VFMADD213SDZr_Intk
    0U,	// VFMADD213SDZr_Intkz
    0U,	// VFMADD213SDZrb
    0U,	// VFMADD213SDZrb_Int
    0U,	// VFMADD213SDZrb_Intk
    0U,	// VFMADD213SDZrb_Intkz
    0U,	// VFMADD213SDm
    0U,	// VFMADD213SDm_Int
    0U,	// VFMADD213SDr
    0U,	// VFMADD213SDr_Int
    0U,	// VFMADD213SSZm
    0U,	// VFMADD213SSZm_Int
    0U,	// VFMADD213SSZm_Intk
    0U,	// VFMADD213SSZm_Intkz
    0U,	// VFMADD213SSZr
    0U,	// VFMADD213SSZr_Int
    0U,	// VFMADD213SSZr_Intk
    0U,	// VFMADD213SSZr_Intkz
    0U,	// VFMADD213SSZrb
    0U,	// VFMADD213SSZrb_Int
    0U,	// VFMADD213SSZrb_Intk
    0U,	// VFMADD213SSZrb_Intkz
    0U,	// VFMADD213SSm
    0U,	// VFMADD213SSm_Int
    0U,	// VFMADD213SSr
    0U,	// VFMADD213SSr_Int
    0U,	// VFMADD231PDYm
    0U,	// VFMADD231PDYr
    0U,	// VFMADD231PDZ128m
    0U,	// VFMADD231PDZ128mb
    0U,	// VFMADD231PDZ128mbk
    0U,	// VFMADD231PDZ128mbkz
    0U,	// VFMADD231PDZ128mk
    0U,	// VFMADD231PDZ128mkz
    0U,	// VFMADD231PDZ128r
    0U,	// VFMADD231PDZ128rk
    0U,	// VFMADD231PDZ128rkz
    0U,	// VFMADD231PDZ256m
    0U,	// VFMADD231PDZ256mb
    0U,	// VFMADD231PDZ256mbk
    0U,	// VFMADD231PDZ256mbkz
    0U,	// VFMADD231PDZ256mk
    0U,	// VFMADD231PDZ256mkz
    0U,	// VFMADD231PDZ256r
    0U,	// VFMADD231PDZ256rk
    0U,	// VFMADD231PDZ256rkz
    0U,	// VFMADD231PDZm
    0U,	// VFMADD231PDZmb
    0U,	// VFMADD231PDZmbk
    0U,	// VFMADD231PDZmbkz
    0U,	// VFMADD231PDZmk
    0U,	// VFMADD231PDZmkz
    0U,	// VFMADD231PDZr
    0U,	// VFMADD231PDZrb
    0U,	// VFMADD231PDZrbk
    0U,	// VFMADD231PDZrbkz
    0U,	// VFMADD231PDZrk
    0U,	// VFMADD231PDZrkz
    0U,	// VFMADD231PDm
    0U,	// VFMADD231PDr
    0U,	// VFMADD231PSYm
    0U,	// VFMADD231PSYr
    0U,	// VFMADD231PSZ128m
    0U,	// VFMADD231PSZ128mb
    0U,	// VFMADD231PSZ128mbk
    0U,	// VFMADD231PSZ128mbkz
    0U,	// VFMADD231PSZ128mk
    0U,	// VFMADD231PSZ128mkz
    0U,	// VFMADD231PSZ128r
    0U,	// VFMADD231PSZ128rk
    0U,	// VFMADD231PSZ128rkz
    0U,	// VFMADD231PSZ256m
    0U,	// VFMADD231PSZ256mb
    0U,	// VFMADD231PSZ256mbk
    0U,	// VFMADD231PSZ256mbkz
    0U,	// VFMADD231PSZ256mk
    0U,	// VFMADD231PSZ256mkz
    0U,	// VFMADD231PSZ256r
    0U,	// VFMADD231PSZ256rk
    0U,	// VFMADD231PSZ256rkz
    0U,	// VFMADD231PSZm
    0U,	// VFMADD231PSZmb
    0U,	// VFMADD231PSZmbk
    0U,	// VFMADD231PSZmbkz
    0U,	// VFMADD231PSZmk
    0U,	// VFMADD231PSZmkz
    0U,	// VFMADD231PSZr
    0U,	// VFMADD231PSZrb
    0U,	// VFMADD231PSZrbk
    0U,	// VFMADD231PSZrbkz
    0U,	// VFMADD231PSZrk
    0U,	// VFMADD231PSZrkz
    0U,	// VFMADD231PSm
    0U,	// VFMADD231PSr
    0U,	// VFMADD231SDZm
    0U,	// VFMADD231SDZm_Int
    0U,	// VFMADD231SDZm_Intk
    0U,	// VFMADD231SDZm_Intkz
    0U,	// VFMADD231SDZr
    0U,	// VFMADD231SDZr_Int
    0U,	// VFMADD231SDZr_Intk
    0U,	// VFMADD231SDZr_Intkz
    0U,	// VFMADD231SDZrb
    0U,	// VFMADD231SDZrb_Int
    0U,	// VFMADD231SDZrb_Intk
    0U,	// VFMADD231SDZrb_Intkz
    0U,	// VFMADD231SDm
    0U,	// VFMADD231SDm_Int
    0U,	// VFMADD231SDr
    0U,	// VFMADD231SDr_Int
    0U,	// VFMADD231SSZm
    0U,	// VFMADD231SSZm_Int
    0U,	// VFMADD231SSZm_Intk
    0U,	// VFMADD231SSZm_Intkz
    0U,	// VFMADD231SSZr
    0U,	// VFMADD231SSZr_Int
    0U,	// VFMADD231SSZr_Intk
    0U,	// VFMADD231SSZr_Intkz
    0U,	// VFMADD231SSZrb
    0U,	// VFMADD231SSZrb_Int
    0U,	// VFMADD231SSZrb_Intk
    0U,	// VFMADD231SSZrb_Intkz
    0U,	// VFMADD231SSm
    0U,	// VFMADD231SSm_Int
    0U,	// VFMADD231SSr
    0U,	// VFMADD231SSr_Int
    0U,	// VFMADDPD4Ymr
    0U,	// VFMADDPD4Yrm
    0U,	// VFMADDPD4Yrr
    0U,	// VFMADDPD4Yrr_REV
    0U,	// VFMADDPD4mr
    0U,	// VFMADDPD4rm
    0U,	// VFMADDPD4rr
    0U,	// VFMADDPD4rr_REV
    0U,	// VFMADDPS4Ymr
    0U,	// VFMADDPS4Yrm
    0U,	// VFMADDPS4Yrr
    0U,	// VFMADDPS4Yrr_REV
    0U,	// VFMADDPS4mr
    0U,	// VFMADDPS4rm
    0U,	// VFMADDPS4rr
    0U,	// VFMADDPS4rr_REV
    0U,	// VFMADDSD4mr
    0U,	// VFMADDSD4mr_Int
    0U,	// VFMADDSD4rm
    0U,	// VFMADDSD4rm_Int
    0U,	// VFMADDSD4rr
    0U,	// VFMADDSD4rr_Int
    0U,	// VFMADDSD4rr_Int_REV
    0U,	// VFMADDSD4rr_REV
    0U,	// VFMADDSS4mr
    0U,	// VFMADDSS4mr_Int
    0U,	// VFMADDSS4rm
    0U,	// VFMADDSS4rm_Int
    0U,	// VFMADDSS4rr
    0U,	// VFMADDSS4rr_Int
    0U,	// VFMADDSS4rr_Int_REV
    0U,	// VFMADDSS4rr_REV
    0U,	// VFMADDSUB132PDYm
    0U,	// VFMADDSUB132PDYr
    0U,	// VFMADDSUB132PDZ128m
    0U,	// VFMADDSUB132PDZ128mb
    0U,	// VFMADDSUB132PDZ128mbk
    0U,	// VFMADDSUB132PDZ128mbkz
    0U,	// VFMADDSUB132PDZ128mk
    0U,	// VFMADDSUB132PDZ128mkz
    0U,	// VFMADDSUB132PDZ128r
    0U,	// VFMADDSUB132PDZ128rk
    0U,	// VFMADDSUB132PDZ128rkz
    0U,	// VFMADDSUB132PDZ256m
    0U,	// VFMADDSUB132PDZ256mb
    0U,	// VFMADDSUB132PDZ256mbk
    0U,	// VFMADDSUB132PDZ256mbkz
    0U,	// VFMADDSUB132PDZ256mk
    0U,	// VFMADDSUB132PDZ256mkz
    0U,	// VFMADDSUB132PDZ256r
    0U,	// VFMADDSUB132PDZ256rk
    0U,	// VFMADDSUB132PDZ256rkz
    0U,	// VFMADDSUB132PDZm
    0U,	// VFMADDSUB132PDZmb
    0U,	// VFMADDSUB132PDZmbk
    0U,	// VFMADDSUB132PDZmbkz
    0U,	// VFMADDSUB132PDZmk
    0U,	// VFMADDSUB132PDZmkz
    0U,	// VFMADDSUB132PDZr
    0U,	// VFMADDSUB132PDZrb
    0U,	// VFMADDSUB132PDZrbk
    0U,	// VFMADDSUB132PDZrbkz
    0U,	// VFMADDSUB132PDZrk
    0U,	// VFMADDSUB132PDZrkz
    0U,	// VFMADDSUB132PDm
    0U,	// VFMADDSUB132PDr
    0U,	// VFMADDSUB132PSYm
    0U,	// VFMADDSUB132PSYr
    0U,	// VFMADDSUB132PSZ128m
    0U,	// VFMADDSUB132PSZ128mb
    0U,	// VFMADDSUB132PSZ128mbk
    0U,	// VFMADDSUB132PSZ128mbkz
    0U,	// VFMADDSUB132PSZ128mk
    0U,	// VFMADDSUB132PSZ128mkz
    0U,	// VFMADDSUB132PSZ128r
    0U,	// VFMADDSUB132PSZ128rk
    0U,	// VFMADDSUB132PSZ128rkz
    0U,	// VFMADDSUB132PSZ256m
    0U,	// VFMADDSUB132PSZ256mb
    0U,	// VFMADDSUB132PSZ256mbk
    0U,	// VFMADDSUB132PSZ256mbkz
    0U,	// VFMADDSUB132PSZ256mk
    0U,	// VFMADDSUB132PSZ256mkz
    0U,	// VFMADDSUB132PSZ256r
    0U,	// VFMADDSUB132PSZ256rk
    0U,	// VFMADDSUB132PSZ256rkz
    0U,	// VFMADDSUB132PSZm
    0U,	// VFMADDSUB132PSZmb
    0U,	// VFMADDSUB132PSZmbk
    0U,	// VFMADDSUB132PSZmbkz
    0U,	// VFMADDSUB132PSZmk
    0U,	// VFMADDSUB132PSZmkz
    0U,	// VFMADDSUB132PSZr
    0U,	// VFMADDSUB132PSZrb
    0U,	// VFMADDSUB132PSZrbk
    0U,	// VFMADDSUB132PSZrbkz
    0U,	// VFMADDSUB132PSZrk
    0U,	// VFMADDSUB132PSZrkz
    0U,	// VFMADDSUB132PSm
    0U,	// VFMADDSUB132PSr
    0U,	// VFMADDSUB213PDYm
    0U,	// VFMADDSUB213PDYr
    0U,	// VFMADDSUB213PDZ128m
    0U,	// VFMADDSUB213PDZ128mb
    0U,	// VFMADDSUB213PDZ128mbk
    0U,	// VFMADDSUB213PDZ128mbkz
    0U,	// VFMADDSUB213PDZ128mk
    0U,	// VFMADDSUB213PDZ128mkz
    0U,	// VFMADDSUB213PDZ128r
    0U,	// VFMADDSUB213PDZ128rk
    0U,	// VFMADDSUB213PDZ128rkz
    0U,	// VFMADDSUB213PDZ256m
    0U,	// VFMADDSUB213PDZ256mb
    0U,	// VFMADDSUB213PDZ256mbk
    0U,	// VFMADDSUB213PDZ256mbkz
    0U,	// VFMADDSUB213PDZ256mk
    0U,	// VFMADDSUB213PDZ256mkz
    0U,	// VFMADDSUB213PDZ256r
    0U,	// VFMADDSUB213PDZ256rk
    0U,	// VFMADDSUB213PDZ256rkz
    0U,	// VFMADDSUB213PDZm
    0U,	// VFMADDSUB213PDZmb
    0U,	// VFMADDSUB213PDZmbk
    0U,	// VFMADDSUB213PDZmbkz
    0U,	// VFMADDSUB213PDZmk
    0U,	// VFMADDSUB213PDZmkz
    0U,	// VFMADDSUB213PDZr
    0U,	// VFMADDSUB213PDZrb
    0U,	// VFMADDSUB213PDZrbk
    0U,	// VFMADDSUB213PDZrbkz
    0U,	// VFMADDSUB213PDZrk
    0U,	// VFMADDSUB213PDZrkz
    0U,	// VFMADDSUB213PDm
    0U,	// VFMADDSUB213PDr
    0U,	// VFMADDSUB213PSYm
    0U,	// VFMADDSUB213PSYr
    0U,	// VFMADDSUB213PSZ128m
    0U,	// VFMADDSUB213PSZ128mb
    0U,	// VFMADDSUB213PSZ128mbk
    0U,	// VFMADDSUB213PSZ128mbkz
    0U,	// VFMADDSUB213PSZ128mk
    0U,	// VFMADDSUB213PSZ128mkz
    0U,	// VFMADDSUB213PSZ128r
    0U,	// VFMADDSUB213PSZ128rk
    0U,	// VFMADDSUB213PSZ128rkz
    0U,	// VFMADDSUB213PSZ256m
    0U,	// VFMADDSUB213PSZ256mb
    0U,	// VFMADDSUB213PSZ256mbk
    0U,	// VFMADDSUB213PSZ256mbkz
    0U,	// VFMADDSUB213PSZ256mk
    0U,	// VFMADDSUB213PSZ256mkz
    0U,	// VFMADDSUB213PSZ256r
    0U,	// VFMADDSUB213PSZ256rk
    0U,	// VFMADDSUB213PSZ256rkz
    0U,	// VFMADDSUB213PSZm
    0U,	// VFMADDSUB213PSZmb
    0U,	// VFMADDSUB213PSZmbk
    0U,	// VFMADDSUB213PSZmbkz
    0U,	// VFMADDSUB213PSZmk
    0U,	// VFMADDSUB213PSZmkz
    0U,	// VFMADDSUB213PSZr
    0U,	// VFMADDSUB213PSZrb
    0U,	// VFMADDSUB213PSZrbk
    0U,	// VFMADDSUB213PSZrbkz
    0U,	// VFMADDSUB213PSZrk
    0U,	// VFMADDSUB213PSZrkz
    0U,	// VFMADDSUB213PSm
    0U,	// VFMADDSUB213PSr
    0U,	// VFMADDSUB231PDYm
    0U,	// VFMADDSUB231PDYr
    0U,	// VFMADDSUB231PDZ128m
    0U,	// VFMADDSUB231PDZ128mb
    0U,	// VFMADDSUB231PDZ128mbk
    0U,	// VFMADDSUB231PDZ128mbkz
    0U,	// VFMADDSUB231PDZ128mk
    0U,	// VFMADDSUB231PDZ128mkz
    0U,	// VFMADDSUB231PDZ128r
    0U,	// VFMADDSUB231PDZ128rk
    0U,	// VFMADDSUB231PDZ128rkz
    0U,	// VFMADDSUB231PDZ256m
    0U,	// VFMADDSUB231PDZ256mb
    0U,	// VFMADDSUB231PDZ256mbk
    0U,	// VFMADDSUB231PDZ256mbkz
    0U,	// VFMADDSUB231PDZ256mk
    0U,	// VFMADDSUB231PDZ256mkz
    0U,	// VFMADDSUB231PDZ256r
    0U,	// VFMADDSUB231PDZ256rk
    0U,	// VFMADDSUB231PDZ256rkz
    0U,	// VFMADDSUB231PDZm
    0U,	// VFMADDSUB231PDZmb
    0U,	// VFMADDSUB231PDZmbk
    0U,	// VFMADDSUB231PDZmbkz
    0U,	// VFMADDSUB231PDZmk
    0U,	// VFMADDSUB231PDZmkz
    0U,	// VFMADDSUB231PDZr
    0U,	// VFMADDSUB231PDZrb
    0U,	// VFMADDSUB231PDZrbk
    0U,	// VFMADDSUB231PDZrbkz
    0U,	// VFMADDSUB231PDZrk
    0U,	// VFMADDSUB231PDZrkz
    0U,	// VFMADDSUB231PDm
    0U,	// VFMADDSUB231PDr
    0U,	// VFMADDSUB231PSYm
    0U,	// VFMADDSUB231PSYr
    0U,	// VFMADDSUB231PSZ128m
    0U,	// VFMADDSUB231PSZ128mb
    0U,	// VFMADDSUB231PSZ128mbk
    0U,	// VFMADDSUB231PSZ128mbkz
    0U,	// VFMADDSUB231PSZ128mk
    0U,	// VFMADDSUB231PSZ128mkz
    0U,	// VFMADDSUB231PSZ128r
    0U,	// VFMADDSUB231PSZ128rk
    0U,	// VFMADDSUB231PSZ128rkz
    0U,	// VFMADDSUB231PSZ256m
    0U,	// VFMADDSUB231PSZ256mb
    0U,	// VFMADDSUB231PSZ256mbk
    0U,	// VFMADDSUB231PSZ256mbkz
    0U,	// VFMADDSUB231PSZ256mk
    0U,	// VFMADDSUB231PSZ256mkz
    0U,	// VFMADDSUB231PSZ256r
    0U,	// VFMADDSUB231PSZ256rk
    0U,	// VFMADDSUB231PSZ256rkz
    0U,	// VFMADDSUB231PSZm
    0U,	// VFMADDSUB231PSZmb
    0U,	// VFMADDSUB231PSZmbk
    0U,	// VFMADDSUB231PSZmbkz
    0U,	// VFMADDSUB231PSZmk
    0U,	// VFMADDSUB231PSZmkz
    0U,	// VFMADDSUB231PSZr
    0U,	// VFMADDSUB231PSZrb
    0U,	// VFMADDSUB231PSZrbk
    0U,	// VFMADDSUB231PSZrbkz
    0U,	// VFMADDSUB231PSZrk
    0U,	// VFMADDSUB231PSZrkz
    0U,	// VFMADDSUB231PSm
    0U,	// VFMADDSUB231PSr
    0U,	// VFMADDSUBPD4Ymr
    0U,	// VFMADDSUBPD4Yrm
    0U,	// VFMADDSUBPD4Yrr
    0U,	// VFMADDSUBPD4Yrr_REV
    0U,	// VFMADDSUBPD4mr
    0U,	// VFMADDSUBPD4rm
    0U,	// VFMADDSUBPD4rr
    0U,	// VFMADDSUBPD4rr_REV
    0U,	// VFMADDSUBPS4Ymr
    0U,	// VFMADDSUBPS4Yrm
    0U,	// VFMADDSUBPS4Yrr
    0U,	// VFMADDSUBPS4Yrr_REV
    0U,	// VFMADDSUBPS4mr
    0U,	// VFMADDSUBPS4rm
    0U,	// VFMADDSUBPS4rr
    0U,	// VFMADDSUBPS4rr_REV
    0U,	// VFMSUB132PDYm
    0U,	// VFMSUB132PDYr
    0U,	// VFMSUB132PDZ128m
    0U,	// VFMSUB132PDZ128mb
    0U,	// VFMSUB132PDZ128mbk
    0U,	// VFMSUB132PDZ128mbkz
    0U,	// VFMSUB132PDZ128mk
    0U,	// VFMSUB132PDZ128mkz
    0U,	// VFMSUB132PDZ128r
    0U,	// VFMSUB132PDZ128rk
    0U,	// VFMSUB132PDZ128rkz
    0U,	// VFMSUB132PDZ256m
    0U,	// VFMSUB132PDZ256mb
    0U,	// VFMSUB132PDZ256mbk
    0U,	// VFMSUB132PDZ256mbkz
    0U,	// VFMSUB132PDZ256mk
    0U,	// VFMSUB132PDZ256mkz
    0U,	// VFMSUB132PDZ256r
    0U,	// VFMSUB132PDZ256rk
    0U,	// VFMSUB132PDZ256rkz
    0U,	// VFMSUB132PDZm
    0U,	// VFMSUB132PDZmb
    0U,	// VFMSUB132PDZmbk
    0U,	// VFMSUB132PDZmbkz
    0U,	// VFMSUB132PDZmk
    0U,	// VFMSUB132PDZmkz
    0U,	// VFMSUB132PDZr
    0U,	// VFMSUB132PDZrb
    0U,	// VFMSUB132PDZrbk
    0U,	// VFMSUB132PDZrbkz
    0U,	// VFMSUB132PDZrk
    0U,	// VFMSUB132PDZrkz
    0U,	// VFMSUB132PDm
    0U,	// VFMSUB132PDr
    0U,	// VFMSUB132PSYm
    0U,	// VFMSUB132PSYr
    0U,	// VFMSUB132PSZ128m
    0U,	// VFMSUB132PSZ128mb
    0U,	// VFMSUB132PSZ128mbk
    0U,	// VFMSUB132PSZ128mbkz
    0U,	// VFMSUB132PSZ128mk
    0U,	// VFMSUB132PSZ128mkz
    0U,	// VFMSUB132PSZ128r
    0U,	// VFMSUB132PSZ128rk
    0U,	// VFMSUB132PSZ128rkz
    0U,	// VFMSUB132PSZ256m
    0U,	// VFMSUB132PSZ256mb
    0U,	// VFMSUB132PSZ256mbk
    0U,	// VFMSUB132PSZ256mbkz
    0U,	// VFMSUB132PSZ256mk
    0U,	// VFMSUB132PSZ256mkz
    0U,	// VFMSUB132PSZ256r
    0U,	// VFMSUB132PSZ256rk
    0U,	// VFMSUB132PSZ256rkz
    0U,	// VFMSUB132PSZm
    0U,	// VFMSUB132PSZmb
    0U,	// VFMSUB132PSZmbk
    0U,	// VFMSUB132PSZmbkz
    0U,	// VFMSUB132PSZmk
    0U,	// VFMSUB132PSZmkz
    0U,	// VFMSUB132PSZr
    0U,	// VFMSUB132PSZrb
    0U,	// VFMSUB132PSZrbk
    0U,	// VFMSUB132PSZrbkz
    0U,	// VFMSUB132PSZrk
    0U,	// VFMSUB132PSZrkz
    0U,	// VFMSUB132PSm
    0U,	// VFMSUB132PSr
    0U,	// VFMSUB132SDZm
    0U,	// VFMSUB132SDZm_Int
    0U,	// VFMSUB132SDZm_Intk
    0U,	// VFMSUB132SDZm_Intkz
    0U,	// VFMSUB132SDZr
    0U,	// VFMSUB132SDZr_Int
    0U,	// VFMSUB132SDZr_Intk
    0U,	// VFMSUB132SDZr_Intkz
    0U,	// VFMSUB132SDZrb
    0U,	// VFMSUB132SDZrb_Int
    0U,	// VFMSUB132SDZrb_Intk
    0U,	// VFMSUB132SDZrb_Intkz
    0U,	// VFMSUB132SDm
    0U,	// VFMSUB132SDm_Int
    0U,	// VFMSUB132SDr
    0U,	// VFMSUB132SDr_Int
    0U,	// VFMSUB132SSZm
    0U,	// VFMSUB132SSZm_Int
    0U,	// VFMSUB132SSZm_Intk
    0U,	// VFMSUB132SSZm_Intkz
    0U,	// VFMSUB132SSZr
    0U,	// VFMSUB132SSZr_Int
    0U,	// VFMSUB132SSZr_Intk
    0U,	// VFMSUB132SSZr_Intkz
    0U,	// VFMSUB132SSZrb
    0U,	// VFMSUB132SSZrb_Int
    0U,	// VFMSUB132SSZrb_Intk
    0U,	// VFMSUB132SSZrb_Intkz
    0U,	// VFMSUB132SSm
    0U,	// VFMSUB132SSm_Int
    0U,	// VFMSUB132SSr
    0U,	// VFMSUB132SSr_Int
    0U,	// VFMSUB213PDYm
    0U,	// VFMSUB213PDYr
    0U,	// VFMSUB213PDZ128m
    0U,	// VFMSUB213PDZ128mb
    0U,	// VFMSUB213PDZ128mbk
    0U,	// VFMSUB213PDZ128mbkz
    0U,	// VFMSUB213PDZ128mk
    0U,	// VFMSUB213PDZ128mkz
    0U,	// VFMSUB213PDZ128r
    0U,	// VFMSUB213PDZ128rk
    0U,	// VFMSUB213PDZ128rkz
    0U,	// VFMSUB213PDZ256m
    0U,	// VFMSUB213PDZ256mb
    0U,	// VFMSUB213PDZ256mbk
    0U,	// VFMSUB213PDZ256mbkz
    0U,	// VFMSUB213PDZ256mk
    0U,	// VFMSUB213PDZ256mkz
    0U,	// VFMSUB213PDZ256r
    0U,	// VFMSUB213PDZ256rk
    0U,	// VFMSUB213PDZ256rkz
    0U,	// VFMSUB213PDZm
    0U,	// VFMSUB213PDZmb
    0U,	// VFMSUB213PDZmbk
    0U,	// VFMSUB213PDZmbkz
    0U,	// VFMSUB213PDZmk
    0U,	// VFMSUB213PDZmkz
    0U,	// VFMSUB213PDZr
    0U,	// VFMSUB213PDZrb
    0U,	// VFMSUB213PDZrbk
    0U,	// VFMSUB213PDZrbkz
    0U,	// VFMSUB213PDZrk
    0U,	// VFMSUB213PDZrkz
    0U,	// VFMSUB213PDm
    0U,	// VFMSUB213PDr
    0U,	// VFMSUB213PSYm
    0U,	// VFMSUB213PSYr
    0U,	// VFMSUB213PSZ128m
    0U,	// VFMSUB213PSZ128mb
    0U,	// VFMSUB213PSZ128mbk
    0U,	// VFMSUB213PSZ128mbkz
    0U,	// VFMSUB213PSZ128mk
    0U,	// VFMSUB213PSZ128mkz
    0U,	// VFMSUB213PSZ128r
    0U,	// VFMSUB213PSZ128rk
    0U,	// VFMSUB213PSZ128rkz
    0U,	// VFMSUB213PSZ256m
    0U,	// VFMSUB213PSZ256mb
    0U,	// VFMSUB213PSZ256mbk
    0U,	// VFMSUB213PSZ256mbkz
    0U,	// VFMSUB213PSZ256mk
    0U,	// VFMSUB213PSZ256mkz
    0U,	// VFMSUB213PSZ256r
    0U,	// VFMSUB213PSZ256rk
    0U,	// VFMSUB213PSZ256rkz
    0U,	// VFMSUB213PSZm
    0U,	// VFMSUB213PSZmb
    0U,	// VFMSUB213PSZmbk
    0U,	// VFMSUB213PSZmbkz
    0U,	// VFMSUB213PSZmk
    0U,	// VFMSUB213PSZmkz
    0U,	// VFMSUB213PSZr
    0U,	// VFMSUB213PSZrb
    0U,	// VFMSUB213PSZrbk
    0U,	// VFMSUB213PSZrbkz
    0U,	// VFMSUB213PSZrk
    0U,	// VFMSUB213PSZrkz
    0U,	// VFMSUB213PSm
    0U,	// VFMSUB213PSr
    0U,	// VFMSUB213SDZm
    0U,	// VFMSUB213SDZm_Int
    0U,	// VFMSUB213SDZm_Intk
    0U,	// VFMSUB213SDZm_Intkz
    0U,	// VFMSUB213SDZr
    0U,	// VFMSUB213SDZr_Int
    0U,	// VFMSUB213SDZr_Intk
    0U,	// VFMSUB213SDZr_Intkz
    0U,	// VFMSUB213SDZrb
    0U,	// VFMSUB213SDZrb_Int
    0U,	// VFMSUB213SDZrb_Intk
    0U,	// VFMSUB213SDZrb_Intkz
    0U,	// VFMSUB213SDm
    0U,	// VFMSUB213SDm_Int
    0U,	// VFMSUB213SDr
    0U,	// VFMSUB213SDr_Int
    0U,	// VFMSUB213SSZm
    0U,	// VFMSUB213SSZm_Int
    0U,	// VFMSUB213SSZm_Intk
    0U,	// VFMSUB213SSZm_Intkz
    0U,	// VFMSUB213SSZr
    0U,	// VFMSUB213SSZr_Int
    0U,	// VFMSUB213SSZr_Intk
    0U,	// VFMSUB213SSZr_Intkz
    0U,	// VFMSUB213SSZrb
    0U,	// VFMSUB213SSZrb_Int
    0U,	// VFMSUB213SSZrb_Intk
    0U,	// VFMSUB213SSZrb_Intkz
    0U,	// VFMSUB213SSm
    0U,	// VFMSUB213SSm_Int
    0U,	// VFMSUB213SSr
    0U,	// VFMSUB213SSr_Int
    0U,	// VFMSUB231PDYm
    0U,	// VFMSUB231PDYr
    0U,	// VFMSUB231PDZ128m
    0U,	// VFMSUB231PDZ128mb
    0U,	// VFMSUB231PDZ128mbk
    0U,	// VFMSUB231PDZ128mbkz
    0U,	// VFMSUB231PDZ128mk
    0U,	// VFMSUB231PDZ128mkz
    0U,	// VFMSUB231PDZ128r
    0U,	// VFMSUB231PDZ128rk
    0U,	// VFMSUB231PDZ128rkz
    0U,	// VFMSUB231PDZ256m
    0U,	// VFMSUB231PDZ256mb
    0U,	// VFMSUB231PDZ256mbk
    0U,	// VFMSUB231PDZ256mbkz
    0U,	// VFMSUB231PDZ256mk
    0U,	// VFMSUB231PDZ256mkz
    0U,	// VFMSUB231PDZ256r
    0U,	// VFMSUB231PDZ256rk
    0U,	// VFMSUB231PDZ256rkz
    0U,	// VFMSUB231PDZm
    0U,	// VFMSUB231PDZmb
    0U,	// VFMSUB231PDZmbk
    0U,	// VFMSUB231PDZmbkz
    0U,	// VFMSUB231PDZmk
    0U,	// VFMSUB231PDZmkz
    0U,	// VFMSUB231PDZr
    0U,	// VFMSUB231PDZrb
    0U,	// VFMSUB231PDZrbk
    0U,	// VFMSUB231PDZrbkz
    0U,	// VFMSUB231PDZrk
    0U,	// VFMSUB231PDZrkz
    0U,	// VFMSUB231PDm
    0U,	// VFMSUB231PDr
    0U,	// VFMSUB231PSYm
    0U,	// VFMSUB231PSYr
    0U,	// VFMSUB231PSZ128m
    0U,	// VFMSUB231PSZ128mb
    0U,	// VFMSUB231PSZ128mbk
    0U,	// VFMSUB231PSZ128mbkz
    0U,	// VFMSUB231PSZ128mk
    0U,	// VFMSUB231PSZ128mkz
    0U,	// VFMSUB231PSZ128r
    0U,	// VFMSUB231PSZ128rk
    0U,	// VFMSUB231PSZ128rkz
    0U,	// VFMSUB231PSZ256m
    0U,	// VFMSUB231PSZ256mb
    0U,	// VFMSUB231PSZ256mbk
    0U,	// VFMSUB231PSZ256mbkz
    0U,	// VFMSUB231PSZ256mk
    0U,	// VFMSUB231PSZ256mkz
    0U,	// VFMSUB231PSZ256r
    0U,	// VFMSUB231PSZ256rk
    0U,	// VFMSUB231PSZ256rkz
    0U,	// VFMSUB231PSZm
    0U,	// VFMSUB231PSZmb
    0U,	// VFMSUB231PSZmbk
    0U,	// VFMSUB231PSZmbkz
    0U,	// VFMSUB231PSZmk
    0U,	// VFMSUB231PSZmkz
    0U,	// VFMSUB231PSZr
    0U,	// VFMSUB231PSZrb
    0U,	// VFMSUB231PSZrbk
    0U,	// VFMSUB231PSZrbkz
    0U,	// VFMSUB231PSZrk
    0U,	// VFMSUB231PSZrkz
    0U,	// VFMSUB231PSm
    0U,	// VFMSUB231PSr
    0U,	// VFMSUB231SDZm
    0U,	// VFMSUB231SDZm_Int
    0U,	// VFMSUB231SDZm_Intk
    0U,	// VFMSUB231SDZm_Intkz
    0U,	// VFMSUB231SDZr
    0U,	// VFMSUB231SDZr_Int
    0U,	// VFMSUB231SDZr_Intk
    0U,	// VFMSUB231SDZr_Intkz
    0U,	// VFMSUB231SDZrb
    0U,	// VFMSUB231SDZrb_Int
    0U,	// VFMSUB231SDZrb_Intk
    0U,	// VFMSUB231SDZrb_Intkz
    0U,	// VFMSUB231SDm
    0U,	// VFMSUB231SDm_Int
    0U,	// VFMSUB231SDr
    0U,	// VFMSUB231SDr_Int
    0U,	// VFMSUB231SSZm
    0U,	// VFMSUB231SSZm_Int
    0U,	// VFMSUB231SSZm_Intk
    0U,	// VFMSUB231SSZm_Intkz
    0U,	// VFMSUB231SSZr
    0U,	// VFMSUB231SSZr_Int
    0U,	// VFMSUB231SSZr_Intk
    0U,	// VFMSUB231SSZr_Intkz
    0U,	// VFMSUB231SSZrb
    0U,	// VFMSUB231SSZrb_Int
    0U,	// VFMSUB231SSZrb_Intk
    0U,	// VFMSUB231SSZrb_Intkz
    0U,	// VFMSUB231SSm
    0U,	// VFMSUB231SSm_Int
    0U,	// VFMSUB231SSr
    0U,	// VFMSUB231SSr_Int
    0U,	// VFMSUBADD132PDYm
    0U,	// VFMSUBADD132PDYr
    0U,	// VFMSUBADD132PDZ128m
    0U,	// VFMSUBADD132PDZ128mb
    0U,	// VFMSUBADD132PDZ128mbk
    0U,	// VFMSUBADD132PDZ128mbkz
    0U,	// VFMSUBADD132PDZ128mk
    0U,	// VFMSUBADD132PDZ128mkz
    0U,	// VFMSUBADD132PDZ128r
    0U,	// VFMSUBADD132PDZ128rk
    0U,	// VFMSUBADD132PDZ128rkz
    0U,	// VFMSUBADD132PDZ256m
    0U,	// VFMSUBADD132PDZ256mb
    0U,	// VFMSUBADD132PDZ256mbk
    0U,	// VFMSUBADD132PDZ256mbkz
    0U,	// VFMSUBADD132PDZ256mk
    0U,	// VFMSUBADD132PDZ256mkz
    0U,	// VFMSUBADD132PDZ256r
    0U,	// VFMSUBADD132PDZ256rk
    0U,	// VFMSUBADD132PDZ256rkz
    0U,	// VFMSUBADD132PDZm
    0U,	// VFMSUBADD132PDZmb
    0U,	// VFMSUBADD132PDZmbk
    0U,	// VFMSUBADD132PDZmbkz
    0U,	// VFMSUBADD132PDZmk
    0U,	// VFMSUBADD132PDZmkz
    0U,	// VFMSUBADD132PDZr
    0U,	// VFMSUBADD132PDZrb
    0U,	// VFMSUBADD132PDZrbk
    0U,	// VFMSUBADD132PDZrbkz
    0U,	// VFMSUBADD132PDZrk
    0U,	// VFMSUBADD132PDZrkz
    0U,	// VFMSUBADD132PDm
    0U,	// VFMSUBADD132PDr
    0U,	// VFMSUBADD132PSYm
    0U,	// VFMSUBADD132PSYr
    0U,	// VFMSUBADD132PSZ128m
    0U,	// VFMSUBADD132PSZ128mb
    0U,	// VFMSUBADD132PSZ128mbk
    0U,	// VFMSUBADD132PSZ128mbkz
    0U,	// VFMSUBADD132PSZ128mk
    0U,	// VFMSUBADD132PSZ128mkz
    0U,	// VFMSUBADD132PSZ128r
    0U,	// VFMSUBADD132PSZ128rk
    0U,	// VFMSUBADD132PSZ128rkz
    0U,	// VFMSUBADD132PSZ256m
    0U,	// VFMSUBADD132PSZ256mb
    0U,	// VFMSUBADD132PSZ256mbk
    0U,	// VFMSUBADD132PSZ256mbkz
    0U,	// VFMSUBADD132PSZ256mk
    0U,	// VFMSUBADD132PSZ256mkz
    0U,	// VFMSUBADD132PSZ256r
    0U,	// VFMSUBADD132PSZ256rk
    0U,	// VFMSUBADD132PSZ256rkz
    0U,	// VFMSUBADD132PSZm
    0U,	// VFMSUBADD132PSZmb
    0U,	// VFMSUBADD132PSZmbk
    0U,	// VFMSUBADD132PSZmbkz
    0U,	// VFMSUBADD132PSZmk
    0U,	// VFMSUBADD132PSZmkz
    0U,	// VFMSUBADD132PSZr
    0U,	// VFMSUBADD132PSZrb
    0U,	// VFMSUBADD132PSZrbk
    0U,	// VFMSUBADD132PSZrbkz
    0U,	// VFMSUBADD132PSZrk
    0U,	// VFMSUBADD132PSZrkz
    0U,	// VFMSUBADD132PSm
    0U,	// VFMSUBADD132PSr
    0U,	// VFMSUBADD213PDYm
    0U,	// VFMSUBADD213PDYr
    0U,	// VFMSUBADD213PDZ128m
    0U,	// VFMSUBADD213PDZ128mb
    0U,	// VFMSUBADD213PDZ128mbk
    0U,	// VFMSUBADD213PDZ128mbkz
    0U,	// VFMSUBADD213PDZ128mk
    0U,	// VFMSUBADD213PDZ128mkz
    0U,	// VFMSUBADD213PDZ128r
    0U,	// VFMSUBADD213PDZ128rk
    0U,	// VFMSUBADD213PDZ128rkz
    0U,	// VFMSUBADD213PDZ256m
    0U,	// VFMSUBADD213PDZ256mb
    0U,	// VFMSUBADD213PDZ256mbk
    0U,	// VFMSUBADD213PDZ256mbkz
    0U,	// VFMSUBADD213PDZ256mk
    0U,	// VFMSUBADD213PDZ256mkz
    0U,	// VFMSUBADD213PDZ256r
    0U,	// VFMSUBADD213PDZ256rk
    0U,	// VFMSUBADD213PDZ256rkz
    0U,	// VFMSUBADD213PDZm
    0U,	// VFMSUBADD213PDZmb
    0U,	// VFMSUBADD213PDZmbk
    0U,	// VFMSUBADD213PDZmbkz
    0U,	// VFMSUBADD213PDZmk
    0U,	// VFMSUBADD213PDZmkz
    0U,	// VFMSUBADD213PDZr
    0U,	// VFMSUBADD213PDZrb
    0U,	// VFMSUBADD213PDZrbk
    0U,	// VFMSUBADD213PDZrbkz
    0U,	// VFMSUBADD213PDZrk
    0U,	// VFMSUBADD213PDZrkz
    0U,	// VFMSUBADD213PDm
    0U,	// VFMSUBADD213PDr
    0U,	// VFMSUBADD213PSYm
    0U,	// VFMSUBADD213PSYr
    0U,	// VFMSUBADD213PSZ128m
    0U,	// VFMSUBADD213PSZ128mb
    0U,	// VFMSUBADD213PSZ128mbk
    0U,	// VFMSUBADD213PSZ128mbkz
    0U,	// VFMSUBADD213PSZ128mk
    0U,	// VFMSUBADD213PSZ128mkz
    0U,	// VFMSUBADD213PSZ128r
    0U,	// VFMSUBADD213PSZ128rk
    0U,	// VFMSUBADD213PSZ128rkz
    0U,	// VFMSUBADD213PSZ256m
    0U,	// VFMSUBADD213PSZ256mb
    0U,	// VFMSUBADD213PSZ256mbk
    0U,	// VFMSUBADD213PSZ256mbkz
    0U,	// VFMSUBADD213PSZ256mk
    0U,	// VFMSUBADD213PSZ256mkz
    0U,	// VFMSUBADD213PSZ256r
    0U,	// VFMSUBADD213PSZ256rk
    0U,	// VFMSUBADD213PSZ256rkz
    0U,	// VFMSUBADD213PSZm
    0U,	// VFMSUBADD213PSZmb
    0U,	// VFMSUBADD213PSZmbk
    0U,	// VFMSUBADD213PSZmbkz
    0U,	// VFMSUBADD213PSZmk
    0U,	// VFMSUBADD213PSZmkz
    0U,	// VFMSUBADD213PSZr
    0U,	// VFMSUBADD213PSZrb
    0U,	// VFMSUBADD213PSZrbk
    0U,	// VFMSUBADD213PSZrbkz
    0U,	// VFMSUBADD213PSZrk
    0U,	// VFMSUBADD213PSZrkz
    0U,	// VFMSUBADD213PSm
    0U,	// VFMSUBADD213PSr
    0U,	// VFMSUBADD231PDYm
    0U,	// VFMSUBADD231PDYr
    0U,	// VFMSUBADD231PDZ128m
    0U,	// VFMSUBADD231PDZ128mb
    0U,	// VFMSUBADD231PDZ128mbk
    0U,	// VFMSUBADD231PDZ128mbkz
    0U,	// VFMSUBADD231PDZ128mk
    0U,	// VFMSUBADD231PDZ128mkz
    0U,	// VFMSUBADD231PDZ128r
    0U,	// VFMSUBADD231PDZ128rk
    0U,	// VFMSUBADD231PDZ128rkz
    0U,	// VFMSUBADD231PDZ256m
    0U,	// VFMSUBADD231PDZ256mb
    0U,	// VFMSUBADD231PDZ256mbk
    0U,	// VFMSUBADD231PDZ256mbkz
    0U,	// VFMSUBADD231PDZ256mk
    0U,	// VFMSUBADD231PDZ256mkz
    0U,	// VFMSUBADD231PDZ256r
    0U,	// VFMSUBADD231PDZ256rk
    0U,	// VFMSUBADD231PDZ256rkz
    0U,	// VFMSUBADD231PDZm
    0U,	// VFMSUBADD231PDZmb
    0U,	// VFMSUBADD231PDZmbk
    0U,	// VFMSUBADD231PDZmbkz
    0U,	// VFMSUBADD231PDZmk
    0U,	// VFMSUBADD231PDZmkz
    0U,	// VFMSUBADD231PDZr
    0U,	// VFMSUBADD231PDZrb
    0U,	// VFMSUBADD231PDZrbk
    0U,	// VFMSUBADD231PDZrbkz
    0U,	// VFMSUBADD231PDZrk
    0U,	// VFMSUBADD231PDZrkz
    0U,	// VFMSUBADD231PDm
    0U,	// VFMSUBADD231PDr
    0U,	// VFMSUBADD231PSYm
    0U,	// VFMSUBADD231PSYr
    0U,	// VFMSUBADD231PSZ128m
    0U,	// VFMSUBADD231PSZ128mb
    0U,	// VFMSUBADD231PSZ128mbk
    0U,	// VFMSUBADD231PSZ128mbkz
    0U,	// VFMSUBADD231PSZ128mk
    0U,	// VFMSUBADD231PSZ128mkz
    0U,	// VFMSUBADD231PSZ128r
    0U,	// VFMSUBADD231PSZ128rk
    0U,	// VFMSUBADD231PSZ128rkz
    0U,	// VFMSUBADD231PSZ256m
    0U,	// VFMSUBADD231PSZ256mb
    0U,	// VFMSUBADD231PSZ256mbk
    0U,	// VFMSUBADD231PSZ256mbkz
    0U,	// VFMSUBADD231PSZ256mk
    0U,	// VFMSUBADD231PSZ256mkz
    0U,	// VFMSUBADD231PSZ256r
    0U,	// VFMSUBADD231PSZ256rk
    0U,	// VFMSUBADD231PSZ256rkz
    0U,	// VFMSUBADD231PSZm
    0U,	// VFMSUBADD231PSZmb
    0U,	// VFMSUBADD231PSZmbk
    0U,	// VFMSUBADD231PSZmbkz
    0U,	// VFMSUBADD231PSZmk
    0U,	// VFMSUBADD231PSZmkz
    0U,	// VFMSUBADD231PSZr
    0U,	// VFMSUBADD231PSZrb
    0U,	// VFMSUBADD231PSZrbk
    0U,	// VFMSUBADD231PSZrbkz
    0U,	// VFMSUBADD231PSZrk
    0U,	// VFMSUBADD231PSZrkz
    0U,	// VFMSUBADD231PSm
    0U,	// VFMSUBADD231PSr
    0U,	// VFMSUBADDPD4Ymr
    0U,	// VFMSUBADDPD4Yrm
    0U,	// VFMSUBADDPD4Yrr
    0U,	// VFMSUBADDPD4Yrr_REV
    0U,	// VFMSUBADDPD4mr
    0U,	// VFMSUBADDPD4rm
    0U,	// VFMSUBADDPD4rr
    0U,	// VFMSUBADDPD4rr_REV
    0U,	// VFMSUBADDPS4Ymr
    0U,	// VFMSUBADDPS4Yrm
    0U,	// VFMSUBADDPS4Yrr
    0U,	// VFMSUBADDPS4Yrr_REV
    0U,	// VFMSUBADDPS4mr
    0U,	// VFMSUBADDPS4rm
    0U,	// VFMSUBADDPS4rr
    0U,	// VFMSUBADDPS4rr_REV
    0U,	// VFMSUBPD4Ymr
    0U,	// VFMSUBPD4Yrm
    0U,	// VFMSUBPD4Yrr
    0U,	// VFMSUBPD4Yrr_REV
    0U,	// VFMSUBPD4mr
    0U,	// VFMSUBPD4rm
    0U,	// VFMSUBPD4rr
    0U,	// VFMSUBPD4rr_REV
    0U,	// VFMSUBPS4Ymr
    0U,	// VFMSUBPS4Yrm
    0U,	// VFMSUBPS4Yrr
    0U,	// VFMSUBPS4Yrr_REV
    0U,	// VFMSUBPS4mr
    0U,	// VFMSUBPS4rm
    0U,	// VFMSUBPS4rr
    0U,	// VFMSUBPS4rr_REV
    0U,	// VFMSUBSD4mr
    0U,	// VFMSUBSD4mr_Int
    0U,	// VFMSUBSD4rm
    0U,	// VFMSUBSD4rm_Int
    0U,	// VFMSUBSD4rr
    0U,	// VFMSUBSD4rr_Int
    0U,	// VFMSUBSD4rr_Int_REV
    0U,	// VFMSUBSD4rr_REV
    0U,	// VFMSUBSS4mr
    0U,	// VFMSUBSS4mr_Int
    0U,	// VFMSUBSS4rm
    0U,	// VFMSUBSS4rm_Int
    0U,	// VFMSUBSS4rr
    0U,	// VFMSUBSS4rr_Int
    0U,	// VFMSUBSS4rr_Int_REV
    0U,	// VFMSUBSS4rr_REV
    0U,	// VFNMADD132PDYm
    0U,	// VFNMADD132PDYr
    0U,	// VFNMADD132PDZ128m
    0U,	// VFNMADD132PDZ128mb
    0U,	// VFNMADD132PDZ128mbk
    0U,	// VFNMADD132PDZ128mbkz
    0U,	// VFNMADD132PDZ128mk
    0U,	// VFNMADD132PDZ128mkz
    0U,	// VFNMADD132PDZ128r
    0U,	// VFNMADD132PDZ128rk
    0U,	// VFNMADD132PDZ128rkz
    0U,	// VFNMADD132PDZ256m
    0U,	// VFNMADD132PDZ256mb
    0U,	// VFNMADD132PDZ256mbk
    0U,	// VFNMADD132PDZ256mbkz
    0U,	// VFNMADD132PDZ256mk
    0U,	// VFNMADD132PDZ256mkz
    0U,	// VFNMADD132PDZ256r
    0U,	// VFNMADD132PDZ256rk
    0U,	// VFNMADD132PDZ256rkz
    0U,	// VFNMADD132PDZm
    0U,	// VFNMADD132PDZmb
    0U,	// VFNMADD132PDZmbk
    0U,	// VFNMADD132PDZmbkz
    0U,	// VFNMADD132PDZmk
    0U,	// VFNMADD132PDZmkz
    0U,	// VFNMADD132PDZr
    0U,	// VFNMADD132PDZrb
    0U,	// VFNMADD132PDZrbk
    0U,	// VFNMADD132PDZrbkz
    0U,	// VFNMADD132PDZrk
    0U,	// VFNMADD132PDZrkz
    0U,	// VFNMADD132PDm
    0U,	// VFNMADD132PDr
    0U,	// VFNMADD132PSYm
    0U,	// VFNMADD132PSYr
    0U,	// VFNMADD132PSZ128m
    0U,	// VFNMADD132PSZ128mb
    0U,	// VFNMADD132PSZ128mbk
    0U,	// VFNMADD132PSZ128mbkz
    0U,	// VFNMADD132PSZ128mk
    0U,	// VFNMADD132PSZ128mkz
    0U,	// VFNMADD132PSZ128r
    0U,	// VFNMADD132PSZ128rk
    0U,	// VFNMADD132PSZ128rkz
    0U,	// VFNMADD132PSZ256m
    0U,	// VFNMADD132PSZ256mb
    0U,	// VFNMADD132PSZ256mbk
    0U,	// VFNMADD132PSZ256mbkz
    0U,	// VFNMADD132PSZ256mk
    0U,	// VFNMADD132PSZ256mkz
    0U,	// VFNMADD132PSZ256r
    0U,	// VFNMADD132PSZ256rk
    0U,	// VFNMADD132PSZ256rkz
    0U,	// VFNMADD132PSZm
    0U,	// VFNMADD132PSZmb
    0U,	// VFNMADD132PSZmbk
    0U,	// VFNMADD132PSZmbkz
    0U,	// VFNMADD132PSZmk
    0U,	// VFNMADD132PSZmkz
    0U,	// VFNMADD132PSZr
    0U,	// VFNMADD132PSZrb
    0U,	// VFNMADD132PSZrbk
    0U,	// VFNMADD132PSZrbkz
    0U,	// VFNMADD132PSZrk
    0U,	// VFNMADD132PSZrkz
    0U,	// VFNMADD132PSm
    0U,	// VFNMADD132PSr
    0U,	// VFNMADD132SDZm
    0U,	// VFNMADD132SDZm_Int
    0U,	// VFNMADD132SDZm_Intk
    0U,	// VFNMADD132SDZm_Intkz
    0U,	// VFNMADD132SDZr
    0U,	// VFNMADD132SDZr_Int
    0U,	// VFNMADD132SDZr_Intk
    0U,	// VFNMADD132SDZr_Intkz
    0U,	// VFNMADD132SDZrb
    0U,	// VFNMADD132SDZrb_Int
    0U,	// VFNMADD132SDZrb_Intk
    0U,	// VFNMADD132SDZrb_Intkz
    0U,	// VFNMADD132SDm
    0U,	// VFNMADD132SDm_Int
    0U,	// VFNMADD132SDr
    0U,	// VFNMADD132SDr_Int
    0U,	// VFNMADD132SSZm
    0U,	// VFNMADD132SSZm_Int
    0U,	// VFNMADD132SSZm_Intk
    0U,	// VFNMADD132SSZm_Intkz
    0U,	// VFNMADD132SSZr
    0U,	// VFNMADD132SSZr_Int
    0U,	// VFNMADD132SSZr_Intk
    0U,	// VFNMADD132SSZr_Intkz
    0U,	// VFNMADD132SSZrb
    0U,	// VFNMADD132SSZrb_Int
    0U,	// VFNMADD132SSZrb_Intk
    0U,	// VFNMADD132SSZrb_Intkz
    0U,	// VFNMADD132SSm
    0U,	// VFNMADD132SSm_Int
    0U,	// VFNMADD132SSr
    0U,	// VFNMADD132SSr_Int
    0U,	// VFNMADD213PDYm
    0U,	// VFNMADD213PDYr
    0U,	// VFNMADD213PDZ128m
    0U,	// VFNMADD213PDZ128mb
    0U,	// VFNMADD213PDZ128mbk
    0U,	// VFNMADD213PDZ128mbkz
    0U,	// VFNMADD213PDZ128mk
    0U,	// VFNMADD213PDZ128mkz
    0U,	// VFNMADD213PDZ128r
    0U,	// VFNMADD213PDZ128rk
    0U,	// VFNMADD213PDZ128rkz
    0U,	// VFNMADD213PDZ256m
    0U,	// VFNMADD213PDZ256mb
    0U,	// VFNMADD213PDZ256mbk
    0U,	// VFNMADD213PDZ256mbkz
    0U,	// VFNMADD213PDZ256mk
    0U,	// VFNMADD213PDZ256mkz
    0U,	// VFNMADD213PDZ256r
    0U,	// VFNMADD213PDZ256rk
    0U,	// VFNMADD213PDZ256rkz
    0U,	// VFNMADD213PDZm
    0U,	// VFNMADD213PDZmb
    0U,	// VFNMADD213PDZmbk
    0U,	// VFNMADD213PDZmbkz
    0U,	// VFNMADD213PDZmk
    0U,	// VFNMADD213PDZmkz
    0U,	// VFNMADD213PDZr
    0U,	// VFNMADD213PDZrb
    0U,	// VFNMADD213PDZrbk
    0U,	// VFNMADD213PDZrbkz
    0U,	// VFNMADD213PDZrk
    0U,	// VFNMADD213PDZrkz
    0U,	// VFNMADD213PDm
    0U,	// VFNMADD213PDr
    0U,	// VFNMADD213PSYm
    0U,	// VFNMADD213PSYr
    0U,	// VFNMADD213PSZ128m
    0U,	// VFNMADD213PSZ128mb
    0U,	// VFNMADD213PSZ128mbk
    0U,	// VFNMADD213PSZ128mbkz
    0U,	// VFNMADD213PSZ128mk
    0U,	// VFNMADD213PSZ128mkz
    0U,	// VFNMADD213PSZ128r
    0U,	// VFNMADD213PSZ128rk
    0U,	// VFNMADD213PSZ128rkz
    0U,	// VFNMADD213PSZ256m
    0U,	// VFNMADD213PSZ256mb
    0U,	// VFNMADD213PSZ256mbk
    0U,	// VFNMADD213PSZ256mbkz
    0U,	// VFNMADD213PSZ256mk
    0U,	// VFNMADD213PSZ256mkz
    0U,	// VFNMADD213PSZ256r
    0U,	// VFNMADD213PSZ256rk
    0U,	// VFNMADD213PSZ256rkz
    0U,	// VFNMADD213PSZm
    0U,	// VFNMADD213PSZmb
    0U,	// VFNMADD213PSZmbk
    0U,	// VFNMADD213PSZmbkz
    0U,	// VFNMADD213PSZmk
    0U,	// VFNMADD213PSZmkz
    0U,	// VFNMADD213PSZr
    0U,	// VFNMADD213PSZrb
    0U,	// VFNMADD213PSZrbk
    0U,	// VFNMADD213PSZrbkz
    0U,	// VFNMADD213PSZrk
    0U,	// VFNMADD213PSZrkz
    0U,	// VFNMADD213PSm
    0U,	// VFNMADD213PSr
    0U,	// VFNMADD213SDZm
    0U,	// VFNMADD213SDZm_Int
    0U,	// VFNMADD213SDZm_Intk
    0U,	// VFNMADD213SDZm_Intkz
    0U,	// VFNMADD213SDZr
    0U,	// VFNMADD213SDZr_Int
    0U,	// VFNMADD213SDZr_Intk
    0U,	// VFNMADD213SDZr_Intkz
    0U,	// VFNMADD213SDZrb
    0U,	// VFNMADD213SDZrb_Int
    0U,	// VFNMADD213SDZrb_Intk
    0U,	// VFNMADD213SDZrb_Intkz
    0U,	// VFNMADD213SDm
    0U,	// VFNMADD213SDm_Int
    0U,	// VFNMADD213SDr
    0U,	// VFNMADD213SDr_Int
    0U,	// VFNMADD213SSZm
    0U,	// VFNMADD213SSZm_Int
    0U,	// VFNMADD213SSZm_Intk
    0U,	// VFNMADD213SSZm_Intkz
    0U,	// VFNMADD213SSZr
    0U,	// VFNMADD213SSZr_Int
    0U,	// VFNMADD213SSZr_Intk
    0U,	// VFNMADD213SSZr_Intkz
    0U,	// VFNMADD213SSZrb
    0U,	// VFNMADD213SSZrb_Int
    0U,	// VFNMADD213SSZrb_Intk
    0U,	// VFNMADD213SSZrb_Intkz
    0U,	// VFNMADD213SSm
    0U,	// VFNMADD213SSm_Int
    0U,	// VFNMADD213SSr
    0U,	// VFNMADD213SSr_Int
    0U,	// VFNMADD231PDYm
    0U,	// VFNMADD231PDYr
    0U,	// VFNMADD231PDZ128m
    0U,	// VFNMADD231PDZ128mb
    0U,	// VFNMADD231PDZ128mbk
    0U,	// VFNMADD231PDZ128mbkz
    0U,	// VFNMADD231PDZ128mk
    0U,	// VFNMADD231PDZ128mkz
    0U,	// VFNMADD231PDZ128r
    0U,	// VFNMADD231PDZ128rk
    0U,	// VFNMADD231PDZ128rkz
    0U,	// VFNMADD231PDZ256m
    0U,	// VFNMADD231PDZ256mb
    0U,	// VFNMADD231PDZ256mbk
    0U,	// VFNMADD231PDZ256mbkz
    0U,	// VFNMADD231PDZ256mk
    0U,	// VFNMADD231PDZ256mkz
    0U,	// VFNMADD231PDZ256r
    0U,	// VFNMADD231PDZ256rk
    0U,	// VFNMADD231PDZ256rkz
    0U,	// VFNMADD231PDZm
    0U,	// VFNMADD231PDZmb
    0U,	// VFNMADD231PDZmbk
    0U,	// VFNMADD231PDZmbkz
    0U,	// VFNMADD231PDZmk
    0U,	// VFNMADD231PDZmkz
    0U,	// VFNMADD231PDZr
    0U,	// VFNMADD231PDZrb
    0U,	// VFNMADD231PDZrbk
    0U,	// VFNMADD231PDZrbkz
    0U,	// VFNMADD231PDZrk
    0U,	// VFNMADD231PDZrkz
    0U,	// VFNMADD231PDm
    0U,	// VFNMADD231PDr
    0U,	// VFNMADD231PSYm
    0U,	// VFNMADD231PSYr
    0U,	// VFNMADD231PSZ128m
    0U,	// VFNMADD231PSZ128mb
    0U,	// VFNMADD231PSZ128mbk
    0U,	// VFNMADD231PSZ128mbkz
    0U,	// VFNMADD231PSZ128mk
    0U,	// VFNMADD231PSZ128mkz
    0U,	// VFNMADD231PSZ128r
    0U,	// VFNMADD231PSZ128rk
    0U,	// VFNMADD231PSZ128rkz
    0U,	// VFNMADD231PSZ256m
    0U,	// VFNMADD231PSZ256mb
    0U,	// VFNMADD231PSZ256mbk
    0U,	// VFNMADD231PSZ256mbkz
    0U,	// VFNMADD231PSZ256mk
    0U,	// VFNMADD231PSZ256mkz
    0U,	// VFNMADD231PSZ256r
    0U,	// VFNMADD231PSZ256rk
    0U,	// VFNMADD231PSZ256rkz
    0U,	// VFNMADD231PSZm
    0U,	// VFNMADD231PSZmb
    0U,	// VFNMADD231PSZmbk
    0U,	// VFNMADD231PSZmbkz
    0U,	// VFNMADD231PSZmk
    0U,	// VFNMADD231PSZmkz
    0U,	// VFNMADD231PSZr
    0U,	// VFNMADD231PSZrb
    0U,	// VFNMADD231PSZrbk
    0U,	// VFNMADD231PSZrbkz
    0U,	// VFNMADD231PSZrk
    0U,	// VFNMADD231PSZrkz
    0U,	// VFNMADD231PSm
    0U,	// VFNMADD231PSr
    0U,	// VFNMADD231SDZm
    0U,	// VFNMADD231SDZm_Int
    0U,	// VFNMADD231SDZm_Intk
    0U,	// VFNMADD231SDZm_Intkz
    0U,	// VFNMADD231SDZr
    0U,	// VFNMADD231SDZr_Int
    0U,	// VFNMADD231SDZr_Intk
    0U,	// VFNMADD231SDZr_Intkz
    0U,	// VFNMADD231SDZrb
    0U,	// VFNMADD231SDZrb_Int
    0U,	// VFNMADD231SDZrb_Intk
    0U,	// VFNMADD231SDZrb_Intkz
    0U,	// VFNMADD231SDm
    0U,	// VFNMADD231SDm_Int
    0U,	// VFNMADD231SDr
    0U,	// VFNMADD231SDr_Int
    0U,	// VFNMADD231SSZm
    0U,	// VFNMADD231SSZm_Int
    0U,	// VFNMADD231SSZm_Intk
    0U,	// VFNMADD231SSZm_Intkz
    0U,	// VFNMADD231SSZr
    0U,	// VFNMADD231SSZr_Int
    0U,	// VFNMADD231SSZr_Intk
    0U,	// VFNMADD231SSZr_Intkz
    0U,	// VFNMADD231SSZrb
    0U,	// VFNMADD231SSZrb_Int
    0U,	// VFNMADD231SSZrb_Intk
    0U,	// VFNMADD231SSZrb_Intkz
    0U,	// VFNMADD231SSm
    0U,	// VFNMADD231SSm_Int
    0U,	// VFNMADD231SSr
    0U,	// VFNMADD231SSr_Int
    0U,	// VFNMADDPD4Ymr
    0U,	// VFNMADDPD4Yrm
    0U,	// VFNMADDPD4Yrr
    0U,	// VFNMADDPD4Yrr_REV
    0U,	// VFNMADDPD4mr
    0U,	// VFNMADDPD4rm
    0U,	// VFNMADDPD4rr
    0U,	// VFNMADDPD4rr_REV
    0U,	// VFNMADDPS4Ymr
    0U,	// VFNMADDPS4Yrm
    0U,	// VFNMADDPS4Yrr
    0U,	// VFNMADDPS4Yrr_REV
    0U,	// VFNMADDPS4mr
    0U,	// VFNMADDPS4rm
    0U,	// VFNMADDPS4rr
    0U,	// VFNMADDPS4rr_REV
    0U,	// VFNMADDSD4mr
    0U,	// VFNMADDSD4mr_Int
    0U,	// VFNMADDSD4rm
    0U,	// VFNMADDSD4rm_Int
    0U,	// VFNMADDSD4rr
    0U,	// VFNMADDSD4rr_Int
    0U,	// VFNMADDSD4rr_Int_REV
    0U,	// VFNMADDSD4rr_REV
    0U,	// VFNMADDSS4mr
    0U,	// VFNMADDSS4mr_Int
    0U,	// VFNMADDSS4rm
    0U,	// VFNMADDSS4rm_Int
    0U,	// VFNMADDSS4rr
    0U,	// VFNMADDSS4rr_Int
    0U,	// VFNMADDSS4rr_Int_REV
    0U,	// VFNMADDSS4rr_REV
    0U,	// VFNMSUB132PDYm
    0U,	// VFNMSUB132PDYr
    0U,	// VFNMSUB132PDZ128m
    0U,	// VFNMSUB132PDZ128mb
    0U,	// VFNMSUB132PDZ128mbk
    0U,	// VFNMSUB132PDZ128mbkz
    0U,	// VFNMSUB132PDZ128mk
    0U,	// VFNMSUB132PDZ128mkz
    0U,	// VFNMSUB132PDZ128r
    0U,	// VFNMSUB132PDZ128rk
    0U,	// VFNMSUB132PDZ128rkz
    0U,	// VFNMSUB132PDZ256m
    0U,	// VFNMSUB132PDZ256mb
    0U,	// VFNMSUB132PDZ256mbk
    0U,	// VFNMSUB132PDZ256mbkz
    0U,	// VFNMSUB132PDZ256mk
    0U,	// VFNMSUB132PDZ256mkz
    0U,	// VFNMSUB132PDZ256r
    0U,	// VFNMSUB132PDZ256rk
    0U,	// VFNMSUB132PDZ256rkz
    0U,	// VFNMSUB132PDZm
    0U,	// VFNMSUB132PDZmb
    0U,	// VFNMSUB132PDZmbk
    0U,	// VFNMSUB132PDZmbkz
    0U,	// VFNMSUB132PDZmk
    0U,	// VFNMSUB132PDZmkz
    0U,	// VFNMSUB132PDZr
    0U,	// VFNMSUB132PDZrb
    0U,	// VFNMSUB132PDZrbk
    0U,	// VFNMSUB132PDZrbkz
    0U,	// VFNMSUB132PDZrk
    0U,	// VFNMSUB132PDZrkz
    0U,	// VFNMSUB132PDm
    0U,	// VFNMSUB132PDr
    0U,	// VFNMSUB132PSYm
    0U,	// VFNMSUB132PSYr
    0U,	// VFNMSUB132PSZ128m
    0U,	// VFNMSUB132PSZ128mb
    0U,	// VFNMSUB132PSZ128mbk
    0U,	// VFNMSUB132PSZ128mbkz
    0U,	// VFNMSUB132PSZ128mk
    0U,	// VFNMSUB132PSZ128mkz
    0U,	// VFNMSUB132PSZ128r
    0U,	// VFNMSUB132PSZ128rk
    0U,	// VFNMSUB132PSZ128rkz
    0U,	// VFNMSUB132PSZ256m
    0U,	// VFNMSUB132PSZ256mb
    0U,	// VFNMSUB132PSZ256mbk
    0U,	// VFNMSUB132PSZ256mbkz
    0U,	// VFNMSUB132PSZ256mk
    0U,	// VFNMSUB132PSZ256mkz
    0U,	// VFNMSUB132PSZ256r
    0U,	// VFNMSUB132PSZ256rk
    0U,	// VFNMSUB132PSZ256rkz
    0U,	// VFNMSUB132PSZm
    0U,	// VFNMSUB132PSZmb
    0U,	// VFNMSUB132PSZmbk
    0U,	// VFNMSUB132PSZmbkz
    0U,	// VFNMSUB132PSZmk
    0U,	// VFNMSUB132PSZmkz
    0U,	// VFNMSUB132PSZr
    0U,	// VFNMSUB132PSZrb
    0U,	// VFNMSUB132PSZrbk
    0U,	// VFNMSUB132PSZrbkz
    0U,	// VFNMSUB132PSZrk
    0U,	// VFNMSUB132PSZrkz
    0U,	// VFNMSUB132PSm
    0U,	// VFNMSUB132PSr
    0U,	// VFNMSUB132SDZm
    0U,	// VFNMSUB132SDZm_Int
    0U,	// VFNMSUB132SDZm_Intk
    0U,	// VFNMSUB132SDZm_Intkz
    0U,	// VFNMSUB132SDZr
    0U,	// VFNMSUB132SDZr_Int
    0U,	// VFNMSUB132SDZr_Intk
    0U,	// VFNMSUB132SDZr_Intkz
    0U,	// VFNMSUB132SDZrb
    0U,	// VFNMSUB132SDZrb_Int
    0U,	// VFNMSUB132SDZrb_Intk
    0U,	// VFNMSUB132SDZrb_Intkz
    0U,	// VFNMSUB132SDm
    0U,	// VFNMSUB132SDm_Int
    0U,	// VFNMSUB132SDr
    0U,	// VFNMSUB132SDr_Int
    0U,	// VFNMSUB132SSZm
    0U,	// VFNMSUB132SSZm_Int
    0U,	// VFNMSUB132SSZm_Intk
    0U,	// VFNMSUB132SSZm_Intkz
    0U,	// VFNMSUB132SSZr
    0U,	// VFNMSUB132SSZr_Int
    0U,	// VFNMSUB132SSZr_Intk
    0U,	// VFNMSUB132SSZr_Intkz
    0U,	// VFNMSUB132SSZrb
    0U,	// VFNMSUB132SSZrb_Int
    0U,	// VFNMSUB132SSZrb_Intk
    0U,	// VFNMSUB132SSZrb_Intkz
    0U,	// VFNMSUB132SSm
    0U,	// VFNMSUB132SSm_Int
    0U,	// VFNMSUB132SSr
    0U,	// VFNMSUB132SSr_Int
    0U,	// VFNMSUB213PDYm
    0U,	// VFNMSUB213PDYr
    0U,	// VFNMSUB213PDZ128m
    0U,	// VFNMSUB213PDZ128mb
    0U,	// VFNMSUB213PDZ128mbk
    0U,	// VFNMSUB213PDZ128mbkz
    0U,	// VFNMSUB213PDZ128mk
    0U,	// VFNMSUB213PDZ128mkz
    0U,	// VFNMSUB213PDZ128r
    0U,	// VFNMSUB213PDZ128rk
    0U,	// VFNMSUB213PDZ128rkz
    0U,	// VFNMSUB213PDZ256m
    0U,	// VFNMSUB213PDZ256mb
    0U,	// VFNMSUB213PDZ256mbk
    0U,	// VFNMSUB213PDZ256mbkz
    0U,	// VFNMSUB213PDZ256mk
    0U,	// VFNMSUB213PDZ256mkz
    0U,	// VFNMSUB213PDZ256r
    0U,	// VFNMSUB213PDZ256rk
    0U,	// VFNMSUB213PDZ256rkz
    0U,	// VFNMSUB213PDZm
    0U,	// VFNMSUB213PDZmb
    0U,	// VFNMSUB213PDZmbk
    0U,	// VFNMSUB213PDZmbkz
    0U,	// VFNMSUB213PDZmk
    0U,	// VFNMSUB213PDZmkz
    0U,	// VFNMSUB213PDZr
    0U,	// VFNMSUB213PDZrb
    0U,	// VFNMSUB213PDZrbk
    0U,	// VFNMSUB213PDZrbkz
    0U,	// VFNMSUB213PDZrk
    0U,	// VFNMSUB213PDZrkz
    0U,	// VFNMSUB213PDm
    0U,	// VFNMSUB213PDr
    0U,	// VFNMSUB213PSYm
    0U,	// VFNMSUB213PSYr
    0U,	// VFNMSUB213PSZ128m
    0U,	// VFNMSUB213PSZ128mb
    0U,	// VFNMSUB213PSZ128mbk
    0U,	// VFNMSUB213PSZ128mbkz
    0U,	// VFNMSUB213PSZ128mk
    0U,	// VFNMSUB213PSZ128mkz
    0U,	// VFNMSUB213PSZ128r
    0U,	// VFNMSUB213PSZ128rk
    0U,	// VFNMSUB213PSZ128rkz
    0U,	// VFNMSUB213PSZ256m
    0U,	// VFNMSUB213PSZ256mb
    0U,	// VFNMSUB213PSZ256mbk
    0U,	// VFNMSUB213PSZ256mbkz
    0U,	// VFNMSUB213PSZ256mk
    0U,	// VFNMSUB213PSZ256mkz
    0U,	// VFNMSUB213PSZ256r
    0U,	// VFNMSUB213PSZ256rk
    0U,	// VFNMSUB213PSZ256rkz
    0U,	// VFNMSUB213PSZm
    0U,	// VFNMSUB213PSZmb
    0U,	// VFNMSUB213PSZmbk
    0U,	// VFNMSUB213PSZmbkz
    0U,	// VFNMSUB213PSZmk
    0U,	// VFNMSUB213PSZmkz
    0U,	// VFNMSUB213PSZr
    0U,	// VFNMSUB213PSZrb
    0U,	// VFNMSUB213PSZrbk
    0U,	// VFNMSUB213PSZrbkz
    0U,	// VFNMSUB213PSZrk
    0U,	// VFNMSUB213PSZrkz
    0U,	// VFNMSUB213PSm
    0U,	// VFNMSUB213PSr
    0U,	// VFNMSUB213SDZm
    0U,	// VFNMSUB213SDZm_Int
    0U,	// VFNMSUB213SDZm_Intk
    0U,	// VFNMSUB213SDZm_Intkz
    0U,	// VFNMSUB213SDZr
    0U,	// VFNMSUB213SDZr_Int
    0U,	// VFNMSUB213SDZr_Intk
    0U,	// VFNMSUB213SDZr_Intkz
    0U,	// VFNMSUB213SDZrb
    0U,	// VFNMSUB213SDZrb_Int
    0U,	// VFNMSUB213SDZrb_Intk
    0U,	// VFNMSUB213SDZrb_Intkz
    0U,	// VFNMSUB213SDm
    0U,	// VFNMSUB213SDm_Int
    0U,	// VFNMSUB213SDr
    0U,	// VFNMSUB213SDr_Int
    0U,	// VFNMSUB213SSZm
    0U,	// VFNMSUB213SSZm_Int
    0U,	// VFNMSUB213SSZm_Intk
    0U,	// VFNMSUB213SSZm_Intkz
    0U,	// VFNMSUB213SSZr
    0U,	// VFNMSUB213SSZr_Int
    0U,	// VFNMSUB213SSZr_Intk
    0U,	// VFNMSUB213SSZr_Intkz
    0U,	// VFNMSUB213SSZrb
    0U,	// VFNMSUB213SSZrb_Int
    0U,	// VFNMSUB213SSZrb_Intk
    0U,	// VFNMSUB213SSZrb_Intkz
    0U,	// VFNMSUB213SSm
    0U,	// VFNMSUB213SSm_Int
    0U,	// VFNMSUB213SSr
    0U,	// VFNMSUB213SSr_Int
    0U,	// VFNMSUB231PDYm
    0U,	// VFNMSUB231PDYr
    0U,	// VFNMSUB231PDZ128m
    0U,	// VFNMSUB231PDZ128mb
    0U,	// VFNMSUB231PDZ128mbk
    0U,	// VFNMSUB231PDZ128mbkz
    0U,	// VFNMSUB231PDZ128mk
    0U,	// VFNMSUB231PDZ128mkz
    0U,	// VFNMSUB231PDZ128r
    0U,	// VFNMSUB231PDZ128rk
    0U,	// VFNMSUB231PDZ128rkz
    0U,	// VFNMSUB231PDZ256m
    0U,	// VFNMSUB231PDZ256mb
    0U,	// VFNMSUB231PDZ256mbk
    0U,	// VFNMSUB231PDZ256mbkz
    0U,	// VFNMSUB231PDZ256mk
    0U,	// VFNMSUB231PDZ256mkz
    0U,	// VFNMSUB231PDZ256r
    0U,	// VFNMSUB231PDZ256rk
    0U,	// VFNMSUB231PDZ256rkz
    0U,	// VFNMSUB231PDZm
    0U,	// VFNMSUB231PDZmb
    0U,	// VFNMSUB231PDZmbk
    0U,	// VFNMSUB231PDZmbkz
    0U,	// VFNMSUB231PDZmk
    0U,	// VFNMSUB231PDZmkz
    0U,	// VFNMSUB231PDZr
    0U,	// VFNMSUB231PDZrb
    0U,	// VFNMSUB231PDZrbk
    0U,	// VFNMSUB231PDZrbkz
    0U,	// VFNMSUB231PDZrk
    0U,	// VFNMSUB231PDZrkz
    0U,	// VFNMSUB231PDm
    0U,	// VFNMSUB231PDr
    0U,	// VFNMSUB231PSYm
    0U,	// VFNMSUB231PSYr
    0U,	// VFNMSUB231PSZ128m
    0U,	// VFNMSUB231PSZ128mb
    0U,	// VFNMSUB231PSZ128mbk
    0U,	// VFNMSUB231PSZ128mbkz
    0U,	// VFNMSUB231PSZ128mk
    0U,	// VFNMSUB231PSZ128mkz
    0U,	// VFNMSUB231PSZ128r
    0U,	// VFNMSUB231PSZ128rk
    0U,	// VFNMSUB231PSZ128rkz
    0U,	// VFNMSUB231PSZ256m
    0U,	// VFNMSUB231PSZ256mb
    0U,	// VFNMSUB231PSZ256mbk
    0U,	// VFNMSUB231PSZ256mbkz
    0U,	// VFNMSUB231PSZ256mk
    0U,	// VFNMSUB231PSZ256mkz
    0U,	// VFNMSUB231PSZ256r
    0U,	// VFNMSUB231PSZ256rk
    0U,	// VFNMSUB231PSZ256rkz
    0U,	// VFNMSUB231PSZm
    0U,	// VFNMSUB231PSZmb
    0U,	// VFNMSUB231PSZmbk
    0U,	// VFNMSUB231PSZmbkz
    0U,	// VFNMSUB231PSZmk
    0U,	// VFNMSUB231PSZmkz
    0U,	// VFNMSUB231PSZr
    0U,	// VFNMSUB231PSZrb
    0U,	// VFNMSUB231PSZrbk
    0U,	// VFNMSUB231PSZrbkz
    0U,	// VFNMSUB231PSZrk
    0U,	// VFNMSUB231PSZrkz
    0U,	// VFNMSUB231PSm
    0U,	// VFNMSUB231PSr
    0U,	// VFNMSUB231SDZm
    0U,	// VFNMSUB231SDZm_Int
    0U,	// VFNMSUB231SDZm_Intk
    0U,	// VFNMSUB231SDZm_Intkz
    0U,	// VFNMSUB231SDZr
    0U,	// VFNMSUB231SDZr_Int
    0U,	// VFNMSUB231SDZr_Intk
    0U,	// VFNMSUB231SDZr_Intkz
    0U,	// VFNMSUB231SDZrb
    0U,	// VFNMSUB231SDZrb_Int
    0U,	// VFNMSUB231SDZrb_Intk
    0U,	// VFNMSUB231SDZrb_Intkz
    0U,	// VFNMSUB231SDm
    0U,	// VFNMSUB231SDm_Int
    0U,	// VFNMSUB231SDr
    0U,	// VFNMSUB231SDr_Int
    0U,	// VFNMSUB231SSZm
    0U,	// VFNMSUB231SSZm_Int
    0U,	// VFNMSUB231SSZm_Intk
    0U,	// VFNMSUB231SSZm_Intkz
    0U,	// VFNMSUB231SSZr
    0U,	// VFNMSUB231SSZr_Int
    0U,	// VFNMSUB231SSZr_Intk
    0U,	// VFNMSUB231SSZr_Intkz
    0U,	// VFNMSUB231SSZrb
    0U,	// VFNMSUB231SSZrb_Int
    0U,	// VFNMSUB231SSZrb_Intk
    0U,	// VFNMSUB231SSZrb_Intkz
    0U,	// VFNMSUB231SSm
    0U,	// VFNMSUB231SSm_Int
    0U,	// VFNMSUB231SSr
    0U,	// VFNMSUB231SSr_Int
    0U,	// VFNMSUBPD4Ymr
    0U,	// VFNMSUBPD4Yrm
    0U,	// VFNMSUBPD4Yrr
    0U,	// VFNMSUBPD4Yrr_REV
    0U,	// VFNMSUBPD4mr
    0U,	// VFNMSUBPD4rm
    0U,	// VFNMSUBPD4rr
    0U,	// VFNMSUBPD4rr_REV
    0U,	// VFNMSUBPS4Ymr
    0U,	// VFNMSUBPS4Yrm
    0U,	// VFNMSUBPS4Yrr
    0U,	// VFNMSUBPS4Yrr_REV
    0U,	// VFNMSUBPS4mr
    0U,	// VFNMSUBPS4rm
    0U,	// VFNMSUBPS4rr
    0U,	// VFNMSUBPS4rr_REV
    0U,	// VFNMSUBSD4mr
    0U,	// VFNMSUBSD4mr_Int
    0U,	// VFNMSUBSD4rm
    0U,	// VFNMSUBSD4rm_Int
    0U,	// VFNMSUBSD4rr
    0U,	// VFNMSUBSD4rr_Int
    0U,	// VFNMSUBSD4rr_Int_REV
    0U,	// VFNMSUBSD4rr_REV
    0U,	// VFNMSUBSS4mr
    0U,	// VFNMSUBSS4mr_Int
    0U,	// VFNMSUBSS4rm
    0U,	// VFNMSUBSS4rm_Int
    0U,	// VFNMSUBSS4rr
    0U,	// VFNMSUBSS4rr_Int
    0U,	// VFNMSUBSS4rr_Int_REV
    0U,	// VFNMSUBSS4rr_REV
    0U,	// VFPCLASSPDZ128rm
    0U,	// VFPCLASSPDZ128rmb
    0U,	// VFPCLASSPDZ128rmbk
    0U,	// VFPCLASSPDZ128rmk
    0U,	// VFPCLASSPDZ128rr
    0U,	// VFPCLASSPDZ128rrk
    0U,	// VFPCLASSPDZ256rm
    0U,	// VFPCLASSPDZ256rmb
    0U,	// VFPCLASSPDZ256rmbk
    0U,	// VFPCLASSPDZ256rmk
    0U,	// VFPCLASSPDZ256rr
    0U,	// VFPCLASSPDZ256rrk
    0U,	// VFPCLASSPDZrm
    0U,	// VFPCLASSPDZrmb
    0U,	// VFPCLASSPDZrmbk
    0U,	// VFPCLASSPDZrmk
    0U,	// VFPCLASSPDZrr
    0U,	// VFPCLASSPDZrrk
    0U,	// VFPCLASSPSZ128rm
    0U,	// VFPCLASSPSZ128rmb
    0U,	// VFPCLASSPSZ128rmbk
    0U,	// VFPCLASSPSZ128rmk
    0U,	// VFPCLASSPSZ128rr
    0U,	// VFPCLASSPSZ128rrk
    0U,	// VFPCLASSPSZ256rm
    0U,	// VFPCLASSPSZ256rmb
    0U,	// VFPCLASSPSZ256rmbk
    0U,	// VFPCLASSPSZ256rmk
    0U,	// VFPCLASSPSZ256rr
    0U,	// VFPCLASSPSZ256rrk
    0U,	// VFPCLASSPSZrm
    0U,	// VFPCLASSPSZrmb
    0U,	// VFPCLASSPSZrmbk
    0U,	// VFPCLASSPSZrmk
    0U,	// VFPCLASSPSZrr
    0U,	// VFPCLASSPSZrrk
    0U,	// VFPCLASSSDZrm
    0U,	// VFPCLASSSDZrmk
    0U,	// VFPCLASSSDZrr
    0U,	// VFPCLASSSDZrrk
    0U,	// VFPCLASSSSZrm
    0U,	// VFPCLASSSSZrmk
    0U,	// VFPCLASSSSZrr
    0U,	// VFPCLASSSSZrrk
    0U,	// VFRCZPDYrm
    0U,	// VFRCZPDYrr
    0U,	// VFRCZPDrm
    0U,	// VFRCZPDrr
    0U,	// VFRCZPSYrm
    0U,	// VFRCZPSYrr
    0U,	// VFRCZPSrm
    0U,	// VFRCZPSrr
    0U,	// VFRCZSDrm
    0U,	// VFRCZSDrr
    0U,	// VFRCZSSrm
    0U,	// VFRCZSSrr
    0U,	// VGATHERDPDYrm
    0U,	// VGATHERDPDZ128rm
    0U,	// VGATHERDPDZ256rm
    0U,	// VGATHERDPDZrm
    0U,	// VGATHERDPDrm
    0U,	// VGATHERDPSYrm
    0U,	// VGATHERDPSZ128rm
    0U,	// VGATHERDPSZ256rm
    0U,	// VGATHERDPSZrm
    0U,	// VGATHERDPSrm
    0U,	// VGATHERPF0DPDm
    0U,	// VGATHERPF0DPSm
    0U,	// VGATHERPF0QPDm
    0U,	// VGATHERPF0QPSm
    0U,	// VGATHERPF1DPDm
    0U,	// VGATHERPF1DPSm
    0U,	// VGATHERPF1QPDm
    0U,	// VGATHERPF1QPSm
    0U,	// VGATHERQPDYrm
    0U,	// VGATHERQPDZ128rm
    0U,	// VGATHERQPDZ256rm
    0U,	// VGATHERQPDZrm
    0U,	// VGATHERQPDrm
    0U,	// VGATHERQPSYrm
    0U,	// VGATHERQPSZ128rm
    0U,	// VGATHERQPSZ256rm
    0U,	// VGATHERQPSZrm
    0U,	// VGATHERQPSrm
    0U,	// VGETEXPPDZ128m
    0U,	// VGETEXPPDZ128mb
    0U,	// VGETEXPPDZ128mbk
    0U,	// VGETEXPPDZ128mbkz
    0U,	// VGETEXPPDZ128mk
    0U,	// VGETEXPPDZ128mkz
    0U,	// VGETEXPPDZ128r
    0U,	// VGETEXPPDZ128rk
    0U,	// VGETEXPPDZ128rkz
    0U,	// VGETEXPPDZ256m
    0U,	// VGETEXPPDZ256mb
    0U,	// VGETEXPPDZ256mbk
    0U,	// VGETEXPPDZ256mbkz
    0U,	// VGETEXPPDZ256mk
    0U,	// VGETEXPPDZ256mkz
    0U,	// VGETEXPPDZ256r
    0U,	// VGETEXPPDZ256rk
    0U,	// VGETEXPPDZ256rkz
    0U,	// VGETEXPPDZm
    0U,	// VGETEXPPDZmb
    0U,	// VGETEXPPDZmbk
    0U,	// VGETEXPPDZmbkz
    0U,	// VGETEXPPDZmk
    0U,	// VGETEXPPDZmkz
    0U,	// VGETEXPPDZr
    0U,	// VGETEXPPDZrb
    0U,	// VGETEXPPDZrbk
    0U,	// VGETEXPPDZrbkz
    0U,	// VGETEXPPDZrk
    0U,	// VGETEXPPDZrkz
    0U,	// VGETEXPPSZ128m
    0U,	// VGETEXPPSZ128mb
    0U,	// VGETEXPPSZ128mbk
    0U,	// VGETEXPPSZ128mbkz
    0U,	// VGETEXPPSZ128mk
    0U,	// VGETEXPPSZ128mkz
    0U,	// VGETEXPPSZ128r
    0U,	// VGETEXPPSZ128rk
    0U,	// VGETEXPPSZ128rkz
    0U,	// VGETEXPPSZ256m
    0U,	// VGETEXPPSZ256mb
    0U,	// VGETEXPPSZ256mbk
    0U,	// VGETEXPPSZ256mbkz
    0U,	// VGETEXPPSZ256mk
    0U,	// VGETEXPPSZ256mkz
    0U,	// VGETEXPPSZ256r
    0U,	// VGETEXPPSZ256rk
    0U,	// VGETEXPPSZ256rkz
    0U,	// VGETEXPPSZm
    0U,	// VGETEXPPSZmb
    0U,	// VGETEXPPSZmbk
    0U,	// VGETEXPPSZmbkz
    0U,	// VGETEXPPSZmk
    0U,	// VGETEXPPSZmkz
    0U,	// VGETEXPPSZr
    0U,	// VGETEXPPSZrb
    0U,	// VGETEXPPSZrbk
    0U,	// VGETEXPPSZrbkz
    0U,	// VGETEXPPSZrk
    0U,	// VGETEXPPSZrkz
    0U,	// VGETEXPSDZm
    0U,	// VGETEXPSDZmk
    0U,	// VGETEXPSDZmkz
    0U,	// VGETEXPSDZr
    0U,	// VGETEXPSDZrb
    0U,	// VGETEXPSDZrbk
    0U,	// VGETEXPSDZrbkz
    0U,	// VGETEXPSDZrk
    0U,	// VGETEXPSDZrkz
    0U,	// VGETEXPSSZm
    0U,	// VGETEXPSSZmk
    0U,	// VGETEXPSSZmkz
    0U,	// VGETEXPSSZr
    0U,	// VGETEXPSSZrb
    0U,	// VGETEXPSSZrbk
    0U,	// VGETEXPSSZrbkz
    0U,	// VGETEXPSSZrk
    0U,	// VGETEXPSSZrkz
    0U,	// VGETMANTPDZ128rmbi
    0U,	// VGETMANTPDZ128rmbik
    0U,	// VGETMANTPDZ128rmbikz
    0U,	// VGETMANTPDZ128rmi
    0U,	// VGETMANTPDZ128rmik
    0U,	// VGETMANTPDZ128rmikz
    0U,	// VGETMANTPDZ128rri
    0U,	// VGETMANTPDZ128rrik
    0U,	// VGETMANTPDZ128rrikz
    0U,	// VGETMANTPDZ256rmbi
    0U,	// VGETMANTPDZ256rmbik
    0U,	// VGETMANTPDZ256rmbikz
    0U,	// VGETMANTPDZ256rmi
    0U,	// VGETMANTPDZ256rmik
    0U,	// VGETMANTPDZ256rmikz
    0U,	// VGETMANTPDZ256rri
    0U,	// VGETMANTPDZ256rrik
    0U,	// VGETMANTPDZ256rrikz
    0U,	// VGETMANTPDZrmbi
    0U,	// VGETMANTPDZrmbik
    0U,	// VGETMANTPDZrmbikz
    0U,	// VGETMANTPDZrmi
    0U,	// VGETMANTPDZrmik
    0U,	// VGETMANTPDZrmikz
    0U,	// VGETMANTPDZrri
    0U,	// VGETMANTPDZrrib
    0U,	// VGETMANTPDZrribk
    0U,	// VGETMANTPDZrribkz
    0U,	// VGETMANTPDZrrik
    0U,	// VGETMANTPDZrrikz
    0U,	// VGETMANTPSZ128rmbi
    0U,	// VGETMANTPSZ128rmbik
    0U,	// VGETMANTPSZ128rmbikz
    0U,	// VGETMANTPSZ128rmi
    0U,	// VGETMANTPSZ128rmik
    0U,	// VGETMANTPSZ128rmikz
    0U,	// VGETMANTPSZ128rri
    0U,	// VGETMANTPSZ128rrik
    0U,	// VGETMANTPSZ128rrikz
    0U,	// VGETMANTPSZ256rmbi
    0U,	// VGETMANTPSZ256rmbik
    0U,	// VGETMANTPSZ256rmbikz
    0U,	// VGETMANTPSZ256rmi
    0U,	// VGETMANTPSZ256rmik
    0U,	// VGETMANTPSZ256rmikz
    0U,	// VGETMANTPSZ256rri
    0U,	// VGETMANTPSZ256rrik
    0U,	// VGETMANTPSZ256rrikz
    0U,	// VGETMANTPSZrmbi
    0U,	// VGETMANTPSZrmbik
    0U,	// VGETMANTPSZrmbikz
    0U,	// VGETMANTPSZrmi
    0U,	// VGETMANTPSZrmik
    0U,	// VGETMANTPSZrmikz
    0U,	// VGETMANTPSZrri
    0U,	// VGETMANTPSZrrib
    0U,	// VGETMANTPSZrribk
    0U,	// VGETMANTPSZrribkz
    0U,	// VGETMANTPSZrrik
    0U,	// VGETMANTPSZrrikz
    0U,	// VGETMANTSDZrmi
    0U,	// VGETMANTSDZrmik
    3U,	// VGETMANTSDZrmikz
    0U,	// VGETMANTSDZrri
    0U,	// VGETMANTSDZrrib
    0U,	// VGETMANTSDZrribk
    3U,	// VGETMANTSDZrribkz
    0U,	// VGETMANTSDZrrik
    3U,	// VGETMANTSDZrrikz
    0U,	// VGETMANTSSZrmi
    0U,	// VGETMANTSSZrmik
    3U,	// VGETMANTSSZrmikz
    0U,	// VGETMANTSSZrri
    0U,	// VGETMANTSSZrrib
    0U,	// VGETMANTSSZrribk
    3U,	// VGETMANTSSZrribkz
    0U,	// VGETMANTSSZrrik
    3U,	// VGETMANTSSZrrikz
    0U,	// VGF2P8AFFINEINVQBYrmi
    0U,	// VGF2P8AFFINEINVQBYrri
    0U,	// VGF2P8AFFINEINVQBZ128rmbi
    0U,	// VGF2P8AFFINEINVQBZ128rmbik
    3U,	// VGF2P8AFFINEINVQBZ128rmbikz
    0U,	// VGF2P8AFFINEINVQBZ128rmi
    0U,	// VGF2P8AFFINEINVQBZ128rmik
    0U,	// VGF2P8AFFINEINVQBZ128rmikz
    0U,	// VGF2P8AFFINEINVQBZ128rri
    0U,	// VGF2P8AFFINEINVQBZ128rrik
    3U,	// VGF2P8AFFINEINVQBZ128rrikz
    0U,	// VGF2P8AFFINEINVQBZ256rmbi
    0U,	// VGF2P8AFFINEINVQBZ256rmbik
    3U,	// VGF2P8AFFINEINVQBZ256rmbikz
    0U,	// VGF2P8AFFINEINVQBZ256rmi
    0U,	// VGF2P8AFFINEINVQBZ256rmik
    0U,	// VGF2P8AFFINEINVQBZ256rmikz
    0U,	// VGF2P8AFFINEINVQBZ256rri
    0U,	// VGF2P8AFFINEINVQBZ256rrik
    3U,	// VGF2P8AFFINEINVQBZ256rrikz
    0U,	// VGF2P8AFFINEINVQBZrmbi
    0U,	// VGF2P8AFFINEINVQBZrmbik
    3U,	// VGF2P8AFFINEINVQBZrmbikz
    0U,	// VGF2P8AFFINEINVQBZrmi
    0U,	// VGF2P8AFFINEINVQBZrmik
    0U,	// VGF2P8AFFINEINVQBZrmikz
    0U,	// VGF2P8AFFINEINVQBZrri
    0U,	// VGF2P8AFFINEINVQBZrrik
    3U,	// VGF2P8AFFINEINVQBZrrikz
    0U,	// VGF2P8AFFINEINVQBrmi
    0U,	// VGF2P8AFFINEINVQBrri
    0U,	// VGF2P8AFFINEQBYrmi
    0U,	// VGF2P8AFFINEQBYrri
    0U,	// VGF2P8AFFINEQBZ128rmbi
    0U,	// VGF2P8AFFINEQBZ128rmbik
    3U,	// VGF2P8AFFINEQBZ128rmbikz
    0U,	// VGF2P8AFFINEQBZ128rmi
    0U,	// VGF2P8AFFINEQBZ128rmik
    0U,	// VGF2P8AFFINEQBZ128rmikz
    0U,	// VGF2P8AFFINEQBZ128rri
    0U,	// VGF2P8AFFINEQBZ128rrik
    3U,	// VGF2P8AFFINEQBZ128rrikz
    0U,	// VGF2P8AFFINEQBZ256rmbi
    0U,	// VGF2P8AFFINEQBZ256rmbik
    3U,	// VGF2P8AFFINEQBZ256rmbikz
    0U,	// VGF2P8AFFINEQBZ256rmi
    0U,	// VGF2P8AFFINEQBZ256rmik
    0U,	// VGF2P8AFFINEQBZ256rmikz
    0U,	// VGF2P8AFFINEQBZ256rri
    0U,	// VGF2P8AFFINEQBZ256rrik
    3U,	// VGF2P8AFFINEQBZ256rrikz
    0U,	// VGF2P8AFFINEQBZrmbi
    0U,	// VGF2P8AFFINEQBZrmbik
    3U,	// VGF2P8AFFINEQBZrmbikz
    0U,	// VGF2P8AFFINEQBZrmi
    0U,	// VGF2P8AFFINEQBZrmik
    0U,	// VGF2P8AFFINEQBZrmikz
    0U,	// VGF2P8AFFINEQBZrri
    0U,	// VGF2P8AFFINEQBZrrik
    3U,	// VGF2P8AFFINEQBZrrikz
    0U,	// VGF2P8AFFINEQBrmi
    0U,	// VGF2P8AFFINEQBrri
    0U,	// VGF2P8MULBYrm
    0U,	// VGF2P8MULBYrr
    0U,	// VGF2P8MULBZ128rm
    0U,	// VGF2P8MULBZ128rmk
    0U,	// VGF2P8MULBZ128rmkz
    0U,	// VGF2P8MULBZ128rr
    0U,	// VGF2P8MULBZ128rrk
    0U,	// VGF2P8MULBZ128rrkz
    0U,	// VGF2P8MULBZ256rm
    0U,	// VGF2P8MULBZ256rmk
    0U,	// VGF2P8MULBZ256rmkz
    0U,	// VGF2P8MULBZ256rr
    0U,	// VGF2P8MULBZ256rrk
    0U,	// VGF2P8MULBZ256rrkz
    0U,	// VGF2P8MULBZrm
    0U,	// VGF2P8MULBZrmk
    0U,	// VGF2P8MULBZrmkz
    0U,	// VGF2P8MULBZrr
    0U,	// VGF2P8MULBZrrk
    0U,	// VGF2P8MULBZrrkz
    0U,	// VGF2P8MULBrm
    0U,	// VGF2P8MULBrr
    0U,	// VHADDPDYrm
    0U,	// VHADDPDYrr
    0U,	// VHADDPDrm
    0U,	// VHADDPDrr
    0U,	// VHADDPSYrm
    0U,	// VHADDPSYrr
    0U,	// VHADDPSrm
    0U,	// VHADDPSrr
    0U,	// VHSUBPDYrm
    0U,	// VHSUBPDYrr
    0U,	// VHSUBPDrm
    0U,	// VHSUBPDrr
    0U,	// VHSUBPSYrm
    0U,	// VHSUBPSYrr
    0U,	// VHSUBPSrm
    0U,	// VHSUBPSrr
    0U,	// VINSERTF128rm
    0U,	// VINSERTF128rr
    0U,	// VINSERTF32x4Z256rm
    0U,	// VINSERTF32x4Z256rmk
    0U,	// VINSERTF32x4Z256rmkz
    0U,	// VINSERTF32x4Z256rr
    0U,	// VINSERTF32x4Z256rrk
    3U,	// VINSERTF32x4Z256rrkz
    0U,	// VINSERTF32x4Zrm
    0U,	// VINSERTF32x4Zrmk
    0U,	// VINSERTF32x4Zrmkz
    0U,	// VINSERTF32x4Zrr
    0U,	// VINSERTF32x4Zrrk
    3U,	// VINSERTF32x4Zrrkz
    0U,	// VINSERTF32x8Zrm
    0U,	// VINSERTF32x8Zrmk
    0U,	// VINSERTF32x8Zrmkz
    0U,	// VINSERTF32x8Zrr
    0U,	// VINSERTF32x8Zrrk
    3U,	// VINSERTF32x8Zrrkz
    0U,	// VINSERTF64x2Z256rm
    0U,	// VINSERTF64x2Z256rmk
    0U,	// VINSERTF64x2Z256rmkz
    0U,	// VINSERTF64x2Z256rr
    0U,	// VINSERTF64x2Z256rrk
    3U,	// VINSERTF64x2Z256rrkz
    0U,	// VINSERTF64x2Zrm
    0U,	// VINSERTF64x2Zrmk
    0U,	// VINSERTF64x2Zrmkz
    0U,	// VINSERTF64x2Zrr
    0U,	// VINSERTF64x2Zrrk
    3U,	// VINSERTF64x2Zrrkz
    0U,	// VINSERTF64x4Zrm
    0U,	// VINSERTF64x4Zrmk
    0U,	// VINSERTF64x4Zrmkz
    0U,	// VINSERTF64x4Zrr
    0U,	// VINSERTF64x4Zrrk
    3U,	// VINSERTF64x4Zrrkz
    0U,	// VINSERTI128rm
    0U,	// VINSERTI128rr
    0U,	// VINSERTI32x4Z256rm
    0U,	// VINSERTI32x4Z256rmk
    0U,	// VINSERTI32x4Z256rmkz
    0U,	// VINSERTI32x4Z256rr
    0U,	// VINSERTI32x4Z256rrk
    3U,	// VINSERTI32x4Z256rrkz
    0U,	// VINSERTI32x4Zrm
    0U,	// VINSERTI32x4Zrmk
    0U,	// VINSERTI32x4Zrmkz
    0U,	// VINSERTI32x4Zrr
    0U,	// VINSERTI32x4Zrrk
    3U,	// VINSERTI32x4Zrrkz
    0U,	// VINSERTI32x8Zrm
    0U,	// VINSERTI32x8Zrmk
    0U,	// VINSERTI32x8Zrmkz
    0U,	// VINSERTI32x8Zrr
    0U,	// VINSERTI32x8Zrrk
    3U,	// VINSERTI32x8Zrrkz
    0U,	// VINSERTI64x2Z256rm
    0U,	// VINSERTI64x2Z256rmk
    0U,	// VINSERTI64x2Z256rmkz
    0U,	// VINSERTI64x2Z256rr
    0U,	// VINSERTI64x2Z256rrk
    3U,	// VINSERTI64x2Z256rrkz
    0U,	// VINSERTI64x2Zrm
    0U,	// VINSERTI64x2Zrmk
    0U,	// VINSERTI64x2Zrmkz
    0U,	// VINSERTI64x2Zrr
    0U,	// VINSERTI64x2Zrrk
    3U,	// VINSERTI64x2Zrrkz
    0U,	// VINSERTI64x4Zrm
    0U,	// VINSERTI64x4Zrmk
    0U,	// VINSERTI64x4Zrmkz
    0U,	// VINSERTI64x4Zrr
    0U,	// VINSERTI64x4Zrrk
    3U,	// VINSERTI64x4Zrrkz
    0U,	// VINSERTPSZrm
    0U,	// VINSERTPSZrr
    0U,	// VINSERTPSrm
    0U,	// VINSERTPSrr
    0U,	// VLDDQUYrm
    0U,	// VLDDQUrm
    0U,	// VLDMXCSR
    0U,	// VMASKMOVDQU
    0U,	// VMASKMOVDQU64
    0U,	// VMASKMOVPDYmr
    0U,	// VMASKMOVPDYrm
    0U,	// VMASKMOVPDmr
    0U,	// VMASKMOVPDrm
    0U,	// VMASKMOVPSYmr
    0U,	// VMASKMOVPSYrm
    0U,	// VMASKMOVPSmr
    0U,	// VMASKMOVPSrm
    0U,	// VMAXCPDYrm
    0U,	// VMAXCPDYrr
    0U,	// VMAXCPDZ128rm
    0U,	// VMAXCPDZ128rmb
    0U,	// VMAXCPDZ128rmbk
    0U,	// VMAXCPDZ128rmbkz
    0U,	// VMAXCPDZ128rmk
    0U,	// VMAXCPDZ128rmkz
    0U,	// VMAXCPDZ128rr
    0U,	// VMAXCPDZ128rrk
    0U,	// VMAXCPDZ128rrkz
    0U,	// VMAXCPDZ256rm
    0U,	// VMAXCPDZ256rmb
    0U,	// VMAXCPDZ256rmbk
    0U,	// VMAXCPDZ256rmbkz
    0U,	// VMAXCPDZ256rmk
    0U,	// VMAXCPDZ256rmkz
    0U,	// VMAXCPDZ256rr
    0U,	// VMAXCPDZ256rrk
    0U,	// VMAXCPDZ256rrkz
    0U,	// VMAXCPDZrm
    0U,	// VMAXCPDZrmb
    0U,	// VMAXCPDZrmbk
    0U,	// VMAXCPDZrmbkz
    0U,	// VMAXCPDZrmk
    0U,	// VMAXCPDZrmkz
    0U,	// VMAXCPDZrr
    0U,	// VMAXCPDZrrk
    0U,	// VMAXCPDZrrkz
    0U,	// VMAXCPDrm
    0U,	// VMAXCPDrr
    0U,	// VMAXCPSYrm
    0U,	// VMAXCPSYrr
    0U,	// VMAXCPSZ128rm
    0U,	// VMAXCPSZ128rmb
    0U,	// VMAXCPSZ128rmbk
    0U,	// VMAXCPSZ128rmbkz
    0U,	// VMAXCPSZ128rmk
    0U,	// VMAXCPSZ128rmkz
    0U,	// VMAXCPSZ128rr
    0U,	// VMAXCPSZ128rrk
    0U,	// VMAXCPSZ128rrkz
    0U,	// VMAXCPSZ256rm
    0U,	// VMAXCPSZ256rmb
    0U,	// VMAXCPSZ256rmbk
    0U,	// VMAXCPSZ256rmbkz
    0U,	// VMAXCPSZ256rmk
    0U,	// VMAXCPSZ256rmkz
    0U,	// VMAXCPSZ256rr
    0U,	// VMAXCPSZ256rrk
    0U,	// VMAXCPSZ256rrkz
    0U,	// VMAXCPSZrm
    0U,	// VMAXCPSZrmb
    0U,	// VMAXCPSZrmbk
    0U,	// VMAXCPSZrmbkz
    0U,	// VMAXCPSZrmk
    0U,	// VMAXCPSZrmkz
    0U,	// VMAXCPSZrr
    0U,	// VMAXCPSZrrk
    0U,	// VMAXCPSZrrkz
    0U,	// VMAXCPSrm
    0U,	// VMAXCPSrr
    0U,	// VMAXCSDZrm
    0U,	// VMAXCSDZrr
    0U,	// VMAXCSDrm
    0U,	// VMAXCSDrr
    0U,	// VMAXCSSZrm
    0U,	// VMAXCSSZrr
    0U,	// VMAXCSSrm
    0U,	// VMAXCSSrr
    0U,	// VMAXPDYrm
    0U,	// VMAXPDYrr
    0U,	// VMAXPDZ128rm
    0U,	// VMAXPDZ128rmb
    0U,	// VMAXPDZ128rmbk
    0U,	// VMAXPDZ128rmbkz
    0U,	// VMAXPDZ128rmk
    0U,	// VMAXPDZ128rmkz
    0U,	// VMAXPDZ128rr
    0U,	// VMAXPDZ128rrk
    0U,	// VMAXPDZ128rrkz
    0U,	// VMAXPDZ256rm
    0U,	// VMAXPDZ256rmb
    0U,	// VMAXPDZ256rmbk
    0U,	// VMAXPDZ256rmbkz
    0U,	// VMAXPDZ256rmk
    0U,	// VMAXPDZ256rmkz
    0U,	// VMAXPDZ256rr
    0U,	// VMAXPDZ256rrk
    0U,	// VMAXPDZ256rrkz
    0U,	// VMAXPDZrm
    0U,	// VMAXPDZrmb
    0U,	// VMAXPDZrmbk
    0U,	// VMAXPDZrmbkz
    0U,	// VMAXPDZrmk
    0U,	// VMAXPDZrmkz
    0U,	// VMAXPDZrr
    0U,	// VMAXPDZrrb
    0U,	// VMAXPDZrrbk
    0U,	// VMAXPDZrrbkz
    0U,	// VMAXPDZrrk
    0U,	// VMAXPDZrrkz
    0U,	// VMAXPDrm
    0U,	// VMAXPDrr
    0U,	// VMAXPSYrm
    0U,	// VMAXPSYrr
    0U,	// VMAXPSZ128rm
    0U,	// VMAXPSZ128rmb
    0U,	// VMAXPSZ128rmbk
    0U,	// VMAXPSZ128rmbkz
    0U,	// VMAXPSZ128rmk
    0U,	// VMAXPSZ128rmkz
    0U,	// VMAXPSZ128rr
    0U,	// VMAXPSZ128rrk
    0U,	// VMAXPSZ128rrkz
    0U,	// VMAXPSZ256rm
    0U,	// VMAXPSZ256rmb
    0U,	// VMAXPSZ256rmbk
    0U,	// VMAXPSZ256rmbkz
    0U,	// VMAXPSZ256rmk
    0U,	// VMAXPSZ256rmkz
    0U,	// VMAXPSZ256rr
    0U,	// VMAXPSZ256rrk
    0U,	// VMAXPSZ256rrkz
    0U,	// VMAXPSZrm
    0U,	// VMAXPSZrmb
    0U,	// VMAXPSZrmbk
    0U,	// VMAXPSZrmbkz
    0U,	// VMAXPSZrmk
    0U,	// VMAXPSZrmkz
    0U,	// VMAXPSZrr
    0U,	// VMAXPSZrrb
    0U,	// VMAXPSZrrbk
    0U,	// VMAXPSZrrbkz
    0U,	// VMAXPSZrrk
    0U,	// VMAXPSZrrkz
    0U,	// VMAXPSrm
    0U,	// VMAXPSrr
    0U,	// VMAXSDZrm
    0U,	// VMAXSDZrm_Int
    0U,	// VMAXSDZrm_Intk
    0U,	// VMAXSDZrm_Intkz
    0U,	// VMAXSDZrr
    0U,	// VMAXSDZrr_Int
    0U,	// VMAXSDZrr_Intk
    0U,	// VMAXSDZrr_Intkz
    0U,	// VMAXSDZrrb_Int
    0U,	// VMAXSDZrrb_Intk
    0U,	// VMAXSDZrrb_Intkz
    0U,	// VMAXSDrm
    0U,	// VMAXSDrm_Int
    0U,	// VMAXSDrr
    0U,	// VMAXSDrr_Int
    0U,	// VMAXSSZrm
    0U,	// VMAXSSZrm_Int
    0U,	// VMAXSSZrm_Intk
    0U,	// VMAXSSZrm_Intkz
    0U,	// VMAXSSZrr
    0U,	// VMAXSSZrr_Int
    0U,	// VMAXSSZrr_Intk
    0U,	// VMAXSSZrr_Intkz
    0U,	// VMAXSSZrrb_Int
    0U,	// VMAXSSZrrb_Intk
    0U,	// VMAXSSZrrb_Intkz
    0U,	// VMAXSSrm
    0U,	// VMAXSSrm_Int
    0U,	// VMAXSSrr
    0U,	// VMAXSSrr_Int
    0U,	// VMCALL
    0U,	// VMCLEARm
    0U,	// VMFUNC
    0U,	// VMINCPDYrm
    0U,	// VMINCPDYrr
    0U,	// VMINCPDZ128rm
    0U,	// VMINCPDZ128rmb
    0U,	// VMINCPDZ128rmbk
    0U,	// VMINCPDZ128rmbkz
    0U,	// VMINCPDZ128rmk
    0U,	// VMINCPDZ128rmkz
    0U,	// VMINCPDZ128rr
    0U,	// VMINCPDZ128rrk
    0U,	// VMINCPDZ128rrkz
    0U,	// VMINCPDZ256rm
    0U,	// VMINCPDZ256rmb
    0U,	// VMINCPDZ256rmbk
    0U,	// VMINCPDZ256rmbkz
    0U,	// VMINCPDZ256rmk
    0U,	// VMINCPDZ256rmkz
    0U,	// VMINCPDZ256rr
    0U,	// VMINCPDZ256rrk
    0U,	// VMINCPDZ256rrkz
    0U,	// VMINCPDZrm
    0U,	// VMINCPDZrmb
    0U,	// VMINCPDZrmbk
    0U,	// VMINCPDZrmbkz
    0U,	// VMINCPDZrmk
    0U,	// VMINCPDZrmkz
    0U,	// VMINCPDZrr
    0U,	// VMINCPDZrrk
    0U,	// VMINCPDZrrkz
    0U,	// VMINCPDrm
    0U,	// VMINCPDrr
    0U,	// VMINCPSYrm
    0U,	// VMINCPSYrr
    0U,	// VMINCPSZ128rm
    0U,	// VMINCPSZ128rmb
    0U,	// VMINCPSZ128rmbk
    0U,	// VMINCPSZ128rmbkz
    0U,	// VMINCPSZ128rmk
    0U,	// VMINCPSZ128rmkz
    0U,	// VMINCPSZ128rr
    0U,	// VMINCPSZ128rrk
    0U,	// VMINCPSZ128rrkz
    0U,	// VMINCPSZ256rm
    0U,	// VMINCPSZ256rmb
    0U,	// VMINCPSZ256rmbk
    0U,	// VMINCPSZ256rmbkz
    0U,	// VMINCPSZ256rmk
    0U,	// VMINCPSZ256rmkz
    0U,	// VMINCPSZ256rr
    0U,	// VMINCPSZ256rrk
    0U,	// VMINCPSZ256rrkz
    0U,	// VMINCPSZrm
    0U,	// VMINCPSZrmb
    0U,	// VMINCPSZrmbk
    0U,	// VMINCPSZrmbkz
    0U,	// VMINCPSZrmk
    0U,	// VMINCPSZrmkz
    0U,	// VMINCPSZrr
    0U,	// VMINCPSZrrk
    0U,	// VMINCPSZrrkz
    0U,	// VMINCPSrm
    0U,	// VMINCPSrr
    0U,	// VMINCSDZrm
    0U,	// VMINCSDZrr
    0U,	// VMINCSDrm
    0U,	// VMINCSDrr
    0U,	// VMINCSSZrm
    0U,	// VMINCSSZrr
    0U,	// VMINCSSrm
    0U,	// VMINCSSrr
    0U,	// VMINPDYrm
    0U,	// VMINPDYrr
    0U,	// VMINPDZ128rm
    0U,	// VMINPDZ128rmb
    0U,	// VMINPDZ128rmbk
    0U,	// VMINPDZ128rmbkz
    0U,	// VMINPDZ128rmk
    0U,	// VMINPDZ128rmkz
    0U,	// VMINPDZ128rr
    0U,	// VMINPDZ128rrk
    0U,	// VMINPDZ128rrkz
    0U,	// VMINPDZ256rm
    0U,	// VMINPDZ256rmb
    0U,	// VMINPDZ256rmbk
    0U,	// VMINPDZ256rmbkz
    0U,	// VMINPDZ256rmk
    0U,	// VMINPDZ256rmkz
    0U,	// VMINPDZ256rr
    0U,	// VMINPDZ256rrk
    0U,	// VMINPDZ256rrkz
    0U,	// VMINPDZrm
    0U,	// VMINPDZrmb
    0U,	// VMINPDZrmbk
    0U,	// VMINPDZrmbkz
    0U,	// VMINPDZrmk
    0U,	// VMINPDZrmkz
    0U,	// VMINPDZrr
    0U,	// VMINPDZrrb
    0U,	// VMINPDZrrbk
    0U,	// VMINPDZrrbkz
    0U,	// VMINPDZrrk
    0U,	// VMINPDZrrkz
    0U,	// VMINPDrm
    0U,	// VMINPDrr
    0U,	// VMINPSYrm
    0U,	// VMINPSYrr
    0U,	// VMINPSZ128rm
    0U,	// VMINPSZ128rmb
    0U,	// VMINPSZ128rmbk
    0U,	// VMINPSZ128rmbkz
    0U,	// VMINPSZ128rmk
    0U,	// VMINPSZ128rmkz
    0U,	// VMINPSZ128rr
    0U,	// VMINPSZ128rrk
    0U,	// VMINPSZ128rrkz
    0U,	// VMINPSZ256rm
    0U,	// VMINPSZ256rmb
    0U,	// VMINPSZ256rmbk
    0U,	// VMINPSZ256rmbkz
    0U,	// VMINPSZ256rmk
    0U,	// VMINPSZ256rmkz
    0U,	// VMINPSZ256rr
    0U,	// VMINPSZ256rrk
    0U,	// VMINPSZ256rrkz
    0U,	// VMINPSZrm
    0U,	// VMINPSZrmb
    0U,	// VMINPSZrmbk
    0U,	// VMINPSZrmbkz
    0U,	// VMINPSZrmk
    0U,	// VMINPSZrmkz
    0U,	// VMINPSZrr
    0U,	// VMINPSZrrb
    0U,	// VMINPSZrrbk
    0U,	// VMINPSZrrbkz
    0U,	// VMINPSZrrk
    0U,	// VMINPSZrrkz
    0U,	// VMINPSrm
    0U,	// VMINPSrr
    0U,	// VMINSDZrm
    0U,	// VMINSDZrm_Int
    0U,	// VMINSDZrm_Intk
    0U,	// VMINSDZrm_Intkz
    0U,	// VMINSDZrr
    0U,	// VMINSDZrr_Int
    0U,	// VMINSDZrr_Intk
    0U,	// VMINSDZrr_Intkz
    0U,	// VMINSDZrrb_Int
    0U,	// VMINSDZrrb_Intk
    0U,	// VMINSDZrrb_Intkz
    0U,	// VMINSDrm
    0U,	// VMINSDrm_Int
    0U,	// VMINSDrr
    0U,	// VMINSDrr_Int
    0U,	// VMINSSZrm
    0U,	// VMINSSZrm_Int
    0U,	// VMINSSZrm_Intk
    0U,	// VMINSSZrm_Intkz
    0U,	// VMINSSZrr
    0U,	// VMINSSZrr_Int
    0U,	// VMINSSZrr_Intk
    0U,	// VMINSSZrr_Intkz
    0U,	// VMINSSZrrb_Int
    0U,	// VMINSSZrrb_Intk
    0U,	// VMINSSZrrb_Intkz
    0U,	// VMINSSrm
    0U,	// VMINSSrm_Int
    0U,	// VMINSSrr
    0U,	// VMINSSrr_Int
    0U,	// VMLAUNCH
    0U,	// VMLOAD32
    0U,	// VMLOAD64
    0U,	// VMMCALL
    0U,	// VMOV64toPQIZrm
    0U,	// VMOV64toPQIZrr
    0U,	// VMOV64toPQIrm
    0U,	// VMOV64toPQIrr
    0U,	// VMOV64toSDZrm
    0U,	// VMOV64toSDZrr
    0U,	// VMOV64toSDrm
    0U,	// VMOV64toSDrr
    0U,	// VMOVAPDYmr
    0U,	// VMOVAPDYrm
    0U,	// VMOVAPDYrr
    0U,	// VMOVAPDYrr_REV
    0U,	// VMOVAPDZ128mr
    0U,	// VMOVAPDZ128mrk
    0U,	// VMOVAPDZ128rm
    0U,	// VMOVAPDZ128rmk
    0U,	// VMOVAPDZ128rmkz
    0U,	// VMOVAPDZ128rr
    0U,	// VMOVAPDZ128rr_REV
    0U,	// VMOVAPDZ128rrk
    0U,	// VMOVAPDZ128rrk_REV
    0U,	// VMOVAPDZ128rrkz
    0U,	// VMOVAPDZ128rrkz_REV
    0U,	// VMOVAPDZ256mr
    0U,	// VMOVAPDZ256mrk
    0U,	// VMOVAPDZ256rm
    0U,	// VMOVAPDZ256rmk
    0U,	// VMOVAPDZ256rmkz
    0U,	// VMOVAPDZ256rr
    0U,	// VMOVAPDZ256rr_REV
    0U,	// VMOVAPDZ256rrk
    0U,	// VMOVAPDZ256rrk_REV
    0U,	// VMOVAPDZ256rrkz
    0U,	// VMOVAPDZ256rrkz_REV
    0U,	// VMOVAPDZmr
    0U,	// VMOVAPDZmrk
    0U,	// VMOVAPDZrm
    0U,	// VMOVAPDZrmk
    0U,	// VMOVAPDZrmkz
    0U,	// VMOVAPDZrr
    0U,	// VMOVAPDZrr_REV
    0U,	// VMOVAPDZrrk
    0U,	// VMOVAPDZrrk_REV
    0U,	// VMOVAPDZrrkz
    0U,	// VMOVAPDZrrkz_REV
    0U,	// VMOVAPDmr
    0U,	// VMOVAPDrm
    0U,	// VMOVAPDrr
    0U,	// VMOVAPDrr_REV
    0U,	// VMOVAPSYmr
    0U,	// VMOVAPSYrm
    0U,	// VMOVAPSYrr
    0U,	// VMOVAPSYrr_REV
    0U,	// VMOVAPSZ128mr
    0U,	// VMOVAPSZ128mrk
    0U,	// VMOVAPSZ128rm
    0U,	// VMOVAPSZ128rmk
    0U,	// VMOVAPSZ128rmkz
    0U,	// VMOVAPSZ128rr
    0U,	// VMOVAPSZ128rr_REV
    0U,	// VMOVAPSZ128rrk
    0U,	// VMOVAPSZ128rrk_REV
    0U,	// VMOVAPSZ128rrkz
    0U,	// VMOVAPSZ128rrkz_REV
    0U,	// VMOVAPSZ256mr
    0U,	// VMOVAPSZ256mrk
    0U,	// VMOVAPSZ256rm
    0U,	// VMOVAPSZ256rmk
    0U,	// VMOVAPSZ256rmkz
    0U,	// VMOVAPSZ256rr
    0U,	// VMOVAPSZ256rr_REV
    0U,	// VMOVAPSZ256rrk
    0U,	// VMOVAPSZ256rrk_REV
    0U,	// VMOVAPSZ256rrkz
    0U,	// VMOVAPSZ256rrkz_REV
    0U,	// VMOVAPSZmr
    0U,	// VMOVAPSZmrk
    0U,	// VMOVAPSZrm
    0U,	// VMOVAPSZrmk
    0U,	// VMOVAPSZrmkz
    0U,	// VMOVAPSZrr
    0U,	// VMOVAPSZrr_REV
    0U,	// VMOVAPSZrrk
    0U,	// VMOVAPSZrrk_REV
    0U,	// VMOVAPSZrrkz
    0U,	// VMOVAPSZrrkz_REV
    0U,	// VMOVAPSmr
    0U,	// VMOVAPSrm
    0U,	// VMOVAPSrr
    0U,	// VMOVAPSrr_REV
    0U,	// VMOVDDUPYrm
    0U,	// VMOVDDUPYrr
    0U,	// VMOVDDUPZ128rm
    0U,	// VMOVDDUPZ128rmk
    0U,	// VMOVDDUPZ128rmkz
    0U,	// VMOVDDUPZ128rr
    0U,	// VMOVDDUPZ128rrk
    0U,	// VMOVDDUPZ128rrkz
    0U,	// VMOVDDUPZ256rm
    0U,	// VMOVDDUPZ256rmk
    0U,	// VMOVDDUPZ256rmkz
    0U,	// VMOVDDUPZ256rr
    0U,	// VMOVDDUPZ256rrk
    0U,	// VMOVDDUPZ256rrkz
    0U,	// VMOVDDUPZrm
    0U,	// VMOVDDUPZrmk
    0U,	// VMOVDDUPZrmkz
    0U,	// VMOVDDUPZrr
    0U,	// VMOVDDUPZrrk
    0U,	// VMOVDDUPZrrkz
    0U,	// VMOVDDUPrm
    0U,	// VMOVDDUPrr
    0U,	// VMOVDI2PDIZrm
    0U,	// VMOVDI2PDIZrr
    0U,	// VMOVDI2PDIrm
    0U,	// VMOVDI2PDIrr
    0U,	// VMOVDI2SSZrm
    0U,	// VMOVDI2SSZrr
    0U,	// VMOVDI2SSrm
    0U,	// VMOVDI2SSrr
    0U,	// VMOVDQA32Z128mr
    0U,	// VMOVDQA32Z128mrk
    0U,	// VMOVDQA32Z128rm
    0U,	// VMOVDQA32Z128rmk
    0U,	// VMOVDQA32Z128rmkz
    0U,	// VMOVDQA32Z128rr
    0U,	// VMOVDQA32Z128rr_REV
    0U,	// VMOVDQA32Z128rrk
    0U,	// VMOVDQA32Z128rrk_REV
    0U,	// VMOVDQA32Z128rrkz
    0U,	// VMOVDQA32Z128rrkz_REV
    0U,	// VMOVDQA32Z256mr
    0U,	// VMOVDQA32Z256mrk
    0U,	// VMOVDQA32Z256rm
    0U,	// VMOVDQA32Z256rmk
    0U,	// VMOVDQA32Z256rmkz
    0U,	// VMOVDQA32Z256rr
    0U,	// VMOVDQA32Z256rr_REV
    0U,	// VMOVDQA32Z256rrk
    0U,	// VMOVDQA32Z256rrk_REV
    0U,	// VMOVDQA32Z256rrkz
    0U,	// VMOVDQA32Z256rrkz_REV
    0U,	// VMOVDQA32Zmr
    0U,	// VMOVDQA32Zmrk
    0U,	// VMOVDQA32Zrm
    0U,	// VMOVDQA32Zrmk
    0U,	// VMOVDQA32Zrmkz
    0U,	// VMOVDQA32Zrr
    0U,	// VMOVDQA32Zrr_REV
    0U,	// VMOVDQA32Zrrk
    0U,	// VMOVDQA32Zrrk_REV
    0U,	// VMOVDQA32Zrrkz
    0U,	// VMOVDQA32Zrrkz_REV
    0U,	// VMOVDQA64Z128mr
    0U,	// VMOVDQA64Z128mrk
    0U,	// VMOVDQA64Z128rm
    0U,	// VMOVDQA64Z128rmk
    0U,	// VMOVDQA64Z128rmkz
    0U,	// VMOVDQA64Z128rr
    0U,	// VMOVDQA64Z128rr_REV
    0U,	// VMOVDQA64Z128rrk
    0U,	// VMOVDQA64Z128rrk_REV
    0U,	// VMOVDQA64Z128rrkz
    0U,	// VMOVDQA64Z128rrkz_REV
    0U,	// VMOVDQA64Z256mr
    0U,	// VMOVDQA64Z256mrk
    0U,	// VMOVDQA64Z256rm
    0U,	// VMOVDQA64Z256rmk
    0U,	// VMOVDQA64Z256rmkz
    0U,	// VMOVDQA64Z256rr
    0U,	// VMOVDQA64Z256rr_REV
    0U,	// VMOVDQA64Z256rrk
    0U,	// VMOVDQA64Z256rrk_REV
    0U,	// VMOVDQA64Z256rrkz
    0U,	// VMOVDQA64Z256rrkz_REV
    0U,	// VMOVDQA64Zmr
    0U,	// VMOVDQA64Zmrk
    0U,	// VMOVDQA64Zrm
    0U,	// VMOVDQA64Zrmk
    0U,	// VMOVDQA64Zrmkz
    0U,	// VMOVDQA64Zrr
    0U,	// VMOVDQA64Zrr_REV
    0U,	// VMOVDQA64Zrrk
    0U,	// VMOVDQA64Zrrk_REV
    0U,	// VMOVDQA64Zrrkz
    0U,	// VMOVDQA64Zrrkz_REV
    0U,	// VMOVDQAYmr
    0U,	// VMOVDQAYrm
    0U,	// VMOVDQAYrr
    0U,	// VMOVDQAYrr_REV
    0U,	// VMOVDQAmr
    0U,	// VMOVDQArm
    0U,	// VMOVDQArr
    0U,	// VMOVDQArr_REV
    0U,	// VMOVDQU16Z128mr
    0U,	// VMOVDQU16Z128mrk
    0U,	// VMOVDQU16Z128rm
    0U,	// VMOVDQU16Z128rmk
    0U,	// VMOVDQU16Z128rmkz
    0U,	// VMOVDQU16Z128rr
    0U,	// VMOVDQU16Z128rr_REV
    0U,	// VMOVDQU16Z128rrk
    0U,	// VMOVDQU16Z128rrk_REV
    0U,	// VMOVDQU16Z128rrkz
    0U,	// VMOVDQU16Z128rrkz_REV
    0U,	// VMOVDQU16Z256mr
    0U,	// VMOVDQU16Z256mrk
    0U,	// VMOVDQU16Z256rm
    0U,	// VMOVDQU16Z256rmk
    0U,	// VMOVDQU16Z256rmkz
    0U,	// VMOVDQU16Z256rr
    0U,	// VMOVDQU16Z256rr_REV
    0U,	// VMOVDQU16Z256rrk
    0U,	// VMOVDQU16Z256rrk_REV
    0U,	// VMOVDQU16Z256rrkz
    0U,	// VMOVDQU16Z256rrkz_REV
    0U,	// VMOVDQU16Zmr
    0U,	// VMOVDQU16Zmrk
    0U,	// VMOVDQU16Zrm
    0U,	// VMOVDQU16Zrmk
    0U,	// VMOVDQU16Zrmkz
    0U,	// VMOVDQU16Zrr
    0U,	// VMOVDQU16Zrr_REV
    0U,	// VMOVDQU16Zrrk
    0U,	// VMOVDQU16Zrrk_REV
    0U,	// VMOVDQU16Zrrkz
    0U,	// VMOVDQU16Zrrkz_REV
    0U,	// VMOVDQU32Z128mr
    0U,	// VMOVDQU32Z128mrk
    0U,	// VMOVDQU32Z128rm
    0U,	// VMOVDQU32Z128rmk
    0U,	// VMOVDQU32Z128rmkz
    0U,	// VMOVDQU32Z128rr
    0U,	// VMOVDQU32Z128rr_REV
    0U,	// VMOVDQU32Z128rrk
    0U,	// VMOVDQU32Z128rrk_REV
    0U,	// VMOVDQU32Z128rrkz
    0U,	// VMOVDQU32Z128rrkz_REV
    0U,	// VMOVDQU32Z256mr
    0U,	// VMOVDQU32Z256mrk
    0U,	// VMOVDQU32Z256rm
    0U,	// VMOVDQU32Z256rmk
    0U,	// VMOVDQU32Z256rmkz
    0U,	// VMOVDQU32Z256rr
    0U,	// VMOVDQU32Z256rr_REV
    0U,	// VMOVDQU32Z256rrk
    0U,	// VMOVDQU32Z256rrk_REV
    0U,	// VMOVDQU32Z256rrkz
    0U,	// VMOVDQU32Z256rrkz_REV
    0U,	// VMOVDQU32Zmr
    0U,	// VMOVDQU32Zmrk
    0U,	// VMOVDQU32Zrm
    0U,	// VMOVDQU32Zrmk
    0U,	// VMOVDQU32Zrmkz
    0U,	// VMOVDQU32Zrr
    0U,	// VMOVDQU32Zrr_REV
    0U,	// VMOVDQU32Zrrk
    0U,	// VMOVDQU32Zrrk_REV
    0U,	// VMOVDQU32Zrrkz
    0U,	// VMOVDQU32Zrrkz_REV
    0U,	// VMOVDQU64Z128mr
    0U,	// VMOVDQU64Z128mrk
    0U,	// VMOVDQU64Z128rm
    0U,	// VMOVDQU64Z128rmk
    0U,	// VMOVDQU64Z128rmkz
    0U,	// VMOVDQU64Z128rr
    0U,	// VMOVDQU64Z128rr_REV
    0U,	// VMOVDQU64Z128rrk
    0U,	// VMOVDQU64Z128rrk_REV
    0U,	// VMOVDQU64Z128rrkz
    0U,	// VMOVDQU64Z128rrkz_REV
    0U,	// VMOVDQU64Z256mr
    0U,	// VMOVDQU64Z256mrk
    0U,	// VMOVDQU64Z256rm
    0U,	// VMOVDQU64Z256rmk
    0U,	// VMOVDQU64Z256rmkz
    0U,	// VMOVDQU64Z256rr
    0U,	// VMOVDQU64Z256rr_REV
    0U,	// VMOVDQU64Z256rrk
    0U,	// VMOVDQU64Z256rrk_REV
    0U,	// VMOVDQU64Z256rrkz
    0U,	// VMOVDQU64Z256rrkz_REV
    0U,	// VMOVDQU64Zmr
    0U,	// VMOVDQU64Zmrk
    0U,	// VMOVDQU64Zrm
    0U,	// VMOVDQU64Zrmk
    0U,	// VMOVDQU64Zrmkz
    0U,	// VMOVDQU64Zrr
    0U,	// VMOVDQU64Zrr_REV
    0U,	// VMOVDQU64Zrrk
    0U,	// VMOVDQU64Zrrk_REV
    0U,	// VMOVDQU64Zrrkz
    0U,	// VMOVDQU64Zrrkz_REV
    0U,	// VMOVDQU8Z128mr
    0U,	// VMOVDQU8Z128mrk
    0U,	// VMOVDQU8Z128rm
    0U,	// VMOVDQU8Z128rmk
    0U,	// VMOVDQU8Z128rmkz
    0U,	// VMOVDQU8Z128rr
    0U,	// VMOVDQU8Z128rr_REV
    0U,	// VMOVDQU8Z128rrk
    0U,	// VMOVDQU8Z128rrk_REV
    0U,	// VMOVDQU8Z128rrkz
    0U,	// VMOVDQU8Z128rrkz_REV
    0U,	// VMOVDQU8Z256mr
    0U,	// VMOVDQU8Z256mrk
    0U,	// VMOVDQU8Z256rm
    0U,	// VMOVDQU8Z256rmk
    0U,	// VMOVDQU8Z256rmkz
    0U,	// VMOVDQU8Z256rr
    0U,	// VMOVDQU8Z256rr_REV
    0U,	// VMOVDQU8Z256rrk
    0U,	// VMOVDQU8Z256rrk_REV
    0U,	// VMOVDQU8Z256rrkz
    0U,	// VMOVDQU8Z256rrkz_REV
    0U,	// VMOVDQU8Zmr
    0U,	// VMOVDQU8Zmrk
    0U,	// VMOVDQU8Zrm
    0U,	// VMOVDQU8Zrmk
    0U,	// VMOVDQU8Zrmkz
    0U,	// VMOVDQU8Zrr
    0U,	// VMOVDQU8Zrr_REV
    0U,	// VMOVDQU8Zrrk
    0U,	// VMOVDQU8Zrrk_REV
    0U,	// VMOVDQU8Zrrkz
    0U,	// VMOVDQU8Zrrkz_REV
    0U,	// VMOVDQUYmr
    0U,	// VMOVDQUYrm
    0U,	// VMOVDQUYrr
    0U,	// VMOVDQUYrr_REV
    0U,	// VMOVDQUmr
    0U,	// VMOVDQUrm
    0U,	// VMOVDQUrr
    0U,	// VMOVDQUrr_REV
    0U,	// VMOVHLPSZrr
    0U,	// VMOVHLPSrr
    0U,	// VMOVHPDZ128mr
    0U,	// VMOVHPDZ128rm
    0U,	// VMOVHPDmr
    0U,	// VMOVHPDrm
    0U,	// VMOVHPSZ128mr
    0U,	// VMOVHPSZ128rm
    0U,	// VMOVHPSmr
    0U,	// VMOVHPSrm
    0U,	// VMOVLHPSZrr
    0U,	// VMOVLHPSrr
    0U,	// VMOVLPDZ128mr
    0U,	// VMOVLPDZ128rm
    0U,	// VMOVLPDmr
    0U,	// VMOVLPDrm
    0U,	// VMOVLPSZ128mr
    0U,	// VMOVLPSZ128rm
    0U,	// VMOVLPSmr
    0U,	// VMOVLPSrm
    0U,	// VMOVMSKPDYrr
    0U,	// VMOVMSKPDrr
    0U,	// VMOVMSKPSYrr
    0U,	// VMOVMSKPSrr
    0U,	// VMOVNTDQAYrm
    0U,	// VMOVNTDQAZ128rm
    0U,	// VMOVNTDQAZ256rm
    0U,	// VMOVNTDQAZrm
    0U,	// VMOVNTDQArm
    0U,	// VMOVNTDQYmr
    0U,	// VMOVNTDQZ128mr
    0U,	// VMOVNTDQZ256mr
    0U,	// VMOVNTDQZmr
    0U,	// VMOVNTDQmr
    0U,	// VMOVNTPDYmr
    0U,	// VMOVNTPDZ128mr
    0U,	// VMOVNTPDZ256mr
    0U,	// VMOVNTPDZmr
    0U,	// VMOVNTPDmr
    0U,	// VMOVNTPSYmr
    0U,	// VMOVNTPSZ128mr
    0U,	// VMOVNTPSZ256mr
    0U,	// VMOVNTPSZmr
    0U,	// VMOVNTPSmr
    0U,	// VMOVPDI2DIZmr
    0U,	// VMOVPDI2DIZrr
    0U,	// VMOVPDI2DImr
    0U,	// VMOVPDI2DIrr
    0U,	// VMOVPQI2QIZmr
    0U,	// VMOVPQI2QIZrr
    0U,	// VMOVPQI2QImr
    0U,	// VMOVPQI2QIrr
    0U,	// VMOVPQIto64Zmr
    0U,	// VMOVPQIto64Zrr
    0U,	// VMOVPQIto64mr
    0U,	// VMOVPQIto64rr
    0U,	// VMOVQI2PQIZrm
    0U,	// VMOVQI2PQIrm
    0U,	// VMOVSDZmr
    0U,	// VMOVSDZmrk
    0U,	// VMOVSDZrm
    0U,	// VMOVSDZrmk
    0U,	// VMOVSDZrmkz
    0U,	// VMOVSDZrr
    0U,	// VMOVSDZrr_REV
    0U,	// VMOVSDZrrk
    0U,	// VMOVSDZrrk_REV
    0U,	// VMOVSDZrrkz
    0U,	// VMOVSDZrrkz_REV
    0U,	// VMOVSDmr
    0U,	// VMOVSDrm
    0U,	// VMOVSDrr
    0U,	// VMOVSDrr_REV
    0U,	// VMOVSDto64Zmr
    0U,	// VMOVSDto64Zrr
    0U,	// VMOVSDto64mr
    0U,	// VMOVSDto64rr
    0U,	// VMOVSHDUPYrm
    0U,	// VMOVSHDUPYrr
    0U,	// VMOVSHDUPZ128rm
    0U,	// VMOVSHDUPZ128rmk
    0U,	// VMOVSHDUPZ128rmkz
    0U,	// VMOVSHDUPZ128rr
    0U,	// VMOVSHDUPZ128rrk
    0U,	// VMOVSHDUPZ128rrkz
    0U,	// VMOVSHDUPZ256rm
    0U,	// VMOVSHDUPZ256rmk
    0U,	// VMOVSHDUPZ256rmkz
    0U,	// VMOVSHDUPZ256rr
    0U,	// VMOVSHDUPZ256rrk
    0U,	// VMOVSHDUPZ256rrkz
    0U,	// VMOVSHDUPZrm
    0U,	// VMOVSHDUPZrmk
    0U,	// VMOVSHDUPZrmkz
    0U,	// VMOVSHDUPZrr
    0U,	// VMOVSHDUPZrrk
    0U,	// VMOVSHDUPZrrkz
    0U,	// VMOVSHDUPrm
    0U,	// VMOVSHDUPrr
    0U,	// VMOVSLDUPYrm
    0U,	// VMOVSLDUPYrr
    0U,	// VMOVSLDUPZ128rm
    0U,	// VMOVSLDUPZ128rmk
    0U,	// VMOVSLDUPZ128rmkz
    0U,	// VMOVSLDUPZ128rr
    0U,	// VMOVSLDUPZ128rrk
    0U,	// VMOVSLDUPZ128rrkz
    0U,	// VMOVSLDUPZ256rm
    0U,	// VMOVSLDUPZ256rmk
    0U,	// VMOVSLDUPZ256rmkz
    0U,	// VMOVSLDUPZ256rr
    0U,	// VMOVSLDUPZ256rrk
    0U,	// VMOVSLDUPZ256rrkz
    0U,	// VMOVSLDUPZrm
    0U,	// VMOVSLDUPZrmk
    0U,	// VMOVSLDUPZrmkz
    0U,	// VMOVSLDUPZrr
    0U,	// VMOVSLDUPZrrk
    0U,	// VMOVSLDUPZrrkz
    0U,	// VMOVSLDUPrm
    0U,	// VMOVSLDUPrr
    0U,	// VMOVSS2DIZmr
    0U,	// VMOVSS2DIZrr
    0U,	// VMOVSS2DImr
    0U,	// VMOVSS2DIrr
    0U,	// VMOVSSZmr
    0U,	// VMOVSSZmrk
    0U,	// VMOVSSZrm
    0U,	// VMOVSSZrmk
    0U,	// VMOVSSZrmkz
    0U,	// VMOVSSZrr
    0U,	// VMOVSSZrr_REV
    0U,	// VMOVSSZrrk
    0U,	// VMOVSSZrrk_REV
    0U,	// VMOVSSZrrkz
    0U,	// VMOVSSZrrkz_REV
    0U,	// VMOVSSmr
    0U,	// VMOVSSrm
    0U,	// VMOVSSrr
    0U,	// VMOVSSrr_REV
    0U,	// VMOVUPDYmr
    0U,	// VMOVUPDYrm
    0U,	// VMOVUPDYrr
    0U,	// VMOVUPDYrr_REV
    0U,	// VMOVUPDZ128mr
    0U,	// VMOVUPDZ128mrk
    0U,	// VMOVUPDZ128rm
    0U,	// VMOVUPDZ128rmk
    0U,	// VMOVUPDZ128rmkz
    0U,	// VMOVUPDZ128rr
    0U,	// VMOVUPDZ128rr_REV
    0U,	// VMOVUPDZ128rrk
    0U,	// VMOVUPDZ128rrk_REV
    0U,	// VMOVUPDZ128rrkz
    0U,	// VMOVUPDZ128rrkz_REV
    0U,	// VMOVUPDZ256mr
    0U,	// VMOVUPDZ256mrk
    0U,	// VMOVUPDZ256rm
    0U,	// VMOVUPDZ256rmk
    0U,	// VMOVUPDZ256rmkz
    0U,	// VMOVUPDZ256rr
    0U,	// VMOVUPDZ256rr_REV
    0U,	// VMOVUPDZ256rrk
    0U,	// VMOVUPDZ256rrk_REV
    0U,	// VMOVUPDZ256rrkz
    0U,	// VMOVUPDZ256rrkz_REV
    0U,	// VMOVUPDZmr
    0U,	// VMOVUPDZmrk
    0U,	// VMOVUPDZrm
    0U,	// VMOVUPDZrmk
    0U,	// VMOVUPDZrmkz
    0U,	// VMOVUPDZrr
    0U,	// VMOVUPDZrr_REV
    0U,	// VMOVUPDZrrk
    0U,	// VMOVUPDZrrk_REV
    0U,	// VMOVUPDZrrkz
    0U,	// VMOVUPDZrrkz_REV
    0U,	// VMOVUPDmr
    0U,	// VMOVUPDrm
    0U,	// VMOVUPDrr
    0U,	// VMOVUPDrr_REV
    0U,	// VMOVUPSYmr
    0U,	// VMOVUPSYrm
    0U,	// VMOVUPSYrr
    0U,	// VMOVUPSYrr_REV
    0U,	// VMOVUPSZ128mr
    0U,	// VMOVUPSZ128mrk
    0U,	// VMOVUPSZ128rm
    0U,	// VMOVUPSZ128rmk
    0U,	// VMOVUPSZ128rmkz
    0U,	// VMOVUPSZ128rr
    0U,	// VMOVUPSZ128rr_REV
    0U,	// VMOVUPSZ128rrk
    0U,	// VMOVUPSZ128rrk_REV
    0U,	// VMOVUPSZ128rrkz
    0U,	// VMOVUPSZ128rrkz_REV
    0U,	// VMOVUPSZ256mr
    0U,	// VMOVUPSZ256mrk
    0U,	// VMOVUPSZ256rm
    0U,	// VMOVUPSZ256rmk
    0U,	// VMOVUPSZ256rmkz
    0U,	// VMOVUPSZ256rr
    0U,	// VMOVUPSZ256rr_REV
    0U,	// VMOVUPSZ256rrk
    0U,	// VMOVUPSZ256rrk_REV
    0U,	// VMOVUPSZ256rrkz
    0U,	// VMOVUPSZ256rrkz_REV
    0U,	// VMOVUPSZmr
    0U,	// VMOVUPSZmrk
    0U,	// VMOVUPSZrm
    0U,	// VMOVUPSZrmk
    0U,	// VMOVUPSZrmkz
    0U,	// VMOVUPSZrr
    0U,	// VMOVUPSZrr_REV
    0U,	// VMOVUPSZrrk
    0U,	// VMOVUPSZrrk_REV
    0U,	// VMOVUPSZrrkz
    0U,	// VMOVUPSZrrkz_REV
    0U,	// VMOVUPSmr
    0U,	// VMOVUPSrm
    0U,	// VMOVUPSrr
    0U,	// VMOVUPSrr_REV
    0U,	// VMOVZPQILo2PQIZrr
    0U,	// VMOVZPQILo2PQIrr
    0U,	// VMPSADBWYrmi
    0U,	// VMPSADBWYrri
    0U,	// VMPSADBWrmi
    0U,	// VMPSADBWrri
    0U,	// VMPTRLDm
    0U,	// VMPTRSTm
    0U,	// VMREAD32mr
    0U,	// VMREAD32rr
    0U,	// VMREAD64mr
    0U,	// VMREAD64rr
    0U,	// VMRESUME
    0U,	// VMRUN32
    0U,	// VMRUN64
    0U,	// VMSAVE32
    0U,	// VMSAVE64
    0U,	// VMULPDYrm
    0U,	// VMULPDYrr
    0U,	// VMULPDZ128rm
    0U,	// VMULPDZ128rmb
    0U,	// VMULPDZ128rmbk
    0U,	// VMULPDZ128rmbkz
    0U,	// VMULPDZ128rmk
    0U,	// VMULPDZ128rmkz
    0U,	// VMULPDZ128rr
    0U,	// VMULPDZ128rrk
    0U,	// VMULPDZ128rrkz
    0U,	// VMULPDZ256rm
    0U,	// VMULPDZ256rmb
    0U,	// VMULPDZ256rmbk
    0U,	// VMULPDZ256rmbkz
    0U,	// VMULPDZ256rmk
    0U,	// VMULPDZ256rmkz
    0U,	// VMULPDZ256rr
    0U,	// VMULPDZ256rrk
    0U,	// VMULPDZ256rrkz
    0U,	// VMULPDZrm
    0U,	// VMULPDZrmb
    0U,	// VMULPDZrmbk
    0U,	// VMULPDZrmbkz
    0U,	// VMULPDZrmk
    0U,	// VMULPDZrmkz
    0U,	// VMULPDZrr
    0U,	// VMULPDZrrb
    0U,	// VMULPDZrrbk
    0U,	// VMULPDZrrbkz
    0U,	// VMULPDZrrk
    0U,	// VMULPDZrrkz
    0U,	// VMULPDrm
    0U,	// VMULPDrr
    0U,	// VMULPSYrm
    0U,	// VMULPSYrr
    0U,	// VMULPSZ128rm
    0U,	// VMULPSZ128rmb
    0U,	// VMULPSZ128rmbk
    0U,	// VMULPSZ128rmbkz
    0U,	// VMULPSZ128rmk
    0U,	// VMULPSZ128rmkz
    0U,	// VMULPSZ128rr
    0U,	// VMULPSZ128rrk
    0U,	// VMULPSZ128rrkz
    0U,	// VMULPSZ256rm
    0U,	// VMULPSZ256rmb
    0U,	// VMULPSZ256rmbk
    0U,	// VMULPSZ256rmbkz
    0U,	// VMULPSZ256rmk
    0U,	// VMULPSZ256rmkz
    0U,	// VMULPSZ256rr
    0U,	// VMULPSZ256rrk
    0U,	// VMULPSZ256rrkz
    0U,	// VMULPSZrm
    0U,	// VMULPSZrmb
    0U,	// VMULPSZrmbk
    0U,	// VMULPSZrmbkz
    0U,	// VMULPSZrmk
    0U,	// VMULPSZrmkz
    0U,	// VMULPSZrr
    0U,	// VMULPSZrrb
    0U,	// VMULPSZrrbk
    0U,	// VMULPSZrrbkz
    0U,	// VMULPSZrrk
    0U,	// VMULPSZrrkz
    0U,	// VMULPSrm
    0U,	// VMULPSrr
    0U,	// VMULSDZrm
    0U,	// VMULSDZrm_Int
    0U,	// VMULSDZrm_Intk
    0U,	// VMULSDZrm_Intkz
    0U,	// VMULSDZrr
    0U,	// VMULSDZrr_Int
    0U,	// VMULSDZrr_Intk
    0U,	// VMULSDZrr_Intkz
    0U,	// VMULSDZrrb_Int
    0U,	// VMULSDZrrb_Intk
    0U,	// VMULSDZrrb_Intkz
    0U,	// VMULSDrm
    0U,	// VMULSDrm_Int
    0U,	// VMULSDrr
    0U,	// VMULSDrr_Int
    0U,	// VMULSSZrm
    0U,	// VMULSSZrm_Int
    0U,	// VMULSSZrm_Intk
    0U,	// VMULSSZrm_Intkz
    0U,	// VMULSSZrr
    0U,	// VMULSSZrr_Int
    0U,	// VMULSSZrr_Intk
    0U,	// VMULSSZrr_Intkz
    0U,	// VMULSSZrrb_Int
    0U,	// VMULSSZrrb_Intk
    0U,	// VMULSSZrrb_Intkz
    0U,	// VMULSSrm
    0U,	// VMULSSrm_Int
    0U,	// VMULSSrr
    0U,	// VMULSSrr_Int
    0U,	// VMWRITE32rm
    0U,	// VMWRITE32rr
    0U,	// VMWRITE64rm
    0U,	// VMWRITE64rr
    0U,	// VMXOFF
    0U,	// VMXON
    0U,	// VORPDYrm
    0U,	// VORPDYrr
    0U,	// VORPDZ128rm
    0U,	// VORPDZ128rmb
    0U,	// VORPDZ128rmbk
    0U,	// VORPDZ128rmbkz
    0U,	// VORPDZ128rmk
    0U,	// VORPDZ128rmkz
    0U,	// VORPDZ128rr
    0U,	// VORPDZ128rrk
    0U,	// VORPDZ128rrkz
    0U,	// VORPDZ256rm
    0U,	// VORPDZ256rmb
    0U,	// VORPDZ256rmbk
    0U,	// VORPDZ256rmbkz
    0U,	// VORPDZ256rmk
    0U,	// VORPDZ256rmkz
    0U,	// VORPDZ256rr
    0U,	// VORPDZ256rrk
    0U,	// VORPDZ256rrkz
    0U,	// VORPDZrm
    0U,	// VORPDZrmb
    0U,	// VORPDZrmbk
    0U,	// VORPDZrmbkz
    0U,	// VORPDZrmk
    0U,	// VORPDZrmkz
    0U,	// VORPDZrr
    0U,	// VORPDZrrk
    0U,	// VORPDZrrkz
    0U,	// VORPDrm
    0U,	// VORPDrr
    0U,	// VORPSYrm
    0U,	// VORPSYrr
    0U,	// VORPSZ128rm
    0U,	// VORPSZ128rmb
    0U,	// VORPSZ128rmbk
    0U,	// VORPSZ128rmbkz
    0U,	// VORPSZ128rmk
    0U,	// VORPSZ128rmkz
    0U,	// VORPSZ128rr
    0U,	// VORPSZ128rrk
    0U,	// VORPSZ128rrkz
    0U,	// VORPSZ256rm
    0U,	// VORPSZ256rmb
    0U,	// VORPSZ256rmbk
    0U,	// VORPSZ256rmbkz
    0U,	// VORPSZ256rmk
    0U,	// VORPSZ256rmkz
    0U,	// VORPSZ256rr
    0U,	// VORPSZ256rrk
    0U,	// VORPSZ256rrkz
    0U,	// VORPSZrm
    0U,	// VORPSZrmb
    0U,	// VORPSZrmbk
    0U,	// VORPSZrmbkz
    0U,	// VORPSZrmk
    0U,	// VORPSZrmkz
    0U,	// VORPSZrr
    0U,	// VORPSZrrk
    0U,	// VORPSZrrkz
    0U,	// VORPSrm
    0U,	// VORPSrr
    0U,	// VP4DPWSSDSrm
    0U,	// VP4DPWSSDSrmk
    0U,	// VP4DPWSSDSrmkz
    0U,	// VP4DPWSSDrm
    0U,	// VP4DPWSSDrmk
    0U,	// VP4DPWSSDrmkz
    0U,	// VPABSBYrm
    0U,	// VPABSBYrr
    0U,	// VPABSBZ128rm
    0U,	// VPABSBZ128rmk
    0U,	// VPABSBZ128rmkz
    0U,	// VPABSBZ128rr
    0U,	// VPABSBZ128rrk
    0U,	// VPABSBZ128rrkz
    0U,	// VPABSBZ256rm
    0U,	// VPABSBZ256rmk
    0U,	// VPABSBZ256rmkz
    0U,	// VPABSBZ256rr
    0U,	// VPABSBZ256rrk
    0U,	// VPABSBZ256rrkz
    0U,	// VPABSBZrm
    0U,	// VPABSBZrmk
    0U,	// VPABSBZrmkz
    0U,	// VPABSBZrr
    0U,	// VPABSBZrrk
    0U,	// VPABSBZrrkz
    0U,	// VPABSBrm
    0U,	// VPABSBrr
    0U,	// VPABSDYrm
    0U,	// VPABSDYrr
    0U,	// VPABSDZ128rm
    0U,	// VPABSDZ128rmb
    0U,	// VPABSDZ128rmbk
    0U,	// VPABSDZ128rmbkz
    0U,	// VPABSDZ128rmk
    0U,	// VPABSDZ128rmkz
    0U,	// VPABSDZ128rr
    0U,	// VPABSDZ128rrk
    0U,	// VPABSDZ128rrkz
    0U,	// VPABSDZ256rm
    0U,	// VPABSDZ256rmb
    0U,	// VPABSDZ256rmbk
    0U,	// VPABSDZ256rmbkz
    0U,	// VPABSDZ256rmk
    0U,	// VPABSDZ256rmkz
    0U,	// VPABSDZ256rr
    0U,	// VPABSDZ256rrk
    0U,	// VPABSDZ256rrkz
    0U,	// VPABSDZrm
    0U,	// VPABSDZrmb
    0U,	// VPABSDZrmbk
    0U,	// VPABSDZrmbkz
    0U,	// VPABSDZrmk
    0U,	// VPABSDZrmkz
    0U,	// VPABSDZrr
    0U,	// VPABSDZrrk
    0U,	// VPABSDZrrkz
    0U,	// VPABSDrm
    0U,	// VPABSDrr
    0U,	// VPABSQZ128rm
    0U,	// VPABSQZ128rmb
    0U,	// VPABSQZ128rmbk
    0U,	// VPABSQZ128rmbkz
    0U,	// VPABSQZ128rmk
    0U,	// VPABSQZ128rmkz
    0U,	// VPABSQZ128rr
    0U,	// VPABSQZ128rrk
    0U,	// VPABSQZ128rrkz
    0U,	// VPABSQZ256rm
    0U,	// VPABSQZ256rmb
    0U,	// VPABSQZ256rmbk
    0U,	// VPABSQZ256rmbkz
    0U,	// VPABSQZ256rmk
    0U,	// VPABSQZ256rmkz
    0U,	// VPABSQZ256rr
    0U,	// VPABSQZ256rrk
    0U,	// VPABSQZ256rrkz
    0U,	// VPABSQZrm
    0U,	// VPABSQZrmb
    0U,	// VPABSQZrmbk
    0U,	// VPABSQZrmbkz
    0U,	// VPABSQZrmk
    0U,	// VPABSQZrmkz
    0U,	// VPABSQZrr
    0U,	// VPABSQZrrk
    0U,	// VPABSQZrrkz
    0U,	// VPABSWYrm
    0U,	// VPABSWYrr
    0U,	// VPABSWZ128rm
    0U,	// VPABSWZ128rmk
    0U,	// VPABSWZ128rmkz
    0U,	// VPABSWZ128rr
    0U,	// VPABSWZ128rrk
    0U,	// VPABSWZ128rrkz
    0U,	// VPABSWZ256rm
    0U,	// VPABSWZ256rmk
    0U,	// VPABSWZ256rmkz
    0U,	// VPABSWZ256rr
    0U,	// VPABSWZ256rrk
    0U,	// VPABSWZ256rrkz
    0U,	// VPABSWZrm
    0U,	// VPABSWZrmk
    0U,	// VPABSWZrmkz
    0U,	// VPABSWZrr
    0U,	// VPABSWZrrk
    0U,	// VPABSWZrrkz
    0U,	// VPABSWrm
    0U,	// VPABSWrr
    0U,	// VPACKSSDWYrm
    0U,	// VPACKSSDWYrr
    0U,	// VPACKSSDWZ128rm
    0U,	// VPACKSSDWZ128rmb
    0U,	// VPACKSSDWZ128rmbk
    0U,	// VPACKSSDWZ128rmbkz
    0U,	// VPACKSSDWZ128rmk
    0U,	// VPACKSSDWZ128rmkz
    0U,	// VPACKSSDWZ128rr
    0U,	// VPACKSSDWZ128rrk
    0U,	// VPACKSSDWZ128rrkz
    0U,	// VPACKSSDWZ256rm
    0U,	// VPACKSSDWZ256rmb
    0U,	// VPACKSSDWZ256rmbk
    0U,	// VPACKSSDWZ256rmbkz
    0U,	// VPACKSSDWZ256rmk
    0U,	// VPACKSSDWZ256rmkz
    0U,	// VPACKSSDWZ256rr
    0U,	// VPACKSSDWZ256rrk
    0U,	// VPACKSSDWZ256rrkz
    0U,	// VPACKSSDWZrm
    0U,	// VPACKSSDWZrmb
    0U,	// VPACKSSDWZrmbk
    0U,	// VPACKSSDWZrmbkz
    0U,	// VPACKSSDWZrmk
    0U,	// VPACKSSDWZrmkz
    0U,	// VPACKSSDWZrr
    0U,	// VPACKSSDWZrrk
    0U,	// VPACKSSDWZrrkz
    0U,	// VPACKSSDWrm
    0U,	// VPACKSSDWrr
    0U,	// VPACKSSWBYrm
    0U,	// VPACKSSWBYrr
    0U,	// VPACKSSWBZ128rm
    0U,	// VPACKSSWBZ128rmk
    0U,	// VPACKSSWBZ128rmkz
    0U,	// VPACKSSWBZ128rr
    0U,	// VPACKSSWBZ128rrk
    0U,	// VPACKSSWBZ128rrkz
    0U,	// VPACKSSWBZ256rm
    0U,	// VPACKSSWBZ256rmk
    0U,	// VPACKSSWBZ256rmkz
    0U,	// VPACKSSWBZ256rr
    0U,	// VPACKSSWBZ256rrk
    0U,	// VPACKSSWBZ256rrkz
    0U,	// VPACKSSWBZrm
    0U,	// VPACKSSWBZrmk
    0U,	// VPACKSSWBZrmkz
    0U,	// VPACKSSWBZrr
    0U,	// VPACKSSWBZrrk
    0U,	// VPACKSSWBZrrkz
    0U,	// VPACKSSWBrm
    0U,	// VPACKSSWBrr
    0U,	// VPACKUSDWYrm
    0U,	// VPACKUSDWYrr
    0U,	// VPACKUSDWZ128rm
    0U,	// VPACKUSDWZ128rmb
    0U,	// VPACKUSDWZ128rmbk
    0U,	// VPACKUSDWZ128rmbkz
    0U,	// VPACKUSDWZ128rmk
    0U,	// VPACKUSDWZ128rmkz
    0U,	// VPACKUSDWZ128rr
    0U,	// VPACKUSDWZ128rrk
    0U,	// VPACKUSDWZ128rrkz
    0U,	// VPACKUSDWZ256rm
    0U,	// VPACKUSDWZ256rmb
    0U,	// VPACKUSDWZ256rmbk
    0U,	// VPACKUSDWZ256rmbkz
    0U,	// VPACKUSDWZ256rmk
    0U,	// VPACKUSDWZ256rmkz
    0U,	// VPACKUSDWZ256rr
    0U,	// VPACKUSDWZ256rrk
    0U,	// VPACKUSDWZ256rrkz
    0U,	// VPACKUSDWZrm
    0U,	// VPACKUSDWZrmb
    0U,	// VPACKUSDWZrmbk
    0U,	// VPACKUSDWZrmbkz
    0U,	// VPACKUSDWZrmk
    0U,	// VPACKUSDWZrmkz
    0U,	// VPACKUSDWZrr
    0U,	// VPACKUSDWZrrk
    0U,	// VPACKUSDWZrrkz
    0U,	// VPACKUSDWrm
    0U,	// VPACKUSDWrr
    0U,	// VPACKUSWBYrm
    0U,	// VPACKUSWBYrr
    0U,	// VPACKUSWBZ128rm
    0U,	// VPACKUSWBZ128rmk
    0U,	// VPACKUSWBZ128rmkz
    0U,	// VPACKUSWBZ128rr
    0U,	// VPACKUSWBZ128rrk
    0U,	// VPACKUSWBZ128rrkz
    0U,	// VPACKUSWBZ256rm
    0U,	// VPACKUSWBZ256rmk
    0U,	// VPACKUSWBZ256rmkz
    0U,	// VPACKUSWBZ256rr
    0U,	// VPACKUSWBZ256rrk
    0U,	// VPACKUSWBZ256rrkz
    0U,	// VPACKUSWBZrm
    0U,	// VPACKUSWBZrmk
    0U,	// VPACKUSWBZrmkz
    0U,	// VPACKUSWBZrr
    0U,	// VPACKUSWBZrrk
    0U,	// VPACKUSWBZrrkz
    0U,	// VPACKUSWBrm
    0U,	// VPACKUSWBrr
    0U,	// VPADDBYrm
    0U,	// VPADDBYrr
    0U,	// VPADDBZ128rm
    0U,	// VPADDBZ128rmk
    0U,	// VPADDBZ128rmkz
    0U,	// VPADDBZ128rr
    0U,	// VPADDBZ128rrk
    0U,	// VPADDBZ128rrkz
    0U,	// VPADDBZ256rm
    0U,	// VPADDBZ256rmk
    0U,	// VPADDBZ256rmkz
    0U,	// VPADDBZ256rr
    0U,	// VPADDBZ256rrk
    0U,	// VPADDBZ256rrkz
    0U,	// VPADDBZrm
    0U,	// VPADDBZrmk
    0U,	// VPADDBZrmkz
    0U,	// VPADDBZrr
    0U,	// VPADDBZrrk
    0U,	// VPADDBZrrkz
    0U,	// VPADDBrm
    0U,	// VPADDBrr
    0U,	// VPADDDYrm
    0U,	// VPADDDYrr
    0U,	// VPADDDZ128rm
    0U,	// VPADDDZ128rmb
    0U,	// VPADDDZ128rmbk
    0U,	// VPADDDZ128rmbkz
    0U,	// VPADDDZ128rmk
    0U,	// VPADDDZ128rmkz
    0U,	// VPADDDZ128rr
    0U,	// VPADDDZ128rrk
    0U,	// VPADDDZ128rrkz
    0U,	// VPADDDZ256rm
    0U,	// VPADDDZ256rmb
    0U,	// VPADDDZ256rmbk
    0U,	// VPADDDZ256rmbkz
    0U,	// VPADDDZ256rmk
    0U,	// VPADDDZ256rmkz
    0U,	// VPADDDZ256rr
    0U,	// VPADDDZ256rrk
    0U,	// VPADDDZ256rrkz
    0U,	// VPADDDZrm
    0U,	// VPADDDZrmb
    0U,	// VPADDDZrmbk
    0U,	// VPADDDZrmbkz
    0U,	// VPADDDZrmk
    0U,	// VPADDDZrmkz
    0U,	// VPADDDZrr
    0U,	// VPADDDZrrk
    0U,	// VPADDDZrrkz
    0U,	// VPADDDrm
    0U,	// VPADDDrr
    0U,	// VPADDQYrm
    0U,	// VPADDQYrr
    0U,	// VPADDQZ128rm
    0U,	// VPADDQZ128rmb
    0U,	// VPADDQZ128rmbk
    0U,	// VPADDQZ128rmbkz
    0U,	// VPADDQZ128rmk
    0U,	// VPADDQZ128rmkz
    0U,	// VPADDQZ128rr
    0U,	// VPADDQZ128rrk
    0U,	// VPADDQZ128rrkz
    0U,	// VPADDQZ256rm
    0U,	// VPADDQZ256rmb
    0U,	// VPADDQZ256rmbk
    0U,	// VPADDQZ256rmbkz
    0U,	// VPADDQZ256rmk
    0U,	// VPADDQZ256rmkz
    0U,	// VPADDQZ256rr
    0U,	// VPADDQZ256rrk
    0U,	// VPADDQZ256rrkz
    0U,	// VPADDQZrm
    0U,	// VPADDQZrmb
    0U,	// VPADDQZrmbk
    0U,	// VPADDQZrmbkz
    0U,	// VPADDQZrmk
    0U,	// VPADDQZrmkz
    0U,	// VPADDQZrr
    0U,	// VPADDQZrrk
    0U,	// VPADDQZrrkz
    0U,	// VPADDQrm
    0U,	// VPADDQrr
    0U,	// VPADDSBYrm
    0U,	// VPADDSBYrr
    0U,	// VPADDSBZ128rm
    0U,	// VPADDSBZ128rmk
    0U,	// VPADDSBZ128rmkz
    0U,	// VPADDSBZ128rr
    0U,	// VPADDSBZ128rrk
    0U,	// VPADDSBZ128rrkz
    0U,	// VPADDSBZ256rm
    0U,	// VPADDSBZ256rmk
    0U,	// VPADDSBZ256rmkz
    0U,	// VPADDSBZ256rr
    0U,	// VPADDSBZ256rrk
    0U,	// VPADDSBZ256rrkz
    0U,	// VPADDSBZrm
    0U,	// VPADDSBZrmk
    0U,	// VPADDSBZrmkz
    0U,	// VPADDSBZrr
    0U,	// VPADDSBZrrk
    0U,	// VPADDSBZrrkz
    0U,	// VPADDSBrm
    0U,	// VPADDSBrr
    0U,	// VPADDSWYrm
    0U,	// VPADDSWYrr
    0U,	// VPADDSWZ128rm
    0U,	// VPADDSWZ128rmk
    0U,	// VPADDSWZ128rmkz
    0U,	// VPADDSWZ128rr
    0U,	// VPADDSWZ128rrk
    0U,	// VPADDSWZ128rrkz
    0U,	// VPADDSWZ256rm
    0U,	// VPADDSWZ256rmk
    0U,	// VPADDSWZ256rmkz
    0U,	// VPADDSWZ256rr
    0U,	// VPADDSWZ256rrk
    0U,	// VPADDSWZ256rrkz
    0U,	// VPADDSWZrm
    0U,	// VPADDSWZrmk
    0U,	// VPADDSWZrmkz
    0U,	// VPADDSWZrr
    0U,	// VPADDSWZrrk
    0U,	// VPADDSWZrrkz
    0U,	// VPADDSWrm
    0U,	// VPADDSWrr
    0U,	// VPADDUSBYrm
    0U,	// VPADDUSBYrr
    0U,	// VPADDUSBZ128rm
    0U,	// VPADDUSBZ128rmk
    0U,	// VPADDUSBZ128rmkz
    0U,	// VPADDUSBZ128rr
    0U,	// VPADDUSBZ128rrk
    0U,	// VPADDUSBZ128rrkz
    0U,	// VPADDUSBZ256rm
    0U,	// VPADDUSBZ256rmk
    0U,	// VPADDUSBZ256rmkz
    0U,	// VPADDUSBZ256rr
    0U,	// VPADDUSBZ256rrk
    0U,	// VPADDUSBZ256rrkz
    0U,	// VPADDUSBZrm
    0U,	// VPADDUSBZrmk
    0U,	// VPADDUSBZrmkz
    0U,	// VPADDUSBZrr
    0U,	// VPADDUSBZrrk
    0U,	// VPADDUSBZrrkz
    0U,	// VPADDUSBrm
    0U,	// VPADDUSBrr
    0U,	// VPADDUSWYrm
    0U,	// VPADDUSWYrr
    0U,	// VPADDUSWZ128rm
    0U,	// VPADDUSWZ128rmk
    0U,	// VPADDUSWZ128rmkz
    0U,	// VPADDUSWZ128rr
    0U,	// VPADDUSWZ128rrk
    0U,	// VPADDUSWZ128rrkz
    0U,	// VPADDUSWZ256rm
    0U,	// VPADDUSWZ256rmk
    0U,	// VPADDUSWZ256rmkz
    0U,	// VPADDUSWZ256rr
    0U,	// VPADDUSWZ256rrk
    0U,	// VPADDUSWZ256rrkz
    0U,	// VPADDUSWZrm
    0U,	// VPADDUSWZrmk
    0U,	// VPADDUSWZrmkz
    0U,	// VPADDUSWZrr
    0U,	// VPADDUSWZrrk
    0U,	// VPADDUSWZrrkz
    0U,	// VPADDUSWrm
    0U,	// VPADDUSWrr
    0U,	// VPADDWYrm
    0U,	// VPADDWYrr
    0U,	// VPADDWZ128rm
    0U,	// VPADDWZ128rmk
    0U,	// VPADDWZ128rmkz
    0U,	// VPADDWZ128rr
    0U,	// VPADDWZ128rrk
    0U,	// VPADDWZ128rrkz
    0U,	// VPADDWZ256rm
    0U,	// VPADDWZ256rmk
    0U,	// VPADDWZ256rmkz
    0U,	// VPADDWZ256rr
    0U,	// VPADDWZ256rrk
    0U,	// VPADDWZ256rrkz
    0U,	// VPADDWZrm
    0U,	// VPADDWZrmk
    0U,	// VPADDWZrmkz
    0U,	// VPADDWZrr
    0U,	// VPADDWZrrk
    0U,	// VPADDWZrrkz
    0U,	// VPADDWrm
    0U,	// VPADDWrr
    0U,	// VPALIGNRYrmi
    0U,	// VPALIGNRYrri
    0U,	// VPALIGNRZ128rmi
    0U,	// VPALIGNRZ128rmik
    0U,	// VPALIGNRZ128rmikz
    0U,	// VPALIGNRZ128rri
    0U,	// VPALIGNRZ128rrik
    3U,	// VPALIGNRZ128rrikz
    0U,	// VPALIGNRZ256rmi
    0U,	// VPALIGNRZ256rmik
    0U,	// VPALIGNRZ256rmikz
    0U,	// VPALIGNRZ256rri
    0U,	// VPALIGNRZ256rrik
    3U,	// VPALIGNRZ256rrikz
    0U,	// VPALIGNRZrmi
    0U,	// VPALIGNRZrmik
    0U,	// VPALIGNRZrmikz
    0U,	// VPALIGNRZrri
    0U,	// VPALIGNRZrrik
    3U,	// VPALIGNRZrrikz
    0U,	// VPALIGNRrmi
    0U,	// VPALIGNRrri
    0U,	// VPANDDZ128rm
    0U,	// VPANDDZ128rmb
    0U,	// VPANDDZ128rmbk
    0U,	// VPANDDZ128rmbkz
    0U,	// VPANDDZ128rmk
    0U,	// VPANDDZ128rmkz
    0U,	// VPANDDZ128rr
    0U,	// VPANDDZ128rrk
    0U,	// VPANDDZ128rrkz
    0U,	// VPANDDZ256rm
    0U,	// VPANDDZ256rmb
    0U,	// VPANDDZ256rmbk
    0U,	// VPANDDZ256rmbkz
    0U,	// VPANDDZ256rmk
    0U,	// VPANDDZ256rmkz
    0U,	// VPANDDZ256rr
    0U,	// VPANDDZ256rrk
    0U,	// VPANDDZ256rrkz
    0U,	// VPANDDZrm
    0U,	// VPANDDZrmb
    0U,	// VPANDDZrmbk
    0U,	// VPANDDZrmbkz
    0U,	// VPANDDZrmk
    0U,	// VPANDDZrmkz
    0U,	// VPANDDZrr
    0U,	// VPANDDZrrk
    0U,	// VPANDDZrrkz
    0U,	// VPANDNDZ128rm
    0U,	// VPANDNDZ128rmb
    0U,	// VPANDNDZ128rmbk
    0U,	// VPANDNDZ128rmbkz
    0U,	// VPANDNDZ128rmk
    0U,	// VPANDNDZ128rmkz
    0U,	// VPANDNDZ128rr
    0U,	// VPANDNDZ128rrk
    0U,	// VPANDNDZ128rrkz
    0U,	// VPANDNDZ256rm
    0U,	// VPANDNDZ256rmb
    0U,	// VPANDNDZ256rmbk
    0U,	// VPANDNDZ256rmbkz
    0U,	// VPANDNDZ256rmk
    0U,	// VPANDNDZ256rmkz
    0U,	// VPANDNDZ256rr
    0U,	// VPANDNDZ256rrk
    0U,	// VPANDNDZ256rrkz
    0U,	// VPANDNDZrm
    0U,	// VPANDNDZrmb
    0U,	// VPANDNDZrmbk
    0U,	// VPANDNDZrmbkz
    0U,	// VPANDNDZrmk
    0U,	// VPANDNDZrmkz
    0U,	// VPANDNDZrr
    0U,	// VPANDNDZrrk
    0U,	// VPANDNDZrrkz
    0U,	// VPANDNQZ128rm
    0U,	// VPANDNQZ128rmb
    0U,	// VPANDNQZ128rmbk
    0U,	// VPANDNQZ128rmbkz
    0U,	// VPANDNQZ128rmk
    0U,	// VPANDNQZ128rmkz
    0U,	// VPANDNQZ128rr
    0U,	// VPANDNQZ128rrk
    0U,	// VPANDNQZ128rrkz
    0U,	// VPANDNQZ256rm
    0U,	// VPANDNQZ256rmb
    0U,	// VPANDNQZ256rmbk
    0U,	// VPANDNQZ256rmbkz
    0U,	// VPANDNQZ256rmk
    0U,	// VPANDNQZ256rmkz
    0U,	// VPANDNQZ256rr
    0U,	// VPANDNQZ256rrk
    0U,	// VPANDNQZ256rrkz
    0U,	// VPANDNQZrm
    0U,	// VPANDNQZrmb
    0U,	// VPANDNQZrmbk
    0U,	// VPANDNQZrmbkz
    0U,	// VPANDNQZrmk
    0U,	// VPANDNQZrmkz
    0U,	// VPANDNQZrr
    0U,	// VPANDNQZrrk
    0U,	// VPANDNQZrrkz
    0U,	// VPANDNYrm
    0U,	// VPANDNYrr
    0U,	// VPANDNrm
    0U,	// VPANDNrr
    0U,	// VPANDQZ128rm
    0U,	// VPANDQZ128rmb
    0U,	// VPANDQZ128rmbk
    0U,	// VPANDQZ128rmbkz
    0U,	// VPANDQZ128rmk
    0U,	// VPANDQZ128rmkz
    0U,	// VPANDQZ128rr
    0U,	// VPANDQZ128rrk
    0U,	// VPANDQZ128rrkz
    0U,	// VPANDQZ256rm
    0U,	// VPANDQZ256rmb
    0U,	// VPANDQZ256rmbk
    0U,	// VPANDQZ256rmbkz
    0U,	// VPANDQZ256rmk
    0U,	// VPANDQZ256rmkz
    0U,	// VPANDQZ256rr
    0U,	// VPANDQZ256rrk
    0U,	// VPANDQZ256rrkz
    0U,	// VPANDQZrm
    0U,	// VPANDQZrmb
    0U,	// VPANDQZrmbk
    0U,	// VPANDQZrmbkz
    0U,	// VPANDQZrmk
    0U,	// VPANDQZrmkz
    0U,	// VPANDQZrr
    0U,	// VPANDQZrrk
    0U,	// VPANDQZrrkz
    0U,	// VPANDYrm
    0U,	// VPANDYrr
    0U,	// VPANDrm
    0U,	// VPANDrr
    0U,	// VPAVGBYrm
    0U,	// VPAVGBYrr
    0U,	// VPAVGBZ128rm
    0U,	// VPAVGBZ128rmk
    0U,	// VPAVGBZ128rmkz
    0U,	// VPAVGBZ128rr
    0U,	// VPAVGBZ128rrk
    0U,	// VPAVGBZ128rrkz
    0U,	// VPAVGBZ256rm
    0U,	// VPAVGBZ256rmk
    0U,	// VPAVGBZ256rmkz
    0U,	// VPAVGBZ256rr
    0U,	// VPAVGBZ256rrk
    0U,	// VPAVGBZ256rrkz
    0U,	// VPAVGBZrm
    0U,	// VPAVGBZrmk
    0U,	// VPAVGBZrmkz
    0U,	// VPAVGBZrr
    0U,	// VPAVGBZrrk
    0U,	// VPAVGBZrrkz
    0U,	// VPAVGBrm
    0U,	// VPAVGBrr
    0U,	// VPAVGWYrm
    0U,	// VPAVGWYrr
    0U,	// VPAVGWZ128rm
    0U,	// VPAVGWZ128rmk
    0U,	// VPAVGWZ128rmkz
    0U,	// VPAVGWZ128rr
    0U,	// VPAVGWZ128rrk
    0U,	// VPAVGWZ128rrkz
    0U,	// VPAVGWZ256rm
    0U,	// VPAVGWZ256rmk
    0U,	// VPAVGWZ256rmkz
    0U,	// VPAVGWZ256rr
    0U,	// VPAVGWZ256rrk
    0U,	// VPAVGWZ256rrkz
    0U,	// VPAVGWZrm
    0U,	// VPAVGWZrmk
    0U,	// VPAVGWZrmkz
    0U,	// VPAVGWZrr
    0U,	// VPAVGWZrrk
    0U,	// VPAVGWZrrkz
    0U,	// VPAVGWrm
    0U,	// VPAVGWrr
    0U,	// VPBLENDDYrmi
    0U,	// VPBLENDDYrri
    0U,	// VPBLENDDrmi
    0U,	// VPBLENDDrri
    0U,	// VPBLENDMBZ128rm
    0U,	// VPBLENDMBZ128rmk
    0U,	// VPBLENDMBZ128rmkz
    0U,	// VPBLENDMBZ128rr
    0U,	// VPBLENDMBZ128rrk
    0U,	// VPBLENDMBZ128rrkz
    0U,	// VPBLENDMBZ256rm
    0U,	// VPBLENDMBZ256rmk
    0U,	// VPBLENDMBZ256rmkz
    0U,	// VPBLENDMBZ256rr
    0U,	// VPBLENDMBZ256rrk
    0U,	// VPBLENDMBZ256rrkz
    0U,	// VPBLENDMBZrm
    0U,	// VPBLENDMBZrmk
    0U,	// VPBLENDMBZrmkz
    0U,	// VPBLENDMBZrr
    0U,	// VPBLENDMBZrrk
    0U,	// VPBLENDMBZrrkz
    0U,	// VPBLENDMDZ128rm
    0U,	// VPBLENDMDZ128rmb
    0U,	// VPBLENDMDZ128rmbk
    0U,	// VPBLENDMDZ128rmbkz
    0U,	// VPBLENDMDZ128rmk
    0U,	// VPBLENDMDZ128rmkz
    0U,	// VPBLENDMDZ128rr
    0U,	// VPBLENDMDZ128rrk
    0U,	// VPBLENDMDZ128rrkz
    0U,	// VPBLENDMDZ256rm
    0U,	// VPBLENDMDZ256rmb
    0U,	// VPBLENDMDZ256rmbk
    0U,	// VPBLENDMDZ256rmbkz
    0U,	// VPBLENDMDZ256rmk
    0U,	// VPBLENDMDZ256rmkz
    0U,	// VPBLENDMDZ256rr
    0U,	// VPBLENDMDZ256rrk
    0U,	// VPBLENDMDZ256rrkz
    0U,	// VPBLENDMDZrm
    0U,	// VPBLENDMDZrmb
    0U,	// VPBLENDMDZrmbk
    0U,	// VPBLENDMDZrmbkz
    0U,	// VPBLENDMDZrmk
    0U,	// VPBLENDMDZrmkz
    0U,	// VPBLENDMDZrr
    0U,	// VPBLENDMDZrrk
    0U,	// VPBLENDMDZrrkz
    0U,	// VPBLENDMQZ128rm
    0U,	// VPBLENDMQZ128rmb
    0U,	// VPBLENDMQZ128rmbk
    0U,	// VPBLENDMQZ128rmbkz
    0U,	// VPBLENDMQZ128rmk
    0U,	// VPBLENDMQZ128rmkz
    0U,	// VPBLENDMQZ128rr
    0U,	// VPBLENDMQZ128rrk
    0U,	// VPBLENDMQZ128rrkz
    0U,	// VPBLENDMQZ256rm
    0U,	// VPBLENDMQZ256rmb
    0U,	// VPBLENDMQZ256rmbk
    0U,	// VPBLENDMQZ256rmbkz
    0U,	// VPBLENDMQZ256rmk
    0U,	// VPBLENDMQZ256rmkz
    0U,	// VPBLENDMQZ256rr
    0U,	// VPBLENDMQZ256rrk
    0U,	// VPBLENDMQZ256rrkz
    0U,	// VPBLENDMQZrm
    0U,	// VPBLENDMQZrmb
    0U,	// VPBLENDMQZrmbk
    0U,	// VPBLENDMQZrmbkz
    0U,	// VPBLENDMQZrmk
    0U,	// VPBLENDMQZrmkz
    0U,	// VPBLENDMQZrr
    0U,	// VPBLENDMQZrrk
    0U,	// VPBLENDMQZrrkz
    0U,	// VPBLENDMWZ128rm
    0U,	// VPBLENDMWZ128rmk
    0U,	// VPBLENDMWZ128rmkz
    0U,	// VPBLENDMWZ128rr
    0U,	// VPBLENDMWZ128rrk
    0U,	// VPBLENDMWZ128rrkz
    0U,	// VPBLENDMWZ256rm
    0U,	// VPBLENDMWZ256rmk
    0U,	// VPBLENDMWZ256rmkz
    0U,	// VPBLENDMWZ256rr
    0U,	// VPBLENDMWZ256rrk
    0U,	// VPBLENDMWZ256rrkz
    0U,	// VPBLENDMWZrm
    0U,	// VPBLENDMWZrmk
    0U,	// VPBLENDMWZrmkz
    0U,	// VPBLENDMWZrr
    0U,	// VPBLENDMWZrrk
    0U,	// VPBLENDMWZrrkz
    0U,	// VPBLENDVBYrm
    0U,	// VPBLENDVBYrr
    0U,	// VPBLENDVBrm
    0U,	// VPBLENDVBrr
    0U,	// VPBLENDWYrmi
    0U,	// VPBLENDWYrri
    0U,	// VPBLENDWrmi
    0U,	// VPBLENDWrri
    0U,	// VPBROADCASTBYrm
    0U,	// VPBROADCASTBYrr
    0U,	// VPBROADCASTBZ128m
    0U,	// VPBROADCASTBZ128mk
    0U,	// VPBROADCASTBZ128mkz
    0U,	// VPBROADCASTBZ128r
    0U,	// VPBROADCASTBZ128rk
    0U,	// VPBROADCASTBZ128rkz
    0U,	// VPBROADCASTBZ256m
    0U,	// VPBROADCASTBZ256mk
    0U,	// VPBROADCASTBZ256mkz
    0U,	// VPBROADCASTBZ256r
    0U,	// VPBROADCASTBZ256rk
    0U,	// VPBROADCASTBZ256rkz
    0U,	// VPBROADCASTBZm
    0U,	// VPBROADCASTBZmk
    0U,	// VPBROADCASTBZmkz
    0U,	// VPBROADCASTBZr
    0U,	// VPBROADCASTBZrk
    0U,	// VPBROADCASTBZrkz
    0U,	// VPBROADCASTBrZ128r
    0U,	// VPBROADCASTBrZ128rk
    0U,	// VPBROADCASTBrZ128rkz
    0U,	// VPBROADCASTBrZ256r
    0U,	// VPBROADCASTBrZ256rk
    0U,	// VPBROADCASTBrZ256rkz
    0U,	// VPBROADCASTBrZr
    0U,	// VPBROADCASTBrZrk
    0U,	// VPBROADCASTBrZrkz
    0U,	// VPBROADCASTBrm
    0U,	// VPBROADCASTBrr
    0U,	// VPBROADCASTDYrm
    0U,	// VPBROADCASTDYrr
    0U,	// VPBROADCASTDZ128m
    0U,	// VPBROADCASTDZ128mk
    0U,	// VPBROADCASTDZ128mkz
    0U,	// VPBROADCASTDZ128r
    0U,	// VPBROADCASTDZ128rk
    0U,	// VPBROADCASTDZ128rkz
    0U,	// VPBROADCASTDZ256m
    0U,	// VPBROADCASTDZ256mk
    0U,	// VPBROADCASTDZ256mkz
    0U,	// VPBROADCASTDZ256r
    0U,	// VPBROADCASTDZ256rk
    0U,	// VPBROADCASTDZ256rkz
    0U,	// VPBROADCASTDZm
    0U,	// VPBROADCASTDZmk
    0U,	// VPBROADCASTDZmkz
    0U,	// VPBROADCASTDZr
    0U,	// VPBROADCASTDZrk
    0U,	// VPBROADCASTDZrkz
    0U,	// VPBROADCASTDrZ128r
    0U,	// VPBROADCASTDrZ128rk
    0U,	// VPBROADCASTDrZ128rkz
    0U,	// VPBROADCASTDrZ256r
    0U,	// VPBROADCASTDrZ256rk
    0U,	// VPBROADCASTDrZ256rkz
    0U,	// VPBROADCASTDrZr
    0U,	// VPBROADCASTDrZrk
    0U,	// VPBROADCASTDrZrkz
    0U,	// VPBROADCASTDrm
    0U,	// VPBROADCASTDrr
    0U,	// VPBROADCASTMB2QZ128rr
    0U,	// VPBROADCASTMB2QZ256rr
    0U,	// VPBROADCASTMB2QZrr
    0U,	// VPBROADCASTMW2DZ128rr
    0U,	// VPBROADCASTMW2DZ256rr
    0U,	// VPBROADCASTMW2DZrr
    0U,	// VPBROADCASTQYrm
    0U,	// VPBROADCASTQYrr
    0U,	// VPBROADCASTQZ128m
    0U,	// VPBROADCASTQZ128mk
    0U,	// VPBROADCASTQZ128mkz
    0U,	// VPBROADCASTQZ128r
    0U,	// VPBROADCASTQZ128rk
    0U,	// VPBROADCASTQZ128rkz
    0U,	// VPBROADCASTQZ256m
    0U,	// VPBROADCASTQZ256mk
    0U,	// VPBROADCASTQZ256mkz
    0U,	// VPBROADCASTQZ256r
    0U,	// VPBROADCASTQZ256rk
    0U,	// VPBROADCASTQZ256rkz
    0U,	// VPBROADCASTQZm
    0U,	// VPBROADCASTQZmk
    0U,	// VPBROADCASTQZmkz
    0U,	// VPBROADCASTQZr
    0U,	// VPBROADCASTQZrk
    0U,	// VPBROADCASTQZrkz
    0U,	// VPBROADCASTQrZ128r
    0U,	// VPBROADCASTQrZ128rk
    0U,	// VPBROADCASTQrZ128rkz
    0U,	// VPBROADCASTQrZ256r
    0U,	// VPBROADCASTQrZ256rk
    0U,	// VPBROADCASTQrZ256rkz
    0U,	// VPBROADCASTQrZr
    0U,	// VPBROADCASTQrZrk
    0U,	// VPBROADCASTQrZrkz
    0U,	// VPBROADCASTQrm
    0U,	// VPBROADCASTQrr
    0U,	// VPBROADCASTWYrm
    0U,	// VPBROADCASTWYrr
    0U,	// VPBROADCASTWZ128m
    0U,	// VPBROADCASTWZ128mk
    0U,	// VPBROADCASTWZ128mkz
    0U,	// VPBROADCASTWZ128r
    0U,	// VPBROADCASTWZ128rk
    0U,	// VPBROADCASTWZ128rkz
    0U,	// VPBROADCASTWZ256m
    0U,	// VPBROADCASTWZ256mk
    0U,	// VPBROADCASTWZ256mkz
    0U,	// VPBROADCASTWZ256r
    0U,	// VPBROADCASTWZ256rk
    0U,	// VPBROADCASTWZ256rkz
    0U,	// VPBROADCASTWZm
    0U,	// VPBROADCASTWZmk
    0U,	// VPBROADCASTWZmkz
    0U,	// VPBROADCASTWZr
    0U,	// VPBROADCASTWZrk
    0U,	// VPBROADCASTWZrkz
    0U,	// VPBROADCASTWrZ128r
    0U,	// VPBROADCASTWrZ128rk
    0U,	// VPBROADCASTWrZ128rkz
    0U,	// VPBROADCASTWrZ256r
    0U,	// VPBROADCASTWrZ256rk
    0U,	// VPBROADCASTWrZ256rkz
    0U,	// VPBROADCASTWrZr
    0U,	// VPBROADCASTWrZrk
    0U,	// VPBROADCASTWrZrkz
    0U,	// VPBROADCASTWrm
    0U,	// VPBROADCASTWrr
    0U,	// VPCLMULQDQYrm
    0U,	// VPCLMULQDQYrr
    0U,	// VPCLMULQDQZ128rm
    0U,	// VPCLMULQDQZ128rr
    0U,	// VPCLMULQDQZ256rm
    0U,	// VPCLMULQDQZ256rr
    0U,	// VPCLMULQDQZrm
    0U,	// VPCLMULQDQZrr
    0U,	// VPCLMULQDQrm
    0U,	// VPCLMULQDQrr
    0U,	// VPCMOVYrmr
    0U,	// VPCMOVYrrm
    0U,	// VPCMOVYrrr
    0U,	// VPCMOVYrrr_REV
    0U,	// VPCMOVrmr
    0U,	// VPCMOVrrm
    0U,	// VPCMOVrrr
    0U,	// VPCMOVrrr_REV
    0U,	// VPCMPBZ128rmi
    0U,	// VPCMPBZ128rmi_alt
    0U,	// VPCMPBZ128rmik
    0U,	// VPCMPBZ128rmik_alt
    0U,	// VPCMPBZ128rri
    0U,	// VPCMPBZ128rri_alt
    1U,	// VPCMPBZ128rrik
    1U,	// VPCMPBZ128rrik_alt
    0U,	// VPCMPBZ256rmi
    0U,	// VPCMPBZ256rmi_alt
    0U,	// VPCMPBZ256rmik
    0U,	// VPCMPBZ256rmik_alt
    0U,	// VPCMPBZ256rri
    0U,	// VPCMPBZ256rri_alt
    1U,	// VPCMPBZ256rrik
    1U,	// VPCMPBZ256rrik_alt
    0U,	// VPCMPBZrmi
    0U,	// VPCMPBZrmi_alt
    0U,	// VPCMPBZrmik
    0U,	// VPCMPBZrmik_alt
    0U,	// VPCMPBZrri
    0U,	// VPCMPBZrri_alt
    1U,	// VPCMPBZrrik
    1U,	// VPCMPBZrrik_alt
    0U,	// VPCMPDZ128rmi
    0U,	// VPCMPDZ128rmi_alt
    0U,	// VPCMPDZ128rmib
    0U,	// VPCMPDZ128rmib_alt
    1U,	// VPCMPDZ128rmibk
    1U,	// VPCMPDZ128rmibk_alt
    0U,	// VPCMPDZ128rmik
    0U,	// VPCMPDZ128rmik_alt
    0U,	// VPCMPDZ128rri
    0U,	// VPCMPDZ128rri_alt
    1U,	// VPCMPDZ128rrik
    1U,	// VPCMPDZ128rrik_alt
    0U,	// VPCMPDZ256rmi
    0U,	// VPCMPDZ256rmi_alt
    0U,	// VPCMPDZ256rmib
    0U,	// VPCMPDZ256rmib_alt
    1U,	// VPCMPDZ256rmibk
    1U,	// VPCMPDZ256rmibk_alt
    0U,	// VPCMPDZ256rmik
    0U,	// VPCMPDZ256rmik_alt
    0U,	// VPCMPDZ256rri
    0U,	// VPCMPDZ256rri_alt
    1U,	// VPCMPDZ256rrik
    1U,	// VPCMPDZ256rrik_alt
    0U,	// VPCMPDZrmi
    0U,	// VPCMPDZrmi_alt
    0U,	// VPCMPDZrmib
    0U,	// VPCMPDZrmib_alt
    1U,	// VPCMPDZrmibk
    1U,	// VPCMPDZrmibk_alt
    0U,	// VPCMPDZrmik
    0U,	// VPCMPDZrmik_alt
    0U,	// VPCMPDZrri
    0U,	// VPCMPDZrri_alt
    1U,	// VPCMPDZrrik
    1U,	// VPCMPDZrrik_alt
    0U,	// VPCMPEQBYrm
    0U,	// VPCMPEQBYrr
    0U,	// VPCMPEQBZ128rm
    0U,	// VPCMPEQBZ128rmk
    0U,	// VPCMPEQBZ128rr
    0U,	// VPCMPEQBZ128rrk
    0U,	// VPCMPEQBZ256rm
    0U,	// VPCMPEQBZ256rmk
    0U,	// VPCMPEQBZ256rr
    0U,	// VPCMPEQBZ256rrk
    0U,	// VPCMPEQBZrm
    0U,	// VPCMPEQBZrmk
    0U,	// VPCMPEQBZrr
    0U,	// VPCMPEQBZrrk
    0U,	// VPCMPEQBrm
    0U,	// VPCMPEQBrr
    0U,	// VPCMPEQDYrm
    0U,	// VPCMPEQDYrr
    0U,	// VPCMPEQDZ128rm
    0U,	// VPCMPEQDZ128rmb
    0U,	// VPCMPEQDZ128rmbk
    0U,	// VPCMPEQDZ128rmk
    0U,	// VPCMPEQDZ128rr
    0U,	// VPCMPEQDZ128rrk
    0U,	// VPCMPEQDZ256rm
    0U,	// VPCMPEQDZ256rmb
    0U,	// VPCMPEQDZ256rmbk
    0U,	// VPCMPEQDZ256rmk
    0U,	// VPCMPEQDZ256rr
    0U,	// VPCMPEQDZ256rrk
    0U,	// VPCMPEQDZrm
    0U,	// VPCMPEQDZrmb
    0U,	// VPCMPEQDZrmbk
    0U,	// VPCMPEQDZrmk
    0U,	// VPCMPEQDZrr
    0U,	// VPCMPEQDZrrk
    0U,	// VPCMPEQDrm
    0U,	// VPCMPEQDrr
    0U,	// VPCMPEQQYrm
    0U,	// VPCMPEQQYrr
    0U,	// VPCMPEQQZ128rm
    0U,	// VPCMPEQQZ128rmb
    0U,	// VPCMPEQQZ128rmbk
    0U,	// VPCMPEQQZ128rmk
    0U,	// VPCMPEQQZ128rr
    0U,	// VPCMPEQQZ128rrk
    0U,	// VPCMPEQQZ256rm
    0U,	// VPCMPEQQZ256rmb
    0U,	// VPCMPEQQZ256rmbk
    0U,	// VPCMPEQQZ256rmk
    0U,	// VPCMPEQQZ256rr
    0U,	// VPCMPEQQZ256rrk
    0U,	// VPCMPEQQZrm
    0U,	// VPCMPEQQZrmb
    0U,	// VPCMPEQQZrmbk
    0U,	// VPCMPEQQZrmk
    0U,	// VPCMPEQQZrr
    0U,	// VPCMPEQQZrrk
    0U,	// VPCMPEQQrm
    0U,	// VPCMPEQQrr
    0U,	// VPCMPEQWYrm
    0U,	// VPCMPEQWYrr
    0U,	// VPCMPEQWZ128rm
    0U,	// VPCMPEQWZ128rmk
    0U,	// VPCMPEQWZ128rr
    0U,	// VPCMPEQWZ128rrk
    0U,	// VPCMPEQWZ256rm
    0U,	// VPCMPEQWZ256rmk
    0U,	// VPCMPEQWZ256rr
    0U,	// VPCMPEQWZ256rrk
    0U,	// VPCMPEQWZrm
    0U,	// VPCMPEQWZrmk
    0U,	// VPCMPEQWZrr
    0U,	// VPCMPEQWZrrk
    0U,	// VPCMPEQWrm
    0U,	// VPCMPEQWrr
    0U,	// VPCMPESTRIrm
    0U,	// VPCMPESTRIrr
    0U,	// VPCMPESTRMrm
    0U,	// VPCMPESTRMrr
    0U,	// VPCMPGTBYrm
    0U,	// VPCMPGTBYrr
    0U,	// VPCMPGTBZ128rm
    0U,	// VPCMPGTBZ128rmk
    0U,	// VPCMPGTBZ128rr
    0U,	// VPCMPGTBZ128rrk
    0U,	// VPCMPGTBZ256rm
    0U,	// VPCMPGTBZ256rmk
    0U,	// VPCMPGTBZ256rr
    0U,	// VPCMPGTBZ256rrk
    0U,	// VPCMPGTBZrm
    0U,	// VPCMPGTBZrmk
    0U,	// VPCMPGTBZrr
    0U,	// VPCMPGTBZrrk
    0U,	// VPCMPGTBrm
    0U,	// VPCMPGTBrr
    0U,	// VPCMPGTDYrm
    0U,	// VPCMPGTDYrr
    0U,	// VPCMPGTDZ128rm
    0U,	// VPCMPGTDZ128rmb
    0U,	// VPCMPGTDZ128rmbk
    0U,	// VPCMPGTDZ128rmk
    0U,	// VPCMPGTDZ128rr
    0U,	// VPCMPGTDZ128rrk
    0U,	// VPCMPGTDZ256rm
    0U,	// VPCMPGTDZ256rmb
    0U,	// VPCMPGTDZ256rmbk
    0U,	// VPCMPGTDZ256rmk
    0U,	// VPCMPGTDZ256rr
    0U,	// VPCMPGTDZ256rrk
    0U,	// VPCMPGTDZrm
    0U,	// VPCMPGTDZrmb
    0U,	// VPCMPGTDZrmbk
    0U,	// VPCMPGTDZrmk
    0U,	// VPCMPGTDZrr
    0U,	// VPCMPGTDZrrk
    0U,	// VPCMPGTDrm
    0U,	// VPCMPGTDrr
    0U,	// VPCMPGTQYrm
    0U,	// VPCMPGTQYrr
    0U,	// VPCMPGTQZ128rm
    0U,	// VPCMPGTQZ128rmb
    0U,	// VPCMPGTQZ128rmbk
    0U,	// VPCMPGTQZ128rmk
    0U,	// VPCMPGTQZ128rr
    0U,	// VPCMPGTQZ128rrk
    0U,	// VPCMPGTQZ256rm
    0U,	// VPCMPGTQZ256rmb
    0U,	// VPCMPGTQZ256rmbk
    0U,	// VPCMPGTQZ256rmk
    0U,	// VPCMPGTQZ256rr
    0U,	// VPCMPGTQZ256rrk
    0U,	// VPCMPGTQZrm
    0U,	// VPCMPGTQZrmb
    0U,	// VPCMPGTQZrmbk
    0U,	// VPCMPGTQZrmk
    0U,	// VPCMPGTQZrr
    0U,	// VPCMPGTQZrrk
    0U,	// VPCMPGTQrm
    0U,	// VPCMPGTQrr
    0U,	// VPCMPGTWYrm
    0U,	// VPCMPGTWYrr
    0U,	// VPCMPGTWZ128rm
    0U,	// VPCMPGTWZ128rmk
    0U,	// VPCMPGTWZ128rr
    0U,	// VPCMPGTWZ128rrk
    0U,	// VPCMPGTWZ256rm
    0U,	// VPCMPGTWZ256rmk
    0U,	// VPCMPGTWZ256rr
    0U,	// VPCMPGTWZ256rrk
    0U,	// VPCMPGTWZrm
    0U,	// VPCMPGTWZrmk
    0U,	// VPCMPGTWZrr
    0U,	// VPCMPGTWZrrk
    0U,	// VPCMPGTWrm
    0U,	// VPCMPGTWrr
    0U,	// VPCMPISTRIrm
    0U,	// VPCMPISTRIrr
    0U,	// VPCMPISTRMrm
    0U,	// VPCMPISTRMrr
    0U,	// VPCMPQZ128rmi
    0U,	// VPCMPQZ128rmi_alt
    0U,	// VPCMPQZ128rmib
    0U,	// VPCMPQZ128rmib_alt
    1U,	// VPCMPQZ128rmibk
    1U,	// VPCMPQZ128rmibk_alt
    0U,	// VPCMPQZ128rmik
    0U,	// VPCMPQZ128rmik_alt
    0U,	// VPCMPQZ128rri
    0U,	// VPCMPQZ128rri_alt
    1U,	// VPCMPQZ128rrik
    1U,	// VPCMPQZ128rrik_alt
    0U,	// VPCMPQZ256rmi
    0U,	// VPCMPQZ256rmi_alt
    0U,	// VPCMPQZ256rmib
    0U,	// VPCMPQZ256rmib_alt
    1U,	// VPCMPQZ256rmibk
    1U,	// VPCMPQZ256rmibk_alt
    0U,	// VPCMPQZ256rmik
    0U,	// VPCMPQZ256rmik_alt
    0U,	// VPCMPQZ256rri
    0U,	// VPCMPQZ256rri_alt
    1U,	// VPCMPQZ256rrik
    1U,	// VPCMPQZ256rrik_alt
    0U,	// VPCMPQZrmi
    0U,	// VPCMPQZrmi_alt
    0U,	// VPCMPQZrmib
    0U,	// VPCMPQZrmib_alt
    1U,	// VPCMPQZrmibk
    1U,	// VPCMPQZrmibk_alt
    0U,	// VPCMPQZrmik
    0U,	// VPCMPQZrmik_alt
    0U,	// VPCMPQZrri
    0U,	// VPCMPQZrri_alt
    1U,	// VPCMPQZrrik
    1U,	// VPCMPQZrrik_alt
    0U,	// VPCMPUBZ128rmi
    0U,	// VPCMPUBZ128rmi_alt
    0U,	// VPCMPUBZ128rmik
    0U,	// VPCMPUBZ128rmik_alt
    0U,	// VPCMPUBZ128rri
    0U,	// VPCMPUBZ128rri_alt
    1U,	// VPCMPUBZ128rrik
    1U,	// VPCMPUBZ128rrik_alt
    0U,	// VPCMPUBZ256rmi
    0U,	// VPCMPUBZ256rmi_alt
    0U,	// VPCMPUBZ256rmik
    0U,	// VPCMPUBZ256rmik_alt
    0U,	// VPCMPUBZ256rri
    0U,	// VPCMPUBZ256rri_alt
    1U,	// VPCMPUBZ256rrik
    1U,	// VPCMPUBZ256rrik_alt
    0U,	// VPCMPUBZrmi
    0U,	// VPCMPUBZrmi_alt
    0U,	// VPCMPUBZrmik
    0U,	// VPCMPUBZrmik_alt
    0U,	// VPCMPUBZrri
    0U,	// VPCMPUBZrri_alt
    1U,	// VPCMPUBZrrik
    1U,	// VPCMPUBZrrik_alt
    0U,	// VPCMPUDZ128rmi
    0U,	// VPCMPUDZ128rmi_alt
    0U,	// VPCMPUDZ128rmib
    0U,	// VPCMPUDZ128rmib_alt
    1U,	// VPCMPUDZ128rmibk
    1U,	// VPCMPUDZ128rmibk_alt
    0U,	// VPCMPUDZ128rmik
    0U,	// VPCMPUDZ128rmik_alt
    0U,	// VPCMPUDZ128rri
    0U,	// VPCMPUDZ128rri_alt
    1U,	// VPCMPUDZ128rrik
    1U,	// VPCMPUDZ128rrik_alt
    0U,	// VPCMPUDZ256rmi
    0U,	// VPCMPUDZ256rmi_alt
    0U,	// VPCMPUDZ256rmib
    0U,	// VPCMPUDZ256rmib_alt
    1U,	// VPCMPUDZ256rmibk
    1U,	// VPCMPUDZ256rmibk_alt
    0U,	// VPCMPUDZ256rmik
    0U,	// VPCMPUDZ256rmik_alt
    0U,	// VPCMPUDZ256rri
    0U,	// VPCMPUDZ256rri_alt
    1U,	// VPCMPUDZ256rrik
    1U,	// VPCMPUDZ256rrik_alt
    0U,	// VPCMPUDZrmi
    0U,	// VPCMPUDZrmi_alt
    0U,	// VPCMPUDZrmib
    0U,	// VPCMPUDZrmib_alt
    1U,	// VPCMPUDZrmibk
    1U,	// VPCMPUDZrmibk_alt
    0U,	// VPCMPUDZrmik
    0U,	// VPCMPUDZrmik_alt
    0U,	// VPCMPUDZrri
    0U,	// VPCMPUDZrri_alt
    1U,	// VPCMPUDZrrik
    1U,	// VPCMPUDZrrik_alt
    0U,	// VPCMPUQZ128rmi
    0U,	// VPCMPUQZ128rmi_alt
    0U,	// VPCMPUQZ128rmib
    0U,	// VPCMPUQZ128rmib_alt
    1U,	// VPCMPUQZ128rmibk
    1U,	// VPCMPUQZ128rmibk_alt
    0U,	// VPCMPUQZ128rmik
    0U,	// VPCMPUQZ128rmik_alt
    0U,	// VPCMPUQZ128rri
    0U,	// VPCMPUQZ128rri_alt
    1U,	// VPCMPUQZ128rrik
    1U,	// VPCMPUQZ128rrik_alt
    0U,	// VPCMPUQZ256rmi
    0U,	// VPCMPUQZ256rmi_alt
    0U,	// VPCMPUQZ256rmib
    0U,	// VPCMPUQZ256rmib_alt
    1U,	// VPCMPUQZ256rmibk
    1U,	// VPCMPUQZ256rmibk_alt
    0U,	// VPCMPUQZ256rmik
    0U,	// VPCMPUQZ256rmik_alt
    0U,	// VPCMPUQZ256rri
    0U,	// VPCMPUQZ256rri_alt
    1U,	// VPCMPUQZ256rrik
    1U,	// VPCMPUQZ256rrik_alt
    0U,	// VPCMPUQZrmi
    0U,	// VPCMPUQZrmi_alt
    0U,	// VPCMPUQZrmib
    0U,	// VPCMPUQZrmib_alt
    1U,	// VPCMPUQZrmibk
    1U,	// VPCMPUQZrmibk_alt
    0U,	// VPCMPUQZrmik
    0U,	// VPCMPUQZrmik_alt
    0U,	// VPCMPUQZrri
    0U,	// VPCMPUQZrri_alt
    1U,	// VPCMPUQZrrik
    1U,	// VPCMPUQZrrik_alt
    0U,	// VPCMPUWZ128rmi
    0U,	// VPCMPUWZ128rmi_alt
    0U,	// VPCMPUWZ128rmik
    0U,	// VPCMPUWZ128rmik_alt
    0U,	// VPCMPUWZ128rri
    0U,	// VPCMPUWZ128rri_alt
    1U,	// VPCMPUWZ128rrik
    1U,	// VPCMPUWZ128rrik_alt
    0U,	// VPCMPUWZ256rmi
    0U,	// VPCMPUWZ256rmi_alt
    0U,	// VPCMPUWZ256rmik
    0U,	// VPCMPUWZ256rmik_alt
    0U,	// VPCMPUWZ256rri
    0U,	// VPCMPUWZ256rri_alt
    1U,	// VPCMPUWZ256rrik
    1U,	// VPCMPUWZ256rrik_alt
    0U,	// VPCMPUWZrmi
    0U,	// VPCMPUWZrmi_alt
    0U,	// VPCMPUWZrmik
    0U,	// VPCMPUWZrmik_alt
    0U,	// VPCMPUWZrri
    0U,	// VPCMPUWZrri_alt
    1U,	// VPCMPUWZrrik
    1U,	// VPCMPUWZrrik_alt
    0U,	// VPCMPWZ128rmi
    0U,	// VPCMPWZ128rmi_alt
    0U,	// VPCMPWZ128rmik
    0U,	// VPCMPWZ128rmik_alt
    0U,	// VPCMPWZ128rri
    0U,	// VPCMPWZ128rri_alt
    1U,	// VPCMPWZ128rrik
    1U,	// VPCMPWZ128rrik_alt
    0U,	// VPCMPWZ256rmi
    0U,	// VPCMPWZ256rmi_alt
    0U,	// VPCMPWZ256rmik
    0U,	// VPCMPWZ256rmik_alt
    0U,	// VPCMPWZ256rri
    0U,	// VPCMPWZ256rri_alt
    1U,	// VPCMPWZ256rrik
    1U,	// VPCMPWZ256rrik_alt
    0U,	// VPCMPWZrmi
    0U,	// VPCMPWZrmi_alt
    0U,	// VPCMPWZrmik
    0U,	// VPCMPWZrmik_alt
    0U,	// VPCMPWZrri
    0U,	// VPCMPWZrri_alt
    1U,	// VPCMPWZrrik
    1U,	// VPCMPWZrrik_alt
    0U,	// VPCOMBmi
    0U,	// VPCOMBmi_alt
    0U,	// VPCOMBri
    0U,	// VPCOMBri_alt
    0U,	// VPCOMDmi
    0U,	// VPCOMDmi_alt
    0U,	// VPCOMDri
    0U,	// VPCOMDri_alt
    0U,	// VPCOMPRESSBZ128mr
    0U,	// VPCOMPRESSBZ128mrk
    0U,	// VPCOMPRESSBZ128rr
    0U,	// VPCOMPRESSBZ128rrk
    0U,	// VPCOMPRESSBZ128rrkz
    0U,	// VPCOMPRESSBZ256mr
    0U,	// VPCOMPRESSBZ256mrk
    0U,	// VPCOMPRESSBZ256rr
    0U,	// VPCOMPRESSBZ256rrk
    0U,	// VPCOMPRESSBZ256rrkz
    0U,	// VPCOMPRESSBZmr
    0U,	// VPCOMPRESSBZmrk
    0U,	// VPCOMPRESSBZrr
    0U,	// VPCOMPRESSBZrrk
    0U,	// VPCOMPRESSBZrrkz
    0U,	// VPCOMPRESSDZ128mr
    0U,	// VPCOMPRESSDZ128mrk
    0U,	// VPCOMPRESSDZ128rr
    0U,	// VPCOMPRESSDZ128rrk
    0U,	// VPCOMPRESSDZ128rrkz
    0U,	// VPCOMPRESSDZ256mr
    0U,	// VPCOMPRESSDZ256mrk
    0U,	// VPCOMPRESSDZ256rr
    0U,	// VPCOMPRESSDZ256rrk
    0U,	// VPCOMPRESSDZ256rrkz
    0U,	// VPCOMPRESSDZmr
    0U,	// VPCOMPRESSDZmrk
    0U,	// VPCOMPRESSDZrr
    0U,	// VPCOMPRESSDZrrk
    0U,	// VPCOMPRESSDZrrkz
    0U,	// VPCOMPRESSQZ128mr
    0U,	// VPCOMPRESSQZ128mrk
    0U,	// VPCOMPRESSQZ128rr
    0U,	// VPCOMPRESSQZ128rrk
    0U,	// VPCOMPRESSQZ128rrkz
    0U,	// VPCOMPRESSQZ256mr
    0U,	// VPCOMPRESSQZ256mrk
    0U,	// VPCOMPRESSQZ256rr
    0U,	// VPCOMPRESSQZ256rrk
    0U,	// VPCOMPRESSQZ256rrkz
    0U,	// VPCOMPRESSQZmr
    0U,	// VPCOMPRESSQZmrk
    0U,	// VPCOMPRESSQZrr
    0U,	// VPCOMPRESSQZrrk
    0U,	// VPCOMPRESSQZrrkz
    0U,	// VPCOMPRESSWZ128mr
    0U,	// VPCOMPRESSWZ128mrk
    0U,	// VPCOMPRESSWZ128rr
    0U,	// VPCOMPRESSWZ128rrk
    0U,	// VPCOMPRESSWZ128rrkz
    0U,	// VPCOMPRESSWZ256mr
    0U,	// VPCOMPRESSWZ256mrk
    0U,	// VPCOMPRESSWZ256rr
    0U,	// VPCOMPRESSWZ256rrk
    0U,	// VPCOMPRESSWZ256rrkz
    0U,	// VPCOMPRESSWZmr
    0U,	// VPCOMPRESSWZmrk
    0U,	// VPCOMPRESSWZrr
    0U,	// VPCOMPRESSWZrrk
    0U,	// VPCOMPRESSWZrrkz
    0U,	// VPCOMQmi
    0U,	// VPCOMQmi_alt
    0U,	// VPCOMQri
    0U,	// VPCOMQri_alt
    0U,	// VPCOMUBmi
    0U,	// VPCOMUBmi_alt
    0U,	// VPCOMUBri
    0U,	// VPCOMUBri_alt
    0U,	// VPCOMUDmi
    0U,	// VPCOMUDmi_alt
    0U,	// VPCOMUDri
    0U,	// VPCOMUDri_alt
    0U,	// VPCOMUQmi
    0U,	// VPCOMUQmi_alt
    0U,	// VPCOMUQri
    0U,	// VPCOMUQri_alt
    0U,	// VPCOMUWmi
    0U,	// VPCOMUWmi_alt
    0U,	// VPCOMUWri
    0U,	// VPCOMUWri_alt
    0U,	// VPCOMWmi
    0U,	// VPCOMWmi_alt
    0U,	// VPCOMWri
    0U,	// VPCOMWri_alt
    0U,	// VPCONFLICTDZ128rm
    0U,	// VPCONFLICTDZ128rmb
    0U,	// VPCONFLICTDZ128rmbk
    0U,	// VPCONFLICTDZ128rmbkz
    0U,	// VPCONFLICTDZ128rmk
    0U,	// VPCONFLICTDZ128rmkz
    0U,	// VPCONFLICTDZ128rr
    0U,	// VPCONFLICTDZ128rrk
    0U,	// VPCONFLICTDZ128rrkz
    0U,	// VPCONFLICTDZ256rm
    0U,	// VPCONFLICTDZ256rmb
    0U,	// VPCONFLICTDZ256rmbk
    0U,	// VPCONFLICTDZ256rmbkz
    0U,	// VPCONFLICTDZ256rmk
    0U,	// VPCONFLICTDZ256rmkz
    0U,	// VPCONFLICTDZ256rr
    0U,	// VPCONFLICTDZ256rrk
    0U,	// VPCONFLICTDZ256rrkz
    0U,	// VPCONFLICTDZrm
    0U,	// VPCONFLICTDZrmb
    0U,	// VPCONFLICTDZrmbk
    0U,	// VPCONFLICTDZrmbkz
    0U,	// VPCONFLICTDZrmk
    0U,	// VPCONFLICTDZrmkz
    0U,	// VPCONFLICTDZrr
    0U,	// VPCONFLICTDZrrk
    0U,	// VPCONFLICTDZrrkz
    0U,	// VPCONFLICTQZ128rm
    0U,	// VPCONFLICTQZ128rmb
    0U,	// VPCONFLICTQZ128rmbk
    0U,	// VPCONFLICTQZ128rmbkz
    0U,	// VPCONFLICTQZ128rmk
    0U,	// VPCONFLICTQZ128rmkz
    0U,	// VPCONFLICTQZ128rr
    0U,	// VPCONFLICTQZ128rrk
    0U,	// VPCONFLICTQZ128rrkz
    0U,	// VPCONFLICTQZ256rm
    0U,	// VPCONFLICTQZ256rmb
    0U,	// VPCONFLICTQZ256rmbk
    0U,	// VPCONFLICTQZ256rmbkz
    0U,	// VPCONFLICTQZ256rmk
    0U,	// VPCONFLICTQZ256rmkz
    0U,	// VPCONFLICTQZ256rr
    0U,	// VPCONFLICTQZ256rrk
    0U,	// VPCONFLICTQZ256rrkz
    0U,	// VPCONFLICTQZrm
    0U,	// VPCONFLICTQZrmb
    0U,	// VPCONFLICTQZrmbk
    0U,	// VPCONFLICTQZrmbkz
    0U,	// VPCONFLICTQZrmk
    0U,	// VPCONFLICTQZrmkz
    0U,	// VPCONFLICTQZrr
    0U,	// VPCONFLICTQZrrk
    0U,	// VPCONFLICTQZrrkz
    0U,	// VPDPBUSDSZ128m
    0U,	// VPDPBUSDSZ128mb
    0U,	// VPDPBUSDSZ128mbk
    0U,	// VPDPBUSDSZ128mbkz
    0U,	// VPDPBUSDSZ128mk
    0U,	// VPDPBUSDSZ128mkz
    0U,	// VPDPBUSDSZ128r
    0U,	// VPDPBUSDSZ128rk
    0U,	// VPDPBUSDSZ128rkz
    0U,	// VPDPBUSDSZ256m
    0U,	// VPDPBUSDSZ256mb
    0U,	// VPDPBUSDSZ256mbk
    0U,	// VPDPBUSDSZ256mbkz
    0U,	// VPDPBUSDSZ256mk
    0U,	// VPDPBUSDSZ256mkz
    0U,	// VPDPBUSDSZ256r
    0U,	// VPDPBUSDSZ256rk
    0U,	// VPDPBUSDSZ256rkz
    0U,	// VPDPBUSDSZm
    0U,	// VPDPBUSDSZmb
    0U,	// VPDPBUSDSZmbk
    0U,	// VPDPBUSDSZmbkz
    0U,	// VPDPBUSDSZmk
    0U,	// VPDPBUSDSZmkz
    0U,	// VPDPBUSDSZr
    0U,	// VPDPBUSDSZrk
    0U,	// VPDPBUSDSZrkz
    0U,	// VPDPBUSDZ128m
    0U,	// VPDPBUSDZ128mb
    0U,	// VPDPBUSDZ128mbk
    0U,	// VPDPBUSDZ128mbkz
    0U,	// VPDPBUSDZ128mk
    0U,	// VPDPBUSDZ128mkz
    0U,	// VPDPBUSDZ128r
    0U,	// VPDPBUSDZ128rk
    0U,	// VPDPBUSDZ128rkz
    0U,	// VPDPBUSDZ256m
    0U,	// VPDPBUSDZ256mb
    0U,	// VPDPBUSDZ256mbk
    0U,	// VPDPBUSDZ256mbkz
    0U,	// VPDPBUSDZ256mk
    0U,	// VPDPBUSDZ256mkz
    0U,	// VPDPBUSDZ256r
    0U,	// VPDPBUSDZ256rk
    0U,	// VPDPBUSDZ256rkz
    0U,	// VPDPBUSDZm
    0U,	// VPDPBUSDZmb
    0U,	// VPDPBUSDZmbk
    0U,	// VPDPBUSDZmbkz
    0U,	// VPDPBUSDZmk
    0U,	// VPDPBUSDZmkz
    0U,	// VPDPBUSDZr
    0U,	// VPDPBUSDZrk
    0U,	// VPDPBUSDZrkz
    0U,	// VPDPWSSDSZ128m
    0U,	// VPDPWSSDSZ128mb
    0U,	// VPDPWSSDSZ128mbk
    0U,	// VPDPWSSDSZ128mbkz
    0U,	// VPDPWSSDSZ128mk
    0U,	// VPDPWSSDSZ128mkz
    0U,	// VPDPWSSDSZ128r
    0U,	// VPDPWSSDSZ128rk
    0U,	// VPDPWSSDSZ128rkz
    0U,	// VPDPWSSDSZ256m
    0U,	// VPDPWSSDSZ256mb
    0U,	// VPDPWSSDSZ256mbk
    0U,	// VPDPWSSDSZ256mbkz
    0U,	// VPDPWSSDSZ256mk
    0U,	// VPDPWSSDSZ256mkz
    0U,	// VPDPWSSDSZ256r
    0U,	// VPDPWSSDSZ256rk
    0U,	// VPDPWSSDSZ256rkz
    0U,	// VPDPWSSDSZm
    0U,	// VPDPWSSDSZmb
    0U,	// VPDPWSSDSZmbk
    0U,	// VPDPWSSDSZmbkz
    0U,	// VPDPWSSDSZmk
    0U,	// VPDPWSSDSZmkz
    0U,	// VPDPWSSDSZr
    0U,	// VPDPWSSDSZrk
    0U,	// VPDPWSSDSZrkz
    0U,	// VPDPWSSDZ128m
    0U,	// VPDPWSSDZ128mb
    0U,	// VPDPWSSDZ128mbk
    0U,	// VPDPWSSDZ128mbkz
    0U,	// VPDPWSSDZ128mk
    0U,	// VPDPWSSDZ128mkz
    0U,	// VPDPWSSDZ128r
    0U,	// VPDPWSSDZ128rk
    0U,	// VPDPWSSDZ128rkz
    0U,	// VPDPWSSDZ256m
    0U,	// VPDPWSSDZ256mb
    0U,	// VPDPWSSDZ256mbk
    0U,	// VPDPWSSDZ256mbkz
    0U,	// VPDPWSSDZ256mk
    0U,	// VPDPWSSDZ256mkz
    0U,	// VPDPWSSDZ256r
    0U,	// VPDPWSSDZ256rk
    0U,	// VPDPWSSDZ256rkz
    0U,	// VPDPWSSDZm
    0U,	// VPDPWSSDZmb
    0U,	// VPDPWSSDZmbk
    0U,	// VPDPWSSDZmbkz
    0U,	// VPDPWSSDZmk
    0U,	// VPDPWSSDZmkz
    0U,	// VPDPWSSDZr
    0U,	// VPDPWSSDZrk
    0U,	// VPDPWSSDZrkz
    0U,	// VPERM2F128rm
    0U,	// VPERM2F128rr
    0U,	// VPERM2I128rm
    0U,	// VPERM2I128rr
    0U,	// VPERMBZ128rm
    0U,	// VPERMBZ128rmk
    0U,	// VPERMBZ128rmkz
    0U,	// VPERMBZ128rr
    0U,	// VPERMBZ128rrk
    0U,	// VPERMBZ128rrkz
    0U,	// VPERMBZ256rm
    0U,	// VPERMBZ256rmk
    0U,	// VPERMBZ256rmkz
    0U,	// VPERMBZ256rr
    0U,	// VPERMBZ256rrk
    0U,	// VPERMBZ256rrkz
    0U,	// VPERMBZrm
    0U,	// VPERMBZrmk
    0U,	// VPERMBZrmkz
    0U,	// VPERMBZrr
    0U,	// VPERMBZrrk
    0U,	// VPERMBZrrkz
    0U,	// VPERMDYrm
    0U,	// VPERMDYrr
    0U,	// VPERMDZ256rm
    0U,	// VPERMDZ256rmb
    0U,	// VPERMDZ256rmbk
    0U,	// VPERMDZ256rmbkz
    0U,	// VPERMDZ256rmk
    0U,	// VPERMDZ256rmkz
    0U,	// VPERMDZ256rr
    0U,	// VPERMDZ256rrk
    0U,	// VPERMDZ256rrkz
    0U,	// VPERMDZrm
    0U,	// VPERMDZrmb
    0U,	// VPERMDZrmbk
    0U,	// VPERMDZrmbkz
    0U,	// VPERMDZrmk
    0U,	// VPERMDZrmkz
    0U,	// VPERMDZrr
    0U,	// VPERMDZrrk
    0U,	// VPERMDZrrkz
    0U,	// VPERMI2B128rm
    0U,	// VPERMI2B128rmk
    0U,	// VPERMI2B128rmkz
    0U,	// VPERMI2B128rr
    0U,	// VPERMI2B128rrk
    0U,	// VPERMI2B128rrkz
    0U,	// VPERMI2B256rm
    0U,	// VPERMI2B256rmk
    0U,	// VPERMI2B256rmkz
    0U,	// VPERMI2B256rr
    0U,	// VPERMI2B256rrk
    0U,	// VPERMI2B256rrkz
    0U,	// VPERMI2Brm
    0U,	// VPERMI2Brmk
    0U,	// VPERMI2Brmkz
    0U,	// VPERMI2Brr
    0U,	// VPERMI2Brrk
    0U,	// VPERMI2Brrkz
    0U,	// VPERMI2D128rm
    0U,	// VPERMI2D128rmb
    0U,	// VPERMI2D128rmbk
    0U,	// VPERMI2D128rmbkz
    0U,	// VPERMI2D128rmk
    0U,	// VPERMI2D128rmkz
    0U,	// VPERMI2D128rr
    0U,	// VPERMI2D128rrk
    0U,	// VPERMI2D128rrkz
    0U,	// VPERMI2D256rm
    0U,	// VPERMI2D256rmb
    0U,	// VPERMI2D256rmbk
    0U,	// VPERMI2D256rmbkz
    0U,	// VPERMI2D256rmk
    0U,	// VPERMI2D256rmkz
    0U,	// VPERMI2D256rr
    0U,	// VPERMI2D256rrk
    0U,	// VPERMI2D256rrkz
    0U,	// VPERMI2Drm
    0U,	// VPERMI2Drmb
    0U,	// VPERMI2Drmbk
    0U,	// VPERMI2Drmbkz
    0U,	// VPERMI2Drmk
    0U,	// VPERMI2Drmkz
    0U,	// VPERMI2Drr
    0U,	// VPERMI2Drrk
    0U,	// VPERMI2Drrkz
    0U,	// VPERMI2PD128rm
    0U,	// VPERMI2PD128rmb
    0U,	// VPERMI2PD128rmbk
    0U,	// VPERMI2PD128rmbkz
    0U,	// VPERMI2PD128rmk
    0U,	// VPERMI2PD128rmkz
    0U,	// VPERMI2PD128rr
    0U,	// VPERMI2PD128rrk
    0U,	// VPERMI2PD128rrkz
    0U,	// VPERMI2PD256rm
    0U,	// VPERMI2PD256rmb
    0U,	// VPERMI2PD256rmbk
    0U,	// VPERMI2PD256rmbkz
    0U,	// VPERMI2PD256rmk
    0U,	// VPERMI2PD256rmkz
    0U,	// VPERMI2PD256rr
    0U,	// VPERMI2PD256rrk
    0U,	// VPERMI2PD256rrkz
    0U,	// VPERMI2PDrm
    0U,	// VPERMI2PDrmb
    0U,	// VPERMI2PDrmbk
    0U,	// VPERMI2PDrmbkz
    0U,	// VPERMI2PDrmk
    0U,	// VPERMI2PDrmkz
    0U,	// VPERMI2PDrr
    0U,	// VPERMI2PDrrk
    0U,	// VPERMI2PDrrkz
    0U,	// VPERMI2PS128rm
    0U,	// VPERMI2PS128rmb
    0U,	// VPERMI2PS128rmbk
    0U,	// VPERMI2PS128rmbkz
    0U,	// VPERMI2PS128rmk
    0U,	// VPERMI2PS128rmkz
    0U,	// VPERMI2PS128rr
    0U,	// VPERMI2PS128rrk
    0U,	// VPERMI2PS128rrkz
    0U,	// VPERMI2PS256rm
    0U,	// VPERMI2PS256rmb
    0U,	// VPERMI2PS256rmbk
    0U,	// VPERMI2PS256rmbkz
    0U,	// VPERMI2PS256rmk
    0U,	// VPERMI2PS256rmkz
    0U,	// VPERMI2PS256rr
    0U,	// VPERMI2PS256rrk
    0U,	// VPERMI2PS256rrkz
    0U,	// VPERMI2PSrm
    0U,	// VPERMI2PSrmb
    0U,	// VPERMI2PSrmbk
    0U,	// VPERMI2PSrmbkz
    0U,	// VPERMI2PSrmk
    0U,	// VPERMI2PSrmkz
    0U,	// VPERMI2PSrr
    0U,	// VPERMI2PSrrk
    0U,	// VPERMI2PSrrkz
    0U,	// VPERMI2Q128rm
    0U,	// VPERMI2Q128rmb
    0U,	// VPERMI2Q128rmbk
    0U,	// VPERMI2Q128rmbkz
    0U,	// VPERMI2Q128rmk
    0U,	// VPERMI2Q128rmkz
    0U,	// VPERMI2Q128rr
    0U,	// VPERMI2Q128rrk
    0U,	// VPERMI2Q128rrkz
    0U,	// VPERMI2Q256rm
    0U,	// VPERMI2Q256rmb
    0U,	// VPERMI2Q256rmbk
    0U,	// VPERMI2Q256rmbkz
    0U,	// VPERMI2Q256rmk
    0U,	// VPERMI2Q256rmkz
    0U,	// VPERMI2Q256rr
    0U,	// VPERMI2Q256rrk
    0U,	// VPERMI2Q256rrkz
    0U,	// VPERMI2Qrm
    0U,	// VPERMI2Qrmb
    0U,	// VPERMI2Qrmbk
    0U,	// VPERMI2Qrmbkz
    0U,	// VPERMI2Qrmk
    0U,	// VPERMI2Qrmkz
    0U,	// VPERMI2Qrr
    0U,	// VPERMI2Qrrk
    0U,	// VPERMI2Qrrkz
    0U,	// VPERMI2W128rm
    0U,	// VPERMI2W128rmk
    0U,	// VPERMI2W128rmkz
    0U,	// VPERMI2W128rr
    0U,	// VPERMI2W128rrk
    0U,	// VPERMI2W128rrkz
    0U,	// VPERMI2W256rm
    0U,	// VPERMI2W256rmk
    0U,	// VPERMI2W256rmkz
    0U,	// VPERMI2W256rr
    0U,	// VPERMI2W256rrk
    0U,	// VPERMI2W256rrkz
    0U,	// VPERMI2Wrm
    0U,	// VPERMI2Wrmk
    0U,	// VPERMI2Wrmkz
    0U,	// VPERMI2Wrr
    0U,	// VPERMI2Wrrk
    0U,	// VPERMI2Wrrkz
    0U,	// VPERMIL2PDYmr
    0U,	// VPERMIL2PDYrm
    0U,	// VPERMIL2PDYrr
    0U,	// VPERMIL2PDYrr_REV
    0U,	// VPERMIL2PDmr
    0U,	// VPERMIL2PDrm
    0U,	// VPERMIL2PDrr
    0U,	// VPERMIL2PDrr_REV
    0U,	// VPERMIL2PSYmr
    0U,	// VPERMIL2PSYrm
    0U,	// VPERMIL2PSYrr
    0U,	// VPERMIL2PSYrr_REV
    0U,	// VPERMIL2PSmr
    0U,	// VPERMIL2PSrm
    0U,	// VPERMIL2PSrr
    0U,	// VPERMIL2PSrr_REV
    0U,	// VPERMILPDYmi
    0U,	// VPERMILPDYri
    0U,	// VPERMILPDYrm
    0U,	// VPERMILPDYrr
    0U,	// VPERMILPDZ128mbi
    0U,	// VPERMILPDZ128mbik
    0U,	// VPERMILPDZ128mbikz
    0U,	// VPERMILPDZ128mi
    0U,	// VPERMILPDZ128mik
    0U,	// VPERMILPDZ128mikz
    0U,	// VPERMILPDZ128ri
    0U,	// VPERMILPDZ128rik
    0U,	// VPERMILPDZ128rikz
    0U,	// VPERMILPDZ128rm
    0U,	// VPERMILPDZ128rmb
    0U,	// VPERMILPDZ128rmbk
    0U,	// VPERMILPDZ128rmbkz
    0U,	// VPERMILPDZ128rmk
    0U,	// VPERMILPDZ128rmkz
    0U,	// VPERMILPDZ128rr
    0U,	// VPERMILPDZ128rrk
    0U,	// VPERMILPDZ128rrkz
    0U,	// VPERMILPDZ256mbi
    0U,	// VPERMILPDZ256mbik
    0U,	// VPERMILPDZ256mbikz
    0U,	// VPERMILPDZ256mi
    0U,	// VPERMILPDZ256mik
    0U,	// VPERMILPDZ256mikz
    0U,	// VPERMILPDZ256ri
    0U,	// VPERMILPDZ256rik
    0U,	// VPERMILPDZ256rikz
    0U,	// VPERMILPDZ256rm
    0U,	// VPERMILPDZ256rmb
    0U,	// VPERMILPDZ256rmbk
    0U,	// VPERMILPDZ256rmbkz
    0U,	// VPERMILPDZ256rmk
    0U,	// VPERMILPDZ256rmkz
    0U,	// VPERMILPDZ256rr
    0U,	// VPERMILPDZ256rrk
    0U,	// VPERMILPDZ256rrkz
    0U,	// VPERMILPDZmbi
    0U,	// VPERMILPDZmbik
    0U,	// VPERMILPDZmbikz
    0U,	// VPERMILPDZmi
    0U,	// VPERMILPDZmik
    0U,	// VPERMILPDZmikz
    0U,	// VPERMILPDZri
    0U,	// VPERMILPDZrik
    0U,	// VPERMILPDZrikz
    0U,	// VPERMILPDZrm
    0U,	// VPERMILPDZrmb
    0U,	// VPERMILPDZrmbk
    0U,	// VPERMILPDZrmbkz
    0U,	// VPERMILPDZrmk
    0U,	// VPERMILPDZrmkz
    0U,	// VPERMILPDZrr
    0U,	// VPERMILPDZrrk
    0U,	// VPERMILPDZrrkz
    0U,	// VPERMILPDmi
    0U,	// VPERMILPDri
    0U,	// VPERMILPDrm
    0U,	// VPERMILPDrr
    0U,	// VPERMILPSYmi
    0U,	// VPERMILPSYri
    0U,	// VPERMILPSYrm
    0U,	// VPERMILPSYrr
    0U,	// VPERMILPSZ128mbi
    0U,	// VPERMILPSZ128mbik
    0U,	// VPERMILPSZ128mbikz
    0U,	// VPERMILPSZ128mi
    0U,	// VPERMILPSZ128mik
    0U,	// VPERMILPSZ128mikz
    0U,	// VPERMILPSZ128ri
    0U,	// VPERMILPSZ128rik
    0U,	// VPERMILPSZ128rikz
    0U,	// VPERMILPSZ128rm
    0U,	// VPERMILPSZ128rmb
    0U,	// VPERMILPSZ128rmbk
    0U,	// VPERMILPSZ128rmbkz
    0U,	// VPERMILPSZ128rmk
    0U,	// VPERMILPSZ128rmkz
    0U,	// VPERMILPSZ128rr
    0U,	// VPERMILPSZ128rrk
    0U,	// VPERMILPSZ128rrkz
    0U,	// VPERMILPSZ256mbi
    0U,	// VPERMILPSZ256mbik
    0U,	// VPERMILPSZ256mbikz
    0U,	// VPERMILPSZ256mi
    0U,	// VPERMILPSZ256mik
    0U,	// VPERMILPSZ256mikz
    0U,	// VPERMILPSZ256ri
    0U,	// VPERMILPSZ256rik
    0U,	// VPERMILPSZ256rikz
    0U,	// VPERMILPSZ256rm
    0U,	// VPERMILPSZ256rmb
    0U,	// VPERMILPSZ256rmbk
    0U,	// VPERMILPSZ256rmbkz
    0U,	// VPERMILPSZ256rmk
    0U,	// VPERMILPSZ256rmkz
    0U,	// VPERMILPSZ256rr
    0U,	// VPERMILPSZ256rrk
    0U,	// VPERMILPSZ256rrkz
    0U,	// VPERMILPSZmbi
    0U,	// VPERMILPSZmbik
    0U,	// VPERMILPSZmbikz
    0U,	// VPERMILPSZmi
    0U,	// VPERMILPSZmik
    0U,	// VPERMILPSZmikz
    0U,	// VPERMILPSZri
    0U,	// VPERMILPSZrik
    0U,	// VPERMILPSZrikz
    0U,	// VPERMILPSZrm
    0U,	// VPERMILPSZrmb
    0U,	// VPERMILPSZrmbk
    0U,	// VPERMILPSZrmbkz
    0U,	// VPERMILPSZrmk
    0U,	// VPERMILPSZrmkz
    0U,	// VPERMILPSZrr
    0U,	// VPERMILPSZrrk
    0U,	// VPERMILPSZrrkz
    0U,	// VPERMILPSmi
    0U,	// VPERMILPSri
    0U,	// VPERMILPSrm
    0U,	// VPERMILPSrr
    0U,	// VPERMPDYmi
    0U,	// VPERMPDYri
    0U,	// VPERMPDZ256mbi
    0U,	// VPERMPDZ256mbik
    0U,	// VPERMPDZ256mbikz
    0U,	// VPERMPDZ256mi
    0U,	// VPERMPDZ256mik
    0U,	// VPERMPDZ256mikz
    0U,	// VPERMPDZ256ri
    0U,	// VPERMPDZ256rik
    0U,	// VPERMPDZ256rikz
    0U,	// VPERMPDZ256rm
    0U,	// VPERMPDZ256rmb
    0U,	// VPERMPDZ256rmbk
    0U,	// VPERMPDZ256rmbkz
    0U,	// VPERMPDZ256rmk
    0U,	// VPERMPDZ256rmkz
    0U,	// VPERMPDZ256rr
    0U,	// VPERMPDZ256rrk
    0U,	// VPERMPDZ256rrkz
    0U,	// VPERMPDZmbi
    0U,	// VPERMPDZmbik
    0U,	// VPERMPDZmbikz
    0U,	// VPERMPDZmi
    0U,	// VPERMPDZmik
    0U,	// VPERMPDZmikz
    0U,	// VPERMPDZri
    0U,	// VPERMPDZrik
    0U,	// VPERMPDZrikz
    0U,	// VPERMPDZrm
    0U,	// VPERMPDZrmb
    0U,	// VPERMPDZrmbk
    0U,	// VPERMPDZrmbkz
    0U,	// VPERMPDZrmk
    0U,	// VPERMPDZrmkz
    0U,	// VPERMPDZrr
    0U,	// VPERMPDZrrk
    0U,	// VPERMPDZrrkz
    0U,	// VPERMPSYrm
    0U,	// VPERMPSYrr
    0U,	// VPERMPSZ256rm
    0U,	// VPERMPSZ256rmb
    0U,	// VPERMPSZ256rmbk
    0U,	// VPERMPSZ256rmbkz
    0U,	// VPERMPSZ256rmk
    0U,	// VPERMPSZ256rmkz
    0U,	// VPERMPSZ256rr
    0U,	// VPERMPSZ256rrk
    0U,	// VPERMPSZ256rrkz
    0U,	// VPERMPSZrm
    0U,	// VPERMPSZrmb
    0U,	// VPERMPSZrmbk
    0U,	// VPERMPSZrmbkz
    0U,	// VPERMPSZrmk
    0U,	// VPERMPSZrmkz
    0U,	// VPERMPSZrr
    0U,	// VPERMPSZrrk
    0U,	// VPERMPSZrrkz
    0U,	// VPERMQYmi
    0U,	// VPERMQYri
    0U,	// VPERMQZ256mbi
    0U,	// VPERMQZ256mbik
    0U,	// VPERMQZ256mbikz
    0U,	// VPERMQZ256mi
    0U,	// VPERMQZ256mik
    0U,	// VPERMQZ256mikz
    0U,	// VPERMQZ256ri
    0U,	// VPERMQZ256rik
    0U,	// VPERMQZ256rikz
    0U,	// VPERMQZ256rm
    0U,	// VPERMQZ256rmb
    0U,	// VPERMQZ256rmbk
    0U,	// VPERMQZ256rmbkz
    0U,	// VPERMQZ256rmk
    0U,	// VPERMQZ256rmkz
    0U,	// VPERMQZ256rr
    0U,	// VPERMQZ256rrk
    0U,	// VPERMQZ256rrkz
    0U,	// VPERMQZmbi
    0U,	// VPERMQZmbik
    0U,	// VPERMQZmbikz
    0U,	// VPERMQZmi
    0U,	// VPERMQZmik
    0U,	// VPERMQZmikz
    0U,	// VPERMQZri
    0U,	// VPERMQZrik
    0U,	// VPERMQZrikz
    0U,	// VPERMQZrm
    0U,	// VPERMQZrmb
    0U,	// VPERMQZrmbk
    0U,	// VPERMQZrmbkz
    0U,	// VPERMQZrmk
    0U,	// VPERMQZrmkz
    0U,	// VPERMQZrr
    0U,	// VPERMQZrrk
    0U,	// VPERMQZrrkz
    0U,	// VPERMT2B128rm
    0U,	// VPERMT2B128rmk
    0U,	// VPERMT2B128rmkz
    0U,	// VPERMT2B128rr
    0U,	// VPERMT2B128rrk
    0U,	// VPERMT2B128rrkz
    0U,	// VPERMT2B256rm
    0U,	// VPERMT2B256rmk
    0U,	// VPERMT2B256rmkz
    0U,	// VPERMT2B256rr
    0U,	// VPERMT2B256rrk
    0U,	// VPERMT2B256rrkz
    0U,	// VPERMT2Brm
    0U,	// VPERMT2Brmk
    0U,	// VPERMT2Brmkz
    0U,	// VPERMT2Brr
    0U,	// VPERMT2Brrk
    0U,	// VPERMT2Brrkz
    0U,	// VPERMT2D128rm
    0U,	// VPERMT2D128rmb
    0U,	// VPERMT2D128rmbk
    0U,	// VPERMT2D128rmbkz
    0U,	// VPERMT2D128rmk
    0U,	// VPERMT2D128rmkz
    0U,	// VPERMT2D128rr
    0U,	// VPERMT2D128rrk
    0U,	// VPERMT2D128rrkz
    0U,	// VPERMT2D256rm
    0U,	// VPERMT2D256rmb
    0U,	// VPERMT2D256rmbk
    0U,	// VPERMT2D256rmbkz
    0U,	// VPERMT2D256rmk
    0U,	// VPERMT2D256rmkz
    0U,	// VPERMT2D256rr
    0U,	// VPERMT2D256rrk
    0U,	// VPERMT2D256rrkz
    0U,	// VPERMT2Drm
    0U,	// VPERMT2Drmb
    0U,	// VPERMT2Drmbk
    0U,	// VPERMT2Drmbkz
    0U,	// VPERMT2Drmk
    0U,	// VPERMT2Drmkz
    0U,	// VPERMT2Drr
    0U,	// VPERMT2Drrk
    0U,	// VPERMT2Drrkz
    0U,	// VPERMT2PD128rm
    0U,	// VPERMT2PD128rmb
    0U,	// VPERMT2PD128rmbk
    0U,	// VPERMT2PD128rmbkz
    0U,	// VPERMT2PD128rmk
    0U,	// VPERMT2PD128rmkz
    0U,	// VPERMT2PD128rr
    0U,	// VPERMT2PD128rrk
    0U,	// VPERMT2PD128rrkz
    0U,	// VPERMT2PD256rm
    0U,	// VPERMT2PD256rmb
    0U,	// VPERMT2PD256rmbk
    0U,	// VPERMT2PD256rmbkz
    0U,	// VPERMT2PD256rmk
    0U,	// VPERMT2PD256rmkz
    0U,	// VPERMT2PD256rr
    0U,	// VPERMT2PD256rrk
    0U,	// VPERMT2PD256rrkz
    0U,	// VPERMT2PDrm
    0U,	// VPERMT2PDrmb
    0U,	// VPERMT2PDrmbk
    0U,	// VPERMT2PDrmbkz
    0U,	// VPERMT2PDrmk
    0U,	// VPERMT2PDrmkz
    0U,	// VPERMT2PDrr
    0U,	// VPERMT2PDrrk
    0U,	// VPERMT2PDrrkz
    0U,	// VPERMT2PS128rm
    0U,	// VPERMT2PS128rmb
    0U,	// VPERMT2PS128rmbk
    0U,	// VPERMT2PS128rmbkz
    0U,	// VPERMT2PS128rmk
    0U,	// VPERMT2PS128rmkz
    0U,	// VPERMT2PS128rr
    0U,	// VPERMT2PS128rrk
    0U,	// VPERMT2PS128rrkz
    0U,	// VPERMT2PS256rm
    0U,	// VPERMT2PS256rmb
    0U,	// VPERMT2PS256rmbk
    0U,	// VPERMT2PS256rmbkz
    0U,	// VPERMT2PS256rmk
    0U,	// VPERMT2PS256rmkz
    0U,	// VPERMT2PS256rr
    0U,	// VPERMT2PS256rrk
    0U,	// VPERMT2PS256rrkz
    0U,	// VPERMT2PSrm
    0U,	// VPERMT2PSrmb
    0U,	// VPERMT2PSrmbk
    0U,	// VPERMT2PSrmbkz
    0U,	// VPERMT2PSrmk
    0U,	// VPERMT2PSrmkz
    0U,	// VPERMT2PSrr
    0U,	// VPERMT2PSrrk
    0U,	// VPERMT2PSrrkz
    0U,	// VPERMT2Q128rm
    0U,	// VPERMT2Q128rmb
    0U,	// VPERMT2Q128rmbk
    0U,	// VPERMT2Q128rmbkz
    0U,	// VPERMT2Q128rmk
    0U,	// VPERMT2Q128rmkz
    0U,	// VPERMT2Q128rr
    0U,	// VPERMT2Q128rrk
    0U,	// VPERMT2Q128rrkz
    0U,	// VPERMT2Q256rm
    0U,	// VPERMT2Q256rmb
    0U,	// VPERMT2Q256rmbk
    0U,	// VPERMT2Q256rmbkz
    0U,	// VPERMT2Q256rmk
    0U,	// VPERMT2Q256rmkz
    0U,	// VPERMT2Q256rr
    0U,	// VPERMT2Q256rrk
    0U,	// VPERMT2Q256rrkz
    0U,	// VPERMT2Qrm
    0U,	// VPERMT2Qrmb
    0U,	// VPERMT2Qrmbk
    0U,	// VPERMT2Qrmbkz
    0U,	// VPERMT2Qrmk
    0U,	// VPERMT2Qrmkz
    0U,	// VPERMT2Qrr
    0U,	// VPERMT2Qrrk
    0U,	// VPERMT2Qrrkz
    0U,	// VPERMT2W128rm
    0U,	// VPERMT2W128rmk
    0U,	// VPERMT2W128rmkz
    0U,	// VPERMT2W128rr
    0U,	// VPERMT2W128rrk
    0U,	// VPERMT2W128rrkz
    0U,	// VPERMT2W256rm
    0U,	// VPERMT2W256rmk
    0U,	// VPERMT2W256rmkz
    0U,	// VPERMT2W256rr
    0U,	// VPERMT2W256rrk
    0U,	// VPERMT2W256rrkz
    0U,	// VPERMT2Wrm
    0U,	// VPERMT2Wrmk
    0U,	// VPERMT2Wrmkz
    0U,	// VPERMT2Wrr
    0U,	// VPERMT2Wrrk
    0U,	// VPERMT2Wrrkz
    0U,	// VPERMWZ128rm
    0U,	// VPERMWZ128rmk
    0U,	// VPERMWZ128rmkz
    0U,	// VPERMWZ128rr
    0U,	// VPERMWZ128rrk
    0U,	// VPERMWZ128rrkz
    0U,	// VPERMWZ256rm
    0U,	// VPERMWZ256rmk
    0U,	// VPERMWZ256rmkz
    0U,	// VPERMWZ256rr
    0U,	// VPERMWZ256rrk
    0U,	// VPERMWZ256rrkz
    0U,	// VPERMWZrm
    0U,	// VPERMWZrmk
    0U,	// VPERMWZrmkz
    0U,	// VPERMWZrr
    0U,	// VPERMWZrrk
    0U,	// VPERMWZrrkz
    0U,	// VPEXPANDBZ128rm
    0U,	// VPEXPANDBZ128rmk
    0U,	// VPEXPANDBZ128rmkz
    0U,	// VPEXPANDBZ128rr
    0U,	// VPEXPANDBZ128rrk
    0U,	// VPEXPANDBZ128rrkz
    0U,	// VPEXPANDBZ256rm
    0U,	// VPEXPANDBZ256rmk
    0U,	// VPEXPANDBZ256rmkz
    0U,	// VPEXPANDBZ256rr
    0U,	// VPEXPANDBZ256rrk
    0U,	// VPEXPANDBZ256rrkz
    0U,	// VPEXPANDBZrm
    0U,	// VPEXPANDBZrmk
    0U,	// VPEXPANDBZrmkz
    0U,	// VPEXPANDBZrr
    0U,	// VPEXPANDBZrrk
    0U,	// VPEXPANDBZrrkz
    0U,	// VPEXPANDDZ128rm
    0U,	// VPEXPANDDZ128rmk
    0U,	// VPEXPANDDZ128rmkz
    0U,	// VPEXPANDDZ128rr
    0U,	// VPEXPANDDZ128rrk
    0U,	// VPEXPANDDZ128rrkz
    0U,	// VPEXPANDDZ256rm
    0U,	// VPEXPANDDZ256rmk
    0U,	// VPEXPANDDZ256rmkz
    0U,	// VPEXPANDDZ256rr
    0U,	// VPEXPANDDZ256rrk
    0U,	// VPEXPANDDZ256rrkz
    0U,	// VPEXPANDDZrm
    0U,	// VPEXPANDDZrmk
    0U,	// VPEXPANDDZrmkz
    0U,	// VPEXPANDDZrr
    0U,	// VPEXPANDDZrrk
    0U,	// VPEXPANDDZrrkz
    0U,	// VPEXPANDQZ128rm
    0U,	// VPEXPANDQZ128rmk
    0U,	// VPEXPANDQZ128rmkz
    0U,	// VPEXPANDQZ128rr
    0U,	// VPEXPANDQZ128rrk
    0U,	// VPEXPANDQZ128rrkz
    0U,	// VPEXPANDQZ256rm
    0U,	// VPEXPANDQZ256rmk
    0U,	// VPEXPANDQZ256rmkz
    0U,	// VPEXPANDQZ256rr
    0U,	// VPEXPANDQZ256rrk
    0U,	// VPEXPANDQZ256rrkz
    0U,	// VPEXPANDQZrm
    0U,	// VPEXPANDQZrmk
    0U,	// VPEXPANDQZrmkz
    0U,	// VPEXPANDQZrr
    0U,	// VPEXPANDQZrrk
    0U,	// VPEXPANDQZrrkz
    0U,	// VPEXPANDWZ128rm
    0U,	// VPEXPANDWZ128rmk
    0U,	// VPEXPANDWZ128rmkz
    0U,	// VPEXPANDWZ128rr
    0U,	// VPEXPANDWZ128rrk
    0U,	// VPEXPANDWZ128rrkz
    0U,	// VPEXPANDWZ256rm
    0U,	// VPEXPANDWZ256rmk
    0U,	// VPEXPANDWZ256rmkz
    0U,	// VPEXPANDWZ256rr
    0U,	// VPEXPANDWZ256rrk
    0U,	// VPEXPANDWZ256rrkz
    0U,	// VPEXPANDWZrm
    0U,	// VPEXPANDWZrmk
    0U,	// VPEXPANDWZrmkz
    0U,	// VPEXPANDWZrr
    0U,	// VPEXPANDWZrrk
    0U,	// VPEXPANDWZrrkz
    0U,	// VPEXTRBZmr
    0U,	// VPEXTRBZrr
    0U,	// VPEXTRBmr
    0U,	// VPEXTRBrr
    0U,	// VPEXTRDZmr
    0U,	// VPEXTRDZrr
    0U,	// VPEXTRDmr
    0U,	// VPEXTRDrr
    0U,	// VPEXTRQZmr
    0U,	// VPEXTRQZrr
    0U,	// VPEXTRQmr
    0U,	// VPEXTRQrr
    0U,	// VPEXTRWZmr
    0U,	// VPEXTRWZrr
    0U,	// VPEXTRWZrr_REV
    0U,	// VPEXTRWmr
    0U,	// VPEXTRWrr
    0U,	// VPEXTRWrr_REV
    0U,	// VPGATHERDDYrm
    0U,	// VPGATHERDDZ128rm
    0U,	// VPGATHERDDZ256rm
    0U,	// VPGATHERDDZrm
    0U,	// VPGATHERDDrm
    0U,	// VPGATHERDQYrm
    0U,	// VPGATHERDQZ128rm
    0U,	// VPGATHERDQZ256rm
    0U,	// VPGATHERDQZrm
    0U,	// VPGATHERDQrm
    0U,	// VPGATHERQDYrm
    0U,	// VPGATHERQDZ128rm
    0U,	// VPGATHERQDZ256rm
    0U,	// VPGATHERQDZrm
    0U,	// VPGATHERQDrm
    0U,	// VPGATHERQQYrm
    0U,	// VPGATHERQQZ128rm
    0U,	// VPGATHERQQZ256rm
    0U,	// VPGATHERQQZrm
    0U,	// VPGATHERQQrm
    0U,	// VPHADDBDrm
    0U,	// VPHADDBDrr
    0U,	// VPHADDBQrm
    0U,	// VPHADDBQrr
    0U,	// VPHADDBWrm
    0U,	// VPHADDBWrr
    0U,	// VPHADDDQrm
    0U,	// VPHADDDQrr
    0U,	// VPHADDDYrm
    0U,	// VPHADDDYrr
    0U,	// VPHADDDrm
    0U,	// VPHADDDrr
    0U,	// VPHADDSWYrm
    0U,	// VPHADDSWYrr
    0U,	// VPHADDSWrm
    0U,	// VPHADDSWrr
    0U,	// VPHADDUBDrm
    0U,	// VPHADDUBDrr
    0U,	// VPHADDUBQrm
    0U,	// VPHADDUBQrr
    0U,	// VPHADDUBWrm
    0U,	// VPHADDUBWrr
    0U,	// VPHADDUDQrm
    0U,	// VPHADDUDQrr
    0U,	// VPHADDUWDrm
    0U,	// VPHADDUWDrr
    0U,	// VPHADDUWQrm
    0U,	// VPHADDUWQrr
    0U,	// VPHADDWDrm
    0U,	// VPHADDWDrr
    0U,	// VPHADDWQrm
    0U,	// VPHADDWQrr
    0U,	// VPHADDWYrm
    0U,	// VPHADDWYrr
    0U,	// VPHADDWrm
    0U,	// VPHADDWrr
    0U,	// VPHMINPOSUWrm
    0U,	// VPHMINPOSUWrr
    0U,	// VPHSUBBWrm
    0U,	// VPHSUBBWrr
    0U,	// VPHSUBDQrm
    0U,	// VPHSUBDQrr
    0U,	// VPHSUBDYrm
    0U,	// VPHSUBDYrr
    0U,	// VPHSUBDrm
    0U,	// VPHSUBDrr
    0U,	// VPHSUBSWYrm
    0U,	// VPHSUBSWYrr
    0U,	// VPHSUBSWrm
    0U,	// VPHSUBSWrr
    0U,	// VPHSUBWDrm
    0U,	// VPHSUBWDrr
    0U,	// VPHSUBWYrm
    0U,	// VPHSUBWYrr
    0U,	// VPHSUBWrm
    0U,	// VPHSUBWrr
    0U,	// VPINSRBZrm
    0U,	// VPINSRBZrr
    0U,	// VPINSRBrm
    0U,	// VPINSRBrr
    0U,	// VPINSRDZrm
    0U,	// VPINSRDZrr
    0U,	// VPINSRDrm
    0U,	// VPINSRDrr
    0U,	// VPINSRQZrm
    0U,	// VPINSRQZrr
    0U,	// VPINSRQrm
    0U,	// VPINSRQrr
    0U,	// VPINSRWZrm
    0U,	// VPINSRWZrr
    0U,	// VPINSRWrm
    0U,	// VPINSRWrr
    0U,	// VPLZCNTDZ128rm
    0U,	// VPLZCNTDZ128rmb
    0U,	// VPLZCNTDZ128rmbk
    0U,	// VPLZCNTDZ128rmbkz
    0U,	// VPLZCNTDZ128rmk
    0U,	// VPLZCNTDZ128rmkz
    0U,	// VPLZCNTDZ128rr
    0U,	// VPLZCNTDZ128rrk
    0U,	// VPLZCNTDZ128rrkz
    0U,	// VPLZCNTDZ256rm
    0U,	// VPLZCNTDZ256rmb
    0U,	// VPLZCNTDZ256rmbk
    0U,	// VPLZCNTDZ256rmbkz
    0U,	// VPLZCNTDZ256rmk
    0U,	// VPLZCNTDZ256rmkz
    0U,	// VPLZCNTDZ256rr
    0U,	// VPLZCNTDZ256rrk
    0U,	// VPLZCNTDZ256rrkz
    0U,	// VPLZCNTDZrm
    0U,	// VPLZCNTDZrmb
    0U,	// VPLZCNTDZrmbk
    0U,	// VPLZCNTDZrmbkz
    0U,	// VPLZCNTDZrmk
    0U,	// VPLZCNTDZrmkz
    0U,	// VPLZCNTDZrr
    0U,	// VPLZCNTDZrrk
    0U,	// VPLZCNTDZrrkz
    0U,	// VPLZCNTQZ128rm
    0U,	// VPLZCNTQZ128rmb
    0U,	// VPLZCNTQZ128rmbk
    0U,	// VPLZCNTQZ128rmbkz
    0U,	// VPLZCNTQZ128rmk
    0U,	// VPLZCNTQZ128rmkz
    0U,	// VPLZCNTQZ128rr
    0U,	// VPLZCNTQZ128rrk
    0U,	// VPLZCNTQZ128rrkz
    0U,	// VPLZCNTQZ256rm
    0U,	// VPLZCNTQZ256rmb
    0U,	// VPLZCNTQZ256rmbk
    0U,	// VPLZCNTQZ256rmbkz
    0U,	// VPLZCNTQZ256rmk
    0U,	// VPLZCNTQZ256rmkz
    0U,	// VPLZCNTQZ256rr
    0U,	// VPLZCNTQZ256rrk
    0U,	// VPLZCNTQZ256rrkz
    0U,	// VPLZCNTQZrm
    0U,	// VPLZCNTQZrmb
    0U,	// VPLZCNTQZrmbk
    0U,	// VPLZCNTQZrmbkz
    0U,	// VPLZCNTQZrmk
    0U,	// VPLZCNTQZrmkz
    0U,	// VPLZCNTQZrr
    0U,	// VPLZCNTQZrrk
    0U,	// VPLZCNTQZrrkz
    0U,	// VPMACSDDrm
    0U,	// VPMACSDDrr
    0U,	// VPMACSDQHrm
    0U,	// VPMACSDQHrr
    0U,	// VPMACSDQLrm
    0U,	// VPMACSDQLrr
    0U,	// VPMACSSDDrm
    0U,	// VPMACSSDDrr
    0U,	// VPMACSSDQHrm
    0U,	// VPMACSSDQHrr
    0U,	// VPMACSSDQLrm
    0U,	// VPMACSSDQLrr
    0U,	// VPMACSSWDrm
    0U,	// VPMACSSWDrr
    0U,	// VPMACSSWWrm
    0U,	// VPMACSSWWrr
    0U,	// VPMACSWDrm
    0U,	// VPMACSWDrr
    0U,	// VPMACSWWrm
    0U,	// VPMACSWWrr
    0U,	// VPMADCSSWDrm
    0U,	// VPMADCSSWDrr
    0U,	// VPMADCSWDrm
    0U,	// VPMADCSWDrr
    0U,	// VPMADD52HUQZ128m
    0U,	// VPMADD52HUQZ128mb
    0U,	// VPMADD52HUQZ128mbk
    0U,	// VPMADD52HUQZ128mbkz
    0U,	// VPMADD52HUQZ128mk
    0U,	// VPMADD52HUQZ128mkz
    0U,	// VPMADD52HUQZ128r
    0U,	// VPMADD52HUQZ128rk
    0U,	// VPMADD52HUQZ128rkz
    0U,	// VPMADD52HUQZ256m
    0U,	// VPMADD52HUQZ256mb
    0U,	// VPMADD52HUQZ256mbk
    0U,	// VPMADD52HUQZ256mbkz
    0U,	// VPMADD52HUQZ256mk
    0U,	// VPMADD52HUQZ256mkz
    0U,	// VPMADD52HUQZ256r
    0U,	// VPMADD52HUQZ256rk
    0U,	// VPMADD52HUQZ256rkz
    0U,	// VPMADD52HUQZm
    0U,	// VPMADD52HUQZmb
    0U,	// VPMADD52HUQZmbk
    0U,	// VPMADD52HUQZmbkz
    0U,	// VPMADD52HUQZmk
    0U,	// VPMADD52HUQZmkz
    0U,	// VPMADD52HUQZr
    0U,	// VPMADD52HUQZrk
    0U,	// VPMADD52HUQZrkz
    0U,	// VPMADD52LUQZ128m
    0U,	// VPMADD52LUQZ128mb
    0U,	// VPMADD52LUQZ128mbk
    0U,	// VPMADD52LUQZ128mbkz
    0U,	// VPMADD52LUQZ128mk
    0U,	// VPMADD52LUQZ128mkz
    0U,	// VPMADD52LUQZ128r
    0U,	// VPMADD52LUQZ128rk
    0U,	// VPMADD52LUQZ128rkz
    0U,	// VPMADD52LUQZ256m
    0U,	// VPMADD52LUQZ256mb
    0U,	// VPMADD52LUQZ256mbk
    0U,	// VPMADD52LUQZ256mbkz
    0U,	// VPMADD52LUQZ256mk
    0U,	// VPMADD52LUQZ256mkz
    0U,	// VPMADD52LUQZ256r
    0U,	// VPMADD52LUQZ256rk
    0U,	// VPMADD52LUQZ256rkz
    0U,	// VPMADD52LUQZm
    0U,	// VPMADD52LUQZmb
    0U,	// VPMADD52LUQZmbk
    0U,	// VPMADD52LUQZmbkz
    0U,	// VPMADD52LUQZmk
    0U,	// VPMADD52LUQZmkz
    0U,	// VPMADD52LUQZr
    0U,	// VPMADD52LUQZrk
    0U,	// VPMADD52LUQZrkz
    0U,	// VPMADDUBSWYrm
    0U,	// VPMADDUBSWYrr
    0U,	// VPMADDUBSWZ128rm
    0U,	// VPMADDUBSWZ128rmk
    0U,	// VPMADDUBSWZ128rmkz
    0U,	// VPMADDUBSWZ128rr
    0U,	// VPMADDUBSWZ128rrk
    0U,	// VPMADDUBSWZ128rrkz
    0U,	// VPMADDUBSWZ256rm
    0U,	// VPMADDUBSWZ256rmk
    0U,	// VPMADDUBSWZ256rmkz
    0U,	// VPMADDUBSWZ256rr
    0U,	// VPMADDUBSWZ256rrk
    0U,	// VPMADDUBSWZ256rrkz
    0U,	// VPMADDUBSWZrm
    0U,	// VPMADDUBSWZrmk
    0U,	// VPMADDUBSWZrmkz
    0U,	// VPMADDUBSWZrr
    0U,	// VPMADDUBSWZrrk
    0U,	// VPMADDUBSWZrrkz
    0U,	// VPMADDUBSWrm
    0U,	// VPMADDUBSWrr
    0U,	// VPMADDWDYrm
    0U,	// VPMADDWDYrr
    0U,	// VPMADDWDZ128rm
    0U,	// VPMADDWDZ128rmk
    0U,	// VPMADDWDZ128rmkz
    0U,	// VPMADDWDZ128rr
    0U,	// VPMADDWDZ128rrk
    0U,	// VPMADDWDZ128rrkz
    0U,	// VPMADDWDZ256rm
    0U,	// VPMADDWDZ256rmk
    0U,	// VPMADDWDZ256rmkz
    0U,	// VPMADDWDZ256rr
    0U,	// VPMADDWDZ256rrk
    0U,	// VPMADDWDZ256rrkz
    0U,	// VPMADDWDZrm
    0U,	// VPMADDWDZrmk
    0U,	// VPMADDWDZrmkz
    0U,	// VPMADDWDZrr
    0U,	// VPMADDWDZrrk
    0U,	// VPMADDWDZrrkz
    0U,	// VPMADDWDrm
    0U,	// VPMADDWDrr
    0U,	// VPMASKMOVDYmr
    0U,	// VPMASKMOVDYrm
    0U,	// VPMASKMOVDmr
    0U,	// VPMASKMOVDrm
    0U,	// VPMASKMOVQYmr
    0U,	// VPMASKMOVQYrm
    0U,	// VPMASKMOVQmr
    0U,	// VPMASKMOVQrm
    0U,	// VPMAXSBYrm
    0U,	// VPMAXSBYrr
    0U,	// VPMAXSBZ128rm
    0U,	// VPMAXSBZ128rmk
    0U,	// VPMAXSBZ128rmkz
    0U,	// VPMAXSBZ128rr
    0U,	// VPMAXSBZ128rrk
    0U,	// VPMAXSBZ128rrkz
    0U,	// VPMAXSBZ256rm
    0U,	// VPMAXSBZ256rmk
    0U,	// VPMAXSBZ256rmkz
    0U,	// VPMAXSBZ256rr
    0U,	// VPMAXSBZ256rrk
    0U,	// VPMAXSBZ256rrkz
    0U,	// VPMAXSBZrm
    0U,	// VPMAXSBZrmk
    0U,	// VPMAXSBZrmkz
    0U,	// VPMAXSBZrr
    0U,	// VPMAXSBZrrk
    0U,	// VPMAXSBZrrkz
    0U,	// VPMAXSBrm
    0U,	// VPMAXSBrr
    0U,	// VPMAXSDYrm
    0U,	// VPMAXSDYrr
    0U,	// VPMAXSDZ128rm
    0U,	// VPMAXSDZ128rmb
    0U,	// VPMAXSDZ128rmbk
    0U,	// VPMAXSDZ128rmbkz
    0U,	// VPMAXSDZ128rmk
    0U,	// VPMAXSDZ128rmkz
    0U,	// VPMAXSDZ128rr
    0U,	// VPMAXSDZ128rrk
    0U,	// VPMAXSDZ128rrkz
    0U,	// VPMAXSDZ256rm
    0U,	// VPMAXSDZ256rmb
    0U,	// VPMAXSDZ256rmbk
    0U,	// VPMAXSDZ256rmbkz
    0U,	// VPMAXSDZ256rmk
    0U,	// VPMAXSDZ256rmkz
    0U,	// VPMAXSDZ256rr
    0U,	// VPMAXSDZ256rrk
    0U,	// VPMAXSDZ256rrkz
    0U,	// VPMAXSDZrm
    0U,	// VPMAXSDZrmb
    0U,	// VPMAXSDZrmbk
    0U,	// VPMAXSDZrmbkz
    0U,	// VPMAXSDZrmk
    0U,	// VPMAXSDZrmkz
    0U,	// VPMAXSDZrr
    0U,	// VPMAXSDZrrk
    0U,	// VPMAXSDZrrkz
    0U,	// VPMAXSDrm
    0U,	// VPMAXSDrr
    0U,	// VPMAXSQZ128rm
    0U,	// VPMAXSQZ128rmb
    0U,	// VPMAXSQZ128rmbk
    0U,	// VPMAXSQZ128rmbkz
    0U,	// VPMAXSQZ128rmk
    0U,	// VPMAXSQZ128rmkz
    0U,	// VPMAXSQZ128rr
    0U,	// VPMAXSQZ128rrk
    0U,	// VPMAXSQZ128rrkz
    0U,	// VPMAXSQZ256rm
    0U,	// VPMAXSQZ256rmb
    0U,	// VPMAXSQZ256rmbk
    0U,	// VPMAXSQZ256rmbkz
    0U,	// VPMAXSQZ256rmk
    0U,	// VPMAXSQZ256rmkz
    0U,	// VPMAXSQZ256rr
    0U,	// VPMAXSQZ256rrk
    0U,	// VPMAXSQZ256rrkz
    0U,	// VPMAXSQZrm
    0U,	// VPMAXSQZrmb
    0U,	// VPMAXSQZrmbk
    0U,	// VPMAXSQZrmbkz
    0U,	// VPMAXSQZrmk
    0U,	// VPMAXSQZrmkz
    0U,	// VPMAXSQZrr
    0U,	// VPMAXSQZrrk
    0U,	// VPMAXSQZrrkz
    0U,	// VPMAXSWYrm
    0U,	// VPMAXSWYrr
    0U,	// VPMAXSWZ128rm
    0U,	// VPMAXSWZ128rmk
    0U,	// VPMAXSWZ128rmkz
    0U,	// VPMAXSWZ128rr
    0U,	// VPMAXSWZ128rrk
    0U,	// VPMAXSWZ128rrkz
    0U,	// VPMAXSWZ256rm
    0U,	// VPMAXSWZ256rmk
    0U,	// VPMAXSWZ256rmkz
    0U,	// VPMAXSWZ256rr
    0U,	// VPMAXSWZ256rrk
    0U,	// VPMAXSWZ256rrkz
    0U,	// VPMAXSWZrm
    0U,	// VPMAXSWZrmk
    0U,	// VPMAXSWZrmkz
    0U,	// VPMAXSWZrr
    0U,	// VPMAXSWZrrk
    0U,	// VPMAXSWZrrkz
    0U,	// VPMAXSWrm
    0U,	// VPMAXSWrr
    0U,	// VPMAXUBYrm
    0U,	// VPMAXUBYrr
    0U,	// VPMAXUBZ128rm
    0U,	// VPMAXUBZ128rmk
    0U,	// VPMAXUBZ128rmkz
    0U,	// VPMAXUBZ128rr
    0U,	// VPMAXUBZ128rrk
    0U,	// VPMAXUBZ128rrkz
    0U,	// VPMAXUBZ256rm
    0U,	// VPMAXUBZ256rmk
    0U,	// VPMAXUBZ256rmkz
    0U,	// VPMAXUBZ256rr
    0U,	// VPMAXUBZ256rrk
    0U,	// VPMAXUBZ256rrkz
    0U,	// VPMAXUBZrm
    0U,	// VPMAXUBZrmk
    0U,	// VPMAXUBZrmkz
    0U,	// VPMAXUBZrr
    0U,	// VPMAXUBZrrk
    0U,	// VPMAXUBZrrkz
    0U,	// VPMAXUBrm
    0U,	// VPMAXUBrr
    0U,	// VPMAXUDYrm
    0U,	// VPMAXUDYrr
    0U,	// VPMAXUDZ128rm
    0U,	// VPMAXUDZ128rmb
    0U,	// VPMAXUDZ128rmbk
    0U,	// VPMAXUDZ128rmbkz
    0U,	// VPMAXUDZ128rmk
    0U,	// VPMAXUDZ128rmkz
    0U,	// VPMAXUDZ128rr
    0U,	// VPMAXUDZ128rrk
    0U,	// VPMAXUDZ128rrkz
    0U,	// VPMAXUDZ256rm
    0U,	// VPMAXUDZ256rmb
    0U,	// VPMAXUDZ256rmbk
    0U,	// VPMAXUDZ256rmbkz
    0U,	// VPMAXUDZ256rmk
    0U,	// VPMAXUDZ256rmkz
    0U,	// VPMAXUDZ256rr
    0U,	// VPMAXUDZ256rrk
    0U,	// VPMAXUDZ256rrkz
    0U,	// VPMAXUDZrm
    0U,	// VPMAXUDZrmb
    0U,	// VPMAXUDZrmbk
    0U,	// VPMAXUDZrmbkz
    0U,	// VPMAXUDZrmk
    0U,	// VPMAXUDZrmkz
    0U,	// VPMAXUDZrr
    0U,	// VPMAXUDZrrk
    0U,	// VPMAXUDZrrkz
    0U,	// VPMAXUDrm
    0U,	// VPMAXUDrr
    0U,	// VPMAXUQZ128rm
    0U,	// VPMAXUQZ128rmb
    0U,	// VPMAXUQZ128rmbk
    0U,	// VPMAXUQZ128rmbkz
    0U,	// VPMAXUQZ128rmk
    0U,	// VPMAXUQZ128rmkz
    0U,	// VPMAXUQZ128rr
    0U,	// VPMAXUQZ128rrk
    0U,	// VPMAXUQZ128rrkz
    0U,	// VPMAXUQZ256rm
    0U,	// VPMAXUQZ256rmb
    0U,	// VPMAXUQZ256rmbk
    0U,	// VPMAXUQZ256rmbkz
    0U,	// VPMAXUQZ256rmk
    0U,	// VPMAXUQZ256rmkz
    0U,	// VPMAXUQZ256rr
    0U,	// VPMAXUQZ256rrk
    0U,	// VPMAXUQZ256rrkz
    0U,	// VPMAXUQZrm
    0U,	// VPMAXUQZrmb
    0U,	// VPMAXUQZrmbk
    0U,	// VPMAXUQZrmbkz
    0U,	// VPMAXUQZrmk
    0U,	// VPMAXUQZrmkz
    0U,	// VPMAXUQZrr
    0U,	// VPMAXUQZrrk
    0U,	// VPMAXUQZrrkz
    0U,	// VPMAXUWYrm
    0U,	// VPMAXUWYrr
    0U,	// VPMAXUWZ128rm
    0U,	// VPMAXUWZ128rmk
    0U,	// VPMAXUWZ128rmkz
    0U,	// VPMAXUWZ128rr
    0U,	// VPMAXUWZ128rrk
    0U,	// VPMAXUWZ128rrkz
    0U,	// VPMAXUWZ256rm
    0U,	// VPMAXUWZ256rmk
    0U,	// VPMAXUWZ256rmkz
    0U,	// VPMAXUWZ256rr
    0U,	// VPMAXUWZ256rrk
    0U,	// VPMAXUWZ256rrkz
    0U,	// VPMAXUWZrm
    0U,	// VPMAXUWZrmk
    0U,	// VPMAXUWZrmkz
    0U,	// VPMAXUWZrr
    0U,	// VPMAXUWZrrk
    0U,	// VPMAXUWZrrkz
    0U,	// VPMAXUWrm
    0U,	// VPMAXUWrr
    0U,	// VPMINSBYrm
    0U,	// VPMINSBYrr
    0U,	// VPMINSBZ128rm
    0U,	// VPMINSBZ128rmk
    0U,	// VPMINSBZ128rmkz
    0U,	// VPMINSBZ128rr
    0U,	// VPMINSBZ128rrk
    0U,	// VPMINSBZ128rrkz
    0U,	// VPMINSBZ256rm
    0U,	// VPMINSBZ256rmk
    0U,	// VPMINSBZ256rmkz
    0U,	// VPMINSBZ256rr
    0U,	// VPMINSBZ256rrk
    0U,	// VPMINSBZ256rrkz
    0U,	// VPMINSBZrm
    0U,	// VPMINSBZrmk
    0U,	// VPMINSBZrmkz
    0U,	// VPMINSBZrr
    0U,	// VPMINSBZrrk
    0U,	// VPMINSBZrrkz
    0U,	// VPMINSBrm
    0U,	// VPMINSBrr
    0U,	// VPMINSDYrm
    0U,	// VPMINSDYrr
    0U,	// VPMINSDZ128rm
    0U,	// VPMINSDZ128rmb
    0U,	// VPMINSDZ128rmbk
    0U,	// VPMINSDZ128rmbkz
    0U,	// VPMINSDZ128rmk
    0U,	// VPMINSDZ128rmkz
    0U,	// VPMINSDZ128rr
    0U,	// VPMINSDZ128rrk
    0U,	// VPMINSDZ128rrkz
    0U,	// VPMINSDZ256rm
    0U,	// VPMINSDZ256rmb
    0U,	// VPMINSDZ256rmbk
    0U,	// VPMINSDZ256rmbkz
    0U,	// VPMINSDZ256rmk
    0U,	// VPMINSDZ256rmkz
    0U,	// VPMINSDZ256rr
    0U,	// VPMINSDZ256rrk
    0U,	// VPMINSDZ256rrkz
    0U,	// VPMINSDZrm
    0U,	// VPMINSDZrmb
    0U,	// VPMINSDZrmbk
    0U,	// VPMINSDZrmbkz
    0U,	// VPMINSDZrmk
    0U,	// VPMINSDZrmkz
    0U,	// VPMINSDZrr
    0U,	// VPMINSDZrrk
    0U,	// VPMINSDZrrkz
    0U,	// VPMINSDrm
    0U,	// VPMINSDrr
    0U,	// VPMINSQZ128rm
    0U,	// VPMINSQZ128rmb
    0U,	// VPMINSQZ128rmbk
    0U,	// VPMINSQZ128rmbkz
    0U,	// VPMINSQZ128rmk
    0U,	// VPMINSQZ128rmkz
    0U,	// VPMINSQZ128rr
    0U,	// VPMINSQZ128rrk
    0U,	// VPMINSQZ128rrkz
    0U,	// VPMINSQZ256rm
    0U,	// VPMINSQZ256rmb
    0U,	// VPMINSQZ256rmbk
    0U,	// VPMINSQZ256rmbkz
    0U,	// VPMINSQZ256rmk
    0U,	// VPMINSQZ256rmkz
    0U,	// VPMINSQZ256rr
    0U,	// VPMINSQZ256rrk
    0U,	// VPMINSQZ256rrkz
    0U,	// VPMINSQZrm
    0U,	// VPMINSQZrmb
    0U,	// VPMINSQZrmbk
    0U,	// VPMINSQZrmbkz
    0U,	// VPMINSQZrmk
    0U,	// VPMINSQZrmkz
    0U,	// VPMINSQZrr
    0U,	// VPMINSQZrrk
    0U,	// VPMINSQZrrkz
    0U,	// VPMINSWYrm
    0U,	// VPMINSWYrr
    0U,	// VPMINSWZ128rm
    0U,	// VPMINSWZ128rmk
    0U,	// VPMINSWZ128rmkz
    0U,	// VPMINSWZ128rr
    0U,	// VPMINSWZ128rrk
    0U,	// VPMINSWZ128rrkz
    0U,	// VPMINSWZ256rm
    0U,	// VPMINSWZ256rmk
    0U,	// VPMINSWZ256rmkz
    0U,	// VPMINSWZ256rr
    0U,	// VPMINSWZ256rrk
    0U,	// VPMINSWZ256rrkz
    0U,	// VPMINSWZrm
    0U,	// VPMINSWZrmk
    0U,	// VPMINSWZrmkz
    0U,	// VPMINSWZrr
    0U,	// VPMINSWZrrk
    0U,	// VPMINSWZrrkz
    0U,	// VPMINSWrm
    0U,	// VPMINSWrr
    0U,	// VPMINUBYrm
    0U,	// VPMINUBYrr
    0U,	// VPMINUBZ128rm
    0U,	// VPMINUBZ128rmk
    0U,	// VPMINUBZ128rmkz
    0U,	// VPMINUBZ128rr
    0U,	// VPMINUBZ128rrk
    0U,	// VPMINUBZ128rrkz
    0U,	// VPMINUBZ256rm
    0U,	// VPMINUBZ256rmk
    0U,	// VPMINUBZ256rmkz
    0U,	// VPMINUBZ256rr
    0U,	// VPMINUBZ256rrk
    0U,	// VPMINUBZ256rrkz
    0U,	// VPMINUBZrm
    0U,	// VPMINUBZrmk
    0U,	// VPMINUBZrmkz
    0U,	// VPMINUBZrr
    0U,	// VPMINUBZrrk
    0U,	// VPMINUBZrrkz
    0U,	// VPMINUBrm
    0U,	// VPMINUBrr
    0U,	// VPMINUDYrm
    0U,	// VPMINUDYrr
    0U,	// VPMINUDZ128rm
    0U,	// VPMINUDZ128rmb
    0U,	// VPMINUDZ128rmbk
    0U,	// VPMINUDZ128rmbkz
    0U,	// VPMINUDZ128rmk
    0U,	// VPMINUDZ128rmkz
    0U,	// VPMINUDZ128rr
    0U,	// VPMINUDZ128rrk
    0U,	// VPMINUDZ128rrkz
    0U,	// VPMINUDZ256rm
    0U,	// VPMINUDZ256rmb
    0U,	// VPMINUDZ256rmbk
    0U,	// VPMINUDZ256rmbkz
    0U,	// VPMINUDZ256rmk
    0U,	// VPMINUDZ256rmkz
    0U,	// VPMINUDZ256rr
    0U,	// VPMINUDZ256rrk
    0U,	// VPMINUDZ256rrkz
    0U,	// VPMINUDZrm
    0U,	// VPMINUDZrmb
    0U,	// VPMINUDZrmbk
    0U,	// VPMINUDZrmbkz
    0U,	// VPMINUDZrmk
    0U,	// VPMINUDZrmkz
    0U,	// VPMINUDZrr
    0U,	// VPMINUDZrrk
    0U,	// VPMINUDZrrkz
    0U,	// VPMINUDrm
    0U,	// VPMINUDrr
    0U,	// VPMINUQZ128rm
    0U,	// VPMINUQZ128rmb
    0U,	// VPMINUQZ128rmbk
    0U,	// VPMINUQZ128rmbkz
    0U,	// VPMINUQZ128rmk
    0U,	// VPMINUQZ128rmkz
    0U,	// VPMINUQZ128rr
    0U,	// VPMINUQZ128rrk
    0U,	// VPMINUQZ128rrkz
    0U,	// VPMINUQZ256rm
    0U,	// VPMINUQZ256rmb
    0U,	// VPMINUQZ256rmbk
    0U,	// VPMINUQZ256rmbkz
    0U,	// VPMINUQZ256rmk
    0U,	// VPMINUQZ256rmkz
    0U,	// VPMINUQZ256rr
    0U,	// VPMINUQZ256rrk
    0U,	// VPMINUQZ256rrkz
    0U,	// VPMINUQZrm
    0U,	// VPMINUQZrmb
    0U,	// VPMINUQZrmbk
    0U,	// VPMINUQZrmbkz
    0U,	// VPMINUQZrmk
    0U,	// VPMINUQZrmkz
    0U,	// VPMINUQZrr
    0U,	// VPMINUQZrrk
    0U,	// VPMINUQZrrkz
    0U,	// VPMINUWYrm
    0U,	// VPMINUWYrr
    0U,	// VPMINUWZ128rm
    0U,	// VPMINUWZ128rmk
    0U,	// VPMINUWZ128rmkz
    0U,	// VPMINUWZ128rr
    0U,	// VPMINUWZ128rrk
    0U,	// VPMINUWZ128rrkz
    0U,	// VPMINUWZ256rm
    0U,	// VPMINUWZ256rmk
    0U,	// VPMINUWZ256rmkz
    0U,	// VPMINUWZ256rr
    0U,	// VPMINUWZ256rrk
    0U,	// VPMINUWZ256rrkz
    0U,	// VPMINUWZrm
    0U,	// VPMINUWZrmk
    0U,	// VPMINUWZrmkz
    0U,	// VPMINUWZrr
    0U,	// VPMINUWZrrk
    0U,	// VPMINUWZrrkz
    0U,	// VPMINUWrm
    0U,	// VPMINUWrr
    0U,	// VPMOVB2MZ128rr
    0U,	// VPMOVB2MZ256rr
    0U,	// VPMOVB2MZrr
    0U,	// VPMOVD2MZ128rr
    0U,	// VPMOVD2MZ256rr
    0U,	// VPMOVD2MZrr
    0U,	// VPMOVDBZ128mr
    0U,	// VPMOVDBZ128mrk
    0U,	// VPMOVDBZ128rr
    0U,	// VPMOVDBZ128rrk
    0U,	// VPMOVDBZ128rrkz
    0U,	// VPMOVDBZ256mr
    0U,	// VPMOVDBZ256mrk
    0U,	// VPMOVDBZ256rr
    0U,	// VPMOVDBZ256rrk
    0U,	// VPMOVDBZ256rrkz
    0U,	// VPMOVDBZmr
    0U,	// VPMOVDBZmrk
    0U,	// VPMOVDBZrr
    0U,	// VPMOVDBZrrk
    0U,	// VPMOVDBZrrkz
    0U,	// VPMOVDWZ128mr
    0U,	// VPMOVDWZ128mrk
    0U,	// VPMOVDWZ128rr
    0U,	// VPMOVDWZ128rrk
    0U,	// VPMOVDWZ128rrkz
    0U,	// VPMOVDWZ256mr
    0U,	// VPMOVDWZ256mrk
    0U,	// VPMOVDWZ256rr
    0U,	// VPMOVDWZ256rrk
    0U,	// VPMOVDWZ256rrkz
    0U,	// VPMOVDWZmr
    0U,	// VPMOVDWZmrk
    0U,	// VPMOVDWZrr
    0U,	// VPMOVDWZrrk
    0U,	// VPMOVDWZrrkz
    0U,	// VPMOVM2BZ128rr
    0U,	// VPMOVM2BZ256rr
    0U,	// VPMOVM2BZrr
    0U,	// VPMOVM2DZ128rr
    0U,	// VPMOVM2DZ256rr
    0U,	// VPMOVM2DZrr
    0U,	// VPMOVM2QZ128rr
    0U,	// VPMOVM2QZ256rr
    0U,	// VPMOVM2QZrr
    0U,	// VPMOVM2WZ128rr
    0U,	// VPMOVM2WZ256rr
    0U,	// VPMOVM2WZrr
    0U,	// VPMOVMSKBYrr
    0U,	// VPMOVMSKBrr
    0U,	// VPMOVQ2MZ128rr
    0U,	// VPMOVQ2MZ256rr
    0U,	// VPMOVQ2MZrr
    0U,	// VPMOVQBZ128mr
    0U,	// VPMOVQBZ128mrk
    0U,	// VPMOVQBZ128rr
    0U,	// VPMOVQBZ128rrk
    0U,	// VPMOVQBZ128rrkz
    0U,	// VPMOVQBZ256mr
    0U,	// VPMOVQBZ256mrk
    0U,	// VPMOVQBZ256rr
    0U,	// VPMOVQBZ256rrk
    0U,	// VPMOVQBZ256rrkz
    0U,	// VPMOVQBZmr
    0U,	// VPMOVQBZmrk
    0U,	// VPMOVQBZrr
    0U,	// VPMOVQBZrrk
    0U,	// VPMOVQBZrrkz
    0U,	// VPMOVQDZ128mr
    0U,	// VPMOVQDZ128mrk
    0U,	// VPMOVQDZ128rr
    0U,	// VPMOVQDZ128rrk
    0U,	// VPMOVQDZ128rrkz
    0U,	// VPMOVQDZ256mr
    0U,	// VPMOVQDZ256mrk
    0U,	// VPMOVQDZ256rr
    0U,	// VPMOVQDZ256rrk
    0U,	// VPMOVQDZ256rrkz
    0U,	// VPMOVQDZmr
    0U,	// VPMOVQDZmrk
    0U,	// VPMOVQDZrr
    0U,	// VPMOVQDZrrk
    0U,	// VPMOVQDZrrkz
    0U,	// VPMOVQWZ128mr
    0U,	// VPMOVQWZ128mrk
    0U,	// VPMOVQWZ128rr
    0U,	// VPMOVQWZ128rrk
    0U,	// VPMOVQWZ128rrkz
    0U,	// VPMOVQWZ256mr
    0U,	// VPMOVQWZ256mrk
    0U,	// VPMOVQWZ256rr
    0U,	// VPMOVQWZ256rrk
    0U,	// VPMOVQWZ256rrkz
    0U,	// VPMOVQWZmr
    0U,	// VPMOVQWZmrk
    0U,	// VPMOVQWZrr
    0U,	// VPMOVQWZrrk
    0U,	// VPMOVQWZrrkz
    0U,	// VPMOVSDBZ128mr
    0U,	// VPMOVSDBZ128mrk
    0U,	// VPMOVSDBZ128rr
    0U,	// VPMOVSDBZ128rrk
    0U,	// VPMOVSDBZ128rrkz
    0U,	// VPMOVSDBZ256mr
    0U,	// VPMOVSDBZ256mrk
    0U,	// VPMOVSDBZ256rr
    0U,	// VPMOVSDBZ256rrk
    0U,	// VPMOVSDBZ256rrkz
    0U,	// VPMOVSDBZmr
    0U,	// VPMOVSDBZmrk
    0U,	// VPMOVSDBZrr
    0U,	// VPMOVSDBZrrk
    0U,	// VPMOVSDBZrrkz
    0U,	// VPMOVSDWZ128mr
    0U,	// VPMOVSDWZ128mrk
    0U,	// VPMOVSDWZ128rr
    0U,	// VPMOVSDWZ128rrk
    0U,	// VPMOVSDWZ128rrkz
    0U,	// VPMOVSDWZ256mr
    0U,	// VPMOVSDWZ256mrk
    0U,	// VPMOVSDWZ256rr
    0U,	// VPMOVSDWZ256rrk
    0U,	// VPMOVSDWZ256rrkz
    0U,	// VPMOVSDWZmr
    0U,	// VPMOVSDWZmrk
    0U,	// VPMOVSDWZrr
    0U,	// VPMOVSDWZrrk
    0U,	// VPMOVSDWZrrkz
    0U,	// VPMOVSQBZ128mr
    0U,	// VPMOVSQBZ128mrk
    0U,	// VPMOVSQBZ128rr
    0U,	// VPMOVSQBZ128rrk
    0U,	// VPMOVSQBZ128rrkz
    0U,	// VPMOVSQBZ256mr
    0U,	// VPMOVSQBZ256mrk
    0U,	// VPMOVSQBZ256rr
    0U,	// VPMOVSQBZ256rrk
    0U,	// VPMOVSQBZ256rrkz
    0U,	// VPMOVSQBZmr
    0U,	// VPMOVSQBZmrk
    0U,	// VPMOVSQBZrr
    0U,	// VPMOVSQBZrrk
    0U,	// VPMOVSQBZrrkz
    0U,	// VPMOVSQDZ128mr
    0U,	// VPMOVSQDZ128mrk
    0U,	// VPMOVSQDZ128rr
    0U,	// VPMOVSQDZ128rrk
    0U,	// VPMOVSQDZ128rrkz
    0U,	// VPMOVSQDZ256mr
    0U,	// VPMOVSQDZ256mrk
    0U,	// VPMOVSQDZ256rr
    0U,	// VPMOVSQDZ256rrk
    0U,	// VPMOVSQDZ256rrkz
    0U,	// VPMOVSQDZmr
    0U,	// VPMOVSQDZmrk
    0U,	// VPMOVSQDZrr
    0U,	// VPMOVSQDZrrk
    0U,	// VPMOVSQDZrrkz
    0U,	// VPMOVSQWZ128mr
    0U,	// VPMOVSQWZ128mrk
    0U,	// VPMOVSQWZ128rr
    0U,	// VPMOVSQWZ128rrk
    0U,	// VPMOVSQWZ128rrkz
    0U,	// VPMOVSQWZ256mr
    0U,	// VPMOVSQWZ256mrk
    0U,	// VPMOVSQWZ256rr
    0U,	// VPMOVSQWZ256rrk
    0U,	// VPMOVSQWZ256rrkz
    0U,	// VPMOVSQWZmr
    0U,	// VPMOVSQWZmrk
    0U,	// VPMOVSQWZrr
    0U,	// VPMOVSQWZrrk
    0U,	// VPMOVSQWZrrkz
    0U,	// VPMOVSWBZ128mr
    0U,	// VPMOVSWBZ128mrk
    0U,	// VPMOVSWBZ128rr
    0U,	// VPMOVSWBZ128rrk
    0U,	// VPMOVSWBZ128rrkz
    0U,	// VPMOVSWBZ256mr
    0U,	// VPMOVSWBZ256mrk
    0U,	// VPMOVSWBZ256rr
    0U,	// VPMOVSWBZ256rrk
    0U,	// VPMOVSWBZ256rrkz
    0U,	// VPMOVSWBZmr
    0U,	// VPMOVSWBZmrk
    0U,	// VPMOVSWBZrr
    0U,	// VPMOVSWBZrrk
    0U,	// VPMOVSWBZrrkz
    0U,	// VPMOVSXBDYrm
    0U,	// VPMOVSXBDYrr
    0U,	// VPMOVSXBDZ128rm
    0U,	// VPMOVSXBDZ128rmk
    0U,	// VPMOVSXBDZ128rmkz
    0U,	// VPMOVSXBDZ128rr
    0U,	// VPMOVSXBDZ128rrk
    0U,	// VPMOVSXBDZ128rrkz
    0U,	// VPMOVSXBDZ256rm
    0U,	// VPMOVSXBDZ256rmk
    0U,	// VPMOVSXBDZ256rmkz
    0U,	// VPMOVSXBDZ256rr
    0U,	// VPMOVSXBDZ256rrk
    0U,	// VPMOVSXBDZ256rrkz
    0U,	// VPMOVSXBDZrm
    0U,	// VPMOVSXBDZrmk
    0U,	// VPMOVSXBDZrmkz
    0U,	// VPMOVSXBDZrr
    0U,	// VPMOVSXBDZrrk
    0U,	// VPMOVSXBDZrrkz
    0U,	// VPMOVSXBDrm
    0U,	// VPMOVSXBDrr
    0U,	// VPMOVSXBQYrm
    0U,	// VPMOVSXBQYrr
    0U,	// VPMOVSXBQZ128rm
    0U,	// VPMOVSXBQZ128rmk
    0U,	// VPMOVSXBQZ128rmkz
    0U,	// VPMOVSXBQZ128rr
    0U,	// VPMOVSXBQZ128rrk
    0U,	// VPMOVSXBQZ128rrkz
    0U,	// VPMOVSXBQZ256rm
    0U,	// VPMOVSXBQZ256rmk
    0U,	// VPMOVSXBQZ256rmkz
    0U,	// VPMOVSXBQZ256rr
    0U,	// VPMOVSXBQZ256rrk
    0U,	// VPMOVSXBQZ256rrkz
    0U,	// VPMOVSXBQZrm
    0U,	// VPMOVSXBQZrmk
    0U,	// VPMOVSXBQZrmkz
    0U,	// VPMOVSXBQZrr
    0U,	// VPMOVSXBQZrrk
    0U,	// VPMOVSXBQZrrkz
    0U,	// VPMOVSXBQrm
    0U,	// VPMOVSXBQrr
    0U,	// VPMOVSXBWYrm
    0U,	// VPMOVSXBWYrr
    0U,	// VPMOVSXBWZ128rm
    0U,	// VPMOVSXBWZ128rmk
    0U,	// VPMOVSXBWZ128rmkz
    0U,	// VPMOVSXBWZ128rr
    0U,	// VPMOVSXBWZ128rrk
    0U,	// VPMOVSXBWZ128rrkz
    0U,	// VPMOVSXBWZ256rm
    0U,	// VPMOVSXBWZ256rmk
    0U,	// VPMOVSXBWZ256rmkz
    0U,	// VPMOVSXBWZ256rr
    0U,	// VPMOVSXBWZ256rrk
    0U,	// VPMOVSXBWZ256rrkz
    0U,	// VPMOVSXBWZrm
    0U,	// VPMOVSXBWZrmk
    0U,	// VPMOVSXBWZrmkz
    0U,	// VPMOVSXBWZrr
    0U,	// VPMOVSXBWZrrk
    0U,	// VPMOVSXBWZrrkz
    0U,	// VPMOVSXBWrm
    0U,	// VPMOVSXBWrr
    0U,	// VPMOVSXDQYrm
    0U,	// VPMOVSXDQYrr
    0U,	// VPMOVSXDQZ128rm
    0U,	// VPMOVSXDQZ128rmk
    0U,	// VPMOVSXDQZ128rmkz
    0U,	// VPMOVSXDQZ128rr
    0U,	// VPMOVSXDQZ128rrk
    0U,	// VPMOVSXDQZ128rrkz
    0U,	// VPMOVSXDQZ256rm
    0U,	// VPMOVSXDQZ256rmk
    0U,	// VPMOVSXDQZ256rmkz
    0U,	// VPMOVSXDQZ256rr
    0U,	// VPMOVSXDQZ256rrk
    0U,	// VPMOVSXDQZ256rrkz
    0U,	// VPMOVSXDQZrm
    0U,	// VPMOVSXDQZrmk
    0U,	// VPMOVSXDQZrmkz
    0U,	// VPMOVSXDQZrr
    0U,	// VPMOVSXDQZrrk
    0U,	// VPMOVSXDQZrrkz
    0U,	// VPMOVSXDQrm
    0U,	// VPMOVSXDQrr
    0U,	// VPMOVSXWDYrm
    0U,	// VPMOVSXWDYrr
    0U,	// VPMOVSXWDZ128rm
    0U,	// VPMOVSXWDZ128rmk
    0U,	// VPMOVSXWDZ128rmkz
    0U,	// VPMOVSXWDZ128rr
    0U,	// VPMOVSXWDZ128rrk
    0U,	// VPMOVSXWDZ128rrkz
    0U,	// VPMOVSXWDZ256rm
    0U,	// VPMOVSXWDZ256rmk
    0U,	// VPMOVSXWDZ256rmkz
    0U,	// VPMOVSXWDZ256rr
    0U,	// VPMOVSXWDZ256rrk
    0U,	// VPMOVSXWDZ256rrkz
    0U,	// VPMOVSXWDZrm
    0U,	// VPMOVSXWDZrmk
    0U,	// VPMOVSXWDZrmkz
    0U,	// VPMOVSXWDZrr
    0U,	// VPMOVSXWDZrrk
    0U,	// VPMOVSXWDZrrkz
    0U,	// VPMOVSXWDrm
    0U,	// VPMOVSXWDrr
    0U,	// VPMOVSXWQYrm
    0U,	// VPMOVSXWQYrr
    0U,	// VPMOVSXWQZ128rm
    0U,	// VPMOVSXWQZ128rmk
    0U,	// VPMOVSXWQZ128rmkz
    0U,	// VPMOVSXWQZ128rr
    0U,	// VPMOVSXWQZ128rrk
    0U,	// VPMOVSXWQZ128rrkz
    0U,	// VPMOVSXWQZ256rm
    0U,	// VPMOVSXWQZ256rmk
    0U,	// VPMOVSXWQZ256rmkz
    0U,	// VPMOVSXWQZ256rr
    0U,	// VPMOVSXWQZ256rrk
    0U,	// VPMOVSXWQZ256rrkz
    0U,	// VPMOVSXWQZrm
    0U,	// VPMOVSXWQZrmk
    0U,	// VPMOVSXWQZrmkz
    0U,	// VPMOVSXWQZrr
    0U,	// VPMOVSXWQZrrk
    0U,	// VPMOVSXWQZrrkz
    0U,	// VPMOVSXWQrm
    0U,	// VPMOVSXWQrr
    0U,	// VPMOVUSDBZ128mr
    0U,	// VPMOVUSDBZ128mrk
    0U,	// VPMOVUSDBZ128rr
    0U,	// VPMOVUSDBZ128rrk
    0U,	// VPMOVUSDBZ128rrkz
    0U,	// VPMOVUSDBZ256mr
    0U,	// VPMOVUSDBZ256mrk
    0U,	// VPMOVUSDBZ256rr
    0U,	// VPMOVUSDBZ256rrk
    0U,	// VPMOVUSDBZ256rrkz
    0U,	// VPMOVUSDBZmr
    0U,	// VPMOVUSDBZmrk
    0U,	// VPMOVUSDBZrr
    0U,	// VPMOVUSDBZrrk
    0U,	// VPMOVUSDBZrrkz
    0U,	// VPMOVUSDWZ128mr
    0U,	// VPMOVUSDWZ128mrk
    0U,	// VPMOVUSDWZ128rr
    0U,	// VPMOVUSDWZ128rrk
    0U,	// VPMOVUSDWZ128rrkz
    0U,	// VPMOVUSDWZ256mr
    0U,	// VPMOVUSDWZ256mrk
    0U,	// VPMOVUSDWZ256rr
    0U,	// VPMOVUSDWZ256rrk
    0U,	// VPMOVUSDWZ256rrkz
    0U,	// VPMOVUSDWZmr
    0U,	// VPMOVUSDWZmrk
    0U,	// VPMOVUSDWZrr
    0U,	// VPMOVUSDWZrrk
    0U,	// VPMOVUSDWZrrkz
    0U,	// VPMOVUSQBZ128mr
    0U,	// VPMOVUSQBZ128mrk
    0U,	// VPMOVUSQBZ128rr
    0U,	// VPMOVUSQBZ128rrk
    0U,	// VPMOVUSQBZ128rrkz
    0U,	// VPMOVUSQBZ256mr
    0U,	// VPMOVUSQBZ256mrk
    0U,	// VPMOVUSQBZ256rr
    0U,	// VPMOVUSQBZ256rrk
    0U,	// VPMOVUSQBZ256rrkz
    0U,	// VPMOVUSQBZmr
    0U,	// VPMOVUSQBZmrk
    0U,	// VPMOVUSQBZrr
    0U,	// VPMOVUSQBZrrk
    0U,	// VPMOVUSQBZrrkz
    0U,	// VPMOVUSQDZ128mr
    0U,	// VPMOVUSQDZ128mrk
    0U,	// VPMOVUSQDZ128rr
    0U,	// VPMOVUSQDZ128rrk
    0U,	// VPMOVUSQDZ128rrkz
    0U,	// VPMOVUSQDZ256mr
    0U,	// VPMOVUSQDZ256mrk
    0U,	// VPMOVUSQDZ256rr
    0U,	// VPMOVUSQDZ256rrk
    0U,	// VPMOVUSQDZ256rrkz
    0U,	// VPMOVUSQDZmr
    0U,	// VPMOVUSQDZmrk
    0U,	// VPMOVUSQDZrr
    0U,	// VPMOVUSQDZrrk
    0U,	// VPMOVUSQDZrrkz
    0U,	// VPMOVUSQWZ128mr
    0U,	// VPMOVUSQWZ128mrk
    0U,	// VPMOVUSQWZ128rr
    0U,	// VPMOVUSQWZ128rrk
    0U,	// VPMOVUSQWZ128rrkz
    0U,	// VPMOVUSQWZ256mr
    0U,	// VPMOVUSQWZ256mrk
    0U,	// VPMOVUSQWZ256rr
    0U,	// VPMOVUSQWZ256rrk
    0U,	// VPMOVUSQWZ256rrkz
    0U,	// VPMOVUSQWZmr
    0U,	// VPMOVUSQWZmrk
    0U,	// VPMOVUSQWZrr
    0U,	// VPMOVUSQWZrrk
    0U,	// VPMOVUSQWZrrkz
    0U,	// VPMOVUSWBZ128mr
    0U,	// VPMOVUSWBZ128mrk
    0U,	// VPMOVUSWBZ128rr
    0U,	// VPMOVUSWBZ128rrk
    0U,	// VPMOVUSWBZ128rrkz
    0U,	// VPMOVUSWBZ256mr
    0U,	// VPMOVUSWBZ256mrk
    0U,	// VPMOVUSWBZ256rr
    0U,	// VPMOVUSWBZ256rrk
    0U,	// VPMOVUSWBZ256rrkz
    0U,	// VPMOVUSWBZmr
    0U,	// VPMOVUSWBZmrk
    0U,	// VPMOVUSWBZrr
    0U,	// VPMOVUSWBZrrk
    0U,	// VPMOVUSWBZrrkz
    0U,	// VPMOVW2MZ128rr
    0U,	// VPMOVW2MZ256rr
    0U,	// VPMOVW2MZrr
    0U,	// VPMOVWBZ128mr
    0U,	// VPMOVWBZ128mrk
    0U,	// VPMOVWBZ128rr
    0U,	// VPMOVWBZ128rrk
    0U,	// VPMOVWBZ128rrkz
    0U,	// VPMOVWBZ256mr
    0U,	// VPMOVWBZ256mrk
    0U,	// VPMOVWBZ256rr
    0U,	// VPMOVWBZ256rrk
    0U,	// VPMOVWBZ256rrkz
    0U,	// VPMOVWBZmr
    0U,	// VPMOVWBZmrk
    0U,	// VPMOVWBZrr
    0U,	// VPMOVWBZrrk
    0U,	// VPMOVWBZrrkz
    0U,	// VPMOVZXBDYrm
    0U,	// VPMOVZXBDYrr
    0U,	// VPMOVZXBDZ128rm
    0U,	// VPMOVZXBDZ128rmk
    0U,	// VPMOVZXBDZ128rmkz
    0U,	// VPMOVZXBDZ128rr
    0U,	// VPMOVZXBDZ128rrk
    0U,	// VPMOVZXBDZ128rrkz
    0U,	// VPMOVZXBDZ256rm
    0U,	// VPMOVZXBDZ256rmk
    0U,	// VPMOVZXBDZ256rmkz
    0U,	// VPMOVZXBDZ256rr
    0U,	// VPMOVZXBDZ256rrk
    0U,	// VPMOVZXBDZ256rrkz
    0U,	// VPMOVZXBDZrm
    0U,	// VPMOVZXBDZrmk
    0U,	// VPMOVZXBDZrmkz
    0U,	// VPMOVZXBDZrr
    0U,	// VPMOVZXBDZrrk
    0U,	// VPMOVZXBDZrrkz
    0U,	// VPMOVZXBDrm
    0U,	// VPMOVZXBDrr
    0U,	// VPMOVZXBQYrm
    0U,	// VPMOVZXBQYrr
    0U,	// VPMOVZXBQZ128rm
    0U,	// VPMOVZXBQZ128rmk
    0U,	// VPMOVZXBQZ128rmkz
    0U,	// VPMOVZXBQZ128rr
    0U,	// VPMOVZXBQZ128rrk
    0U,	// VPMOVZXBQZ128rrkz
    0U,	// VPMOVZXBQZ256rm
    0U,	// VPMOVZXBQZ256rmk
    0U,	// VPMOVZXBQZ256rmkz
    0U,	// VPMOVZXBQZ256rr
    0U,	// VPMOVZXBQZ256rrk
    0U,	// VPMOVZXBQZ256rrkz
    0U,	// VPMOVZXBQZrm
    0U,	// VPMOVZXBQZrmk
    0U,	// VPMOVZXBQZrmkz
    0U,	// VPMOVZXBQZrr
    0U,	// VPMOVZXBQZrrk
    0U,	// VPMOVZXBQZrrkz
    0U,	// VPMOVZXBQrm
    0U,	// VPMOVZXBQrr
    0U,	// VPMOVZXBWYrm
    0U,	// VPMOVZXBWYrr
    0U,	// VPMOVZXBWZ128rm
    0U,	// VPMOVZXBWZ128rmk
    0U,	// VPMOVZXBWZ128rmkz
    0U,	// VPMOVZXBWZ128rr
    0U,	// VPMOVZXBWZ128rrk
    0U,	// VPMOVZXBWZ128rrkz
    0U,	// VPMOVZXBWZ256rm
    0U,	// VPMOVZXBWZ256rmk
    0U,	// VPMOVZXBWZ256rmkz
    0U,	// VPMOVZXBWZ256rr
    0U,	// VPMOVZXBWZ256rrk
    0U,	// VPMOVZXBWZ256rrkz
    0U,	// VPMOVZXBWZrm
    0U,	// VPMOVZXBWZrmk
    0U,	// VPMOVZXBWZrmkz
    0U,	// VPMOVZXBWZrr
    0U,	// VPMOVZXBWZrrk
    0U,	// VPMOVZXBWZrrkz
    0U,	// VPMOVZXBWrm
    0U,	// VPMOVZXBWrr
    0U,	// VPMOVZXDQYrm
    0U,	// VPMOVZXDQYrr
    0U,	// VPMOVZXDQZ128rm
    0U,	// VPMOVZXDQZ128rmk
    0U,	// VPMOVZXDQZ128rmkz
    0U,	// VPMOVZXDQZ128rr
    0U,	// VPMOVZXDQZ128rrk
    0U,	// VPMOVZXDQZ128rrkz
    0U,	// VPMOVZXDQZ256rm
    0U,	// VPMOVZXDQZ256rmk
    0U,	// VPMOVZXDQZ256rmkz
    0U,	// VPMOVZXDQZ256rr
    0U,	// VPMOVZXDQZ256rrk
    0U,	// VPMOVZXDQZ256rrkz
    0U,	// VPMOVZXDQZrm
    0U,	// VPMOVZXDQZrmk
    0U,	// VPMOVZXDQZrmkz
    0U,	// VPMOVZXDQZrr
    0U,	// VPMOVZXDQZrrk
    0U,	// VPMOVZXDQZrrkz
    0U,	// VPMOVZXDQrm
    0U,	// VPMOVZXDQrr
    0U,	// VPMOVZXWDYrm
    0U,	// VPMOVZXWDYrr
    0U,	// VPMOVZXWDZ128rm
    0U,	// VPMOVZXWDZ128rmk
    0U,	// VPMOVZXWDZ128rmkz
    0U,	// VPMOVZXWDZ128rr
    0U,	// VPMOVZXWDZ128rrk
    0U,	// VPMOVZXWDZ128rrkz
    0U,	// VPMOVZXWDZ256rm
    0U,	// VPMOVZXWDZ256rmk
    0U,	// VPMOVZXWDZ256rmkz
    0U,	// VPMOVZXWDZ256rr
    0U,	// VPMOVZXWDZ256rrk
    0U,	// VPMOVZXWDZ256rrkz
    0U,	// VPMOVZXWDZrm
    0U,	// VPMOVZXWDZrmk
    0U,	// VPMOVZXWDZrmkz
    0U,	// VPMOVZXWDZrr
    0U,	// VPMOVZXWDZrrk
    0U,	// VPMOVZXWDZrrkz
    0U,	// VPMOVZXWDrm
    0U,	// VPMOVZXWDrr
    0U,	// VPMOVZXWQYrm
    0U,	// VPMOVZXWQYrr
    0U,	// VPMOVZXWQZ128rm
    0U,	// VPMOVZXWQZ128rmk
    0U,	// VPMOVZXWQZ128rmkz
    0U,	// VPMOVZXWQZ128rr
    0U,	// VPMOVZXWQZ128rrk
    0U,	// VPMOVZXWQZ128rrkz
    0U,	// VPMOVZXWQZ256rm
    0U,	// VPMOVZXWQZ256rmk
    0U,	// VPMOVZXWQZ256rmkz
    0U,	// VPMOVZXWQZ256rr
    0U,	// VPMOVZXWQZ256rrk
    0U,	// VPMOVZXWQZ256rrkz
    0U,	// VPMOVZXWQZrm
    0U,	// VPMOVZXWQZrmk
    0U,	// VPMOVZXWQZrmkz
    0U,	// VPMOVZXWQZrr
    0U,	// VPMOVZXWQZrrk
    0U,	// VPMOVZXWQZrrkz
    0U,	// VPMOVZXWQrm
    0U,	// VPMOVZXWQrr
    0U,	// VPMULDQYrm
    0U,	// VPMULDQYrr
    0U,	// VPMULDQZ128rm
    0U,	// VPMULDQZ128rmb
    0U,	// VPMULDQZ128rmbk
    0U,	// VPMULDQZ128rmbkz
    0U,	// VPMULDQZ128rmk
    0U,	// VPMULDQZ128rmkz
    0U,	// VPMULDQZ128rr
    0U,	// VPMULDQZ128rrk
    0U,	// VPMULDQZ128rrkz
    0U,	// VPMULDQZ256rm
    0U,	// VPMULDQZ256rmb
    0U,	// VPMULDQZ256rmbk
    0U,	// VPMULDQZ256rmbkz
    0U,	// VPMULDQZ256rmk
    0U,	// VPMULDQZ256rmkz
    0U,	// VPMULDQZ256rr
    0U,	// VPMULDQZ256rrk
    0U,	// VPMULDQZ256rrkz
    0U,	// VPMULDQZrm
    0U,	// VPMULDQZrmb
    0U,	// VPMULDQZrmbk
    0U,	// VPMULDQZrmbkz
    0U,	// VPMULDQZrmk
    0U,	// VPMULDQZrmkz
    0U,	// VPMULDQZrr
    0U,	// VPMULDQZrrk
    0U,	// VPMULDQZrrkz
    0U,	// VPMULDQrm
    0U,	// VPMULDQrr
    0U,	// VPMULHRSWYrm
    0U,	// VPMULHRSWYrr
    0U,	// VPMULHRSWZ128rm
    0U,	// VPMULHRSWZ128rmk
    0U,	// VPMULHRSWZ128rmkz
    0U,	// VPMULHRSWZ128rr
    0U,	// VPMULHRSWZ128rrk
    0U,	// VPMULHRSWZ128rrkz
    0U,	// VPMULHRSWZ256rm
    0U,	// VPMULHRSWZ256rmk
    0U,	// VPMULHRSWZ256rmkz
    0U,	// VPMULHRSWZ256rr
    0U,	// VPMULHRSWZ256rrk
    0U,	// VPMULHRSWZ256rrkz
    0U,	// VPMULHRSWZrm
    0U,	// VPMULHRSWZrmk
    0U,	// VPMULHRSWZrmkz
    0U,	// VPMULHRSWZrr
    0U,	// VPMULHRSWZrrk
    0U,	// VPMULHRSWZrrkz
    0U,	// VPMULHRSWrm
    0U,	// VPMULHRSWrr
    0U,	// VPMULHUWYrm
    0U,	// VPMULHUWYrr
    0U,	// VPMULHUWZ128rm
    0U,	// VPMULHUWZ128rmk
    0U,	// VPMULHUWZ128rmkz
    0U,	// VPMULHUWZ128rr
    0U,	// VPMULHUWZ128rrk
    0U,	// VPMULHUWZ128rrkz
    0U,	// VPMULHUWZ256rm
    0U,	// VPMULHUWZ256rmk
    0U,	// VPMULHUWZ256rmkz
    0U,	// VPMULHUWZ256rr
    0U,	// VPMULHUWZ256rrk
    0U,	// VPMULHUWZ256rrkz
    0U,	// VPMULHUWZrm
    0U,	// VPMULHUWZrmk
    0U,	// VPMULHUWZrmkz
    0U,	// VPMULHUWZrr
    0U,	// VPMULHUWZrrk
    0U,	// VPMULHUWZrrkz
    0U,	// VPMULHUWrm
    0U,	// VPMULHUWrr
    0U,	// VPMULHWYrm
    0U,	// VPMULHWYrr
    0U,	// VPMULHWZ128rm
    0U,	// VPMULHWZ128rmk
    0U,	// VPMULHWZ128rmkz
    0U,	// VPMULHWZ128rr
    0U,	// VPMULHWZ128rrk
    0U,	// VPMULHWZ128rrkz
    0U,	// VPMULHWZ256rm
    0U,	// VPMULHWZ256rmk
    0U,	// VPMULHWZ256rmkz
    0U,	// VPMULHWZ256rr
    0U,	// VPMULHWZ256rrk
    0U,	// VPMULHWZ256rrkz
    0U,	// VPMULHWZrm
    0U,	// VPMULHWZrmk
    0U,	// VPMULHWZrmkz
    0U,	// VPMULHWZrr
    0U,	// VPMULHWZrrk
    0U,	// VPMULHWZrrkz
    0U,	// VPMULHWrm
    0U,	// VPMULHWrr
    0U,	// VPMULLDYrm
    0U,	// VPMULLDYrr
    0U,	// VPMULLDZ128rm
    0U,	// VPMULLDZ128rmb
    0U,	// VPMULLDZ128rmbk
    0U,	// VPMULLDZ128rmbkz
    0U,	// VPMULLDZ128rmk
    0U,	// VPMULLDZ128rmkz
    0U,	// VPMULLDZ128rr
    0U,	// VPMULLDZ128rrk
    0U,	// VPMULLDZ128rrkz
    0U,	// VPMULLDZ256rm
    0U,	// VPMULLDZ256rmb
    0U,	// VPMULLDZ256rmbk
    0U,	// VPMULLDZ256rmbkz
    0U,	// VPMULLDZ256rmk
    0U,	// VPMULLDZ256rmkz
    0U,	// VPMULLDZ256rr
    0U,	// VPMULLDZ256rrk
    0U,	// VPMULLDZ256rrkz
    0U,	// VPMULLDZrm
    0U,	// VPMULLDZrmb
    0U,	// VPMULLDZrmbk
    0U,	// VPMULLDZrmbkz
    0U,	// VPMULLDZrmk
    0U,	// VPMULLDZrmkz
    0U,	// VPMULLDZrr
    0U,	// VPMULLDZrrk
    0U,	// VPMULLDZrrkz
    0U,	// VPMULLDrm
    0U,	// VPMULLDrr
    0U,	// VPMULLQZ128rm
    0U,	// VPMULLQZ128rmb
    0U,	// VPMULLQZ128rmbk
    0U,	// VPMULLQZ128rmbkz
    0U,	// VPMULLQZ128rmk
    0U,	// VPMULLQZ128rmkz
    0U,	// VPMULLQZ128rr
    0U,	// VPMULLQZ128rrk
    0U,	// VPMULLQZ128rrkz
    0U,	// VPMULLQZ256rm
    0U,	// VPMULLQZ256rmb
    0U,	// VPMULLQZ256rmbk
    0U,	// VPMULLQZ256rmbkz
    0U,	// VPMULLQZ256rmk
    0U,	// VPMULLQZ256rmkz
    0U,	// VPMULLQZ256rr
    0U,	// VPMULLQZ256rrk
    0U,	// VPMULLQZ256rrkz
    0U,	// VPMULLQZrm
    0U,	// VPMULLQZrmb
    0U,	// VPMULLQZrmbk
    0U,	// VPMULLQZrmbkz
    0U,	// VPMULLQZrmk
    0U,	// VPMULLQZrmkz
    0U,	// VPMULLQZrr
    0U,	// VPMULLQZrrk
    0U,	// VPMULLQZrrkz
    0U,	// VPMULLWYrm
    0U,	// VPMULLWYrr
    0U,	// VPMULLWZ128rm
    0U,	// VPMULLWZ128rmk
    0U,	// VPMULLWZ128rmkz
    0U,	// VPMULLWZ128rr
    0U,	// VPMULLWZ128rrk
    0U,	// VPMULLWZ128rrkz
    0U,	// VPMULLWZ256rm
    0U,	// VPMULLWZ256rmk
    0U,	// VPMULLWZ256rmkz
    0U,	// VPMULLWZ256rr
    0U,	// VPMULLWZ256rrk
    0U,	// VPMULLWZ256rrkz
    0U,	// VPMULLWZrm
    0U,	// VPMULLWZrmk
    0U,	// VPMULLWZrmkz
    0U,	// VPMULLWZrr
    0U,	// VPMULLWZrrk
    0U,	// VPMULLWZrrkz
    0U,	// VPMULLWrm
    0U,	// VPMULLWrr
    0U,	// VPMULTISHIFTQBZ128rm
    0U,	// VPMULTISHIFTQBZ128rmb
    0U,	// VPMULTISHIFTQBZ128rmbk
    0U,	// VPMULTISHIFTQBZ128rmbkz
    0U,	// VPMULTISHIFTQBZ128rmk
    0U,	// VPMULTISHIFTQBZ128rmkz
    0U,	// VPMULTISHIFTQBZ128rr
    0U,	// VPMULTISHIFTQBZ128rrk
    0U,	// VPMULTISHIFTQBZ128rrkz
    0U,	// VPMULTISHIFTQBZ256rm
    0U,	// VPMULTISHIFTQBZ256rmb
    0U,	// VPMULTISHIFTQBZ256rmbk
    0U,	// VPMULTISHIFTQBZ256rmbkz
    0U,	// VPMULTISHIFTQBZ256rmk
    0U,	// VPMULTISHIFTQBZ256rmkz
    0U,	// VPMULTISHIFTQBZ256rr
    0U,	// VPMULTISHIFTQBZ256rrk
    0U,	// VPMULTISHIFTQBZ256rrkz
    0U,	// VPMULTISHIFTQBZrm
    0U,	// VPMULTISHIFTQBZrmb
    0U,	// VPMULTISHIFTQBZrmbk
    0U,	// VPMULTISHIFTQBZrmbkz
    0U,	// VPMULTISHIFTQBZrmk
    0U,	// VPMULTISHIFTQBZrmkz
    0U,	// VPMULTISHIFTQBZrr
    0U,	// VPMULTISHIFTQBZrrk
    0U,	// VPMULTISHIFTQBZrrkz
    0U,	// VPMULUDQYrm
    0U,	// VPMULUDQYrr
    0U,	// VPMULUDQZ128rm
    0U,	// VPMULUDQZ128rmb
    0U,	// VPMULUDQZ128rmbk
    0U,	// VPMULUDQZ128rmbkz
    0U,	// VPMULUDQZ128rmk
    0U,	// VPMULUDQZ128rmkz
    0U,	// VPMULUDQZ128rr
    0U,	// VPMULUDQZ128rrk
    0U,	// VPMULUDQZ128rrkz
    0U,	// VPMULUDQZ256rm
    0U,	// VPMULUDQZ256rmb
    0U,	// VPMULUDQZ256rmbk
    0U,	// VPMULUDQZ256rmbkz
    0U,	// VPMULUDQZ256rmk
    0U,	// VPMULUDQZ256rmkz
    0U,	// VPMULUDQZ256rr
    0U,	// VPMULUDQZ256rrk
    0U,	// VPMULUDQZ256rrkz
    0U,	// VPMULUDQZrm
    0U,	// VPMULUDQZrmb
    0U,	// VPMULUDQZrmbk
    0U,	// VPMULUDQZrmbkz
    0U,	// VPMULUDQZrmk
    0U,	// VPMULUDQZrmkz
    0U,	// VPMULUDQZrr
    0U,	// VPMULUDQZrrk
    0U,	// VPMULUDQZrrkz
    0U,	// VPMULUDQrm
    0U,	// VPMULUDQrr
    0U,	// VPOPCNTBZ128rm
    0U,	// VPOPCNTBZ128rmk
    0U,	// VPOPCNTBZ128rmkz
    0U,	// VPOPCNTBZ128rr
    0U,	// VPOPCNTBZ128rrk
    0U,	// VPOPCNTBZ128rrkz
    0U,	// VPOPCNTBZ256rm
    0U,	// VPOPCNTBZ256rmk
    0U,	// VPOPCNTBZ256rmkz
    0U,	// VPOPCNTBZ256rr
    0U,	// VPOPCNTBZ256rrk
    0U,	// VPOPCNTBZ256rrkz
    0U,	// VPOPCNTBZrm
    0U,	// VPOPCNTBZrmk
    0U,	// VPOPCNTBZrmkz
    0U,	// VPOPCNTBZrr
    0U,	// VPOPCNTBZrrk
    0U,	// VPOPCNTBZrrkz
    0U,	// VPOPCNTDZ128rm
    0U,	// VPOPCNTDZ128rmb
    0U,	// VPOPCNTDZ128rmbk
    0U,	// VPOPCNTDZ128rmbkz
    0U,	// VPOPCNTDZ128rmk
    0U,	// VPOPCNTDZ128rmkz
    0U,	// VPOPCNTDZ128rr
    0U,	// VPOPCNTDZ128rrk
    0U,	// VPOPCNTDZ128rrkz
    0U,	// VPOPCNTDZ256rm
    0U,	// VPOPCNTDZ256rmb
    0U,	// VPOPCNTDZ256rmbk
    0U,	// VPOPCNTDZ256rmbkz
    0U,	// VPOPCNTDZ256rmk
    0U,	// VPOPCNTDZ256rmkz
    0U,	// VPOPCNTDZ256rr
    0U,	// VPOPCNTDZ256rrk
    0U,	// VPOPCNTDZ256rrkz
    0U,	// VPOPCNTDZrm
    0U,	// VPOPCNTDZrmb
    0U,	// VPOPCNTDZrmbk
    0U,	// VPOPCNTDZrmbkz
    0U,	// VPOPCNTDZrmk
    0U,	// VPOPCNTDZrmkz
    0U,	// VPOPCNTDZrr
    0U,	// VPOPCNTDZrrk
    0U,	// VPOPCNTDZrrkz
    0U,	// VPOPCNTQZ128rm
    0U,	// VPOPCNTQZ128rmb
    0U,	// VPOPCNTQZ128rmbk
    0U,	// VPOPCNTQZ128rmbkz
    0U,	// VPOPCNTQZ128rmk
    0U,	// VPOPCNTQZ128rmkz
    0U,	// VPOPCNTQZ128rr
    0U,	// VPOPCNTQZ128rrk
    0U,	// VPOPCNTQZ128rrkz
    0U,	// VPOPCNTQZ256rm
    0U,	// VPOPCNTQZ256rmb
    0U,	// VPOPCNTQZ256rmbk
    0U,	// VPOPCNTQZ256rmbkz
    0U,	// VPOPCNTQZ256rmk
    0U,	// VPOPCNTQZ256rmkz
    0U,	// VPOPCNTQZ256rr
    0U,	// VPOPCNTQZ256rrk
    0U,	// VPOPCNTQZ256rrkz
    0U,	// VPOPCNTQZrm
    0U,	// VPOPCNTQZrmb
    0U,	// VPOPCNTQZrmbk
    0U,	// VPOPCNTQZrmbkz
    0U,	// VPOPCNTQZrmk
    0U,	// VPOPCNTQZrmkz
    0U,	// VPOPCNTQZrr
    0U,	// VPOPCNTQZrrk
    0U,	// VPOPCNTQZrrkz
    0U,	// VPOPCNTWZ128rm
    0U,	// VPOPCNTWZ128rmk
    0U,	// VPOPCNTWZ128rmkz
    0U,	// VPOPCNTWZ128rr
    0U,	// VPOPCNTWZ128rrk
    0U,	// VPOPCNTWZ128rrkz
    0U,	// VPOPCNTWZ256rm
    0U,	// VPOPCNTWZ256rmk
    0U,	// VPOPCNTWZ256rmkz
    0U,	// VPOPCNTWZ256rr
    0U,	// VPOPCNTWZ256rrk
    0U,	// VPOPCNTWZ256rrkz
    0U,	// VPOPCNTWZrm
    0U,	// VPOPCNTWZrmk
    0U,	// VPOPCNTWZrmkz
    0U,	// VPOPCNTWZrr
    0U,	// VPOPCNTWZrrk
    0U,	// VPOPCNTWZrrkz
    0U,	// VPORDZ128rm
    0U,	// VPORDZ128rmb
    0U,	// VPORDZ128rmbk
    0U,	// VPORDZ128rmbkz
    0U,	// VPORDZ128rmk
    0U,	// VPORDZ128rmkz
    0U,	// VPORDZ128rr
    0U,	// VPORDZ128rrk
    0U,	// VPORDZ128rrkz
    0U,	// VPORDZ256rm
    0U,	// VPORDZ256rmb
    0U,	// VPORDZ256rmbk
    0U,	// VPORDZ256rmbkz
    0U,	// VPORDZ256rmk
    0U,	// VPORDZ256rmkz
    0U,	// VPORDZ256rr
    0U,	// VPORDZ256rrk
    0U,	// VPORDZ256rrkz
    0U,	// VPORDZrm
    0U,	// VPORDZrmb
    0U,	// VPORDZrmbk
    0U,	// VPORDZrmbkz
    0U,	// VPORDZrmk
    0U,	// VPORDZrmkz
    0U,	// VPORDZrr
    0U,	// VPORDZrrk
    0U,	// VPORDZrrkz
    0U,	// VPORQZ128rm
    0U,	// VPORQZ128rmb
    0U,	// VPORQZ128rmbk
    0U,	// VPORQZ128rmbkz
    0U,	// VPORQZ128rmk
    0U,	// VPORQZ128rmkz
    0U,	// VPORQZ128rr
    0U,	// VPORQZ128rrk
    0U,	// VPORQZ128rrkz
    0U,	// VPORQZ256rm
    0U,	// VPORQZ256rmb
    0U,	// VPORQZ256rmbk
    0U,	// VPORQZ256rmbkz
    0U,	// VPORQZ256rmk
    0U,	// VPORQZ256rmkz
    0U,	// VPORQZ256rr
    0U,	// VPORQZ256rrk
    0U,	// VPORQZ256rrkz
    0U,	// VPORQZrm
    0U,	// VPORQZrmb
    0U,	// VPORQZrmbk
    0U,	// VPORQZrmbkz
    0U,	// VPORQZrmk
    0U,	// VPORQZrmkz
    0U,	// VPORQZrr
    0U,	// VPORQZrrk
    0U,	// VPORQZrrkz
    0U,	// VPORYrm
    0U,	// VPORYrr
    0U,	// VPORrm
    0U,	// VPORrr
    0U,	// VPPERMrmr
    0U,	// VPPERMrrm
    0U,	// VPPERMrrr
    0U,	// VPPERMrrr_REV
    0U,	// VPROLDZ128mbi
    0U,	// VPROLDZ128mbik
    0U,	// VPROLDZ128mbikz
    0U,	// VPROLDZ128mi
    0U,	// VPROLDZ128mik
    0U,	// VPROLDZ128mikz
    0U,	// VPROLDZ128ri
    0U,	// VPROLDZ128rik
    0U,	// VPROLDZ128rikz
    0U,	// VPROLDZ256mbi
    0U,	// VPROLDZ256mbik
    0U,	// VPROLDZ256mbikz
    0U,	// VPROLDZ256mi
    0U,	// VPROLDZ256mik
    0U,	// VPROLDZ256mikz
    0U,	// VPROLDZ256ri
    0U,	// VPROLDZ256rik
    0U,	// VPROLDZ256rikz
    0U,	// VPROLDZmbi
    0U,	// VPROLDZmbik
    0U,	// VPROLDZmbikz
    0U,	// VPROLDZmi
    0U,	// VPROLDZmik
    0U,	// VPROLDZmikz
    0U,	// VPROLDZri
    0U,	// VPROLDZrik
    0U,	// VPROLDZrikz
    0U,	// VPROLQZ128mbi
    0U,	// VPROLQZ128mbik
    0U,	// VPROLQZ128mbikz
    0U,	// VPROLQZ128mi
    0U,	// VPROLQZ128mik
    0U,	// VPROLQZ128mikz
    0U,	// VPROLQZ128ri
    0U,	// VPROLQZ128rik
    0U,	// VPROLQZ128rikz
    0U,	// VPROLQZ256mbi
    0U,	// VPROLQZ256mbik
    0U,	// VPROLQZ256mbikz
    0U,	// VPROLQZ256mi
    0U,	// VPROLQZ256mik
    0U,	// VPROLQZ256mikz
    0U,	// VPROLQZ256ri
    0U,	// VPROLQZ256rik
    0U,	// VPROLQZ256rikz
    0U,	// VPROLQZmbi
    0U,	// VPROLQZmbik
    0U,	// VPROLQZmbikz
    0U,	// VPROLQZmi
    0U,	// VPROLQZmik
    0U,	// VPROLQZmikz
    0U,	// VPROLQZri
    0U,	// VPROLQZrik
    0U,	// VPROLQZrikz
    0U,	// VPROLVDZ128rm
    0U,	// VPROLVDZ128rmb
    0U,	// VPROLVDZ128rmbk
    0U,	// VPROLVDZ128rmbkz
    0U,	// VPROLVDZ128rmk
    0U,	// VPROLVDZ128rmkz
    0U,	// VPROLVDZ128rr
    0U,	// VPROLVDZ128rrk
    0U,	// VPROLVDZ128rrkz
    0U,	// VPROLVDZ256rm
    0U,	// VPROLVDZ256rmb
    0U,	// VPROLVDZ256rmbk
    0U,	// VPROLVDZ256rmbkz
    0U,	// VPROLVDZ256rmk
    0U,	// VPROLVDZ256rmkz
    0U,	// VPROLVDZ256rr
    0U,	// VPROLVDZ256rrk
    0U,	// VPROLVDZ256rrkz
    0U,	// VPROLVDZrm
    0U,	// VPROLVDZrmb
    0U,	// VPROLVDZrmbk
    0U,	// VPROLVDZrmbkz
    0U,	// VPROLVDZrmk
    0U,	// VPROLVDZrmkz
    0U,	// VPROLVDZrr
    0U,	// VPROLVDZrrk
    0U,	// VPROLVDZrrkz
    0U,	// VPROLVQZ128rm
    0U,	// VPROLVQZ128rmb
    0U,	// VPROLVQZ128rmbk
    0U,	// VPROLVQZ128rmbkz
    0U,	// VPROLVQZ128rmk
    0U,	// VPROLVQZ128rmkz
    0U,	// VPROLVQZ128rr
    0U,	// VPROLVQZ128rrk
    0U,	// VPROLVQZ128rrkz
    0U,	// VPROLVQZ256rm
    0U,	// VPROLVQZ256rmb
    0U,	// VPROLVQZ256rmbk
    0U,	// VPROLVQZ256rmbkz
    0U,	// VPROLVQZ256rmk
    0U,	// VPROLVQZ256rmkz
    0U,	// VPROLVQZ256rr
    0U,	// VPROLVQZ256rrk
    0U,	// VPROLVQZ256rrkz
    0U,	// VPROLVQZrm
    0U,	// VPROLVQZrmb
    0U,	// VPROLVQZrmbk
    0U,	// VPROLVQZrmbkz
    0U,	// VPROLVQZrmk
    0U,	// VPROLVQZrmkz
    0U,	// VPROLVQZrr
    0U,	// VPROLVQZrrk
    0U,	// VPROLVQZrrkz
    0U,	// VPRORDZ128mbi
    0U,	// VPRORDZ128mbik
    0U,	// VPRORDZ128mbikz
    0U,	// VPRORDZ128mi
    0U,	// VPRORDZ128mik
    0U,	// VPRORDZ128mikz
    0U,	// VPRORDZ128ri
    0U,	// VPRORDZ128rik
    0U,	// VPRORDZ128rikz
    0U,	// VPRORDZ256mbi
    0U,	// VPRORDZ256mbik
    0U,	// VPRORDZ256mbikz
    0U,	// VPRORDZ256mi
    0U,	// VPRORDZ256mik
    0U,	// VPRORDZ256mikz
    0U,	// VPRORDZ256ri
    0U,	// VPRORDZ256rik
    0U,	// VPRORDZ256rikz
    0U,	// VPRORDZmbi
    0U,	// VPRORDZmbik
    0U,	// VPRORDZmbikz
    0U,	// VPRORDZmi
    0U,	// VPRORDZmik
    0U,	// VPRORDZmikz
    0U,	// VPRORDZri
    0U,	// VPRORDZrik
    0U,	// VPRORDZrikz
    0U,	// VPRORQZ128mbi
    0U,	// VPRORQZ128mbik
    0U,	// VPRORQZ128mbikz
    0U,	// VPRORQZ128mi
    0U,	// VPRORQZ128mik
    0U,	// VPRORQZ128mikz
    0U,	// VPRORQZ128ri
    0U,	// VPRORQZ128rik
    0U,	// VPRORQZ128rikz
    0U,	// VPRORQZ256mbi
    0U,	// VPRORQZ256mbik
    0U,	// VPRORQZ256mbikz
    0U,	// VPRORQZ256mi
    0U,	// VPRORQZ256mik
    0U,	// VPRORQZ256mikz
    0U,	// VPRORQZ256ri
    0U,	// VPRORQZ256rik
    0U,	// VPRORQZ256rikz
    0U,	// VPRORQZmbi
    0U,	// VPRORQZmbik
    0U,	// VPRORQZmbikz
    0U,	// VPRORQZmi
    0U,	// VPRORQZmik
    0U,	// VPRORQZmikz
    0U,	// VPRORQZri
    0U,	// VPRORQZrik
    0U,	// VPRORQZrikz
    0U,	// VPRORVDZ128rm
    0U,	// VPRORVDZ128rmb
    0U,	// VPRORVDZ128rmbk
    0U,	// VPRORVDZ128rmbkz
    0U,	// VPRORVDZ128rmk
    0U,	// VPRORVDZ128rmkz
    0U,	// VPRORVDZ128rr
    0U,	// VPRORVDZ128rrk
    0U,	// VPRORVDZ128rrkz
    0U,	// VPRORVDZ256rm
    0U,	// VPRORVDZ256rmb
    0U,	// VPRORVDZ256rmbk
    0U,	// VPRORVDZ256rmbkz
    0U,	// VPRORVDZ256rmk
    0U,	// VPRORVDZ256rmkz
    0U,	// VPRORVDZ256rr
    0U,	// VPRORVDZ256rrk
    0U,	// VPRORVDZ256rrkz
    0U,	// VPRORVDZrm
    0U,	// VPRORVDZrmb
    0U,	// VPRORVDZrmbk
    0U,	// VPRORVDZrmbkz
    0U,	// VPRORVDZrmk
    0U,	// VPRORVDZrmkz
    0U,	// VPRORVDZrr
    0U,	// VPRORVDZrrk
    0U,	// VPRORVDZrrkz
    0U,	// VPRORVQZ128rm
    0U,	// VPRORVQZ128rmb
    0U,	// VPRORVQZ128rmbk
    0U,	// VPRORVQZ128rmbkz
    0U,	// VPRORVQZ128rmk
    0U,	// VPRORVQZ128rmkz
    0U,	// VPRORVQZ128rr
    0U,	// VPRORVQZ128rrk
    0U,	// VPRORVQZ128rrkz
    0U,	// VPRORVQZ256rm
    0U,	// VPRORVQZ256rmb
    0U,	// VPRORVQZ256rmbk
    0U,	// VPRORVQZ256rmbkz
    0U,	// VPRORVQZ256rmk
    0U,	// VPRORVQZ256rmkz
    0U,	// VPRORVQZ256rr
    0U,	// VPRORVQZ256rrk
    0U,	// VPRORVQZ256rrkz
    0U,	// VPRORVQZrm
    0U,	// VPRORVQZrmb
    0U,	// VPRORVQZrmbk
    0U,	// VPRORVQZrmbkz
    0U,	// VPRORVQZrmk
    0U,	// VPRORVQZrmkz
    0U,	// VPRORVQZrr
    0U,	// VPRORVQZrrk
    0U,	// VPRORVQZrrkz
    0U,	// VPROTBmi
    0U,	// VPROTBmr
    0U,	// VPROTBri
    0U,	// VPROTBrm
    0U,	// VPROTBrr
    0U,	// VPROTBrr_REV
    0U,	// VPROTDmi
    0U,	// VPROTDmr
    0U,	// VPROTDri
    0U,	// VPROTDrm
    0U,	// VPROTDrr
    0U,	// VPROTDrr_REV
    0U,	// VPROTQmi
    0U,	// VPROTQmr
    0U,	// VPROTQri
    0U,	// VPROTQrm
    0U,	// VPROTQrr
    0U,	// VPROTQrr_REV
    0U,	// VPROTWmi
    0U,	// VPROTWmr
    0U,	// VPROTWri
    0U,	// VPROTWrm
    0U,	// VPROTWrr
    0U,	// VPROTWrr_REV
    0U,	// VPSADBWYrm
    0U,	// VPSADBWYrr
    0U,	// VPSADBWZ128rm
    0U,	// VPSADBWZ128rr
    0U,	// VPSADBWZ256rm
    0U,	// VPSADBWZ256rr
    0U,	// VPSADBWZrm
    0U,	// VPSADBWZrr
    0U,	// VPSADBWrm
    0U,	// VPSADBWrr
    0U,	// VPSCATTERDDZ128mr
    0U,	// VPSCATTERDDZ256mr
    0U,	// VPSCATTERDDZmr
    0U,	// VPSCATTERDQZ128mr
    0U,	// VPSCATTERDQZ256mr
    0U,	// VPSCATTERDQZmr
    0U,	// VPSCATTERQDZ128mr
    0U,	// VPSCATTERQDZ256mr
    0U,	// VPSCATTERQDZmr
    0U,	// VPSCATTERQQZ128mr
    0U,	// VPSCATTERQQZ256mr
    0U,	// VPSCATTERQQZmr
    0U,	// VPSHABmr
    0U,	// VPSHABrm
    0U,	// VPSHABrr
    0U,	// VPSHABrr_REV
    0U,	// VPSHADmr
    0U,	// VPSHADrm
    0U,	// VPSHADrr
    0U,	// VPSHADrr_REV
    0U,	// VPSHAQmr
    0U,	// VPSHAQrm
    0U,	// VPSHAQrr
    0U,	// VPSHAQrr_REV
    0U,	// VPSHAWmr
    0U,	// VPSHAWrm
    0U,	// VPSHAWrr
    0U,	// VPSHAWrr_REV
    0U,	// VPSHLBmr
    0U,	// VPSHLBrm
    0U,	// VPSHLBrr
    0U,	// VPSHLBrr_REV
    0U,	// VPSHLDDZ128rmbi
    0U,	// VPSHLDDZ128rmbik
    3U,	// VPSHLDDZ128rmbikz
    0U,	// VPSHLDDZ128rmi
    0U,	// VPSHLDDZ128rmik
    0U,	// VPSHLDDZ128rmikz
    0U,	// VPSHLDDZ128rri
    0U,	// VPSHLDDZ128rrik
    3U,	// VPSHLDDZ128rrikz
    0U,	// VPSHLDDZ256rmbi
    0U,	// VPSHLDDZ256rmbik
    3U,	// VPSHLDDZ256rmbikz
    0U,	// VPSHLDDZ256rmi
    0U,	// VPSHLDDZ256rmik
    0U,	// VPSHLDDZ256rmikz
    0U,	// VPSHLDDZ256rri
    0U,	// VPSHLDDZ256rrik
    3U,	// VPSHLDDZ256rrikz
    0U,	// VPSHLDDZrmbi
    0U,	// VPSHLDDZrmbik
    3U,	// VPSHLDDZrmbikz
    0U,	// VPSHLDDZrmi
    0U,	// VPSHLDDZrmik
    0U,	// VPSHLDDZrmikz
    0U,	// VPSHLDDZrri
    0U,	// VPSHLDDZrrik
    3U,	// VPSHLDDZrrikz
    0U,	// VPSHLDQZ128rmbi
    0U,	// VPSHLDQZ128rmbik
    3U,	// VPSHLDQZ128rmbikz
    0U,	// VPSHLDQZ128rmi
    0U,	// VPSHLDQZ128rmik
    0U,	// VPSHLDQZ128rmikz
    0U,	// VPSHLDQZ128rri
    0U,	// VPSHLDQZ128rrik
    3U,	// VPSHLDQZ128rrikz
    0U,	// VPSHLDQZ256rmbi
    0U,	// VPSHLDQZ256rmbik
    3U,	// VPSHLDQZ256rmbikz
    0U,	// VPSHLDQZ256rmi
    0U,	// VPSHLDQZ256rmik
    0U,	// VPSHLDQZ256rmikz
    0U,	// VPSHLDQZ256rri
    0U,	// VPSHLDQZ256rrik
    3U,	// VPSHLDQZ256rrikz
    0U,	// VPSHLDQZrmbi
    0U,	// VPSHLDQZrmbik
    3U,	// VPSHLDQZrmbikz
    0U,	// VPSHLDQZrmi
    0U,	// VPSHLDQZrmik
    0U,	// VPSHLDQZrmikz
    0U,	// VPSHLDQZrri
    0U,	// VPSHLDQZrrik
    3U,	// VPSHLDQZrrikz
    0U,	// VPSHLDVDZ128m
    0U,	// VPSHLDVDZ128mb
    0U,	// VPSHLDVDZ128mbk
    0U,	// VPSHLDVDZ128mbkz
    0U,	// VPSHLDVDZ128mk
    0U,	// VPSHLDVDZ128mkz
    0U,	// VPSHLDVDZ128r
    0U,	// VPSHLDVDZ128rk
    0U,	// VPSHLDVDZ128rkz
    0U,	// VPSHLDVDZ256m
    0U,	// VPSHLDVDZ256mb
    0U,	// VPSHLDVDZ256mbk
    0U,	// VPSHLDVDZ256mbkz
    0U,	// VPSHLDVDZ256mk
    0U,	// VPSHLDVDZ256mkz
    0U,	// VPSHLDVDZ256r
    0U,	// VPSHLDVDZ256rk
    0U,	// VPSHLDVDZ256rkz
    0U,	// VPSHLDVDZm
    0U,	// VPSHLDVDZmb
    0U,	// VPSHLDVDZmbk
    0U,	// VPSHLDVDZmbkz
    0U,	// VPSHLDVDZmk
    0U,	// VPSHLDVDZmkz
    0U,	// VPSHLDVDZr
    0U,	// VPSHLDVDZrk
    0U,	// VPSHLDVDZrkz
    0U,	// VPSHLDVQZ128m
    0U,	// VPSHLDVQZ128mb
    0U,	// VPSHLDVQZ128mbk
    0U,	// VPSHLDVQZ128mbkz
    0U,	// VPSHLDVQZ128mk
    0U,	// VPSHLDVQZ128mkz
    0U,	// VPSHLDVQZ128r
    0U,	// VPSHLDVQZ128rk
    0U,	// VPSHLDVQZ128rkz
    0U,	// VPSHLDVQZ256m
    0U,	// VPSHLDVQZ256mb
    0U,	// VPSHLDVQZ256mbk
    0U,	// VPSHLDVQZ256mbkz
    0U,	// VPSHLDVQZ256mk
    0U,	// VPSHLDVQZ256mkz
    0U,	// VPSHLDVQZ256r
    0U,	// VPSHLDVQZ256rk
    0U,	// VPSHLDVQZ256rkz
    0U,	// VPSHLDVQZm
    0U,	// VPSHLDVQZmb
    0U,	// VPSHLDVQZmbk
    0U,	// VPSHLDVQZmbkz
    0U,	// VPSHLDVQZmk
    0U,	// VPSHLDVQZmkz
    0U,	// VPSHLDVQZr
    0U,	// VPSHLDVQZrk
    0U,	// VPSHLDVQZrkz
    0U,	// VPSHLDVWZ128m
    0U,	// VPSHLDVWZ128mk
    0U,	// VPSHLDVWZ128mkz
    0U,	// VPSHLDVWZ128r
    0U,	// VPSHLDVWZ128rk
    0U,	// VPSHLDVWZ128rkz
    0U,	// VPSHLDVWZ256m
    0U,	// VPSHLDVWZ256mk
    0U,	// VPSHLDVWZ256mkz
    0U,	// VPSHLDVWZ256r
    0U,	// VPSHLDVWZ256rk
    0U,	// VPSHLDVWZ256rkz
    0U,	// VPSHLDVWZm
    0U,	// VPSHLDVWZmk
    0U,	// VPSHLDVWZmkz
    0U,	// VPSHLDVWZr
    0U,	// VPSHLDVWZrk
    0U,	// VPSHLDVWZrkz
    0U,	// VPSHLDWZ128rmi
    0U,	// VPSHLDWZ128rmik
    0U,	// VPSHLDWZ128rmikz
    0U,	// VPSHLDWZ128rri
    0U,	// VPSHLDWZ128rrik
    3U,	// VPSHLDWZ128rrikz
    0U,	// VPSHLDWZ256rmi
    0U,	// VPSHLDWZ256rmik
    0U,	// VPSHLDWZ256rmikz
    0U,	// VPSHLDWZ256rri
    0U,	// VPSHLDWZ256rrik
    3U,	// VPSHLDWZ256rrikz
    0U,	// VPSHLDWZrmi
    0U,	// VPSHLDWZrmik
    0U,	// VPSHLDWZrmikz
    0U,	// VPSHLDWZrri
    0U,	// VPSHLDWZrrik
    3U,	// VPSHLDWZrrikz
    0U,	// VPSHLDmr
    0U,	// VPSHLDrm
    0U,	// VPSHLDrr
    0U,	// VPSHLDrr_REV
    0U,	// VPSHLQmr
    0U,	// VPSHLQrm
    0U,	// VPSHLQrr
    0U,	// VPSHLQrr_REV
    0U,	// VPSHLWmr
    0U,	// VPSHLWrm
    0U,	// VPSHLWrr
    0U,	// VPSHLWrr_REV
    0U,	// VPSHRDDZ128rmbi
    0U,	// VPSHRDDZ128rmbik
    3U,	// VPSHRDDZ128rmbikz
    0U,	// VPSHRDDZ128rmi
    0U,	// VPSHRDDZ128rmik
    0U,	// VPSHRDDZ128rmikz
    0U,	// VPSHRDDZ128rri
    0U,	// VPSHRDDZ128rrik
    3U,	// VPSHRDDZ128rrikz
    0U,	// VPSHRDDZ256rmbi
    0U,	// VPSHRDDZ256rmbik
    3U,	// VPSHRDDZ256rmbikz
    0U,	// VPSHRDDZ256rmi
    0U,	// VPSHRDDZ256rmik
    0U,	// VPSHRDDZ256rmikz
    0U,	// VPSHRDDZ256rri
    0U,	// VPSHRDDZ256rrik
    3U,	// VPSHRDDZ256rrikz
    0U,	// VPSHRDDZrmbi
    0U,	// VPSHRDDZrmbik
    3U,	// VPSHRDDZrmbikz
    0U,	// VPSHRDDZrmi
    0U,	// VPSHRDDZrmik
    0U,	// VPSHRDDZrmikz
    0U,	// VPSHRDDZrri
    0U,	// VPSHRDDZrrik
    3U,	// VPSHRDDZrrikz
    0U,	// VPSHRDQZ128rmbi
    0U,	// VPSHRDQZ128rmbik
    3U,	// VPSHRDQZ128rmbikz
    0U,	// VPSHRDQZ128rmi
    0U,	// VPSHRDQZ128rmik
    0U,	// VPSHRDQZ128rmikz
    0U,	// VPSHRDQZ128rri
    0U,	// VPSHRDQZ128rrik
    3U,	// VPSHRDQZ128rrikz
    0U,	// VPSHRDQZ256rmbi
    0U,	// VPSHRDQZ256rmbik
    3U,	// VPSHRDQZ256rmbikz
    0U,	// VPSHRDQZ256rmi
    0U,	// VPSHRDQZ256rmik
    0U,	// VPSHRDQZ256rmikz
    0U,	// VPSHRDQZ256rri
    0U,	// VPSHRDQZ256rrik
    3U,	// VPSHRDQZ256rrikz
    0U,	// VPSHRDQZrmbi
    0U,	// VPSHRDQZrmbik
    3U,	// VPSHRDQZrmbikz
    0U,	// VPSHRDQZrmi
    0U,	// VPSHRDQZrmik
    0U,	// VPSHRDQZrmikz
    0U,	// VPSHRDQZrri
    0U,	// VPSHRDQZrrik
    3U,	// VPSHRDQZrrikz
    0U,	// VPSHRDVDZ128m
    0U,	// VPSHRDVDZ128mb
    0U,	// VPSHRDVDZ128mbk
    0U,	// VPSHRDVDZ128mbkz
    0U,	// VPSHRDVDZ128mk
    0U,	// VPSHRDVDZ128mkz
    0U,	// VPSHRDVDZ128r
    0U,	// VPSHRDVDZ128rk
    0U,	// VPSHRDVDZ128rkz
    0U,	// VPSHRDVDZ256m
    0U,	// VPSHRDVDZ256mb
    0U,	// VPSHRDVDZ256mbk
    0U,	// VPSHRDVDZ256mbkz
    0U,	// VPSHRDVDZ256mk
    0U,	// VPSHRDVDZ256mkz
    0U,	// VPSHRDVDZ256r
    0U,	// VPSHRDVDZ256rk
    0U,	// VPSHRDVDZ256rkz
    0U,	// VPSHRDVDZm
    0U,	// VPSHRDVDZmb
    0U,	// VPSHRDVDZmbk
    0U,	// VPSHRDVDZmbkz
    0U,	// VPSHRDVDZmk
    0U,	// VPSHRDVDZmkz
    0U,	// VPSHRDVDZr
    0U,	// VPSHRDVDZrk
    0U,	// VPSHRDVDZrkz
    0U,	// VPSHRDVQZ128m
    0U,	// VPSHRDVQZ128mb
    0U,	// VPSHRDVQZ128mbk
    0U,	// VPSHRDVQZ128mbkz
    0U,	// VPSHRDVQZ128mk
    0U,	// VPSHRDVQZ128mkz
    0U,	// VPSHRDVQZ128r
    0U,	// VPSHRDVQZ128rk
    0U,	// VPSHRDVQZ128rkz
    0U,	// VPSHRDVQZ256m
    0U,	// VPSHRDVQZ256mb
    0U,	// VPSHRDVQZ256mbk
    0U,	// VPSHRDVQZ256mbkz
    0U,	// VPSHRDVQZ256mk
    0U,	// VPSHRDVQZ256mkz
    0U,	// VPSHRDVQZ256r
    0U,	// VPSHRDVQZ256rk
    0U,	// VPSHRDVQZ256rkz
    0U,	// VPSHRDVQZm
    0U,	// VPSHRDVQZmb
    0U,	// VPSHRDVQZmbk
    0U,	// VPSHRDVQZmbkz
    0U,	// VPSHRDVQZmk
    0U,	// VPSHRDVQZmkz
    0U,	// VPSHRDVQZr
    0U,	// VPSHRDVQZrk
    0U,	// VPSHRDVQZrkz
    0U,	// VPSHRDVWZ128m
    0U,	// VPSHRDVWZ128mk
    0U,	// VPSHRDVWZ128mkz
    0U,	// VPSHRDVWZ128r
    0U,	// VPSHRDVWZ128rk
    0U,	// VPSHRDVWZ128rkz
    0U,	// VPSHRDVWZ256m
    0U,	// VPSHRDVWZ256mk
    0U,	// VPSHRDVWZ256mkz
    0U,	// VPSHRDVWZ256r
    0U,	// VPSHRDVWZ256rk
    0U,	// VPSHRDVWZ256rkz
    0U,	// VPSHRDVWZm
    0U,	// VPSHRDVWZmk
    0U,	// VPSHRDVWZmkz
    0U,	// VPSHRDVWZr
    0U,	// VPSHRDVWZrk
    0U,	// VPSHRDVWZrkz
    0U,	// VPSHRDWZ128rmi
    0U,	// VPSHRDWZ128rmik
    0U,	// VPSHRDWZ128rmikz
    0U,	// VPSHRDWZ128rri
    0U,	// VPSHRDWZ128rrik
    3U,	// VPSHRDWZ128rrikz
    0U,	// VPSHRDWZ256rmi
    0U,	// VPSHRDWZ256rmik
    0U,	// VPSHRDWZ256rmikz
    0U,	// VPSHRDWZ256rri
    0U,	// VPSHRDWZ256rrik
    3U,	// VPSHRDWZ256rrikz
    0U,	// VPSHRDWZrmi
    0U,	// VPSHRDWZrmik
    0U,	// VPSHRDWZrmikz
    0U,	// VPSHRDWZrri
    0U,	// VPSHRDWZrrik
    3U,	// VPSHRDWZrrikz
    0U,	// VPSHUFBITQMBZ128rm
    0U,	// VPSHUFBITQMBZ128rmk
    0U,	// VPSHUFBITQMBZ128rr
    0U,	// VPSHUFBITQMBZ128rrk
    0U,	// VPSHUFBITQMBZ256rm
    0U,	// VPSHUFBITQMBZ256rmk
    0U,	// VPSHUFBITQMBZ256rr
    0U,	// VPSHUFBITQMBZ256rrk
    0U,	// VPSHUFBITQMBZrm
    0U,	// VPSHUFBITQMBZrmk
    0U,	// VPSHUFBITQMBZrr
    0U,	// VPSHUFBITQMBZrrk
    0U,	// VPSHUFBYrm
    0U,	// VPSHUFBYrr
    0U,	// VPSHUFBZ128rm
    0U,	// VPSHUFBZ128rmk
    0U,	// VPSHUFBZ128rmkz
    0U,	// VPSHUFBZ128rr
    0U,	// VPSHUFBZ128rrk
    0U,	// VPSHUFBZ128rrkz
    0U,	// VPSHUFBZ256rm
    0U,	// VPSHUFBZ256rmk
    0U,	// VPSHUFBZ256rmkz
    0U,	// VPSHUFBZ256rr
    0U,	// VPSHUFBZ256rrk
    0U,	// VPSHUFBZ256rrkz
    0U,	// VPSHUFBZrm
    0U,	// VPSHUFBZrmk
    0U,	// VPSHUFBZrmkz
    0U,	// VPSHUFBZrr
    0U,	// VPSHUFBZrrk
    0U,	// VPSHUFBZrrkz
    0U,	// VPSHUFBrm
    0U,	// VPSHUFBrr
    0U,	// VPSHUFDYmi
    0U,	// VPSHUFDYri
    0U,	// VPSHUFDZ128mbi
    0U,	// VPSHUFDZ128mbik
    0U,	// VPSHUFDZ128mbikz
    0U,	// VPSHUFDZ128mi
    0U,	// VPSHUFDZ128mik
    0U,	// VPSHUFDZ128mikz
    0U,	// VPSHUFDZ128ri
    0U,	// VPSHUFDZ128rik
    0U,	// VPSHUFDZ128rikz
    0U,	// VPSHUFDZ256mbi
    0U,	// VPSHUFDZ256mbik
    0U,	// VPSHUFDZ256mbikz
    0U,	// VPSHUFDZ256mi
    0U,	// VPSHUFDZ256mik
    0U,	// VPSHUFDZ256mikz
    0U,	// VPSHUFDZ256ri
    0U,	// VPSHUFDZ256rik
    0U,	// VPSHUFDZ256rikz
    0U,	// VPSHUFDZmbi
    0U,	// VPSHUFDZmbik
    0U,	// VPSHUFDZmbikz
    0U,	// VPSHUFDZmi
    0U,	// VPSHUFDZmik
    0U,	// VPSHUFDZmikz
    0U,	// VPSHUFDZri
    0U,	// VPSHUFDZrik
    0U,	// VPSHUFDZrikz
    0U,	// VPSHUFDmi
    0U,	// VPSHUFDri
    0U,	// VPSHUFHWYmi
    0U,	// VPSHUFHWYri
    0U,	// VPSHUFHWZ128mi
    0U,	// VPSHUFHWZ128mik
    0U,	// VPSHUFHWZ128mikz
    0U,	// VPSHUFHWZ128ri
    0U,	// VPSHUFHWZ128rik
    0U,	// VPSHUFHWZ128rikz
    0U,	// VPSHUFHWZ256mi
    0U,	// VPSHUFHWZ256mik
    0U,	// VPSHUFHWZ256mikz
    0U,	// VPSHUFHWZ256ri
    0U,	// VPSHUFHWZ256rik
    0U,	// VPSHUFHWZ256rikz
    0U,	// VPSHUFHWZmi
    0U,	// VPSHUFHWZmik
    0U,	// VPSHUFHWZmikz
    0U,	// VPSHUFHWZri
    0U,	// VPSHUFHWZrik
    0U,	// VPSHUFHWZrikz
    0U,	// VPSHUFHWmi
    0U,	// VPSHUFHWri
    0U,	// VPSHUFLWYmi
    0U,	// VPSHUFLWYri
    0U,	// VPSHUFLWZ128mi
    0U,	// VPSHUFLWZ128mik
    0U,	// VPSHUFLWZ128mikz
    0U,	// VPSHUFLWZ128ri
    0U,	// VPSHUFLWZ128rik
    0U,	// VPSHUFLWZ128rikz
    0U,	// VPSHUFLWZ256mi
    0U,	// VPSHUFLWZ256mik
    0U,	// VPSHUFLWZ256mikz
    0U,	// VPSHUFLWZ256ri
    0U,	// VPSHUFLWZ256rik
    0U,	// VPSHUFLWZ256rikz
    0U,	// VPSHUFLWZmi
    0U,	// VPSHUFLWZmik
    0U,	// VPSHUFLWZmikz
    0U,	// VPSHUFLWZri
    0U,	// VPSHUFLWZrik
    0U,	// VPSHUFLWZrikz
    0U,	// VPSHUFLWmi
    0U,	// VPSHUFLWri
    0U,	// VPSIGNBYrm
    0U,	// VPSIGNBYrr
    0U,	// VPSIGNBrm
    0U,	// VPSIGNBrr
    0U,	// VPSIGNDYrm
    0U,	// VPSIGNDYrr
    0U,	// VPSIGNDrm
    0U,	// VPSIGNDrr
    0U,	// VPSIGNWYrm
    0U,	// VPSIGNWYrr
    0U,	// VPSIGNWrm
    0U,	// VPSIGNWrr
    0U,	// VPSLLDQYri
    0U,	// VPSLLDQZ128rm
    0U,	// VPSLLDQZ128rr
    0U,	// VPSLLDQZ256rm
    0U,	// VPSLLDQZ256rr
    0U,	// VPSLLDQZrm
    0U,	// VPSLLDQZrr
    0U,	// VPSLLDQri
    0U,	// VPSLLDYri
    0U,	// VPSLLDYrm
    0U,	// VPSLLDYrr
    0U,	// VPSLLDZ128mbi
    0U,	// VPSLLDZ128mbik
    0U,	// VPSLLDZ128mbikz
    0U,	// VPSLLDZ128mi
    0U,	// VPSLLDZ128mik
    0U,	// VPSLLDZ128mikz
    0U,	// VPSLLDZ128ri
    0U,	// VPSLLDZ128rik
    0U,	// VPSLLDZ128rikz
    0U,	// VPSLLDZ128rm
    0U,	// VPSLLDZ128rmk
    0U,	// VPSLLDZ128rmkz
    0U,	// VPSLLDZ128rr
    0U,	// VPSLLDZ128rrk
    0U,	// VPSLLDZ128rrkz
    0U,	// VPSLLDZ256mbi
    0U,	// VPSLLDZ256mbik
    0U,	// VPSLLDZ256mbikz
    0U,	// VPSLLDZ256mi
    0U,	// VPSLLDZ256mik
    0U,	// VPSLLDZ256mikz
    0U,	// VPSLLDZ256ri
    0U,	// VPSLLDZ256rik
    0U,	// VPSLLDZ256rikz
    0U,	// VPSLLDZ256rm
    0U,	// VPSLLDZ256rmk
    0U,	// VPSLLDZ256rmkz
    0U,	// VPSLLDZ256rr
    0U,	// VPSLLDZ256rrk
    0U,	// VPSLLDZ256rrkz
    0U,	// VPSLLDZmbi
    0U,	// VPSLLDZmbik
    0U,	// VPSLLDZmbikz
    0U,	// VPSLLDZmi
    0U,	// VPSLLDZmik
    0U,	// VPSLLDZmikz
    0U,	// VPSLLDZri
    0U,	// VPSLLDZrik
    0U,	// VPSLLDZrikz
    0U,	// VPSLLDZrm
    0U,	// VPSLLDZrmk
    0U,	// VPSLLDZrmkz
    0U,	// VPSLLDZrr
    0U,	// VPSLLDZrrk
    0U,	// VPSLLDZrrkz
    0U,	// VPSLLDri
    0U,	// VPSLLDrm
    0U,	// VPSLLDrr
    0U,	// VPSLLQYri
    0U,	// VPSLLQYrm
    0U,	// VPSLLQYrr
    0U,	// VPSLLQZ128mbi
    0U,	// VPSLLQZ128mbik
    0U,	// VPSLLQZ128mbikz
    0U,	// VPSLLQZ128mi
    0U,	// VPSLLQZ128mik
    0U,	// VPSLLQZ128mikz
    0U,	// VPSLLQZ128ri
    0U,	// VPSLLQZ128rik
    0U,	// VPSLLQZ128rikz
    0U,	// VPSLLQZ128rm
    0U,	// VPSLLQZ128rmk
    0U,	// VPSLLQZ128rmkz
    0U,	// VPSLLQZ128rr
    0U,	// VPSLLQZ128rrk
    0U,	// VPSLLQZ128rrkz
    0U,	// VPSLLQZ256mbi
    0U,	// VPSLLQZ256mbik
    0U,	// VPSLLQZ256mbikz
    0U,	// VPSLLQZ256mi
    0U,	// VPSLLQZ256mik
    0U,	// VPSLLQZ256mikz
    0U,	// VPSLLQZ256ri
    0U,	// VPSLLQZ256rik
    0U,	// VPSLLQZ256rikz
    0U,	// VPSLLQZ256rm
    0U,	// VPSLLQZ256rmk
    0U,	// VPSLLQZ256rmkz
    0U,	// VPSLLQZ256rr
    0U,	// VPSLLQZ256rrk
    0U,	// VPSLLQZ256rrkz
    0U,	// VPSLLQZmbi
    0U,	// VPSLLQZmbik
    0U,	// VPSLLQZmbikz
    0U,	// VPSLLQZmi
    0U,	// VPSLLQZmik
    0U,	// VPSLLQZmikz
    0U,	// VPSLLQZri
    0U,	// VPSLLQZrik
    0U,	// VPSLLQZrikz
    0U,	// VPSLLQZrm
    0U,	// VPSLLQZrmk
    0U,	// VPSLLQZrmkz
    0U,	// VPSLLQZrr
    0U,	// VPSLLQZrrk
    0U,	// VPSLLQZrrkz
    0U,	// VPSLLQri
    0U,	// VPSLLQrm
    0U,	// VPSLLQrr
    0U,	// VPSLLVDYrm
    0U,	// VPSLLVDYrr
    0U,	// VPSLLVDZ128rm
    0U,	// VPSLLVDZ128rmb
    0U,	// VPSLLVDZ128rmbk
    0U,	// VPSLLVDZ128rmbkz
    0U,	// VPSLLVDZ128rmk
    0U,	// VPSLLVDZ128rmkz
    0U,	// VPSLLVDZ128rr
    0U,	// VPSLLVDZ128rrk
    0U,	// VPSLLVDZ128rrkz
    0U,	// VPSLLVDZ256rm
    0U,	// VPSLLVDZ256rmb
    0U,	// VPSLLVDZ256rmbk
    0U,	// VPSLLVDZ256rmbkz
    0U,	// VPSLLVDZ256rmk
    0U,	// VPSLLVDZ256rmkz
    0U,	// VPSLLVDZ256rr
    0U,	// VPSLLVDZ256rrk
    0U,	// VPSLLVDZ256rrkz
    0U,	// VPSLLVDZrm
    0U,	// VPSLLVDZrmb
    0U,	// VPSLLVDZrmbk
    0U,	// VPSLLVDZrmbkz
    0U,	// VPSLLVDZrmk
    0U,	// VPSLLVDZrmkz
    0U,	// VPSLLVDZrr
    0U,	// VPSLLVDZrrk
    0U,	// VPSLLVDZrrkz
    0U,	// VPSLLVDrm
    0U,	// VPSLLVDrr
    0U,	// VPSLLVQYrm
    0U,	// VPSLLVQYrr
    0U,	// VPSLLVQZ128rm
    0U,	// VPSLLVQZ128rmb
    0U,	// VPSLLVQZ128rmbk
    0U,	// VPSLLVQZ128rmbkz
    0U,	// VPSLLVQZ128rmk
    0U,	// VPSLLVQZ128rmkz
    0U,	// VPSLLVQZ128rr
    0U,	// VPSLLVQZ128rrk
    0U,	// VPSLLVQZ128rrkz
    0U,	// VPSLLVQZ256rm
    0U,	// VPSLLVQZ256rmb
    0U,	// VPSLLVQZ256rmbk
    0U,	// VPSLLVQZ256rmbkz
    0U,	// VPSLLVQZ256rmk
    0U,	// VPSLLVQZ256rmkz
    0U,	// VPSLLVQZ256rr
    0U,	// VPSLLVQZ256rrk
    0U,	// VPSLLVQZ256rrkz
    0U,	// VPSLLVQZrm
    0U,	// VPSLLVQZrmb
    0U,	// VPSLLVQZrmbk
    0U,	// VPSLLVQZrmbkz
    0U,	// VPSLLVQZrmk
    0U,	// VPSLLVQZrmkz
    0U,	// VPSLLVQZrr
    0U,	// VPSLLVQZrrk
    0U,	// VPSLLVQZrrkz
    0U,	// VPSLLVQrm
    0U,	// VPSLLVQrr
    0U,	// VPSLLVWZ128rm
    0U,	// VPSLLVWZ128rmk
    0U,	// VPSLLVWZ128rmkz
    0U,	// VPSLLVWZ128rr
    0U,	// VPSLLVWZ128rrk
    0U,	// VPSLLVWZ128rrkz
    0U,	// VPSLLVWZ256rm
    0U,	// VPSLLVWZ256rmk
    0U,	// VPSLLVWZ256rmkz
    0U,	// VPSLLVWZ256rr
    0U,	// VPSLLVWZ256rrk
    0U,	// VPSLLVWZ256rrkz
    0U,	// VPSLLVWZrm
    0U,	// VPSLLVWZrmk
    0U,	// VPSLLVWZrmkz
    0U,	// VPSLLVWZrr
    0U,	// VPSLLVWZrrk
    0U,	// VPSLLVWZrrkz
    0U,	// VPSLLWYri
    0U,	// VPSLLWYrm
    0U,	// VPSLLWYrr
    0U,	// VPSLLWZ128mi
    0U,	// VPSLLWZ128mik
    0U,	// VPSLLWZ128mikz
    0U,	// VPSLLWZ128ri
    0U,	// VPSLLWZ128rik
    0U,	// VPSLLWZ128rikz
    0U,	// VPSLLWZ128rm
    0U,	// VPSLLWZ128rmk
    0U,	// VPSLLWZ128rmkz
    0U,	// VPSLLWZ128rr
    0U,	// VPSLLWZ128rrk
    0U,	// VPSLLWZ128rrkz
    0U,	// VPSLLWZ256mi
    0U,	// VPSLLWZ256mik
    0U,	// VPSLLWZ256mikz
    0U,	// VPSLLWZ256ri
    0U,	// VPSLLWZ256rik
    0U,	// VPSLLWZ256rikz
    0U,	// VPSLLWZ256rm
    0U,	// VPSLLWZ256rmk
    0U,	// VPSLLWZ256rmkz
    0U,	// VPSLLWZ256rr
    0U,	// VPSLLWZ256rrk
    0U,	// VPSLLWZ256rrkz
    0U,	// VPSLLWZmi
    0U,	// VPSLLWZmik
    0U,	// VPSLLWZmikz
    0U,	// VPSLLWZri
    0U,	// VPSLLWZrik
    0U,	// VPSLLWZrikz
    0U,	// VPSLLWZrm
    0U,	// VPSLLWZrmk
    0U,	// VPSLLWZrmkz
    0U,	// VPSLLWZrr
    0U,	// VPSLLWZrrk
    0U,	// VPSLLWZrrkz
    0U,	// VPSLLWri
    0U,	// VPSLLWrm
    0U,	// VPSLLWrr
    0U,	// VPSRADYri
    0U,	// VPSRADYrm
    0U,	// VPSRADYrr
    0U,	// VPSRADZ128mbi
    0U,	// VPSRADZ128mbik
    0U,	// VPSRADZ128mbikz
    0U,	// VPSRADZ128mi
    0U,	// VPSRADZ128mik
    0U,	// VPSRADZ128mikz
    0U,	// VPSRADZ128ri
    0U,	// VPSRADZ128rik
    0U,	// VPSRADZ128rikz
    0U,	// VPSRADZ128rm
    0U,	// VPSRADZ128rmk
    0U,	// VPSRADZ128rmkz
    0U,	// VPSRADZ128rr
    0U,	// VPSRADZ128rrk
    0U,	// VPSRADZ128rrkz
    0U,	// VPSRADZ256mbi
    0U,	// VPSRADZ256mbik
    0U,	// VPSRADZ256mbikz
    0U,	// VPSRADZ256mi
    0U,	// VPSRADZ256mik
    0U,	// VPSRADZ256mikz
    0U,	// VPSRADZ256ri
    0U,	// VPSRADZ256rik
    0U,	// VPSRADZ256rikz
    0U,	// VPSRADZ256rm
    0U,	// VPSRADZ256rmk
    0U,	// VPSRADZ256rmkz
    0U,	// VPSRADZ256rr
    0U,	// VPSRADZ256rrk
    0U,	// VPSRADZ256rrkz
    0U,	// VPSRADZmbi
    0U,	// VPSRADZmbik
    0U,	// VPSRADZmbikz
    0U,	// VPSRADZmi
    0U,	// VPSRADZmik
    0U,	// VPSRADZmikz
    0U,	// VPSRADZri
    0U,	// VPSRADZrik
    0U,	// VPSRADZrikz
    0U,	// VPSRADZrm
    0U,	// VPSRADZrmk
    0U,	// VPSRADZrmkz
    0U,	// VPSRADZrr
    0U,	// VPSRADZrrk
    0U,	// VPSRADZrrkz
    0U,	// VPSRADri
    0U,	// VPSRADrm
    0U,	// VPSRADrr
    0U,	// VPSRAQZ128mbi
    0U,	// VPSRAQZ128mbik
    0U,	// VPSRAQZ128mbikz
    0U,	// VPSRAQZ128mi
    0U,	// VPSRAQZ128mik
    0U,	// VPSRAQZ128mikz
    0U,	// VPSRAQZ128ri
    0U,	// VPSRAQZ128rik
    0U,	// VPSRAQZ128rikz
    0U,	// VPSRAQZ128rm
    0U,	// VPSRAQZ128rmk
    0U,	// VPSRAQZ128rmkz
    0U,	// VPSRAQZ128rr
    0U,	// VPSRAQZ128rrk
    0U,	// VPSRAQZ128rrkz
    0U,	// VPSRAQZ256mbi
    0U,	// VPSRAQZ256mbik
    0U,	// VPSRAQZ256mbikz
    0U,	// VPSRAQZ256mi
    0U,	// VPSRAQZ256mik
    0U,	// VPSRAQZ256mikz
    0U,	// VPSRAQZ256ri
    0U,	// VPSRAQZ256rik
    0U,	// VPSRAQZ256rikz
    0U,	// VPSRAQZ256rm
    0U,	// VPSRAQZ256rmk
    0U,	// VPSRAQZ256rmkz
    0U,	// VPSRAQZ256rr
    0U,	// VPSRAQZ256rrk
    0U,	// VPSRAQZ256rrkz
    0U,	// VPSRAQZmbi
    0U,	// VPSRAQZmbik
    0U,	// VPSRAQZmbikz
    0U,	// VPSRAQZmi
    0U,	// VPSRAQZmik
    0U,	// VPSRAQZmikz
    0U,	// VPSRAQZri
    0U,	// VPSRAQZrik
    0U,	// VPSRAQZrikz
    0U,	// VPSRAQZrm
    0U,	// VPSRAQZrmk
    0U,	// VPSRAQZrmkz
    0U,	// VPSRAQZrr
    0U,	// VPSRAQZrrk
    0U,	// VPSRAQZrrkz
    0U,	// VPSRAVDYrm
    0U,	// VPSRAVDYrr
    0U,	// VPSRAVDZ128rm
    0U,	// VPSRAVDZ128rmb
    0U,	// VPSRAVDZ128rmbk
    0U,	// VPSRAVDZ128rmbkz
    0U,	// VPSRAVDZ128rmk
    0U,	// VPSRAVDZ128rmkz
    0U,	// VPSRAVDZ128rr
    0U,	// VPSRAVDZ128rrk
    0U,	// VPSRAVDZ128rrkz
    0U,	// VPSRAVDZ256rm
    0U,	// VPSRAVDZ256rmb
    0U,	// VPSRAVDZ256rmbk
    0U,	// VPSRAVDZ256rmbkz
    0U,	// VPSRAVDZ256rmk
    0U,	// VPSRAVDZ256rmkz
    0U,	// VPSRAVDZ256rr
    0U,	// VPSRAVDZ256rrk
    0U,	// VPSRAVDZ256rrkz
    0U,	// VPSRAVDZrm
    0U,	// VPSRAVDZrmb
    0U,	// VPSRAVDZrmbk
    0U,	// VPSRAVDZrmbkz
    0U,	// VPSRAVDZrmk
    0U,	// VPSRAVDZrmkz
    0U,	// VPSRAVDZrr
    0U,	// VPSRAVDZrrk
    0U,	// VPSRAVDZrrkz
    0U,	// VPSRAVDrm
    0U,	// VPSRAVDrr
    0U,	// VPSRAVQZ128rm
    0U,	// VPSRAVQZ128rmb
    0U,	// VPSRAVQZ128rmbk
    0U,	// VPSRAVQZ128rmbkz
    0U,	// VPSRAVQZ128rmk
    0U,	// VPSRAVQZ128rmkz
    0U,	// VPSRAVQZ128rr
    0U,	// VPSRAVQZ128rrk
    0U,	// VPSRAVQZ128rrkz
    0U,	// VPSRAVQZ256rm
    0U,	// VPSRAVQZ256rmb
    0U,	// VPSRAVQZ256rmbk
    0U,	// VPSRAVQZ256rmbkz
    0U,	// VPSRAVQZ256rmk
    0U,	// VPSRAVQZ256rmkz
    0U,	// VPSRAVQZ256rr
    0U,	// VPSRAVQZ256rrk
    0U,	// VPSRAVQZ256rrkz
    0U,	// VPSRAVQZrm
    0U,	// VPSRAVQZrmb
    0U,	// VPSRAVQZrmbk
    0U,	// VPSRAVQZrmbkz
    0U,	// VPSRAVQZrmk
    0U,	// VPSRAVQZrmkz
    0U,	// VPSRAVQZrr
    0U,	// VPSRAVQZrrk
    0U,	// VPSRAVQZrrkz
    0U,	// VPSRAVWZ128rm
    0U,	// VPSRAVWZ128rmk
    0U,	// VPSRAVWZ128rmkz
    0U,	// VPSRAVWZ128rr
    0U,	// VPSRAVWZ128rrk
    0U,	// VPSRAVWZ128rrkz
    0U,	// VPSRAVWZ256rm
    0U,	// VPSRAVWZ256rmk
    0U,	// VPSRAVWZ256rmkz
    0U,	// VPSRAVWZ256rr
    0U,	// VPSRAVWZ256rrk
    0U,	// VPSRAVWZ256rrkz
    0U,	// VPSRAVWZrm
    0U,	// VPSRAVWZrmk
    0U,	// VPSRAVWZrmkz
    0U,	// VPSRAVWZrr
    0U,	// VPSRAVWZrrk
    0U,	// VPSRAVWZrrkz
    0U,	// VPSRAWYri
    0U,	// VPSRAWYrm
    0U,	// VPSRAWYrr
    0U,	// VPSRAWZ128mi
    0U,	// VPSRAWZ128mik
    0U,	// VPSRAWZ128mikz
    0U,	// VPSRAWZ128ri
    0U,	// VPSRAWZ128rik
    0U,	// VPSRAWZ128rikz
    0U,	// VPSRAWZ128rm
    0U,	// VPSRAWZ128rmk
    0U,	// VPSRAWZ128rmkz
    0U,	// VPSRAWZ128rr
    0U,	// VPSRAWZ128rrk
    0U,	// VPSRAWZ128rrkz
    0U,	// VPSRAWZ256mi
    0U,	// VPSRAWZ256mik
    0U,	// VPSRAWZ256mikz
    0U,	// VPSRAWZ256ri
    0U,	// VPSRAWZ256rik
    0U,	// VPSRAWZ256rikz
    0U,	// VPSRAWZ256rm
    0U,	// VPSRAWZ256rmk
    0U,	// VPSRAWZ256rmkz
    0U,	// VPSRAWZ256rr
    0U,	// VPSRAWZ256rrk
    0U,	// VPSRAWZ256rrkz
    0U,	// VPSRAWZmi
    0U,	// VPSRAWZmik
    0U,	// VPSRAWZmikz
    0U,	// VPSRAWZri
    0U,	// VPSRAWZrik
    0U,	// VPSRAWZrikz
    0U,	// VPSRAWZrm
    0U,	// VPSRAWZrmk
    0U,	// VPSRAWZrmkz
    0U,	// VPSRAWZrr
    0U,	// VPSRAWZrrk
    0U,	// VPSRAWZrrkz
    0U,	// VPSRAWri
    0U,	// VPSRAWrm
    0U,	// VPSRAWrr
    0U,	// VPSRLDQYri
    0U,	// VPSRLDQZ128rm
    0U,	// VPSRLDQZ128rr
    0U,	// VPSRLDQZ256rm
    0U,	// VPSRLDQZ256rr
    0U,	// VPSRLDQZrm
    0U,	// VPSRLDQZrr
    0U,	// VPSRLDQri
    0U,	// VPSRLDYri
    0U,	// VPSRLDYrm
    0U,	// VPSRLDYrr
    0U,	// VPSRLDZ128mbi
    0U,	// VPSRLDZ128mbik
    0U,	// VPSRLDZ128mbikz
    0U,	// VPSRLDZ128mi
    0U,	// VPSRLDZ128mik
    0U,	// VPSRLDZ128mikz
    0U,	// VPSRLDZ128ri
    0U,	// VPSRLDZ128rik
    0U,	// VPSRLDZ128rikz
    0U,	// VPSRLDZ128rm
    0U,	// VPSRLDZ128rmk
    0U,	// VPSRLDZ128rmkz
    0U,	// VPSRLDZ128rr
    0U,	// VPSRLDZ128rrk
    0U,	// VPSRLDZ128rrkz
    0U,	// VPSRLDZ256mbi
    0U,	// VPSRLDZ256mbik
    0U,	// VPSRLDZ256mbikz
    0U,	// VPSRLDZ256mi
    0U,	// VPSRLDZ256mik
    0U,	// VPSRLDZ256mikz
    0U,	// VPSRLDZ256ri
    0U,	// VPSRLDZ256rik
    0U,	// VPSRLDZ256rikz
    0U,	// VPSRLDZ256rm
    0U,	// VPSRLDZ256rmk
    0U,	// VPSRLDZ256rmkz
    0U,	// VPSRLDZ256rr
    0U,	// VPSRLDZ256rrk
    0U,	// VPSRLDZ256rrkz
    0U,	// VPSRLDZmbi
    0U,	// VPSRLDZmbik
    0U,	// VPSRLDZmbikz
    0U,	// VPSRLDZmi
    0U,	// VPSRLDZmik
    0U,	// VPSRLDZmikz
    0U,	// VPSRLDZri
    0U,	// VPSRLDZrik
    0U,	// VPSRLDZrikz
    0U,	// VPSRLDZrm
    0U,	// VPSRLDZrmk
    0U,	// VPSRLDZrmkz
    0U,	// VPSRLDZrr
    0U,	// VPSRLDZrrk
    0U,	// VPSRLDZrrkz
    0U,	// VPSRLDri
    0U,	// VPSRLDrm
    0U,	// VPSRLDrr
    0U,	// VPSRLQYri
    0U,	// VPSRLQYrm
    0U,	// VPSRLQYrr
    0U,	// VPSRLQZ128mbi
    0U,	// VPSRLQZ128mbik
    0U,	// VPSRLQZ128mbikz
    0U,	// VPSRLQZ128mi
    0U,	// VPSRLQZ128mik
    0U,	// VPSRLQZ128mikz
    0U,	// VPSRLQZ128ri
    0U,	// VPSRLQZ128rik
    0U,	// VPSRLQZ128rikz
    0U,	// VPSRLQZ128rm
    0U,	// VPSRLQZ128rmk
    0U,	// VPSRLQZ128rmkz
    0U,	// VPSRLQZ128rr
    0U,	// VPSRLQZ128rrk
    0U,	// VPSRLQZ128rrkz
    0U,	// VPSRLQZ256mbi
    0U,	// VPSRLQZ256mbik
    0U,	// VPSRLQZ256mbikz
    0U,	// VPSRLQZ256mi
    0U,	// VPSRLQZ256mik
    0U,	// VPSRLQZ256mikz
    0U,	// VPSRLQZ256ri
    0U,	// VPSRLQZ256rik
    0U,	// VPSRLQZ256rikz
    0U,	// VPSRLQZ256rm
    0U,	// VPSRLQZ256rmk
    0U,	// VPSRLQZ256rmkz
    0U,	// VPSRLQZ256rr
    0U,	// VPSRLQZ256rrk
    0U,	// VPSRLQZ256rrkz
    0U,	// VPSRLQZmbi
    0U,	// VPSRLQZmbik
    0U,	// VPSRLQZmbikz
    0U,	// VPSRLQZmi
    0U,	// VPSRLQZmik
    0U,	// VPSRLQZmikz
    0U,	// VPSRLQZri
    0U,	// VPSRLQZrik
    0U,	// VPSRLQZrikz
    0U,	// VPSRLQZrm
    0U,	// VPSRLQZrmk
    0U,	// VPSRLQZrmkz
    0U,	// VPSRLQZrr
    0U,	// VPSRLQZrrk
    0U,	// VPSRLQZrrkz
    0U,	// VPSRLQri
    0U,	// VPSRLQrm
    0U,	// VPSRLQrr
    0U,	// VPSRLVDYrm
    0U,	// VPSRLVDYrr
    0U,	// VPSRLVDZ128rm
    0U,	// VPSRLVDZ128rmb
    0U,	// VPSRLVDZ128rmbk
    0U,	// VPSRLVDZ128rmbkz
    0U,	// VPSRLVDZ128rmk
    0U,	// VPSRLVDZ128rmkz
    0U,	// VPSRLVDZ128rr
    0U,	// VPSRLVDZ128rrk
    0U,	// VPSRLVDZ128rrkz
    0U,	// VPSRLVDZ256rm
    0U,	// VPSRLVDZ256rmb
    0U,	// VPSRLVDZ256rmbk
    0U,	// VPSRLVDZ256rmbkz
    0U,	// VPSRLVDZ256rmk
    0U,	// VPSRLVDZ256rmkz
    0U,	// VPSRLVDZ256rr
    0U,	// VPSRLVDZ256rrk
    0U,	// VPSRLVDZ256rrkz
    0U,	// VPSRLVDZrm
    0U,	// VPSRLVDZrmb
    0U,	// VPSRLVDZrmbk
    0U,	// VPSRLVDZrmbkz
    0U,	// VPSRLVDZrmk
    0U,	// VPSRLVDZrmkz
    0U,	// VPSRLVDZrr
    0U,	// VPSRLVDZrrk
    0U,	// VPSRLVDZrrkz
    0U,	// VPSRLVDrm
    0U,	// VPSRLVDrr
    0U,	// VPSRLVQYrm
    0U,	// VPSRLVQYrr
    0U,	// VPSRLVQZ128rm
    0U,	// VPSRLVQZ128rmb
    0U,	// VPSRLVQZ128rmbk
    0U,	// VPSRLVQZ128rmbkz
    0U,	// VPSRLVQZ128rmk
    0U,	// VPSRLVQZ128rmkz
    0U,	// VPSRLVQZ128rr
    0U,	// VPSRLVQZ128rrk
    0U,	// VPSRLVQZ128rrkz
    0U,	// VPSRLVQZ256rm
    0U,	// VPSRLVQZ256rmb
    0U,	// VPSRLVQZ256rmbk
    0U,	// VPSRLVQZ256rmbkz
    0U,	// VPSRLVQZ256rmk
    0U,	// VPSRLVQZ256rmkz
    0U,	// VPSRLVQZ256rr
    0U,	// VPSRLVQZ256rrk
    0U,	// VPSRLVQZ256rrkz
    0U,	// VPSRLVQZrm
    0U,	// VPSRLVQZrmb
    0U,	// VPSRLVQZrmbk
    0U,	// VPSRLVQZrmbkz
    0U,	// VPSRLVQZrmk
    0U,	// VPSRLVQZrmkz
    0U,	// VPSRLVQZrr
    0U,	// VPSRLVQZrrk
    0U,	// VPSRLVQZrrkz
    0U,	// VPSRLVQrm
    0U,	// VPSRLVQrr
    0U,	// VPSRLVWZ128rm
    0U,	// VPSRLVWZ128rmk
    0U,	// VPSRLVWZ128rmkz
    0U,	// VPSRLVWZ128rr
    0U,	// VPSRLVWZ128rrk
    0U,	// VPSRLVWZ128rrkz
    0U,	// VPSRLVWZ256rm
    0U,	// VPSRLVWZ256rmk
    0U,	// VPSRLVWZ256rmkz
    0U,	// VPSRLVWZ256rr
    0U,	// VPSRLVWZ256rrk
    0U,	// VPSRLVWZ256rrkz
    0U,	// VPSRLVWZrm
    0U,	// VPSRLVWZrmk
    0U,	// VPSRLVWZrmkz
    0U,	// VPSRLVWZrr
    0U,	// VPSRLVWZrrk
    0U,	// VPSRLVWZrrkz
    0U,	// VPSRLWYri
    0U,	// VPSRLWYrm
    0U,	// VPSRLWYrr
    0U,	// VPSRLWZ128mi
    0U,	// VPSRLWZ128mik
    0U,	// VPSRLWZ128mikz
    0U,	// VPSRLWZ128ri
    0U,	// VPSRLWZ128rik
    0U,	// VPSRLWZ128rikz
    0U,	// VPSRLWZ128rm
    0U,	// VPSRLWZ128rmk
    0U,	// VPSRLWZ128rmkz
    0U,	// VPSRLWZ128rr
    0U,	// VPSRLWZ128rrk
    0U,	// VPSRLWZ128rrkz
    0U,	// VPSRLWZ256mi
    0U,	// VPSRLWZ256mik
    0U,	// VPSRLWZ256mikz
    0U,	// VPSRLWZ256ri
    0U,	// VPSRLWZ256rik
    0U,	// VPSRLWZ256rikz
    0U,	// VPSRLWZ256rm
    0U,	// VPSRLWZ256rmk
    0U,	// VPSRLWZ256rmkz
    0U,	// VPSRLWZ256rr
    0U,	// VPSRLWZ256rrk
    0U,	// VPSRLWZ256rrkz
    0U,	// VPSRLWZmi
    0U,	// VPSRLWZmik
    0U,	// VPSRLWZmikz
    0U,	// VPSRLWZri
    0U,	// VPSRLWZrik
    0U,	// VPSRLWZrikz
    0U,	// VPSRLWZrm
    0U,	// VPSRLWZrmk
    0U,	// VPSRLWZrmkz
    0U,	// VPSRLWZrr
    0U,	// VPSRLWZrrk
    0U,	// VPSRLWZrrkz
    0U,	// VPSRLWri
    0U,	// VPSRLWrm
    0U,	// VPSRLWrr
    0U,	// VPSUBBYrm
    0U,	// VPSUBBYrr
    0U,	// VPSUBBZ128rm
    0U,	// VPSUBBZ128rmk
    0U,	// VPSUBBZ128rmkz
    0U,	// VPSUBBZ128rr
    0U,	// VPSUBBZ128rrk
    0U,	// VPSUBBZ128rrkz
    0U,	// VPSUBBZ256rm
    0U,	// VPSUBBZ256rmk
    0U,	// VPSUBBZ256rmkz
    0U,	// VPSUBBZ256rr
    0U,	// VPSUBBZ256rrk
    0U,	// VPSUBBZ256rrkz
    0U,	// VPSUBBZrm
    0U,	// VPSUBBZrmk
    0U,	// VPSUBBZrmkz
    0U,	// VPSUBBZrr
    0U,	// VPSUBBZrrk
    0U,	// VPSUBBZrrkz
    0U,	// VPSUBBrm
    0U,	// VPSUBBrr
    0U,	// VPSUBDYrm
    0U,	// VPSUBDYrr
    0U,	// VPSUBDZ128rm
    0U,	// VPSUBDZ128rmb
    0U,	// VPSUBDZ128rmbk
    0U,	// VPSUBDZ128rmbkz
    0U,	// VPSUBDZ128rmk
    0U,	// VPSUBDZ128rmkz
    0U,	// VPSUBDZ128rr
    0U,	// VPSUBDZ128rrk
    0U,	// VPSUBDZ128rrkz
    0U,	// VPSUBDZ256rm
    0U,	// VPSUBDZ256rmb
    0U,	// VPSUBDZ256rmbk
    0U,	// VPSUBDZ256rmbkz
    0U,	// VPSUBDZ256rmk
    0U,	// VPSUBDZ256rmkz
    0U,	// VPSUBDZ256rr
    0U,	// VPSUBDZ256rrk
    0U,	// VPSUBDZ256rrkz
    0U,	// VPSUBDZrm
    0U,	// VPSUBDZrmb
    0U,	// VPSUBDZrmbk
    0U,	// VPSUBDZrmbkz
    0U,	// VPSUBDZrmk
    0U,	// VPSUBDZrmkz
    0U,	// VPSUBDZrr
    0U,	// VPSUBDZrrk
    0U,	// VPSUBDZrrkz
    0U,	// VPSUBDrm
    0U,	// VPSUBDrr
    0U,	// VPSUBQYrm
    0U,	// VPSUBQYrr
    0U,	// VPSUBQZ128rm
    0U,	// VPSUBQZ128rmb
    0U,	// VPSUBQZ128rmbk
    0U,	// VPSUBQZ128rmbkz
    0U,	// VPSUBQZ128rmk
    0U,	// VPSUBQZ128rmkz
    0U,	// VPSUBQZ128rr
    0U,	// VPSUBQZ128rrk
    0U,	// VPSUBQZ128rrkz
    0U,	// VPSUBQZ256rm
    0U,	// VPSUBQZ256rmb
    0U,	// VPSUBQZ256rmbk
    0U,	// VPSUBQZ256rmbkz
    0U,	// VPSUBQZ256rmk
    0U,	// VPSUBQZ256rmkz
    0U,	// VPSUBQZ256rr
    0U,	// VPSUBQZ256rrk
    0U,	// VPSUBQZ256rrkz
    0U,	// VPSUBQZrm
    0U,	// VPSUBQZrmb
    0U,	// VPSUBQZrmbk
    0U,	// VPSUBQZrmbkz
    0U,	// VPSUBQZrmk
    0U,	// VPSUBQZrmkz
    0U,	// VPSUBQZrr
    0U,	// VPSUBQZrrk
    0U,	// VPSUBQZrrkz
    0U,	// VPSUBQrm
    0U,	// VPSUBQrr
    0U,	// VPSUBSBYrm
    0U,	// VPSUBSBYrr
    0U,	// VPSUBSBZ128rm
    0U,	// VPSUBSBZ128rmk
    0U,	// VPSUBSBZ128rmkz
    0U,	// VPSUBSBZ128rr
    0U,	// VPSUBSBZ128rrk
    0U,	// VPSUBSBZ128rrkz
    0U,	// VPSUBSBZ256rm
    0U,	// VPSUBSBZ256rmk
    0U,	// VPSUBSBZ256rmkz
    0U,	// VPSUBSBZ256rr
    0U,	// VPSUBSBZ256rrk
    0U,	// VPSUBSBZ256rrkz
    0U,	// VPSUBSBZrm
    0U,	// VPSUBSBZrmk
    0U,	// VPSUBSBZrmkz
    0U,	// VPSUBSBZrr
    0U,	// VPSUBSBZrrk
    0U,	// VPSUBSBZrrkz
    0U,	// VPSUBSBrm
    0U,	// VPSUBSBrr
    0U,	// VPSUBSWYrm
    0U,	// VPSUBSWYrr
    0U,	// VPSUBSWZ128rm
    0U,	// VPSUBSWZ128rmk
    0U,	// VPSUBSWZ128rmkz
    0U,	// VPSUBSWZ128rr
    0U,	// VPSUBSWZ128rrk
    0U,	// VPSUBSWZ128rrkz
    0U,	// VPSUBSWZ256rm
    0U,	// VPSUBSWZ256rmk
    0U,	// VPSUBSWZ256rmkz
    0U,	// VPSUBSWZ256rr
    0U,	// VPSUBSWZ256rrk
    0U,	// VPSUBSWZ256rrkz
    0U,	// VPSUBSWZrm
    0U,	// VPSUBSWZrmk
    0U,	// VPSUBSWZrmkz
    0U,	// VPSUBSWZrr
    0U,	// VPSUBSWZrrk
    0U,	// VPSUBSWZrrkz
    0U,	// VPSUBSWrm
    0U,	// VPSUBSWrr
    0U,	// VPSUBUSBYrm
    0U,	// VPSUBUSBYrr
    0U,	// VPSUBUSBZ128rm
    0U,	// VPSUBUSBZ128rmk
    0U,	// VPSUBUSBZ128rmkz
    0U,	// VPSUBUSBZ128rr
    0U,	// VPSUBUSBZ128rrk
    0U,	// VPSUBUSBZ128rrkz
    0U,	// VPSUBUSBZ256rm
    0U,	// VPSUBUSBZ256rmk
    0U,	// VPSUBUSBZ256rmkz
    0U,	// VPSUBUSBZ256rr
    0U,	// VPSUBUSBZ256rrk
    0U,	// VPSUBUSBZ256rrkz
    0U,	// VPSUBUSBZrm
    0U,	// VPSUBUSBZrmk
    0U,	// VPSUBUSBZrmkz
    0U,	// VPSUBUSBZrr
    0U,	// VPSUBUSBZrrk
    0U,	// VPSUBUSBZrrkz
    0U,	// VPSUBUSBrm
    0U,	// VPSUBUSBrr
    0U,	// VPSUBUSWYrm
    0U,	// VPSUBUSWYrr
    0U,	// VPSUBUSWZ128rm
    0U,	// VPSUBUSWZ128rmk
    0U,	// VPSUBUSWZ128rmkz
    0U,	// VPSUBUSWZ128rr
    0U,	// VPSUBUSWZ128rrk
    0U,	// VPSUBUSWZ128rrkz
    0U,	// VPSUBUSWZ256rm
    0U,	// VPSUBUSWZ256rmk
    0U,	// VPSUBUSWZ256rmkz
    0U,	// VPSUBUSWZ256rr
    0U,	// VPSUBUSWZ256rrk
    0U,	// VPSUBUSWZ256rrkz
    0U,	// VPSUBUSWZrm
    0U,	// VPSUBUSWZrmk
    0U,	// VPSUBUSWZrmkz
    0U,	// VPSUBUSWZrr
    0U,	// VPSUBUSWZrrk
    0U,	// VPSUBUSWZrrkz
    0U,	// VPSUBUSWrm
    0U,	// VPSUBUSWrr
    0U,	// VPSUBWYrm
    0U,	// VPSUBWYrr
    0U,	// VPSUBWZ128rm
    0U,	// VPSUBWZ128rmk
    0U,	// VPSUBWZ128rmkz
    0U,	// VPSUBWZ128rr
    0U,	// VPSUBWZ128rrk
    0U,	// VPSUBWZ128rrkz
    0U,	// VPSUBWZ256rm
    0U,	// VPSUBWZ256rmk
    0U,	// VPSUBWZ256rmkz
    0U,	// VPSUBWZ256rr
    0U,	// VPSUBWZ256rrk
    0U,	// VPSUBWZ256rrkz
    0U,	// VPSUBWZrm
    0U,	// VPSUBWZrmk
    0U,	// VPSUBWZrmkz
    0U,	// VPSUBWZrr
    0U,	// VPSUBWZrrk
    0U,	// VPSUBWZrrkz
    0U,	// VPSUBWrm
    0U,	// VPSUBWrr
    0U,	// VPTERNLOGDZ128rmbi
    0U,	// VPTERNLOGDZ128rmbik
    2U,	// VPTERNLOGDZ128rmbikz
    0U,	// VPTERNLOGDZ128rmi
    0U,	// VPTERNLOGDZ128rmik
    0U,	// VPTERNLOGDZ128rmikz
    0U,	// VPTERNLOGDZ128rri
    0U,	// VPTERNLOGDZ128rrik
    0U,	// VPTERNLOGDZ128rrikz
    0U,	// VPTERNLOGDZ256rmbi
    0U,	// VPTERNLOGDZ256rmbik
    2U,	// VPTERNLOGDZ256rmbikz
    0U,	// VPTERNLOGDZ256rmi
    0U,	// VPTERNLOGDZ256rmik
    0U,	// VPTERNLOGDZ256rmikz
    0U,	// VPTERNLOGDZ256rri
    0U,	// VPTERNLOGDZ256rrik
    0U,	// VPTERNLOGDZ256rrikz
    0U,	// VPTERNLOGDZrmbi
    0U,	// VPTERNLOGDZrmbik
    2U,	// VPTERNLOGDZrmbikz
    0U,	// VPTERNLOGDZrmi
    0U,	// VPTERNLOGDZrmik
    0U,	// VPTERNLOGDZrmikz
    0U,	// VPTERNLOGDZrri
    0U,	// VPTERNLOGDZrrik
    0U,	// VPTERNLOGDZrrikz
    0U,	// VPTERNLOGQZ128rmbi
    0U,	// VPTERNLOGQZ128rmbik
    2U,	// VPTERNLOGQZ128rmbikz
    0U,	// VPTERNLOGQZ128rmi
    0U,	// VPTERNLOGQZ128rmik
    0U,	// VPTERNLOGQZ128rmikz
    0U,	// VPTERNLOGQZ128rri
    0U,	// VPTERNLOGQZ128rrik
    0U,	// VPTERNLOGQZ128rrikz
    0U,	// VPTERNLOGQZ256rmbi
    0U,	// VPTERNLOGQZ256rmbik
    2U,	// VPTERNLOGQZ256rmbikz
    0U,	// VPTERNLOGQZ256rmi
    0U,	// VPTERNLOGQZ256rmik
    0U,	// VPTERNLOGQZ256rmikz
    0U,	// VPTERNLOGQZ256rri
    0U,	// VPTERNLOGQZ256rrik
    0U,	// VPTERNLOGQZ256rrikz
    0U,	// VPTERNLOGQZrmbi
    0U,	// VPTERNLOGQZrmbik
    2U,	// VPTERNLOGQZrmbikz
    0U,	// VPTERNLOGQZrmi
    0U,	// VPTERNLOGQZrmik
    0U,	// VPTERNLOGQZrmikz
    0U,	// VPTERNLOGQZrri
    0U,	// VPTERNLOGQZrrik
    0U,	// VPTERNLOGQZrrikz
    0U,	// VPTESTMBZ128rm
    0U,	// VPTESTMBZ128rmk
    0U,	// VPTESTMBZ128rr
    0U,	// VPTESTMBZ128rrk
    0U,	// VPTESTMBZ256rm
    0U,	// VPTESTMBZ256rmk
    0U,	// VPTESTMBZ256rr
    0U,	// VPTESTMBZ256rrk
    0U,	// VPTESTMBZrm
    0U,	// VPTESTMBZrmk
    0U,	// VPTESTMBZrr
    0U,	// VPTESTMBZrrk
    0U,	// VPTESTMDZ128rm
    0U,	// VPTESTMDZ128rmb
    0U,	// VPTESTMDZ128rmbk
    0U,	// VPTESTMDZ128rmk
    0U,	// VPTESTMDZ128rr
    0U,	// VPTESTMDZ128rrk
    0U,	// VPTESTMDZ256rm
    0U,	// VPTESTMDZ256rmb
    0U,	// VPTESTMDZ256rmbk
    0U,	// VPTESTMDZ256rmk
    0U,	// VPTESTMDZ256rr
    0U,	// VPTESTMDZ256rrk
    0U,	// VPTESTMDZrm
    0U,	// VPTESTMDZrmb
    0U,	// VPTESTMDZrmbk
    0U,	// VPTESTMDZrmk
    0U,	// VPTESTMDZrr
    0U,	// VPTESTMDZrrk
    0U,	// VPTESTMQZ128rm
    0U,	// VPTESTMQZ128rmb
    0U,	// VPTESTMQZ128rmbk
    0U,	// VPTESTMQZ128rmk
    0U,	// VPTESTMQZ128rr
    0U,	// VPTESTMQZ128rrk
    0U,	// VPTESTMQZ256rm
    0U,	// VPTESTMQZ256rmb
    0U,	// VPTESTMQZ256rmbk
    0U,	// VPTESTMQZ256rmk
    0U,	// VPTESTMQZ256rr
    0U,	// VPTESTMQZ256rrk
    0U,	// VPTESTMQZrm
    0U,	// VPTESTMQZrmb
    0U,	// VPTESTMQZrmbk
    0U,	// VPTESTMQZrmk
    0U,	// VPTESTMQZrr
    0U,	// VPTESTMQZrrk
    0U,	// VPTESTMWZ128rm
    0U,	// VPTESTMWZ128rmk
    0U,	// VPTESTMWZ128rr
    0U,	// VPTESTMWZ128rrk
    0U,	// VPTESTMWZ256rm
    0U,	// VPTESTMWZ256rmk
    0U,	// VPTESTMWZ256rr
    0U,	// VPTESTMWZ256rrk
    0U,	// VPTESTMWZrm
    0U,	// VPTESTMWZrmk
    0U,	// VPTESTMWZrr
    0U,	// VPTESTMWZrrk
    0U,	// VPTESTNMBZ128rm
    0U,	// VPTESTNMBZ128rmk
    0U,	// VPTESTNMBZ128rr
    0U,	// VPTESTNMBZ128rrk
    0U,	// VPTESTNMBZ256rm
    0U,	// VPTESTNMBZ256rmk
    0U,	// VPTESTNMBZ256rr
    0U,	// VPTESTNMBZ256rrk
    0U,	// VPTESTNMBZrm
    0U,	// VPTESTNMBZrmk
    0U,	// VPTESTNMBZrr
    0U,	// VPTESTNMBZrrk
    0U,	// VPTESTNMDZ128rm
    0U,	// VPTESTNMDZ128rmb
    0U,	// VPTESTNMDZ128rmbk
    0U,	// VPTESTNMDZ128rmk
    0U,	// VPTESTNMDZ128rr
    0U,	// VPTESTNMDZ128rrk
    0U,	// VPTESTNMDZ256rm
    0U,	// VPTESTNMDZ256rmb
    0U,	// VPTESTNMDZ256rmbk
    0U,	// VPTESTNMDZ256rmk
    0U,	// VPTESTNMDZ256rr
    0U,	// VPTESTNMDZ256rrk
    0U,	// VPTESTNMDZrm
    0U,	// VPTESTNMDZrmb
    0U,	// VPTESTNMDZrmbk
    0U,	// VPTESTNMDZrmk
    0U,	// VPTESTNMDZrr
    0U,	// VPTESTNMDZrrk
    0U,	// VPTESTNMQZ128rm
    0U,	// VPTESTNMQZ128rmb
    0U,	// VPTESTNMQZ128rmbk
    0U,	// VPTESTNMQZ128rmk
    0U,	// VPTESTNMQZ128rr
    0U,	// VPTESTNMQZ128rrk
    0U,	// VPTESTNMQZ256rm
    0U,	// VPTESTNMQZ256rmb
    0U,	// VPTESTNMQZ256rmbk
    0U,	// VPTESTNMQZ256rmk
    0U,	// VPTESTNMQZ256rr
    0U,	// VPTESTNMQZ256rrk
    0U,	// VPTESTNMQZrm
    0U,	// VPTESTNMQZrmb
    0U,	// VPTESTNMQZrmbk
    0U,	// VPTESTNMQZrmk
    0U,	// VPTESTNMQZrr
    0U,	// VPTESTNMQZrrk
    0U,	// VPTESTNMWZ128rm
    0U,	// VPTESTNMWZ128rmk
    0U,	// VPTESTNMWZ128rr
    0U,	// VPTESTNMWZ128rrk
    0U,	// VPTESTNMWZ256rm
    0U,	// VPTESTNMWZ256rmk
    0U,	// VPTESTNMWZ256rr
    0U,	// VPTESTNMWZ256rrk
    0U,	// VPTESTNMWZrm
    0U,	// VPTESTNMWZrmk
    0U,	// VPTESTNMWZrr
    0U,	// VPTESTNMWZrrk
    0U,	// VPTESTYrm
    0U,	// VPTESTYrr
    0U,	// VPTESTrm
    0U,	// VPTESTrr
    0U,	// VPUNPCKHBWYrm
    0U,	// VPUNPCKHBWYrr
    0U,	// VPUNPCKHBWZ128rm
    0U,	// VPUNPCKHBWZ128rmk
    0U,	// VPUNPCKHBWZ128rmkz
    0U,	// VPUNPCKHBWZ128rr
    0U,	// VPUNPCKHBWZ128rrk
    0U,	// VPUNPCKHBWZ128rrkz
    0U,	// VPUNPCKHBWZ256rm
    0U,	// VPUNPCKHBWZ256rmk
    0U,	// VPUNPCKHBWZ256rmkz
    0U,	// VPUNPCKHBWZ256rr
    0U,	// VPUNPCKHBWZ256rrk
    0U,	// VPUNPCKHBWZ256rrkz
    0U,	// VPUNPCKHBWZrm
    0U,	// VPUNPCKHBWZrmk
    0U,	// VPUNPCKHBWZrmkz
    0U,	// VPUNPCKHBWZrr
    0U,	// VPUNPCKHBWZrrk
    0U,	// VPUNPCKHBWZrrkz
    0U,	// VPUNPCKHBWrm
    0U,	// VPUNPCKHBWrr
    0U,	// VPUNPCKHDQYrm
    0U,	// VPUNPCKHDQYrr
    0U,	// VPUNPCKHDQZ128rm
    0U,	// VPUNPCKHDQZ128rmb
    0U,	// VPUNPCKHDQZ128rmbk
    0U,	// VPUNPCKHDQZ128rmbkz
    0U,	// VPUNPCKHDQZ128rmk
    0U,	// VPUNPCKHDQZ128rmkz
    0U,	// VPUNPCKHDQZ128rr
    0U,	// VPUNPCKHDQZ128rrk
    0U,	// VPUNPCKHDQZ128rrkz
    0U,	// VPUNPCKHDQZ256rm
    0U,	// VPUNPCKHDQZ256rmb
    0U,	// VPUNPCKHDQZ256rmbk
    0U,	// VPUNPCKHDQZ256rmbkz
    0U,	// VPUNPCKHDQZ256rmk
    0U,	// VPUNPCKHDQZ256rmkz
    0U,	// VPUNPCKHDQZ256rr
    0U,	// VPUNPCKHDQZ256rrk
    0U,	// VPUNPCKHDQZ256rrkz
    0U,	// VPUNPCKHDQZrm
    0U,	// VPUNPCKHDQZrmb
    0U,	// VPUNPCKHDQZrmbk
    0U,	// VPUNPCKHDQZrmbkz
    0U,	// VPUNPCKHDQZrmk
    0U,	// VPUNPCKHDQZrmkz
    0U,	// VPUNPCKHDQZrr
    0U,	// VPUNPCKHDQZrrk
    0U,	// VPUNPCKHDQZrrkz
    0U,	// VPUNPCKHDQrm
    0U,	// VPUNPCKHDQrr
    0U,	// VPUNPCKHQDQYrm
    0U,	// VPUNPCKHQDQYrr
    0U,	// VPUNPCKHQDQZ128rm
    0U,	// VPUNPCKHQDQZ128rmb
    0U,	// VPUNPCKHQDQZ128rmbk
    0U,	// VPUNPCKHQDQZ128rmbkz
    0U,	// VPUNPCKHQDQZ128rmk
    0U,	// VPUNPCKHQDQZ128rmkz
    0U,	// VPUNPCKHQDQZ128rr
    0U,	// VPUNPCKHQDQZ128rrk
    0U,	// VPUNPCKHQDQZ128rrkz
    0U,	// VPUNPCKHQDQZ256rm
    0U,	// VPUNPCKHQDQZ256rmb
    0U,	// VPUNPCKHQDQZ256rmbk
    0U,	// VPUNPCKHQDQZ256rmbkz
    0U,	// VPUNPCKHQDQZ256rmk
    0U,	// VPUNPCKHQDQZ256rmkz
    0U,	// VPUNPCKHQDQZ256rr
    0U,	// VPUNPCKHQDQZ256rrk
    0U,	// VPUNPCKHQDQZ256rrkz
    0U,	// VPUNPCKHQDQZrm
    0U,	// VPUNPCKHQDQZrmb
    0U,	// VPUNPCKHQDQZrmbk
    0U,	// VPUNPCKHQDQZrmbkz
    0U,	// VPUNPCKHQDQZrmk
    0U,	// VPUNPCKHQDQZrmkz
    0U,	// VPUNPCKHQDQZrr
    0U,	// VPUNPCKHQDQZrrk
    0U,	// VPUNPCKHQDQZrrkz
    0U,	// VPUNPCKHQDQrm
    0U,	// VPUNPCKHQDQrr
    0U,	// VPUNPCKHWDYrm
    0U,	// VPUNPCKHWDYrr
    0U,	// VPUNPCKHWDZ128rm
    0U,	// VPUNPCKHWDZ128rmk
    0U,	// VPUNPCKHWDZ128rmkz
    0U,	// VPUNPCKHWDZ128rr
    0U,	// VPUNPCKHWDZ128rrk
    0U,	// VPUNPCKHWDZ128rrkz
    0U,	// VPUNPCKHWDZ256rm
    0U,	// VPUNPCKHWDZ256rmk
    0U,	// VPUNPCKHWDZ256rmkz
    0U,	// VPUNPCKHWDZ256rr
    0U,	// VPUNPCKHWDZ256rrk
    0U,	// VPUNPCKHWDZ256rrkz
    0U,	// VPUNPCKHWDZrm
    0U,	// VPUNPCKHWDZrmk
    0U,	// VPUNPCKHWDZrmkz
    0U,	// VPUNPCKHWDZrr
    0U,	// VPUNPCKHWDZrrk
    0U,	// VPUNPCKHWDZrrkz
    0U,	// VPUNPCKHWDrm
    0U,	// VPUNPCKHWDrr
    0U,	// VPUNPCKLBWYrm
    0U,	// VPUNPCKLBWYrr
    0U,	// VPUNPCKLBWZ128rm
    0U,	// VPUNPCKLBWZ128rmk
    0U,	// VPUNPCKLBWZ128rmkz
    0U,	// VPUNPCKLBWZ128rr
    0U,	// VPUNPCKLBWZ128rrk
    0U,	// VPUNPCKLBWZ128rrkz
    0U,	// VPUNPCKLBWZ256rm
    0U,	// VPUNPCKLBWZ256rmk
    0U,	// VPUNPCKLBWZ256rmkz
    0U,	// VPUNPCKLBWZ256rr
    0U,	// VPUNPCKLBWZ256rrk
    0U,	// VPUNPCKLBWZ256rrkz
    0U,	// VPUNPCKLBWZrm
    0U,	// VPUNPCKLBWZrmk
    0U,	// VPUNPCKLBWZrmkz
    0U,	// VPUNPCKLBWZrr
    0U,	// VPUNPCKLBWZrrk
    0U,	// VPUNPCKLBWZrrkz
    0U,	// VPUNPCKLBWrm
    0U,	// VPUNPCKLBWrr
    0U,	// VPUNPCKLDQYrm
    0U,	// VPUNPCKLDQYrr
    0U,	// VPUNPCKLDQZ128rm
    0U,	// VPUNPCKLDQZ128rmb
    0U,	// VPUNPCKLDQZ128rmbk
    0U,	// VPUNPCKLDQZ128rmbkz
    0U,	// VPUNPCKLDQZ128rmk
    0U,	// VPUNPCKLDQZ128rmkz
    0U,	// VPUNPCKLDQZ128rr
    0U,	// VPUNPCKLDQZ128rrk
    0U,	// VPUNPCKLDQZ128rrkz
    0U,	// VPUNPCKLDQZ256rm
    0U,	// VPUNPCKLDQZ256rmb
    0U,	// VPUNPCKLDQZ256rmbk
    0U,	// VPUNPCKLDQZ256rmbkz
    0U,	// VPUNPCKLDQZ256rmk
    0U,	// VPUNPCKLDQZ256rmkz
    0U,	// VPUNPCKLDQZ256rr
    0U,	// VPUNPCKLDQZ256rrk
    0U,	// VPUNPCKLDQZ256rrkz
    0U,	// VPUNPCKLDQZrm
    0U,	// VPUNPCKLDQZrmb
    0U,	// VPUNPCKLDQZrmbk
    0U,	// VPUNPCKLDQZrmbkz
    0U,	// VPUNPCKLDQZrmk
    0U,	// VPUNPCKLDQZrmkz
    0U,	// VPUNPCKLDQZrr
    0U,	// VPUNPCKLDQZrrk
    0U,	// VPUNPCKLDQZrrkz
    0U,	// VPUNPCKLDQrm
    0U,	// VPUNPCKLDQrr
    0U,	// VPUNPCKLQDQYrm
    0U,	// VPUNPCKLQDQYrr
    0U,	// VPUNPCKLQDQZ128rm
    0U,	// VPUNPCKLQDQZ128rmb
    0U,	// VPUNPCKLQDQZ128rmbk
    0U,	// VPUNPCKLQDQZ128rmbkz
    0U,	// VPUNPCKLQDQZ128rmk
    0U,	// VPUNPCKLQDQZ128rmkz
    0U,	// VPUNPCKLQDQZ128rr
    0U,	// VPUNPCKLQDQZ128rrk
    0U,	// VPUNPCKLQDQZ128rrkz
    0U,	// VPUNPCKLQDQZ256rm
    0U,	// VPUNPCKLQDQZ256rmb
    0U,	// VPUNPCKLQDQZ256rmbk
    0U,	// VPUNPCKLQDQZ256rmbkz
    0U,	// VPUNPCKLQDQZ256rmk
    0U,	// VPUNPCKLQDQZ256rmkz
    0U,	// VPUNPCKLQDQZ256rr
    0U,	// VPUNPCKLQDQZ256rrk
    0U,	// VPUNPCKLQDQZ256rrkz
    0U,	// VPUNPCKLQDQZrm
    0U,	// VPUNPCKLQDQZrmb
    0U,	// VPUNPCKLQDQZrmbk
    0U,	// VPUNPCKLQDQZrmbkz
    0U,	// VPUNPCKLQDQZrmk
    0U,	// VPUNPCKLQDQZrmkz
    0U,	// VPUNPCKLQDQZrr
    0U,	// VPUNPCKLQDQZrrk
    0U,	// VPUNPCKLQDQZrrkz
    0U,	// VPUNPCKLQDQrm
    0U,	// VPUNPCKLQDQrr
    0U,	// VPUNPCKLWDYrm
    0U,	// VPUNPCKLWDYrr
    0U,	// VPUNPCKLWDZ128rm
    0U,	// VPUNPCKLWDZ128rmk
    0U,	// VPUNPCKLWDZ128rmkz
    0U,	// VPUNPCKLWDZ128rr
    0U,	// VPUNPCKLWDZ128rrk
    0U,	// VPUNPCKLWDZ128rrkz
    0U,	// VPUNPCKLWDZ256rm
    0U,	// VPUNPCKLWDZ256rmk
    0U,	// VPUNPCKLWDZ256rmkz
    0U,	// VPUNPCKLWDZ256rr
    0U,	// VPUNPCKLWDZ256rrk
    0U,	// VPUNPCKLWDZ256rrkz
    0U,	// VPUNPCKLWDZrm
    0U,	// VPUNPCKLWDZrmk
    0U,	// VPUNPCKLWDZrmkz
    0U,	// VPUNPCKLWDZrr
    0U,	// VPUNPCKLWDZrrk
    0U,	// VPUNPCKLWDZrrkz
    0U,	// VPUNPCKLWDrm
    0U,	// VPUNPCKLWDrr
    0U,	// VPXORDZ128rm
    0U,	// VPXORDZ128rmb
    0U,	// VPXORDZ128rmbk
    0U,	// VPXORDZ128rmbkz
    0U,	// VPXORDZ128rmk
    0U,	// VPXORDZ128rmkz
    0U,	// VPXORDZ128rr
    0U,	// VPXORDZ128rrk
    0U,	// VPXORDZ128rrkz
    0U,	// VPXORDZ256rm
    0U,	// VPXORDZ256rmb
    0U,	// VPXORDZ256rmbk
    0U,	// VPXORDZ256rmbkz
    0U,	// VPXORDZ256rmk
    0U,	// VPXORDZ256rmkz
    0U,	// VPXORDZ256rr
    0U,	// VPXORDZ256rrk
    0U,	// VPXORDZ256rrkz
    0U,	// VPXORDZrm
    0U,	// VPXORDZrmb
    0U,	// VPXORDZrmbk
    0U,	// VPXORDZrmbkz
    0U,	// VPXORDZrmk
    0U,	// VPXORDZrmkz
    0U,	// VPXORDZrr
    0U,	// VPXORDZrrk
    0U,	// VPXORDZrrkz
    0U,	// VPXORQZ128rm
    0U,	// VPXORQZ128rmb
    0U,	// VPXORQZ128rmbk
    0U,	// VPXORQZ128rmbkz
    0U,	// VPXORQZ128rmk
    0U,	// VPXORQZ128rmkz
    0U,	// VPXORQZ128rr
    0U,	// VPXORQZ128rrk
    0U,	// VPXORQZ128rrkz
    0U,	// VPXORQZ256rm
    0U,	// VPXORQZ256rmb
    0U,	// VPXORQZ256rmbk
    0U,	// VPXORQZ256rmbkz
    0U,	// VPXORQZ256rmk
    0U,	// VPXORQZ256rmkz
    0U,	// VPXORQZ256rr
    0U,	// VPXORQZ256rrk
    0U,	// VPXORQZ256rrkz
    0U,	// VPXORQZrm
    0U,	// VPXORQZrmb
    0U,	// VPXORQZrmbk
    0U,	// VPXORQZrmbkz
    0U,	// VPXORQZrmk
    0U,	// VPXORQZrmkz
    0U,	// VPXORQZrr
    0U,	// VPXORQZrrk
    0U,	// VPXORQZrrkz
    0U,	// VPXORYrm
    0U,	// VPXORYrr
    0U,	// VPXORrm
    0U,	// VPXORrr
    0U,	// VRANGEPDZ128rmbi
    0U,	// VRANGEPDZ128rmbik
    3U,	// VRANGEPDZ128rmbikz
    0U,	// VRANGEPDZ128rmi
    0U,	// VRANGEPDZ128rmik
    0U,	// VRANGEPDZ128rmikz
    0U,	// VRANGEPDZ128rri
    0U,	// VRANGEPDZ128rrik
    3U,	// VRANGEPDZ128rrikz
    0U,	// VRANGEPDZ256rmbi
    0U,	// VRANGEPDZ256rmbik
    3U,	// VRANGEPDZ256rmbikz
    0U,	// VRANGEPDZ256rmi
    0U,	// VRANGEPDZ256rmik
    0U,	// VRANGEPDZ256rmikz
    0U,	// VRANGEPDZ256rri
    0U,	// VRANGEPDZ256rrik
    3U,	// VRANGEPDZ256rrikz
    0U,	// VRANGEPDZrmbi
    0U,	// VRANGEPDZrmbik
    3U,	// VRANGEPDZrmbikz
    0U,	// VRANGEPDZrmi
    0U,	// VRANGEPDZrmik
    0U,	// VRANGEPDZrmikz
    0U,	// VRANGEPDZrri
    0U,	// VRANGEPDZrrib
    0U,	// VRANGEPDZrribk
    3U,	// VRANGEPDZrribkz
    0U,	// VRANGEPDZrrik
    3U,	// VRANGEPDZrrikz
    0U,	// VRANGEPSZ128rmbi
    0U,	// VRANGEPSZ128rmbik
    3U,	// VRANGEPSZ128rmbikz
    0U,	// VRANGEPSZ128rmi
    0U,	// VRANGEPSZ128rmik
    0U,	// VRANGEPSZ128rmikz
    0U,	// VRANGEPSZ128rri
    0U,	// VRANGEPSZ128rrik
    3U,	// VRANGEPSZ128rrikz
    0U,	// VRANGEPSZ256rmbi
    0U,	// VRANGEPSZ256rmbik
    3U,	// VRANGEPSZ256rmbikz
    0U,	// VRANGEPSZ256rmi
    0U,	// VRANGEPSZ256rmik
    0U,	// VRANGEPSZ256rmikz
    0U,	// VRANGEPSZ256rri
    0U,	// VRANGEPSZ256rrik
    3U,	// VRANGEPSZ256rrikz
    0U,	// VRANGEPSZrmbi
    0U,	// VRANGEPSZrmbik
    3U,	// VRANGEPSZrmbikz
    0U,	// VRANGEPSZrmi
    0U,	// VRANGEPSZrmik
    0U,	// VRANGEPSZrmikz
    0U,	// VRANGEPSZrri
    0U,	// VRANGEPSZrrib
    0U,	// VRANGEPSZrribk
    3U,	// VRANGEPSZrribkz
    0U,	// VRANGEPSZrrik
    3U,	// VRANGEPSZrrikz
    0U,	// VRANGESDZrmi
    0U,	// VRANGESDZrmik
    3U,	// VRANGESDZrmikz
    0U,	// VRANGESDZrri
    0U,	// VRANGESDZrrib
    0U,	// VRANGESDZrribk
    3U,	// VRANGESDZrribkz
    0U,	// VRANGESDZrrik
    3U,	// VRANGESDZrrikz
    0U,	// VRANGESSZrmi
    0U,	// VRANGESSZrmik
    3U,	// VRANGESSZrmikz
    0U,	// VRANGESSZrri
    0U,	// VRANGESSZrrib
    0U,	// VRANGESSZrribk
    3U,	// VRANGESSZrribkz
    0U,	// VRANGESSZrrik
    3U,	// VRANGESSZrrikz
    0U,	// VRCP14PDZ128m
    0U,	// VRCP14PDZ128mb
    0U,	// VRCP14PDZ128mbk
    0U,	// VRCP14PDZ128mbkz
    0U,	// VRCP14PDZ128mk
    0U,	// VRCP14PDZ128mkz
    0U,	// VRCP14PDZ128r
    0U,	// VRCP14PDZ128rk
    0U,	// VRCP14PDZ128rkz
    0U,	// VRCP14PDZ256m
    0U,	// VRCP14PDZ256mb
    0U,	// VRCP14PDZ256mbk
    0U,	// VRCP14PDZ256mbkz
    0U,	// VRCP14PDZ256mk
    0U,	// VRCP14PDZ256mkz
    0U,	// VRCP14PDZ256r
    0U,	// VRCP14PDZ256rk
    0U,	// VRCP14PDZ256rkz
    0U,	// VRCP14PDZm
    0U,	// VRCP14PDZmb
    0U,	// VRCP14PDZmbk
    0U,	// VRCP14PDZmbkz
    0U,	// VRCP14PDZmk
    0U,	// VRCP14PDZmkz
    0U,	// VRCP14PDZr
    0U,	// VRCP14PDZrk
    0U,	// VRCP14PDZrkz
    0U,	// VRCP14PSZ128m
    0U,	// VRCP14PSZ128mb
    0U,	// VRCP14PSZ128mbk
    0U,	// VRCP14PSZ128mbkz
    0U,	// VRCP14PSZ128mk
    0U,	// VRCP14PSZ128mkz
    0U,	// VRCP14PSZ128r
    0U,	// VRCP14PSZ128rk
    0U,	// VRCP14PSZ128rkz
    0U,	// VRCP14PSZ256m
    0U,	// VRCP14PSZ256mb
    0U,	// VRCP14PSZ256mbk
    0U,	// VRCP14PSZ256mbkz
    0U,	// VRCP14PSZ256mk
    0U,	// VRCP14PSZ256mkz
    0U,	// VRCP14PSZ256r
    0U,	// VRCP14PSZ256rk
    0U,	// VRCP14PSZ256rkz
    0U,	// VRCP14PSZm
    0U,	// VRCP14PSZmb
    0U,	// VRCP14PSZmbk
    0U,	// VRCP14PSZmbkz
    0U,	// VRCP14PSZmk
    0U,	// VRCP14PSZmkz
    0U,	// VRCP14PSZr
    0U,	// VRCP14PSZrk
    0U,	// VRCP14PSZrkz
    0U,	// VRCP14SDZrm
    0U,	// VRCP14SDZrmk
    0U,	// VRCP14SDZrmkz
    0U,	// VRCP14SDZrr
    0U,	// VRCP14SDZrrk
    0U,	// VRCP14SDZrrkz
    0U,	// VRCP14SSZrm
    0U,	// VRCP14SSZrmk
    0U,	// VRCP14SSZrmkz
    0U,	// VRCP14SSZrr
    0U,	// VRCP14SSZrrk
    0U,	// VRCP14SSZrrkz
    0U,	// VRCP28PDZm
    0U,	// VRCP28PDZmb
    0U,	// VRCP28PDZmbk
    0U,	// VRCP28PDZmbkz
    0U,	// VRCP28PDZmk
    0U,	// VRCP28PDZmkz
    0U,	// VRCP28PDZr
    0U,	// VRCP28PDZrb
    0U,	// VRCP28PDZrbk
    0U,	// VRCP28PDZrbkz
    0U,	// VRCP28PDZrk
    0U,	// VRCP28PDZrkz
    0U,	// VRCP28PSZm
    0U,	// VRCP28PSZmb
    0U,	// VRCP28PSZmbk
    0U,	// VRCP28PSZmbkz
    0U,	// VRCP28PSZmk
    0U,	// VRCP28PSZmkz
    0U,	// VRCP28PSZr
    0U,	// VRCP28PSZrb
    0U,	// VRCP28PSZrbk
    0U,	// VRCP28PSZrbkz
    0U,	// VRCP28PSZrk
    0U,	// VRCP28PSZrkz
    0U,	// VRCP28SDZm
    0U,	// VRCP28SDZmk
    0U,	// VRCP28SDZmkz
    0U,	// VRCP28SDZr
    0U,	// VRCP28SDZrb
    0U,	// VRCP28SDZrbk
    0U,	// VRCP28SDZrbkz
    0U,	// VRCP28SDZrk
    0U,	// VRCP28SDZrkz
    0U,	// VRCP28SSZm
    0U,	// VRCP28SSZmk
    0U,	// VRCP28SSZmkz
    0U,	// VRCP28SSZr
    0U,	// VRCP28SSZrb
    0U,	// VRCP28SSZrbk
    0U,	// VRCP28SSZrbkz
    0U,	// VRCP28SSZrk
    0U,	// VRCP28SSZrkz
    0U,	// VRCPPSYm
    0U,	// VRCPPSYr
    0U,	// VRCPPSm
    0U,	// VRCPPSr
    0U,	// VRCPSSm
    0U,	// VRCPSSm_Int
    0U,	// VRCPSSr
    0U,	// VRCPSSr_Int
    0U,	// VREDUCEPDZ128rmbi
    0U,	// VREDUCEPDZ128rmbik
    0U,	// VREDUCEPDZ128rmbikz
    0U,	// VREDUCEPDZ128rmi
    0U,	// VREDUCEPDZ128rmik
    0U,	// VREDUCEPDZ128rmikz
    0U,	// VREDUCEPDZ128rri
    0U,	// VREDUCEPDZ128rrik
    0U,	// VREDUCEPDZ128rrikz
    0U,	// VREDUCEPDZ256rmbi
    0U,	// VREDUCEPDZ256rmbik
    0U,	// VREDUCEPDZ256rmbikz
    0U,	// VREDUCEPDZ256rmi
    0U,	// VREDUCEPDZ256rmik
    0U,	// VREDUCEPDZ256rmikz
    0U,	// VREDUCEPDZ256rri
    0U,	// VREDUCEPDZ256rrik
    0U,	// VREDUCEPDZ256rrikz
    0U,	// VREDUCEPDZrmbi
    0U,	// VREDUCEPDZrmbik
    0U,	// VREDUCEPDZrmbikz
    0U,	// VREDUCEPDZrmi
    0U,	// VREDUCEPDZrmik
    0U,	// VREDUCEPDZrmikz
    0U,	// VREDUCEPDZrri
    0U,	// VREDUCEPDZrrib
    0U,	// VREDUCEPDZrribk
    0U,	// VREDUCEPDZrribkz
    0U,	// VREDUCEPDZrrik
    0U,	// VREDUCEPDZrrikz
    0U,	// VREDUCEPSZ128rmbi
    0U,	// VREDUCEPSZ128rmbik
    0U,	// VREDUCEPSZ128rmbikz
    0U,	// VREDUCEPSZ128rmi
    0U,	// VREDUCEPSZ128rmik
    0U,	// VREDUCEPSZ128rmikz
    0U,	// VREDUCEPSZ128rri
    0U,	// VREDUCEPSZ128rrik
    0U,	// VREDUCEPSZ128rrikz
    0U,	// VREDUCEPSZ256rmbi
    0U,	// VREDUCEPSZ256rmbik
    0U,	// VREDUCEPSZ256rmbikz
    0U,	// VREDUCEPSZ256rmi
    0U,	// VREDUCEPSZ256rmik
    0U,	// VREDUCEPSZ256rmikz
    0U,	// VREDUCEPSZ256rri
    0U,	// VREDUCEPSZ256rrik
    0U,	// VREDUCEPSZ256rrikz
    0U,	// VREDUCEPSZrmbi
    0U,	// VREDUCEPSZrmbik
    0U,	// VREDUCEPSZrmbikz
    0U,	// VREDUCEPSZrmi
    0U,	// VREDUCEPSZrmik
    0U,	// VREDUCEPSZrmikz
    0U,	// VREDUCEPSZrri
    0U,	// VREDUCEPSZrrib
    0U,	// VREDUCEPSZrribk
    0U,	// VREDUCEPSZrribkz
    0U,	// VREDUCEPSZrrik
    0U,	// VREDUCEPSZrrikz
    0U,	// VREDUCESDZrmi
    0U,	// VREDUCESDZrmik
    3U,	// VREDUCESDZrmikz
    0U,	// VREDUCESDZrri
    0U,	// VREDUCESDZrrib
    0U,	// VREDUCESDZrribk
    3U,	// VREDUCESDZrribkz
    0U,	// VREDUCESDZrrik
    3U,	// VREDUCESDZrrikz
    0U,	// VREDUCESSZrmi
    0U,	// VREDUCESSZrmik
    3U,	// VREDUCESSZrmikz
    0U,	// VREDUCESSZrri
    0U,	// VREDUCESSZrrib
    0U,	// VREDUCESSZrribk
    3U,	// VREDUCESSZrribkz
    0U,	// VREDUCESSZrrik
    3U,	// VREDUCESSZrrikz
    0U,	// VRNDSCALEPDZ128rmbi
    0U,	// VRNDSCALEPDZ128rmbik
    0U,	// VRNDSCALEPDZ128rmbikz
    0U,	// VRNDSCALEPDZ128rmi
    0U,	// VRNDSCALEPDZ128rmik
    0U,	// VRNDSCALEPDZ128rmikz
    0U,	// VRNDSCALEPDZ128rri
    0U,	// VRNDSCALEPDZ128rrik
    0U,	// VRNDSCALEPDZ128rrikz
    0U,	// VRNDSCALEPDZ256rmbi
    0U,	// VRNDSCALEPDZ256rmbik
    0U,	// VRNDSCALEPDZ256rmbikz
    0U,	// VRNDSCALEPDZ256rmi
    0U,	// VRNDSCALEPDZ256rmik
    0U,	// VRNDSCALEPDZ256rmikz
    0U,	// VRNDSCALEPDZ256rri
    0U,	// VRNDSCALEPDZ256rrik
    0U,	// VRNDSCALEPDZ256rrikz
    0U,	// VRNDSCALEPDZrmbi
    0U,	// VRNDSCALEPDZrmbik
    0U,	// VRNDSCALEPDZrmbikz
    0U,	// VRNDSCALEPDZrmi
    0U,	// VRNDSCALEPDZrmik
    0U,	// VRNDSCALEPDZrmikz
    0U,	// VRNDSCALEPDZrri
    0U,	// VRNDSCALEPDZrrib
    0U,	// VRNDSCALEPDZrribk
    0U,	// VRNDSCALEPDZrribkz
    0U,	// VRNDSCALEPDZrrik
    0U,	// VRNDSCALEPDZrrikz
    0U,	// VRNDSCALEPSZ128rmbi
    0U,	// VRNDSCALEPSZ128rmbik
    0U,	// VRNDSCALEPSZ128rmbikz
    0U,	// VRNDSCALEPSZ128rmi
    0U,	// VRNDSCALEPSZ128rmik
    0U,	// VRNDSCALEPSZ128rmikz
    0U,	// VRNDSCALEPSZ128rri
    0U,	// VRNDSCALEPSZ128rrik
    0U,	// VRNDSCALEPSZ128rrikz
    0U,	// VRNDSCALEPSZ256rmbi
    0U,	// VRNDSCALEPSZ256rmbik
    0U,	// VRNDSCALEPSZ256rmbikz
    0U,	// VRNDSCALEPSZ256rmi
    0U,	// VRNDSCALEPSZ256rmik
    0U,	// VRNDSCALEPSZ256rmikz
    0U,	// VRNDSCALEPSZ256rri
    0U,	// VRNDSCALEPSZ256rrik
    0U,	// VRNDSCALEPSZ256rrikz
    0U,	// VRNDSCALEPSZrmbi
    0U,	// VRNDSCALEPSZrmbik
    0U,	// VRNDSCALEPSZrmbikz
    0U,	// VRNDSCALEPSZrmi
    0U,	// VRNDSCALEPSZrmik
    0U,	// VRNDSCALEPSZrmikz
    0U,	// VRNDSCALEPSZrri
    0U,	// VRNDSCALEPSZrrib
    0U,	// VRNDSCALEPSZrribk
    0U,	// VRNDSCALEPSZrribkz
    0U,	// VRNDSCALEPSZrrik
    0U,	// VRNDSCALEPSZrrikz
    0U,	// VRNDSCALESDZm
    0U,	// VRNDSCALESDZm_Int
    0U,	// VRNDSCALESDZm_Intk
    3U,	// VRNDSCALESDZm_Intkz
    0U,	// VRNDSCALESDZr
    0U,	// VRNDSCALESDZr_Int
    0U,	// VRNDSCALESDZr_Intk
    3U,	// VRNDSCALESDZr_Intkz
    0U,	// VRNDSCALESDZrb_Int
    0U,	// VRNDSCALESDZrb_Intk
    3U,	// VRNDSCALESDZrb_Intkz
    0U,	// VRNDSCALESSZm
    0U,	// VRNDSCALESSZm_Int
    0U,	// VRNDSCALESSZm_Intk
    3U,	// VRNDSCALESSZm_Intkz
    0U,	// VRNDSCALESSZr
    0U,	// VRNDSCALESSZr_Int
    0U,	// VRNDSCALESSZr_Intk
    3U,	// VRNDSCALESSZr_Intkz
    0U,	// VRNDSCALESSZrb_Int
    0U,	// VRNDSCALESSZrb_Intk
    3U,	// VRNDSCALESSZrb_Intkz
    0U,	// VROUNDPDYm
    0U,	// VROUNDPDYr
    0U,	// VROUNDPDm
    0U,	// VROUNDPDr
    0U,	// VROUNDPSYm
    0U,	// VROUNDPSYr
    0U,	// VROUNDPSm
    0U,	// VROUNDPSr
    0U,	// VROUNDSDm
    0U,	// VROUNDSDm_Int
    0U,	// VROUNDSDr
    0U,	// VROUNDSDr_Int
    0U,	// VROUNDSSm
    0U,	// VROUNDSSm_Int
    0U,	// VROUNDSSr
    0U,	// VROUNDSSr_Int
    0U,	// VRSQRT14PDZ128m
    0U,	// VRSQRT14PDZ128mb
    0U,	// VRSQRT14PDZ128mbk
    0U,	// VRSQRT14PDZ128mbkz
    0U,	// VRSQRT14PDZ128mk
    0U,	// VRSQRT14PDZ128mkz
    0U,	// VRSQRT14PDZ128r
    0U,	// VRSQRT14PDZ128rk
    0U,	// VRSQRT14PDZ128rkz
    0U,	// VRSQRT14PDZ256m
    0U,	// VRSQRT14PDZ256mb
    0U,	// VRSQRT14PDZ256mbk
    0U,	// VRSQRT14PDZ256mbkz
    0U,	// VRSQRT14PDZ256mk
    0U,	// VRSQRT14PDZ256mkz
    0U,	// VRSQRT14PDZ256r
    0U,	// VRSQRT14PDZ256rk
    0U,	// VRSQRT14PDZ256rkz
    0U,	// VRSQRT14PDZm
    0U,	// VRSQRT14PDZmb
    0U,	// VRSQRT14PDZmbk
    0U,	// VRSQRT14PDZmbkz
    0U,	// VRSQRT14PDZmk
    0U,	// VRSQRT14PDZmkz
    0U,	// VRSQRT14PDZr
    0U,	// VRSQRT14PDZrk
    0U,	// VRSQRT14PDZrkz
    0U,	// VRSQRT14PSZ128m
    0U,	// VRSQRT14PSZ128mb
    0U,	// VRSQRT14PSZ128mbk
    0U,	// VRSQRT14PSZ128mbkz
    0U,	// VRSQRT14PSZ128mk
    0U,	// VRSQRT14PSZ128mkz
    0U,	// VRSQRT14PSZ128r
    0U,	// VRSQRT14PSZ128rk
    0U,	// VRSQRT14PSZ128rkz
    0U,	// VRSQRT14PSZ256m
    0U,	// VRSQRT14PSZ256mb
    0U,	// VRSQRT14PSZ256mbk
    0U,	// VRSQRT14PSZ256mbkz
    0U,	// VRSQRT14PSZ256mk
    0U,	// VRSQRT14PSZ256mkz
    0U,	// VRSQRT14PSZ256r
    0U,	// VRSQRT14PSZ256rk
    0U,	// VRSQRT14PSZ256rkz
    0U,	// VRSQRT14PSZm
    0U,	// VRSQRT14PSZmb
    0U,	// VRSQRT14PSZmbk
    0U,	// VRSQRT14PSZmbkz
    0U,	// VRSQRT14PSZmk
    0U,	// VRSQRT14PSZmkz
    0U,	// VRSQRT14PSZr
    0U,	// VRSQRT14PSZrk
    0U,	// VRSQRT14PSZrkz
    0U,	// VRSQRT14SDZrm
    0U,	// VRSQRT14SDZrmk
    0U,	// VRSQRT14SDZrmkz
    0U,	// VRSQRT14SDZrr
    0U,	// VRSQRT14SDZrrk
    0U,	// VRSQRT14SDZrrkz
    0U,	// VRSQRT14SSZrm
    0U,	// VRSQRT14SSZrmk
    0U,	// VRSQRT14SSZrmkz
    0U,	// VRSQRT14SSZrr
    0U,	// VRSQRT14SSZrrk
    0U,	// VRSQRT14SSZrrkz
    0U,	// VRSQRT28PDZm
    0U,	// VRSQRT28PDZmb
    0U,	// VRSQRT28PDZmbk
    0U,	// VRSQRT28PDZmbkz
    0U,	// VRSQRT28PDZmk
    0U,	// VRSQRT28PDZmkz
    0U,	// VRSQRT28PDZr
    0U,	// VRSQRT28PDZrb
    0U,	// VRSQRT28PDZrbk
    0U,	// VRSQRT28PDZrbkz
    0U,	// VRSQRT28PDZrk
    0U,	// VRSQRT28PDZrkz
    0U,	// VRSQRT28PSZm
    0U,	// VRSQRT28PSZmb
    0U,	// VRSQRT28PSZmbk
    0U,	// VRSQRT28PSZmbkz
    0U,	// VRSQRT28PSZmk
    0U,	// VRSQRT28PSZmkz
    0U,	// VRSQRT28PSZr
    0U,	// VRSQRT28PSZrb
    0U,	// VRSQRT28PSZrbk
    0U,	// VRSQRT28PSZrbkz
    0U,	// VRSQRT28PSZrk
    0U,	// VRSQRT28PSZrkz
    0U,	// VRSQRT28SDZm
    0U,	// VRSQRT28SDZmk
    0U,	// VRSQRT28SDZmkz
    0U,	// VRSQRT28SDZr
    0U,	// VRSQRT28SDZrb
    0U,	// VRSQRT28SDZrbk
    0U,	// VRSQRT28SDZrbkz
    0U,	// VRSQRT28SDZrk
    0U,	// VRSQRT28SDZrkz
    0U,	// VRSQRT28SSZm
    0U,	// VRSQRT28SSZmk
    0U,	// VRSQRT28SSZmkz
    0U,	// VRSQRT28SSZr
    0U,	// VRSQRT28SSZrb
    0U,	// VRSQRT28SSZrbk
    0U,	// VRSQRT28SSZrbkz
    0U,	// VRSQRT28SSZrk
    0U,	// VRSQRT28SSZrkz
    0U,	// VRSQRTPSYm
    0U,	// VRSQRTPSYr
    0U,	// VRSQRTPSm
    0U,	// VRSQRTPSr
    0U,	// VRSQRTSSm
    0U,	// VRSQRTSSm_Int
    0U,	// VRSQRTSSr
    0U,	// VRSQRTSSr_Int
    0U,	// VSCALEFPDZ128rm
    0U,	// VSCALEFPDZ128rmb
    0U,	// VSCALEFPDZ128rmbk
    0U,	// VSCALEFPDZ128rmbkz
    0U,	// VSCALEFPDZ128rmk
    0U,	// VSCALEFPDZ128rmkz
    0U,	// VSCALEFPDZ128rr
    0U,	// VSCALEFPDZ128rrk
    0U,	// VSCALEFPDZ128rrkz
    0U,	// VSCALEFPDZ256rm
    0U,	// VSCALEFPDZ256rmb
    0U,	// VSCALEFPDZ256rmbk
    0U,	// VSCALEFPDZ256rmbkz
    0U,	// VSCALEFPDZ256rmk
    0U,	// VSCALEFPDZ256rmkz
    0U,	// VSCALEFPDZ256rr
    0U,	// VSCALEFPDZ256rrk
    0U,	// VSCALEFPDZ256rrkz
    0U,	// VSCALEFPDZrm
    0U,	// VSCALEFPDZrmb
    0U,	// VSCALEFPDZrmbk
    0U,	// VSCALEFPDZrmbkz
    0U,	// VSCALEFPDZrmk
    0U,	// VSCALEFPDZrmkz
    0U,	// VSCALEFPDZrr
    0U,	// VSCALEFPDZrrb
    0U,	// VSCALEFPDZrrbk
    0U,	// VSCALEFPDZrrbkz
    0U,	// VSCALEFPDZrrk
    0U,	// VSCALEFPDZrrkz
    0U,	// VSCALEFPSZ128rm
    0U,	// VSCALEFPSZ128rmb
    0U,	// VSCALEFPSZ128rmbk
    0U,	// VSCALEFPSZ128rmbkz
    0U,	// VSCALEFPSZ128rmk
    0U,	// VSCALEFPSZ128rmkz
    0U,	// VSCALEFPSZ128rr
    0U,	// VSCALEFPSZ128rrk
    0U,	// VSCALEFPSZ128rrkz
    0U,	// VSCALEFPSZ256rm
    0U,	// VSCALEFPSZ256rmb
    0U,	// VSCALEFPSZ256rmbk
    0U,	// VSCALEFPSZ256rmbkz
    0U,	// VSCALEFPSZ256rmk
    0U,	// VSCALEFPSZ256rmkz
    0U,	// VSCALEFPSZ256rr
    0U,	// VSCALEFPSZ256rrk
    0U,	// VSCALEFPSZ256rrkz
    0U,	// VSCALEFPSZrm
    0U,	// VSCALEFPSZrmb
    0U,	// VSCALEFPSZrmbk
    0U,	// VSCALEFPSZrmbkz
    0U,	// VSCALEFPSZrmk
    0U,	// VSCALEFPSZrmkz
    0U,	// VSCALEFPSZrr
    0U,	// VSCALEFPSZrrb
    0U,	// VSCALEFPSZrrbk
    0U,	// VSCALEFPSZrrbkz
    0U,	// VSCALEFPSZrrk
    0U,	// VSCALEFPSZrrkz
    0U,	// VSCALEFSDZrm
    0U,	// VSCALEFSDZrmk
    0U,	// VSCALEFSDZrmkz
    0U,	// VSCALEFSDZrr
    0U,	// VSCALEFSDZrrb_Int
    0U,	// VSCALEFSDZrrb_Intk
    0U,	// VSCALEFSDZrrb_Intkz
    0U,	// VSCALEFSDZrrk
    0U,	// VSCALEFSDZrrkz
    0U,	// VSCALEFSSZrm
    0U,	// VSCALEFSSZrmk
    0U,	// VSCALEFSSZrmkz
    0U,	// VSCALEFSSZrr
    0U,	// VSCALEFSSZrrb_Int
    0U,	// VSCALEFSSZrrb_Intk
    0U,	// VSCALEFSSZrrb_Intkz
    0U,	// VSCALEFSSZrrk
    0U,	// VSCALEFSSZrrkz
    0U,	// VSCATTERDPDZ128mr
    0U,	// VSCATTERDPDZ256mr
    0U,	// VSCATTERDPDZmr
    0U,	// VSCATTERDPSZ128mr
    0U,	// VSCATTERDPSZ256mr
    0U,	// VSCATTERDPSZmr
    0U,	// VSCATTERPF0DPDm
    0U,	// VSCATTERPF0DPSm
    0U,	// VSCATTERPF0QPDm
    0U,	// VSCATTERPF0QPSm
    0U,	// VSCATTERPF1DPDm
    0U,	// VSCATTERPF1DPSm
    0U,	// VSCATTERPF1QPDm
    0U,	// VSCATTERPF1QPSm
    0U,	// VSCATTERQPDZ128mr
    0U,	// VSCATTERQPDZ256mr
    0U,	// VSCATTERQPDZmr
    0U,	// VSCATTERQPSZ128mr
    0U,	// VSCATTERQPSZ256mr
    0U,	// VSCATTERQPSZmr
    0U,	// VSHUFF32X4Z256rmbi
    0U,	// VSHUFF32X4Z256rmbik
    3U,	// VSHUFF32X4Z256rmbikz
    0U,	// VSHUFF32X4Z256rmi
    0U,	// VSHUFF32X4Z256rmik
    0U,	// VSHUFF32X4Z256rmikz
    0U,	// VSHUFF32X4Z256rri
    0U,	// VSHUFF32X4Z256rrik
    3U,	// VSHUFF32X4Z256rrikz
    0U,	// VSHUFF32X4Zrmbi
    0U,	// VSHUFF32X4Zrmbik
    3U,	// VSHUFF32X4Zrmbikz
    0U,	// VSHUFF32X4Zrmi
    0U,	// VSHUFF32X4Zrmik
    0U,	// VSHUFF32X4Zrmikz
    0U,	// VSHUFF32X4Zrri
    0U,	// VSHUFF32X4Zrrik
    3U,	// VSHUFF32X4Zrrikz
    0U,	// VSHUFF64X2Z256rmbi
    0U,	// VSHUFF64X2Z256rmbik
    3U,	// VSHUFF64X2Z256rmbikz
    0U,	// VSHUFF64X2Z256rmi
    0U,	// VSHUFF64X2Z256rmik
    0U,	// VSHUFF64X2Z256rmikz
    0U,	// VSHUFF64X2Z256rri
    0U,	// VSHUFF64X2Z256rrik
    3U,	// VSHUFF64X2Z256rrikz
    0U,	// VSHUFF64X2Zrmbi
    0U,	// VSHUFF64X2Zrmbik
    3U,	// VSHUFF64X2Zrmbikz
    0U,	// VSHUFF64X2Zrmi
    0U,	// VSHUFF64X2Zrmik
    0U,	// VSHUFF64X2Zrmikz
    0U,	// VSHUFF64X2Zrri
    0U,	// VSHUFF64X2Zrrik
    3U,	// VSHUFF64X2Zrrikz
    0U,	// VSHUFI32X4Z256rmbi
    0U,	// VSHUFI32X4Z256rmbik
    3U,	// VSHUFI32X4Z256rmbikz
    0U,	// VSHUFI32X4Z256rmi
    0U,	// VSHUFI32X4Z256rmik
    0U,	// VSHUFI32X4Z256rmikz
    0U,	// VSHUFI32X4Z256rri
    0U,	// VSHUFI32X4Z256rrik
    3U,	// VSHUFI32X4Z256rrikz
    0U,	// VSHUFI32X4Zrmbi
    0U,	// VSHUFI32X4Zrmbik
    3U,	// VSHUFI32X4Zrmbikz
    0U,	// VSHUFI32X4Zrmi
    0U,	// VSHUFI32X4Zrmik
    0U,	// VSHUFI32X4Zrmikz
    0U,	// VSHUFI32X4Zrri
    0U,	// VSHUFI32X4Zrrik
    3U,	// VSHUFI32X4Zrrikz
    0U,	// VSHUFI64X2Z256rmbi
    0U,	// VSHUFI64X2Z256rmbik
    3U,	// VSHUFI64X2Z256rmbikz
    0U,	// VSHUFI64X2Z256rmi
    0U,	// VSHUFI64X2Z256rmik
    0U,	// VSHUFI64X2Z256rmikz
    0U,	// VSHUFI64X2Z256rri
    0U,	// VSHUFI64X2Z256rrik
    3U,	// VSHUFI64X2Z256rrikz
    0U,	// VSHUFI64X2Zrmbi
    0U,	// VSHUFI64X2Zrmbik
    3U,	// VSHUFI64X2Zrmbikz
    0U,	// VSHUFI64X2Zrmi
    0U,	// VSHUFI64X2Zrmik
    0U,	// VSHUFI64X2Zrmikz
    0U,	// VSHUFI64X2Zrri
    0U,	// VSHUFI64X2Zrrik
    3U,	// VSHUFI64X2Zrrikz
    0U,	// VSHUFPDYrmi
    0U,	// VSHUFPDYrri
    0U,	// VSHUFPDZ128rmbi
    0U,	// VSHUFPDZ128rmbik
    3U,	// VSHUFPDZ128rmbikz
    0U,	// VSHUFPDZ128rmi
    0U,	// VSHUFPDZ128rmik
    0U,	// VSHUFPDZ128rmikz
    0U,	// VSHUFPDZ128rri
    0U,	// VSHUFPDZ128rrik
    3U,	// VSHUFPDZ128rrikz
    0U,	// VSHUFPDZ256rmbi
    0U,	// VSHUFPDZ256rmbik
    3U,	// VSHUFPDZ256rmbikz
    0U,	// VSHUFPDZ256rmi
    0U,	// VSHUFPDZ256rmik
    0U,	// VSHUFPDZ256rmikz
    0U,	// VSHUFPDZ256rri
    0U,	// VSHUFPDZ256rrik
    3U,	// VSHUFPDZ256rrikz
    0U,	// VSHUFPDZrmbi
    0U,	// VSHUFPDZrmbik
    3U,	// VSHUFPDZrmbikz
    0U,	// VSHUFPDZrmi
    0U,	// VSHUFPDZrmik
    0U,	// VSHUFPDZrmikz
    0U,	// VSHUFPDZrri
    0U,	// VSHUFPDZrrik
    3U,	// VSHUFPDZrrikz
    0U,	// VSHUFPDrmi
    0U,	// VSHUFPDrri
    0U,	// VSHUFPSYrmi
    0U,	// VSHUFPSYrri
    0U,	// VSHUFPSZ128rmbi
    0U,	// VSHUFPSZ128rmbik
    3U,	// VSHUFPSZ128rmbikz
    0U,	// VSHUFPSZ128rmi
    0U,	// VSHUFPSZ128rmik
    0U,	// VSHUFPSZ128rmikz
    0U,	// VSHUFPSZ128rri
    0U,	// VSHUFPSZ128rrik
    3U,	// VSHUFPSZ128rrikz
    0U,	// VSHUFPSZ256rmbi
    0U,	// VSHUFPSZ256rmbik
    3U,	// VSHUFPSZ256rmbikz
    0U,	// VSHUFPSZ256rmi
    0U,	// VSHUFPSZ256rmik
    0U,	// VSHUFPSZ256rmikz
    0U,	// VSHUFPSZ256rri
    0U,	// VSHUFPSZ256rrik
    3U,	// VSHUFPSZ256rrikz
    0U,	// VSHUFPSZrmbi
    0U,	// VSHUFPSZrmbik
    3U,	// VSHUFPSZrmbikz
    0U,	// VSHUFPSZrmi
    0U,	// VSHUFPSZrmik
    0U,	// VSHUFPSZrmikz
    0U,	// VSHUFPSZrri
    0U,	// VSHUFPSZrrik
    3U,	// VSHUFPSZrrikz
    0U,	// VSHUFPSrmi
    0U,	// VSHUFPSrri
    0U,	// VSQRTPDYm
    0U,	// VSQRTPDYr
    0U,	// VSQRTPDZ128m
    0U,	// VSQRTPDZ128mb
    0U,	// VSQRTPDZ128mbk
    0U,	// VSQRTPDZ128mbkz
    0U,	// VSQRTPDZ128mk
    0U,	// VSQRTPDZ128mkz
    0U,	// VSQRTPDZ128r
    0U,	// VSQRTPDZ128rk
    0U,	// VSQRTPDZ128rkz
    0U,	// VSQRTPDZ256m
    0U,	// VSQRTPDZ256mb
    0U,	// VSQRTPDZ256mbk
    0U,	// VSQRTPDZ256mbkz
    0U,	// VSQRTPDZ256mk
    0U,	// VSQRTPDZ256mkz
    0U,	// VSQRTPDZ256r
    0U,	// VSQRTPDZ256rk
    0U,	// VSQRTPDZ256rkz
    0U,	// VSQRTPDZm
    0U,	// VSQRTPDZmb
    0U,	// VSQRTPDZmbk
    0U,	// VSQRTPDZmbkz
    0U,	// VSQRTPDZmk
    0U,	// VSQRTPDZmkz
    0U,	// VSQRTPDZr
    0U,	// VSQRTPDZrb
    0U,	// VSQRTPDZrbk
    0U,	// VSQRTPDZrbkz
    0U,	// VSQRTPDZrk
    0U,	// VSQRTPDZrkz
    0U,	// VSQRTPDm
    0U,	// VSQRTPDr
    0U,	// VSQRTPSYm
    0U,	// VSQRTPSYr
    0U,	// VSQRTPSZ128m
    0U,	// VSQRTPSZ128mb
    0U,	// VSQRTPSZ128mbk
    0U,	// VSQRTPSZ128mbkz
    0U,	// VSQRTPSZ128mk
    0U,	// VSQRTPSZ128mkz
    0U,	// VSQRTPSZ128r
    0U,	// VSQRTPSZ128rk
    0U,	// VSQRTPSZ128rkz
    0U,	// VSQRTPSZ256m
    0U,	// VSQRTPSZ256mb
    0U,	// VSQRTPSZ256mbk
    0U,	// VSQRTPSZ256mbkz
    0U,	// VSQRTPSZ256mk
    0U,	// VSQRTPSZ256mkz
    0U,	// VSQRTPSZ256r
    0U,	// VSQRTPSZ256rk
    0U,	// VSQRTPSZ256rkz
    0U,	// VSQRTPSZm
    0U,	// VSQRTPSZmb
    0U,	// VSQRTPSZmbk
    0U,	// VSQRTPSZmbkz
    0U,	// VSQRTPSZmk
    0U,	// VSQRTPSZmkz
    0U,	// VSQRTPSZr
    0U,	// VSQRTPSZrb
    0U,	// VSQRTPSZrbk
    0U,	// VSQRTPSZrbkz
    0U,	// VSQRTPSZrk
    0U,	// VSQRTPSZrkz
    0U,	// VSQRTPSm
    0U,	// VSQRTPSr
    0U,	// VSQRTSDZm
    0U,	// VSQRTSDZm_Int
    0U,	// VSQRTSDZm_Intk
    0U,	// VSQRTSDZm_Intkz
    0U,	// VSQRTSDZr
    0U,	// VSQRTSDZr_Int
    0U,	// VSQRTSDZr_Intk
    0U,	// VSQRTSDZr_Intkz
    0U,	// VSQRTSDZrb_Int
    0U,	// VSQRTSDZrb_Intk
    0U,	// VSQRTSDZrb_Intkz
    0U,	// VSQRTSDm
    0U,	// VSQRTSDm_Int
    0U,	// VSQRTSDr
    0U,	// VSQRTSDr_Int
    0U,	// VSQRTSSZm
    0U,	// VSQRTSSZm_Int
    0U,	// VSQRTSSZm_Intk
    0U,	// VSQRTSSZm_Intkz
    0U,	// VSQRTSSZr
    0U,	// VSQRTSSZr_Int
    0U,	// VSQRTSSZr_Intk
    0U,	// VSQRTSSZr_Intkz
    0U,	// VSQRTSSZrb_Int
    0U,	// VSQRTSSZrb_Intk
    0U,	// VSQRTSSZrb_Intkz
    0U,	// VSQRTSSm
    0U,	// VSQRTSSm_Int
    0U,	// VSQRTSSr
    0U,	// VSQRTSSr_Int
    0U,	// VSTMXCSR
    0U,	// VSUBPDYrm
    0U,	// VSUBPDYrr
    0U,	// VSUBPDZ128rm
    0U,	// VSUBPDZ128rmb
    0U,	// VSUBPDZ128rmbk
    0U,	// VSUBPDZ128rmbkz
    0U,	// VSUBPDZ128rmk
    0U,	// VSUBPDZ128rmkz
    0U,	// VSUBPDZ128rr
    0U,	// VSUBPDZ128rrk
    0U,	// VSUBPDZ128rrkz
    0U,	// VSUBPDZ256rm
    0U,	// VSUBPDZ256rmb
    0U,	// VSUBPDZ256rmbk
    0U,	// VSUBPDZ256rmbkz
    0U,	// VSUBPDZ256rmk
    0U,	// VSUBPDZ256rmkz
    0U,	// VSUBPDZ256rr
    0U,	// VSUBPDZ256rrk
    0U,	// VSUBPDZ256rrkz
    0U,	// VSUBPDZrm
    0U,	// VSUBPDZrmb
    0U,	// VSUBPDZrmbk
    0U,	// VSUBPDZrmbkz
    0U,	// VSUBPDZrmk
    0U,	// VSUBPDZrmkz
    0U,	// VSUBPDZrr
    0U,	// VSUBPDZrrb
    0U,	// VSUBPDZrrbk
    0U,	// VSUBPDZrrbkz
    0U,	// VSUBPDZrrk
    0U,	// VSUBPDZrrkz
    0U,	// VSUBPDrm
    0U,	// VSUBPDrr
    0U,	// VSUBPSYrm
    0U,	// VSUBPSYrr
    0U,	// VSUBPSZ128rm
    0U,	// VSUBPSZ128rmb
    0U,	// VSUBPSZ128rmbk
    0U,	// VSUBPSZ128rmbkz
    0U,	// VSUBPSZ128rmk
    0U,	// VSUBPSZ128rmkz
    0U,	// VSUBPSZ128rr
    0U,	// VSUBPSZ128rrk
    0U,	// VSUBPSZ128rrkz
    0U,	// VSUBPSZ256rm
    0U,	// VSUBPSZ256rmb
    0U,	// VSUBPSZ256rmbk
    0U,	// VSUBPSZ256rmbkz
    0U,	// VSUBPSZ256rmk
    0U,	// VSUBPSZ256rmkz
    0U,	// VSUBPSZ256rr
    0U,	// VSUBPSZ256rrk
    0U,	// VSUBPSZ256rrkz
    0U,	// VSUBPSZrm
    0U,	// VSUBPSZrmb
    0U,	// VSUBPSZrmbk
    0U,	// VSUBPSZrmbkz
    0U,	// VSUBPSZrmk
    0U,	// VSUBPSZrmkz
    0U,	// VSUBPSZrr
    0U,	// VSUBPSZrrb
    0U,	// VSUBPSZrrbk
    0U,	// VSUBPSZrrbkz
    0U,	// VSUBPSZrrk
    0U,	// VSUBPSZrrkz
    0U,	// VSUBPSrm
    0U,	// VSUBPSrr
    0U,	// VSUBSDZrm
    0U,	// VSUBSDZrm_Int
    0U,	// VSUBSDZrm_Intk
    0U,	// VSUBSDZrm_Intkz
    0U,	// VSUBSDZrr
    0U,	// VSUBSDZrr_Int
    0U,	// VSUBSDZrr_Intk
    0U,	// VSUBSDZrr_Intkz
    0U,	// VSUBSDZrrb_Int
    0U,	// VSUBSDZrrb_Intk
    0U,	// VSUBSDZrrb_Intkz
    0U,	// VSUBSDrm
    0U,	// VSUBSDrm_Int
    0U,	// VSUBSDrr
    0U,	// VSUBSDrr_Int
    0U,	// VSUBSSZrm
    0U,	// VSUBSSZrm_Int
    0U,	// VSUBSSZrm_Intk
    0U,	// VSUBSSZrm_Intkz
    0U,	// VSUBSSZrr
    0U,	// VSUBSSZrr_Int
    0U,	// VSUBSSZrr_Intk
    0U,	// VSUBSSZrr_Intkz
    0U,	// VSUBSSZrrb_Int
    0U,	// VSUBSSZrrb_Intk
    0U,	// VSUBSSZrrb_Intkz
    0U,	// VSUBSSrm
    0U,	// VSUBSSrm_Int
    0U,	// VSUBSSrr
    0U,	// VSUBSSrr_Int
    0U,	// VTESTPDYrm
    0U,	// VTESTPDYrr
    0U,	// VTESTPDrm
    0U,	// VTESTPDrr
    0U,	// VTESTPSYrm
    0U,	// VTESTPSYrr
    0U,	// VTESTPSrm
    0U,	// VTESTPSrr
    0U,	// VUCOMISDZrm
    0U,	// VUCOMISDZrm_Int
    0U,	// VUCOMISDZrr
    0U,	// VUCOMISDZrr_Int
    0U,	// VUCOMISDZrrb
    0U,	// VUCOMISDrm
    0U,	// VUCOMISDrm_Int
    0U,	// VUCOMISDrr
    0U,	// VUCOMISDrr_Int
    0U,	// VUCOMISSZrm
    0U,	// VUCOMISSZrm_Int
    0U,	// VUCOMISSZrr
    0U,	// VUCOMISSZrr_Int
    0U,	// VUCOMISSZrrb
    0U,	// VUCOMISSrm
    0U,	// VUCOMISSrm_Int
    0U,	// VUCOMISSrr
    0U,	// VUCOMISSrr_Int
    0U,	// VUNPCKHPDYrm
    0U,	// VUNPCKHPDYrr
    0U,	// VUNPCKHPDZ128rm
    0U,	// VUNPCKHPDZ128rmb
    0U,	// VUNPCKHPDZ128rmbk
    0U,	// VUNPCKHPDZ128rmbkz
    0U,	// VUNPCKHPDZ128rmk
    0U,	// VUNPCKHPDZ128rmkz
    0U,	// VUNPCKHPDZ128rr
    0U,	// VUNPCKHPDZ128rrk
    0U,	// VUNPCKHPDZ128rrkz
    0U,	// VUNPCKHPDZ256rm
    0U,	// VUNPCKHPDZ256rmb
    0U,	// VUNPCKHPDZ256rmbk
    0U,	// VUNPCKHPDZ256rmbkz
    0U,	// VUNPCKHPDZ256rmk
    0U,	// VUNPCKHPDZ256rmkz
    0U,	// VUNPCKHPDZ256rr
    0U,	// VUNPCKHPDZ256rrk
    0U,	// VUNPCKHPDZ256rrkz
    0U,	// VUNPCKHPDZrm
    0U,	// VUNPCKHPDZrmb
    0U,	// VUNPCKHPDZrmbk
    0U,	// VUNPCKHPDZrmbkz
    0U,	// VUNPCKHPDZrmk
    0U,	// VUNPCKHPDZrmkz
    0U,	// VUNPCKHPDZrr
    0U,	// VUNPCKHPDZrrk
    0U,	// VUNPCKHPDZrrkz
    0U,	// VUNPCKHPDrm
    0U,	// VUNPCKHPDrr
    0U,	// VUNPCKHPSYrm
    0U,	// VUNPCKHPSYrr
    0U,	// VUNPCKHPSZ128rm
    0U,	// VUNPCKHPSZ128rmb
    0U,	// VUNPCKHPSZ128rmbk
    0U,	// VUNPCKHPSZ128rmbkz
    0U,	// VUNPCKHPSZ128rmk
    0U,	// VUNPCKHPSZ128rmkz
    0U,	// VUNPCKHPSZ128rr
    0U,	// VUNPCKHPSZ128rrk
    0U,	// VUNPCKHPSZ128rrkz
    0U,	// VUNPCKHPSZ256rm
    0U,	// VUNPCKHPSZ256rmb
    0U,	// VUNPCKHPSZ256rmbk
    0U,	// VUNPCKHPSZ256rmbkz
    0U,	// VUNPCKHPSZ256rmk
    0U,	// VUNPCKHPSZ256rmkz
    0U,	// VUNPCKHPSZ256rr
    0U,	// VUNPCKHPSZ256rrk
    0U,	// VUNPCKHPSZ256rrkz
    0U,	// VUNPCKHPSZrm
    0U,	// VUNPCKHPSZrmb
    0U,	// VUNPCKHPSZrmbk
    0U,	// VUNPCKHPSZrmbkz
    0U,	// VUNPCKHPSZrmk
    0U,	// VUNPCKHPSZrmkz
    0U,	// VUNPCKHPSZrr
    0U,	// VUNPCKHPSZrrk
    0U,	// VUNPCKHPSZrrkz
    0U,	// VUNPCKHPSrm
    0U,	// VUNPCKHPSrr
    0U,	// VUNPCKLPDYrm
    0U,	// VUNPCKLPDYrr
    0U,	// VUNPCKLPDZ128rm
    0U,	// VUNPCKLPDZ128rmb
    0U,	// VUNPCKLPDZ128rmbk
    0U,	// VUNPCKLPDZ128rmbkz
    0U,	// VUNPCKLPDZ128rmk
    0U,	// VUNPCKLPDZ128rmkz
    0U,	// VUNPCKLPDZ128rr
    0U,	// VUNPCKLPDZ128rrk
    0U,	// VUNPCKLPDZ128rrkz
    0U,	// VUNPCKLPDZ256rm
    0U,	// VUNPCKLPDZ256rmb
    0U,	// VUNPCKLPDZ256rmbk
    0U,	// VUNPCKLPDZ256rmbkz
    0U,	// VUNPCKLPDZ256rmk
    0U,	// VUNPCKLPDZ256rmkz
    0U,	// VUNPCKLPDZ256rr
    0U,	// VUNPCKLPDZ256rrk
    0U,	// VUNPCKLPDZ256rrkz
    0U,	// VUNPCKLPDZrm
    0U,	// VUNPCKLPDZrmb
    0U,	// VUNPCKLPDZrmbk
    0U,	// VUNPCKLPDZrmbkz
    0U,	// VUNPCKLPDZrmk
    0U,	// VUNPCKLPDZrmkz
    0U,	// VUNPCKLPDZrr
    0U,	// VUNPCKLPDZrrk
    0U,	// VUNPCKLPDZrrkz
    0U,	// VUNPCKLPDrm
    0U,	// VUNPCKLPDrr
    0U,	// VUNPCKLPSYrm
    0U,	// VUNPCKLPSYrr
    0U,	// VUNPCKLPSZ128rm
    0U,	// VUNPCKLPSZ128rmb
    0U,	// VUNPCKLPSZ128rmbk
    0U,	// VUNPCKLPSZ128rmbkz
    0U,	// VUNPCKLPSZ128rmk
    0U,	// VUNPCKLPSZ128rmkz
    0U,	// VUNPCKLPSZ128rr
    0U,	// VUNPCKLPSZ128rrk
    0U,	// VUNPCKLPSZ128rrkz
    0U,	// VUNPCKLPSZ256rm
    0U,	// VUNPCKLPSZ256rmb
    0U,	// VUNPCKLPSZ256rmbk
    0U,	// VUNPCKLPSZ256rmbkz
    0U,	// VUNPCKLPSZ256rmk
    0U,	// VUNPCKLPSZ256rmkz
    0U,	// VUNPCKLPSZ256rr
    0U,	// VUNPCKLPSZ256rrk
    0U,	// VUNPCKLPSZ256rrkz
    0U,	// VUNPCKLPSZrm
    0U,	// VUNPCKLPSZrmb
    0U,	// VUNPCKLPSZrmbk
    0U,	// VUNPCKLPSZrmbkz
    0U,	// VUNPCKLPSZrmk
    0U,	// VUNPCKLPSZrmkz
    0U,	// VUNPCKLPSZrr
    0U,	// VUNPCKLPSZrrk
    0U,	// VUNPCKLPSZrrkz
    0U,	// VUNPCKLPSrm
    0U,	// VUNPCKLPSrr
    0U,	// VXORPDYrm
    0U,	// VXORPDYrr
    0U,	// VXORPDZ128rm
    0U,	// VXORPDZ128rmb
    0U,	// VXORPDZ128rmbk
    0U,	// VXORPDZ128rmbkz
    0U,	// VXORPDZ128rmk
    0U,	// VXORPDZ128rmkz
    0U,	// VXORPDZ128rr
    0U,	// VXORPDZ128rrk
    0U,	// VXORPDZ128rrkz
    0U,	// VXORPDZ256rm
    0U,	// VXORPDZ256rmb
    0U,	// VXORPDZ256rmbk
    0U,	// VXORPDZ256rmbkz
    0U,	// VXORPDZ256rmk
    0U,	// VXORPDZ256rmkz
    0U,	// VXORPDZ256rr
    0U,	// VXORPDZ256rrk
    0U,	// VXORPDZ256rrkz
    0U,	// VXORPDZrm
    0U,	// VXORPDZrmb
    0U,	// VXORPDZrmbk
    0U,	// VXORPDZrmbkz
    0U,	// VXORPDZrmk
    0U,	// VXORPDZrmkz
    0U,	// VXORPDZrr
    0U,	// VXORPDZrrk
    0U,	// VXORPDZrrkz
    0U,	// VXORPDrm
    0U,	// VXORPDrr
    0U,	// VXORPSYrm
    0U,	// VXORPSYrr
    0U,	// VXORPSZ128rm
    0U,	// VXORPSZ128rmb
    0U,	// VXORPSZ128rmbk
    0U,	// VXORPSZ128rmbkz
    0U,	// VXORPSZ128rmk
    0U,	// VXORPSZ128rmkz
    0U,	// VXORPSZ128rr
    0U,	// VXORPSZ128rrk
    0U,	// VXORPSZ128rrkz
    0U,	// VXORPSZ256rm
    0U,	// VXORPSZ256rmb
    0U,	// VXORPSZ256rmbk
    0U,	// VXORPSZ256rmbkz
    0U,	// VXORPSZ256rmk
    0U,	// VXORPSZ256rmkz
    0U,	// VXORPSZ256rr
    0U,	// VXORPSZ256rrk
    0U,	// VXORPSZ256rrkz
    0U,	// VXORPSZrm
    0U,	// VXORPSZrmb
    0U,	// VXORPSZrmbk
    0U,	// VXORPSZrmbkz
    0U,	// VXORPSZrmk
    0U,	// VXORPSZrmkz
    0U,	// VXORPSZrr
    0U,	// VXORPSZrrk
    0U,	// VXORPSZrrkz
    0U,	// VXORPSrm
    0U,	// VXORPSrr
    0U,	// VZEROALL
    0U,	// VZEROUPPER
    0U,	// WAIT
    0U,	// WBINVD
    0U,	// WBNOINVD
    0U,	// WRFSBASE
    0U,	// WRFSBASE64
    0U,	// WRGSBASE
    0U,	// WRGSBASE64
    0U,	// WRMSR
    0U,	// WRPKRUr
    0U,	// WRSSD
    0U,	// WRSSQ
    0U,	// WRUSSD
    0U,	// WRUSSQ
    0U,	// XABORT
    0U,	// XACQUIRE_PREFIX
    0U,	// XADD16rm
    0U,	// XADD16rr
    0U,	// XADD32rm
    0U,	// XADD32rr
    0U,	// XADD64rm
    0U,	// XADD64rr
    0U,	// XADD8rm
    0U,	// XADD8rr
    0U,	// XBEGIN_2
    0U,	// XBEGIN_4
    0U,	// XCHG16ar
    0U,	// XCHG16rm
    0U,	// XCHG16rr
    0U,	// XCHG32ar
    0U,	// XCHG32rm
    0U,	// XCHG32rr
    0U,	// XCHG64ar
    0U,	// XCHG64rm
    0U,	// XCHG64rr
    0U,	// XCHG8rm
    0U,	// XCHG8rr
    0U,	// XCH_F
    0U,	// XCRYPTCBC
    0U,	// XCRYPTCFB
    0U,	// XCRYPTCTR
    0U,	// XCRYPTECB
    0U,	// XCRYPTOFB
    0U,	// XEND
    0U,	// XGETBV
    0U,	// XLAT
    0U,	// XOR16i16
    0U,	// XOR16mi
    0U,	// XOR16mi8
    0U,	// XOR16mr
    0U,	// XOR16ri
    0U,	// XOR16ri8
    0U,	// XOR16rm
    0U,	// XOR16rr
    0U,	// XOR16rr_REV
    0U,	// XOR32i32
    0U,	// XOR32mi
    0U,	// XOR32mi8
    0U,	// XOR32mr
    0U,	// XOR32ri
    0U,	// XOR32ri8
    0U,	// XOR32rm
    0U,	// XOR32rr
    0U,	// XOR32rr_REV
    0U,	// XOR64i32
    0U,	// XOR64mi32
    0U,	// XOR64mi8
    0U,	// XOR64mr
    0U,	// XOR64ri32
    0U,	// XOR64ri8
    0U,	// XOR64rm
    0U,	// XOR64rr
    0U,	// XOR64rr_REV
    0U,	// XOR8i8
    0U,	// XOR8mi
    0U,	// XOR8mi8
    0U,	// XOR8mr
    0U,	// XOR8ri
    0U,	// XOR8ri8
    0U,	// XOR8rm
    0U,	// XOR8rr
    0U,	// XOR8rr_REV
    0U,	// XORPDrm
    0U,	// XORPDrr
    0U,	// XORPSrm
    0U,	// XORPSrr
    0U,	// XRELEASE_PREFIX
    0U,	// XRSTOR
    0U,	// XRSTOR64
    0U,	// XRSTORS
    0U,	// XRSTORS64
    0U,	// XSAVE
    0U,	// XSAVE64
    0U,	// XSAVEC
    0U,	// XSAVEC64
    0U,	// XSAVEOPT
    0U,	// XSAVEOPT64
    0U,	// XSAVES
    0U,	// XSAVES64
    0U,	// XSETBV
    0U,	// XSHA1
    0U,	// XSHA256
    0U,	// XSTORE
    0U,	// XTEST
  };

  unsigned int opcode = MCInst_getOpcode(MI);
  // printf("opcode = %u\n", opcode);

  // Emit the opcode for the instruction.
  uint64_t Bits = 0;
  Bits |= (uint64_t)OpInfo0[opcode] << 0;
  Bits |= (uint64_t)OpInfo1[opcode] << 32;
  Bits |= (uint64_t)OpInfo2[opcode] << 48;
  SStream_concat0(O, AsmStrs+(Bits & 16383)-1);


  // Fragment 0 encoded into 7 bits for 103 unique commands.
  // printf("Fragment 0: %"PRIu64"\n", ((Bits >> 14) & 127));
  switch ((Bits >> 14) & 127) {
  default: // unreachable
  case 0:
    // DBG_VALUE, DBG_LABEL, BUNDLE, LIFETIME_START, LIFETIME_END, FENTRY_CAL...
    return;
    break;
  case 1:
    // AAD8i8, AAM8i8, ADC16i16, ADC32i32, ADC64i32, ADC8i8, ADD16i16, ADD32i...
    printOperand(MI, 0, O);
    break;
  case 2:
    // ADC16mi, ADC16mi8, ADC16mr, ADC32mi, ADC32mi8, ADC32mr, ADC64mi32, ADC...
    printOperand(MI, 5, O);
    SStream_concat0(O, ", ");
    break;
  case 3:
    // ADC16ri, ADC16ri8, ADC16rr, ADC16rr_REV, ADC32ri, ADC32ri8, ADC32rr, A...
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 4:
    // ADC16rm, ADD16rm, AND16rm, CMOVA16rm, CMOVAE16rm, CMOVB16rm, CMOVBE16r...
    printi16mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 5:
    // ADC32rm, ADCX32rm, ADD32rm, ADOX32rm, AND32rm, ANDN32rm, CMOVA32rm, CM...
    printi32mem(MI, 2, O);
    break;
  case 6:
    // ADC64rm, ADCX64rm, ADD64rm, ADOX64rm, AND64rm, ANDN64rm, CMOVA64rm, CM...
    printi64mem(MI, 2, O);
    break;
  case 7:
    // ADC8rm, ADD8rm, AND8rm, CRC32r32m8, CRC32r64m8, OR8rm, SBB8rm, SUB8rm,...
    printi8mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 8:
    // ADDPDrm, ADDPSrm, ADDSUBPDrm, ADDSUBPSrm, ANDNPDrm, ANDNPSrm, ANDPDrm,...
    printf128mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 9:
    // ADDSDrm, ADDSDrm_Int, CVTSD2SSrm_Int, DIVSDrm, DIVSDrm_Int, MAXCSDrm, ...
    printf64mem(MI, 2, O);
    break;
  case 10:
    // ADDSSrm, ADDSSrm_Int, CVTSS2SDrm_Int, DIVSSrm, DIVSSrm_Int, MAXCSSrm, ...
    printf32mem(MI, 2, O);
    break;
  case 11:
    // ADD_F32m, DIVR_F32m, DIV_F32m, FCOM32m, FCOMP32m, FLDENVm, FRSTORm, FS...
    printf32mem(MI, 0, O);
    return;
    break;
  case 12:
    // ADD_F64m, DIVR_F64m, DIV_F64m, FCOM64m, FCOMP64m, LD_F64m, MUL_F64m, S...
    printf64mem(MI, 0, O);
    return;
    break;
  case 13:
    // ADD_FI16m, CALL16m, CALL16m_NT, DEC16m, DIV16m, DIVR_FI16m, DIV_FI16m,...
    printi16mem(MI, 0, O);
    return;
    break;
  case 14:
    // ADD_FI32m, CALL32m, CALL32m_NT, CLRSSBSY, DEC32m, DIV32m, DIVR_FI32m, ...
    printi32mem(MI, 0, O);
    return;
    break;
  case 15:
    // AESDECLASTrm, AESDECrm, AESENCLASTrm, AESENCrm, GF2P8MULBrm, PACKSSDWr...
    printi128mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 16:
    // AESIMCrm, BNDMOV64rm, CVTDQ2PSrm, INVEPT32, INVEPT64, INVPCID32, INVPC...
    printi128mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 17:
    // AESIMCrr, ARPL16rr, BLCFILL32rr, BLCFILL64rr, BLCI32rr, BLCI64rr, BLCI...
    printOperand(MI, 1, O);
    break;
  case 18:
    // AESKEYGENASSIST128rm, EXTRACTPSmr, MMX_PSHUFWmi, PCMPESTRIrm, PCMPESTR...
    printU8Imm(MI, 6, O);
    SStream_concat0(O, ", ");
    break;
  case 19:
    // AESKEYGENASSIST128rr, EXTRACTPSrr, KSHIFTLBri, KSHIFTLDri, KSHIFTLQri,...
    printU8Imm(MI, 2, O);
    break;
  case 20:
    // BEXTR32rm, BEXTR64rm, BEXTRI32mi, BEXTRI64mi, BZHI32rm, BZHI64rm, IMUL...
    printOperand(MI, 6, O);
    SStream_concat0(O, ", ");
    break;
  case 21:
    // BLCFILL32rm, BLCI32rm, BLCIC32rm, BLCMSK32rm, BLCS32rm, BLSFILL32rm, B...
    printi32mem(MI, 1, O);
    break;
  case 22:
    // BLCFILL64rm, BLCI64rm, BLCIC64rm, BLCMSK64rm, BLCS64rm, BLSFILL64rm, B...
    printi64mem(MI, 1, O);
    break;
  case 23:
    // BLENDPDrmi, BLENDPSrmi, CMPPDrmi_alt, CMPPSrmi_alt, CMPSDrm_alt, CMPSS...
    printU8Imm(MI, 7, O);
    SStream_concat0(O, ", ");
    break;
  case 24:
    // BLENDPDrri, BLENDPSrri, CMPPDrri_alt, CMPPSrri_alt, CMPSDrr_alt, CMPSS...
    printU8Imm(MI, 3, O);
    break;
  case 25:
    // BNDCL32rm, BNDCL64rm, BNDCN32rm, BNDCN64rm, BNDCU32rm, BNDCU64rm, BNDL...
    printanymem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 26:
    // BSF16rm, BSR16rm, CMP16rm, KMOVWkm, LAR16rm, LAR32rm, LAR64rm, LSL16rm...
    printi16mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 27:
    // CALL64m, CALL64m_NT, CMPXCHG8B, DEC64m, DIV64m, IDIV64m, ILD_F64m, IMU...
    printi64mem(MI, 0, O);
    return;
    break;
  case 28:
    // CALL64pcrel32, CALLpcrel16, CALLpcrel32, JAE_1, JAE_2, JAE_4, JA_1, JA...
    printPCRelImm(MI, 0, O);
    return;
    break;
  case 29:
    // CLDEMOTE, CLFLUSH, CLFLUSHOPT, CLWB, DEC8m, DIV8m, IDIV8m, IMUL8m, INC...
    printi8mem(MI, 0, O);
    return;
    break;
  case 30:
    // CMP8rm, KMOVBkm, MOV8rm, MOV8rm_NOREX, MOVSX16rm8, MOVSX32rm8, MOVSX32...
    printi8mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 31:
    // CMPPDrmi, CMPPSrmi, CMPSDrm, CMPSDrm_Int, CMPSSrm, CMPSSrm_Int, VCMPPD...
    printSSEAVXCC(MI, 7, O);
    break;
  case 32:
    // CMPPDrri, CMPPSrri, CMPSDrr, CMPSDrr_Int, CMPSSrr, CMPSSrr_Int, VCMPPD...
    printSSEAVXCC(MI, 3, O);
    break;
  case 33:
    // CMPSB, INSB, SCASB, STOSB
    printDstIdx8(MI, 0, O);
    break;
  case 34:
    // CMPSL, INSL, SCASL, STOSL
    printDstIdx32(MI, 0, O);
    break;
  case 35:
    // CMPSQ, SCASQ, STOSQ
    printDstIdx64(MI, 0, O);
    break;
  case 36:
    // CMPSW, INSW, SCASW, STOSW
    printDstIdx16(MI, 0, O);
    break;
  case 37:
    // CMPXCHG16B
    printi128mem(MI, 0, O);
    return;
    break;
  case 38:
    // COMISDrm, COMISDrm_Int, CVTPS2PDrm, CVTSD2SI64rm_Int, CVTSD2SIrm_Int, ...
    printf64mem(MI, 1, O);
    break;
  case 39:
    // COMISSrm, COMISSrm_Int, CVTSS2SDrm, CVTSS2SI64rm_Int, CVTSS2SIrm_Int, ...
    printf32mem(MI, 1, O);
    break;
  case 40:
    // CVTPD2DQrm, CVTPD2PSrm, CVTPS2DQrm, CVTTPD2DQrm, CVTTPS2DQrm, MMX_CVTP...
    printf128mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 41:
    // FARCALL16m, FARCALL32m, FARCALL64, FARJMP16m, FARJMP32m, FARJMP64, FXR...
    printopaquemem(MI, 0, O);
    return;
    break;
  case 42:
    // FBLDm, FBSTPm, LD_F80m, ST_FP80m
    printf80mem(MI, 0, O);
    return;
    break;
  case 43:
    // IN16ri, IN32ri, IN8ri, INT, OUT16ir, OUT32ir, OUT8ir
    printU8Imm(MI, 0, O);
    break;
  case 44:
    // INSERTQI, VALIGNDZ128rrikz, VALIGNDZ256rrikz, VALIGNDZrrikz, VALIGNQZ1...
    printU8Imm(MI, 4, O);
    break;
  case 45:
    // LDS16rm, LDS32rm, LES16rm, LES32rm, LFS16rm, LFS32rm, LFS64rm, LGS16rm...
    printopaquemem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 46:
    // LODSB, OUTSB
    printSrcIdx8(MI, 0, O);
    break;
  case 47:
    // LODSL, OUTSL
    printSrcIdx32(MI, 0, O);
    break;
  case 48:
    // LODSQ
    printSrcIdx64(MI, 0, O);
    SStream_concat0(O, ", %rax");
    op_addReg(MI, X86_REG_RAX);
    return;
    break;
  case 49:
    // LODSW, OUTSW
    printSrcIdx16(MI, 0, O);
    break;
  case 50:
    // MOV16ao16, MOV16ao32, MOV16ao64, MOV16o16a, MOV16o32a, MOV16o64a
    printMemOffs16(MI, 0, O);
    break;
  case 51:
    // MOV32ao16, MOV32ao32, MOV32ao64, MOV32o16a, MOV32o32a, MOV32o64a
    printMemOffs32(MI, 0, O);
    break;
  case 52:
    // MOV64ao32, MOV64ao64, MOV64o32a, MOV64o64a
    printMemOffs64(MI, 0, O);
    break;
  case 53:
    // MOV8ao16, MOV8ao32, MOV8ao64, MOV8o16a, MOV8o32a, MOV8o64a
    printMemOffs8(MI, 0, O);
    break;
  case 54:
    // MOVDIR64B16, MOVDIR64B32, MOVDIR64B64, VCVTDQ2PSZrm, VCVTQQ2PDZrm, VCV...
    printi512mem(MI, 1, O);
    break;
  case 55:
    // MOVSB
    printSrcIdx8(MI, 1, O);
    SStream_concat0(O, ", ");
    printDstIdx8(MI, 0, O);
    return;
    break;
  case 56:
    // MOVSL
    printSrcIdx32(MI, 1, O);
    SStream_concat0(O, ", ");
    printDstIdx32(MI, 0, O);
    return;
    break;
  case 57:
    // MOVSQ
    printSrcIdx64(MI, 1, O);
    SStream_concat0(O, ", ");
    printDstIdx64(MI, 0, O);
    return;
    break;
  case 58:
    // MOVSW
    printSrcIdx16(MI, 1, O);
    SStream_concat0(O, ", ");
    printDstIdx16(MI, 0, O);
    return;
    break;
  case 59:
    // RCL16mi, RCL32mi, RCL64mi, RCL8mi, RCR16mi, RCR32mi, RCR64mi, RCR8mi, ...
    printU8Imm(MI, 5, O);
    break;
  case 60:
    // V4FMADDPSrm, V4FMADDSSrm, V4FNMADDPSrm, V4FNMADDSSrm, VADDPDZ128rmkz, ...
    printf128mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 61:
    // V4FMADDPSrmk, V4FMADDPSrmkz, V4FMADDSSrmk, V4FMADDSSrmkz, V4FNMADDPSrm...
    printf128mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 62:
    // VADDPDYrm, VADDPDZ256rm, VADDPSYrm, VADDPSZ256rm, VADDSUBPDYrm, VADDSU...
    printf256mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 63:
    // VADDPDZ128rmbk, VADDPDZ256rmbk, VADDPDZrmbk, VADDSDZrm_Intk, VANDNPDZ1...
    printf64mem(MI, 4, O);
    break;
  case 64:
    // VADDPDZ128rmbkz, VADDPDZ256rmbkz, VADDPDZrmbkz, VADDSDZrm_Intkz, VANDN...
    printf64mem(MI, 3, O);
    break;
  case 65:
    // VADDPDZ128rrk, VADDPDZ256rrk, VADDPDZrrk, VADDPSZ128rrk, VADDPSZ256rrk...
    printOperand(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 66:
    // VADDPDZ128rrkz, VADDPDZ256rrkz, VADDPDZrrkz, VADDPSZ128rrkz, VADDPSZ25...
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 67:
    // VADDPDZ256rmk, VADDPSZ256rmk, VANDNPDZ256rmk, VANDNPSZ256rmk, VANDPDZ2...
    printf256mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 68:
    // VADDPDZ256rmkz, VADDPSZ256rmkz, VANDNPDZ256rmkz, VANDNPSZ256rmkz, VAND...
    printf256mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 69:
    // VADDPDZrm, VADDPSZrm, VANDNPDZrm, VANDNPSZrm, VANDPDZrm, VANDPSZrm, VB...
    printf512mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 70:
    // VADDPDZrmk, VADDPSZrmk, VANDNPDZrmk, VANDNPSZrmk, VANDPDZrmk, VANDPSZr...
    printf512mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 71:
    // VADDPDZrmkz, VADDPSZrmkz, VANDNPDZrmkz, VANDNPSZrmkz, VANDPDZrmkz, VAN...
    printf512mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 72:
    // VADDPDZrrb, VADDPSZrrb, VADDSDZrrb_Int, VADDSSZrrb_Int, VCVTDQ2PSZrrbk...
    printRoundingControl(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 73:
    // VADDPDZrrbk, VADDPSZrrbk, VADDSDZrrb_Intk, VADDSSZrrb_Intk, VCVTSD2SSZ...
    printRoundingControl(MI, 5, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 74:
    // VADDPDZrrbkz, VADDPSZrrbkz, VADDSDZrrb_Intkz, VADDSSZrrb_Intkz, VCVTDQ...
    printRoundingControl(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 75:
    // VADDPSZ128rmbk, VADDPSZ256rmbk, VADDPSZrmbk, VADDSSZrm_Intk, VANDNPSZ1...
    printf32mem(MI, 4, O);
    break;
  case 76:
    // VADDPSZ128rmbkz, VADDPSZ256rmbkz, VADDPSZrmbkz, VADDSSZrm_Intkz, VANDN...
    printf32mem(MI, 3, O);
    break;
  case 77:
    // VAESDECLASTYrm, VAESDECLASTZ256rm, VAESDECYrm, VAESDECZ256rm, VAESENCL...
    printi256mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 78:
    // VAESDECLASTZrm, VAESDECZrm, VAESENCLASTZrm, VAESENCZrm, VCVTDQ2PSZrmkz...
    printi512mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 79:
    // VALIGNDZ128rmbik, VALIGNDZ128rmik, VALIGNDZ256rmbik, VALIGNDZ256rmik, ...
    printU8Imm(MI, 9, O);
    SStream_concat0(O, ", ");
    break;
  case 80:
    // VALIGNDZ128rmbikz, VALIGNDZ128rmikz, VALIGNDZ256rmbikz, VALIGNDZ256rmi...
    printU8Imm(MI, 8, O);
    SStream_concat0(O, ", ");
    break;
  case 81:
    // VBLENDVPDYrm, VBLENDVPDrm, VBLENDVPSYrm, VBLENDVPSrm, VFMADDPD4Ymr, VF...
    printOperand(MI, 7, O);
    SStream_concat0(O, ", ");
    break;
  case 82:
    // VBROADCASTF32X8rm, VBROADCASTF64X4rm, VCVTPD2DQYrm, VCVTPD2DQZ256rm, V...
    printf256mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 83:
    // VBROADCASTI32X2Z128mk, VBROADCASTI32X2Z256mk, VBROADCASTI32X2Zmk, VCVT...
    printi64mem(MI, 3, O);
    break;
  case 84:
    // VBROADCASTI32X4Z256rmk, VBROADCASTI32X4rmk, VBROADCASTI64X2Z128rmk, VB...
    printi128mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 85:
    // VBROADCASTI32X8rm, VBROADCASTI64X4rm, VCVTDQ2PDZrm, VCVTDQ2PSYrm, VCVT...
    printi256mem(MI, 1, O);
    break;
  case 86:
    // VBROADCASTI32X8rmk, VBROADCASTI64X4rmk, VCVTDQ2PDZrmk, VCVTDQ2PSZ256rm...
    printi256mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 87:
    // VCMPPDZ128rmbik, VCMPPDZ128rmik, VCMPPDZ256rmbik, VCMPPDZ256rmik, VCMP...
    printSSEAVXCC(MI, 8, O);
    break;
  case 88:
    // VCMPPDZ128rrik, VCMPPDZ256rrik, VCMPPDZrribk, VCMPPDZrrik, VCMPPSZ128r...
    printSSEAVXCC(MI, 4, O);
    break;
  case 89:
    // VCVTDQ2PDZ128rmbk, VCVTDQ2PDZ256rmbk, VCVTDQ2PDZrmbk, VCVTDQ2PSZ128rmb...
    printi32mem(MI, 3, O);
    break;
  case 90:
    // VCVTDQ2PSZrmk, VCVTQQ2PDZrmk, VCVTQQ2PSZrmk, VCVTUDQ2PSZrmk, VCVTUQQ2P...
    printi512mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 91:
    // VCVTDQ2PSZrrb, VCVTPD2DQZrrb, VCVTPD2PSZrrb, VCVTPD2QQZrrb, VCVTPD2UDQ...
    printRoundingControl(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 92:
    // VCVTPD2DQZrm, VCVTPD2PSZrm, VCVTPD2QQZrm, VCVTPD2UDQZrm, VCVTPD2UQQZrm...
    printf512mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 93:
    // VGATHERDPDYrm, VGATHERDPDrm, VGATHERDPSYrm, VGATHERDPSrm, VGATHERQPDYr...
    printOperand(MI, 8, O);
    SStream_concat0(O, ", ");
    break;
  case 94:
    // VGATHERDPDZ128rm, VGATHERDPSZ128rm, VGATHERQPDZ128rm, VGATHERQPSZ256rm...
    printi128mem(MI, 4, O);
    SStream_concat0(O, ", ");
    break;
  case 95:
    // VGATHERDPDZ256rm, VGATHERDPSZ256rm, VGATHERQPDZ256rm, VGATHERQPSZrm, V...
    printi256mem(MI, 4, O);
    SStream_concat0(O, ", ");
    break;
  case 96:
    // VGATHERDPDZrm, VGATHERDPSZrm, VGATHERQPDZrm, VGF2P8MULBZrmk, VPACKSSDW...
    printi512mem(MI, 4, O);
    SStream_concat0(O, ", ");
    break;
  case 97:
    // VGATHERQPSZ128rm, VPADDQZ128rmbk, VPADDQZ256rmbk, VPADDQZrmbk, VPANDNQ...
    printi64mem(MI, 4, O);
    break;
  case 98:
    // VPACKSSDWZ128rmbk, VPACKSSDWZ256rmbk, VPACKSSDWZrmbk, VPACKUSDWZ128rmb...
    printi32mem(MI, 4, O);
    break;
  case 99:
    // VPBROADCASTBZ128mk, VPBROADCASTBZ256mk, VPBROADCASTBZmk
    printi8mem(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 100:
    // VPBROADCASTWZ128mk, VPBROADCASTWZ256mk, VPBROADCASTWZmk, VPMOVSXBQZ128...
    printi16mem(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 101:
    // VPCOMBmi, VPCOMDmi, VPCOMQmi, VPCOMUBmi, VPCOMUDmi, VPCOMUQmi, VPCOMUW...
    printXOPCC(MI, 7, O);
    break;
  case 102:
    // VPCOMBri, VPCOMDri, VPCOMQri, VPCOMUBri, VPCOMUDri, VPCOMUQri, VPCOMUW...
    printXOPCC(MI, 3, O);
    break;
  }


  // Fragment 1 encoded into 7 bits for 99 unique commands.
  // printf("Fragment 1: %"PRIu64"\n", ((Bits >> 21) & 127));
  switch ((Bits >> 21) & 127) {
  default: // unreachable
  case 0:
    // AAD8i8, AAM8i8, ADD_FPrST0, ADD_FST0r, ADD_FrST0, BSWAP16r_BAD, BSWAP3...
    return;
    break;
  case 1:
    // ADC16i16, ADD16i16, AND16i16, CMP16i16, IN16ri, LODSW, MOV16ao16, MOV1...
    SStream_concat0(O, ", %ax");
    op_addReg(MI, X86_REG_AX);
    return;
    break;
  case 2:
    // ADC16mi, ADC16mi8, ADC16mr, ADD16mi, ADD16mi8, ADD16mr, AND16mi, AND16...
    printi16mem(MI, 0, O);
    break;
  case 3:
    // ADC16ri, ADC16ri8, ADC16rm, ADC16rr, ADC32ri, ADC32ri8, ADC32rr, ADC64...
    printOperand(MI, 1, O);
    break;
  case 4:
    // ADC16rr_REV, ADC32rr_REV, ADC64rr_REV, ADC8rr_REV, ADCX32rr, ADCX64rr,...
    printOperand(MI, 0, O);
    break;
  case 5:
    // ADC32i32, ADD32i32, AND32i32, CMP32i32, IN32ri, LODSL, MOV32ao16, MOV3...
    SStream_concat0(O, ", %eax");
    op_addReg(MI, X86_REG_EAX);
    return;
    break;
  case 6:
    // ADC32mi, ADC32mi8, ADC32mr, ADD32mi, ADD32mi8, ADD32mr, AND32mi, AND32...
    printi32mem(MI, 0, O);
    break;
  case 7:
    // ADC32rm, ADC64rm, ADCX32rm, ADCX64rm, ADD32rm, ADD64rm, ADDSDrm, ADDSD...
    SStream_concat0(O, ", ");
    break;
  case 8:
    // ADC64i32, ADD64i32, AND64i32, CMP64i32, MOV64ao32, MOV64ao64, OR64i32,...
    SStream_concat0(O, ", %rax");
    op_addReg(MI, X86_REG_RAX);
    return;
    break;
  case 9:
    // ADC64mi32, ADC64mi8, ADC64mr, ADD64mi32, ADD64mi8, ADD64mr, AND64mi32,...
    printi64mem(MI, 0, O);
    break;
  case 10:
    // ADC8i8, ADD8i8, AND8i8, CMP8i8, IN8ri, LODSB, MOV8ao16, MOV8ao32, MOV8...
    SStream_concat0(O, ", %al");
    op_addReg(MI, X86_REG_AL);
    return;
    break;
  case 11:
    // ADC8mi, ADC8mi8, ADC8mr, ADD8mi, ADD8mi8, ADD8mr, AND8mi, AND8mi8, AND...
    printi8mem(MI, 0, O);
    return;
    break;
  case 12:
    // AESKEYGENASSIST128rm, PCMPESTRIrm, PCMPESTRMrm, PCMPISTRIrm, PCMPISTRM...
    printi128mem(MI, 1, O);
    break;
  case 13:
    // BEXTR32rm, BEXTRI32mi, BZHI32rm, IMUL32rmi, IMUL32rmi8, LWPINS32rmi, L...
    printi32mem(MI, 1, O);
    break;
  case 14:
    // BEXTR64rm, BEXTRI64mi, BZHI64rm, IMUL64rmi32, IMUL64rmi8, MMX_PSHUFWmi...
    printi64mem(MI, 1, O);
    break;
  case 15:
    // BLENDPDrmi, BLENDPSrmi, CMPPDrmi_alt, CMPPSrmi_alt, DPPDrmi, DPPSrmi, ...
    printf128mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 16:
    // BNDMOV64mr, MOVDQAmr, MOVDQUmr, VMOVDQA32Z128mr, VMOVDQA32Z128mrk, VMO...
    printi128mem(MI, 0, O);
    break;
  case 17:
    // BNDSTXmr
    printanymem(MI, 0, O);
    return;
    break;
  case 18:
    // CMOVBE_F, CMOVB_F, CMOVE_F, CMOVNBE_F, CMOVNB_F, CMOVNE_F, CMOVNP_F, C...
    SStream_concat0(O, ", %st(0)");
    op_addReg(MI, X86_REG_ST0);
    return;
    break;
  case 19:
    // CMPPDrmi, CMPPDrri, VCMPPDYrmi, VCMPPDYrri, VCMPPDZ128rmbi, VCMPPDZ128...
    SStream_concat0(O, "pd\t");
    break;
  case 20:
    // CMPPSrmi, CMPPSrri, VCMPPSYrmi, VCMPPSYrri, VCMPPSZ128rmbi, VCMPPSZ128...
    SStream_concat0(O, "ps\t");
    break;
  case 21:
    // CMPSDrm, CMPSDrm_Int, CMPSDrr, CMPSDrr_Int, VCMPSDZrm, VCMPSDZrm_Int, ...
    SStream_concat0(O, "sd\t");
    break;
  case 22:
    // CMPSDrm_alt, ROUNDSDm_Int, VCMPPDZ128rmbi_alt, VCMPPDZ256rmbi_alt, VCM...
    printf64mem(MI, 2, O);
    break;
  case 23:
    // CMPSSrm, CMPSSrm_Int, CMPSSrr, CMPSSrr_Int, VCMPSSZrm, VCMPSSZrm_Int, ...
    SStream_concat0(O, "ss\t");
    break;
  case 24:
    // CMPSSrm_alt, INSERTPSrm, ROUNDSSm_Int, VCMPPSZ128rmbi_alt, VCMPPSZ256r...
    printf32mem(MI, 2, O);
    break;
  case 25:
    // EXTRACTPSmr, PEXTRBmr, PEXTRDmr, PEXTRQmr, PEXTRWmr, SHLD16mri8, SHLD3...
    printOperand(MI, 5, O);
    SStream_concat0(O, ", ");
    break;
  case 26:
    // FARJMP16i, FARJMP32i
    SStream_concat0(O, ":");
    printOperand(MI, 0, O);
    return;
    break;
  case 27:
    // GF2P8AFFINEINVQBrmi, GF2P8AFFINEQBrmi, MPSADBWrmi, PALIGNRrmi, PBLENDW...
    printi128mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 28:
    // IMUL16rmi, IMUL16rmi8
    printi16mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 29:
    // MMX_PALIGNRrmi, PINSRQrm, VALIGNQZ128rmbi, VALIGNQZ256rmbi, VALIGNQZrm...
    printi64mem(MI, 2, O);
    break;
  case 30:
    // MMX_PINSRWrm, PINSRWrm, VPINSRWZrm, VPINSRWrm
    printi16mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 31:
    // MOVAPDmr, MOVAPSmr, MOVNTDQmr, MOVNTPDmr, MOVNTPSmr, MOVUPDmr, MOVUPSm...
    printf128mem(MI, 0, O);
    break;
  case 32:
    // MOVHPDmr, MOVHPSmr, MOVLPDmr, MOVLPSmr, MOVNTSD, MOVSDmr, VMOVHPDZ128m...
    printf64mem(MI, 0, O);
    break;
  case 33:
    // MOVNTSS, MOVSSmr, VMOVSSZmr, VMOVSSZmrk, VMOVSSmr
    printf32mem(MI, 0, O);
    break;
  case 34:
    // OUTSB, OUTSL, OUTSW
    SStream_concat0(O, ", %dx");
    op_addReg(MI, X86_REG_DX);
    return;
    break;
  case 35:
    // PINSRBrm, VGF2P8AFFINEINVQBZ128rmbi, VGF2P8AFFINEINVQBZ256rmbi, VGF2P8...
    printi8mem(MI, 2, O);
    break;
  case 36:
    // PINSRDrm, VALIGNDZ128rmbi, VALIGNDZ256rmbi, VALIGNDZrmbi, VPCMPDZ128rm...
    printi32mem(MI, 2, O);
    break;
  case 37:
    // ROUNDPDm, ROUNDPSm, VFPCLASSPDZ128rm, VFPCLASSPSZ128rm, VGETMANTPDZ128...
    printf128mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 38:
    // ROUNDSDm, VFPCLASSPDZ128rmb, VFPCLASSPDZ256rmb, VFPCLASSPDZrmb, VFPCLA...
    printf64mem(MI, 1, O);
    break;
  case 39:
    // ROUNDSSm, VFPCLASSPSZ128rmb, VFPCLASSPSZ256rmb, VFPCLASSPSZrmb, VFPCLA...
    printf32mem(MI, 1, O);
    break;
  case 40:
    // V4FMADDPSrm, V4FMADDSSrm, V4FNMADDPSrm, V4FNMADDSSrm, VADDPDZ128rmkz, ...
    printOperand(MI, 2, O);
    break;
  case 41:
    // V4FMADDPSrmk, V4FMADDSSrmk, V4FNMADDPSrmk, V4FNMADDSSrmk, VADDPDZ128rm...
    SStream_concat0(O, "}");
    return;
    break;
  case 42:
    // V4FMADDPSrmkz, V4FMADDSSrmkz, V4FNMADDPSrmkz, V4FNMADDSSrmkz, VFMADD13...
    SStream_concat0(O, "} {z}");
    op_addAvxZeroOpmask(MI);
    return;
    break;
  case 43:
    // VADDPDZ128rmb, VADDPDZ128rmbk, VADDPDZ128rmbkz, VANDNPDZ128rmb, VANDNP...
    SStream_concat0(O, "{1to2}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_2);
    break;
  case 44:
    // VADDPDZ256rmb, VADDPDZ256rmbk, VADDPDZ256rmbkz, VADDPSZ128rmb, VADDPSZ...
    SStream_concat0(O, "{1to4}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_4);
    break;
  case 45:
    // VADDPDZrmb, VADDPDZrmbk, VADDPDZrmbkz, VADDPSZ256rmb, VADDPSZ256rmbk, ...
    SStream_concat0(O, "{1to8}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_8);
    break;
  case 46:
    // VADDPSZrmb, VADDPSZrmbk, VADDPSZrmbkz, VANDNPSZrmb, VANDNPSZrmbk, VAND...
    SStream_concat0(O, "{1to16}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_16);
    break;
  case 47:
    // VALIGNDZ128rmbik, VALIGNDZ256rmbik, VALIGNDZrmbik, VPSHLDDZ128rmbik, V...
    printi32mem(MI, 4, O);
    break;
  case 48:
    // VALIGNDZ128rmbikz, VALIGNDZ256rmbikz, VALIGNDZrmbikz, VPCMPDZ128rmibk_...
    printi32mem(MI, 3, O);
    break;
  case 49:
    // VALIGNDZ128rmik, VALIGNQZ128rmik, VDBPSADBWZ128rmik, VGF2P8AFFINEINVQB...
    printi128mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 50:
    // VALIGNDZ128rmikz, VALIGNQZ128rmikz, VDBPSADBWZ128rmikz, VGATHERDPDrm, ...
    printi128mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 51:
    // VALIGNDZ256rmi, VALIGNQZ256rmi, VDBPSADBWZ256rmi, VDPPSYrmi, VGF2P8AFF...
    printi256mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 52:
    // VALIGNDZ256rmik, VALIGNQZ256rmik, VDBPSADBWZ256rmik, VGF2P8AFFINEINVQB...
    printi256mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 53:
    // VALIGNDZ256rmikz, VALIGNQZ256rmikz, VDBPSADBWZ256rmikz, VGATHERDPDYrm,...
    printi256mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 54:
    // VALIGNDZrmi, VALIGNQZrmi, VDBPSADBWZrmi, VGF2P8AFFINEINVQBZrmi, VGF2P8...
    printi512mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 55:
    // VALIGNDZrmik, VALIGNQZrmik, VDBPSADBWZrmik, VGF2P8AFFINEINVQBZrmik, VG...
    printi512mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 56:
    // VALIGNDZrmikz, VALIGNQZrmikz, VDBPSADBWZrmikz, VGF2P8AFFINEINVQBZrmikz...
    printi512mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 57:
    // VALIGNQZ128rmbik, VALIGNQZ256rmbik, VALIGNQZrmbik, VPSHLDQZ128rmbik, V...
    printi64mem(MI, 4, O);
    break;
  case 58:
    // VALIGNQZ128rmbikz, VALIGNQZ256rmbikz, VALIGNQZrmbikz, VGATHERQPSrm, VP...
    printi64mem(MI, 3, O);
    break;
  case 59:
    // VBLENDPDYrmi, VBLENDPSYrmi, VBLENDVPDYrm, VBLENDVPSYrm, VCMPPDYrmi_alt...
    printf256mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 60:
    // VCMPPDZ128rmbi_altk, VCMPPDZ256rmbi_altk, VCMPPDZrmbi_altk, VCMPSDZrmi...
    printf64mem(MI, 3, O);
    break;
  case 61:
    // VCMPPDZ128rmi_altk, VCMPPSZ128rmi_altk, VFIXUPIMMPDZ128rmi, VFIXUPIMMP...
    printf128mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 62:
    // VCMPPDZ256rmi_altk, VCMPPSZ256rmi_altk, VFIXUPIMMPDZ256rmi, VFIXUPIMMP...
    printf256mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 63:
    // VCMPPDZrmi_alt, VCMPPSZrmi_alt, VFPCLASSPDZrmk, VFPCLASSPSZrmk, VGETMA...
    printf512mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 64:
    // VCMPPDZrmi_altk, VCMPPSZrmi_altk, VFIXUPIMMPDZrmi, VFIXUPIMMPSZrmi, VG...
    printf512mem(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 65:
    // VCMPPDZrrib, VCMPPDZrribk
    SStream_concat0(O, "pd\t{sae}, ");
    op_addAvxSae(MI);
    break;
  case 66:
    // VCMPPDZrrib_alt, VCMPPDZrrib_altk, VCMPPSZrrib_alt, VCMPPSZrrib_altk, ...
    SStream_concat0(O, ", {sae}, ");
    op_addAvxSae(MI);
    break;
  case 67:
    // VCMPPSZ128rmbi_altk, VCMPPSZ256rmbi_altk, VCMPPSZrmbi_altk, VCMPSSZrmi...
    printf32mem(MI, 3, O);
    break;
  case 68:
    // VCMPPSZrrib, VCMPPSZrribk
    SStream_concat0(O, "ps\t{sae}, ");
    op_addAvxSae(MI);
    break;
  case 69:
    // VCMPSDZrrb_Int, VCMPSDZrrb_Intk
    SStream_concat0(O, "sd\t{sae}, ");
    op_addAvxSae(MI);
    break;
  case 70:
    // VCMPSSZrrb_Int, VCMPSSZrrb_Intk
    SStream_concat0(O, "ss\t{sae}, ");
    op_addAvxSae(MI);
    break;
  case 71:
    // VCOMPRESSPDZ256mr, VCOMPRESSPDZ256mrk, VCOMPRESSPSZ256mr, VCOMPRESSPSZ...
    printf256mem(MI, 0, O);
    break;
  case 72:
    // VCOMPRESSPDZmr, VCOMPRESSPDZmrk, VCOMPRESSPSZmr, VCOMPRESSPSZmrk, VMOV...
    printf512mem(MI, 0, O);
    break;
  case 73:
    // VCVTPS2PHZ128mrk, VCVTPS2PHZ256mrk, VCVTPS2PHZmrk, VEXTRACTF32x4Z256mr...
    printOperand(MI, 6, O);
    SStream_concat0(O, ", ");
    break;
  case 74:
    // VCVTSI2SDZrrb_Int, VCVTSI2SSZrrb_Int, VCVTSI642SDZrrb_Int, VCVTSI642SS...
    printRoundingControl(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 75:
    // VFIXUPIMMPDZ128rmbik, VFIXUPIMMPDZ128rmbikz, VFIXUPIMMPDZ256rmbik, VFI...
    printf64mem(MI, 4, O);
    break;
  case 76:
    // VFIXUPIMMPDZ128rmik, VFIXUPIMMPDZ128rmikz, VFIXUPIMMPSZ128rmik, VFIXUP...
    printf128mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 77:
    // VFIXUPIMMPDZ256rmik, VFIXUPIMMPDZ256rmikz, VFIXUPIMMPSZ256rmik, VFIXUP...
    printf256mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 78:
    // VFIXUPIMMPDZrmik, VFIXUPIMMPDZrmikz, VFIXUPIMMPSZrmik, VFIXUPIMMPSZrmi...
    printf512mem(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 79:
    // VFIXUPIMMPSZ128rmbik, VFIXUPIMMPSZ128rmbikz, VFIXUPIMMPSZ256rmbik, VFI...
    printf32mem(MI, 4, O);
    break;
  case 80:
    // VFPCLASSPDZ256rm, VFPCLASSPSZ256rm, VGETMANTPDZ256rmi, VGETMANTPSZ256r...
    printf256mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 81:
    // VFPCLASSPDZrm, VFPCLASSPSZrm, VGETMANTPDZrmi, VGETMANTPSZrmi, VPERMILP...
    printf512mem(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 82:
    // VGATHERPF0DPDm, VGATHERPF0DPSm, VGATHERPF0QPDm, VGATHERPF0QPSm, VGATHE...
    SStream_concat0(O, " {");
    printOperand(MI, 0, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 83:
    // VGF2P8AFFINEINVQBZ128rmbik, VGF2P8AFFINEINVQBZ256rmbik, VGF2P8AFFINEIN...
    printi8mem(MI, 4, O);
    break;
  case 84:
    // VGF2P8AFFINEINVQBZ128rmbikz, VGF2P8AFFINEINVQBZ256rmbikz, VGF2P8AFFINE...
    printi8mem(MI, 3, O);
    break;
  case 85:
    // VGF2P8MULBZ128rmk, VGF2P8MULBZ256rmk, VGF2P8MULBZrmk, VPACKSSDWZ128rmk...
    printOperand(MI, 3, O);
    break;
  case 86:
    // VMOVDQA32Z256mr, VMOVDQA32Z256mrk, VMOVDQA64Z256mr, VMOVDQA64Z256mrk, ...
    printi256mem(MI, 0, O);
    break;
  case 87:
    // VMOVDQA32Zmr, VMOVDQA32Zmrk, VMOVDQA64Zmr, VMOVDQA64Zmrk, VMOVDQU16Zmr...
    printi512mem(MI, 0, O);
    break;
  case 88:
    // VPCMPBZ128rmi, VPCMPBZ128rmik, VPCMPBZ128rri, VPCMPBZ128rrik, VPCMPBZ2...
    SStream_concat0(O, "b\t");
    break;
  case 89:
    // VPCMPDZ128rmi, VPCMPDZ128rmib, VPCMPDZ128rmibk, VPCMPDZ128rmik, VPCMPD...
    SStream_concat0(O, "d\t");
    break;
  case 90:
    // VPCMPQZ128rmi, VPCMPQZ128rmib, VPCMPQZ128rmibk, VPCMPQZ128rmik, VPCMPQ...
    SStream_concat0(O, "q\t");
    break;
  case 91:
    // VPCMPUBZ128rmi, VPCMPUBZ128rmik, VPCMPUBZ128rri, VPCMPUBZ128rrik, VPCM...
    SStream_concat0(O, "ub\t");
    break;
  case 92:
    // VPCMPUDZ128rmi, VPCMPUDZ128rmib, VPCMPUDZ128rmibk, VPCMPUDZ128rmik, VP...
    SStream_concat0(O, "ud\t");
    break;
  case 93:
    // VPCMPUQZ128rmi, VPCMPUQZ128rmib, VPCMPUQZ128rmibk, VPCMPUQZ128rmik, VP...
    SStream_concat0(O, "uq\t");
    break;
  case 94:
    // VPCMPUWZ128rmi, VPCMPUWZ128rmik, VPCMPUWZ128rri, VPCMPUWZ128rrik, VPCM...
    SStream_concat0(O, "uw\t");
    break;
  case 95:
    // VPCMPWZ128rmi, VPCMPWZ128rmik, VPCMPWZ128rri, VPCMPWZ128rrik, VPCMPWZ2...
    SStream_concat0(O, "w\t");
    break;
  case 96:
    // VPERMIL2PDYmr, VPERMIL2PDmr, VPERMIL2PSYmr, VPERMIL2PSmr
    printOperand(MI, 7, O);
    SStream_concat0(O, ", ");
    break;
  case 97:
    // VPERMQYmi, VPERMQZ256mi, VPROLDZ256mi, VPROLQZ256mi, VPRORDZ256mi, VPR...
    printi256mem(MI, 1, O);
    break;
  case 98:
    // VPERMQZmi, VPROLDZmi, VPROLQZmi, VPRORDZmi, VPRORQZmi, VPSCATTERDDZmr,...
    printi512mem(MI, 1, O);
    break;
  }


  // Fragment 2 encoded into 6 bits for 54 unique commands.
  // printf("Fragment 2: %"PRIu64"\n", ((Bits >> 28) & 63));
  switch ((Bits >> 28) & 63) {
  default: // unreachable
  case 0:
    // ADC16mi, ADC16mi8, ADC16mr, ADC16ri, ADC16ri8, ADC16rm, ADC16rr, ADC16...
    return;
    break;
  case 1:
    // ADC32rm, ADC64rm, ADD32rm, ADD64rm, AESKEYGENASSIST128rr, AND32rm, AND...
    printOperand(MI, 1, O);
    break;
  case 2:
    // ADCX32rm, ADCX64rm, ADDSDrm, ADDSDrm_Int, ADDSSrm, ADDSSrm_Int, ADOX32...
    printOperand(MI, 0, O);
    break;
  case 3:
    // AESKEYGENASSIST128rm, ANDN32rr, ANDN64rr, BEXTR32rm, BEXTR32rr, BEXTR6...
    SStream_concat0(O, ", ");
    break;
  case 4:
    // BLENDPDrri, BLENDPSrri, CMPPDrri, CMPPDrri_alt, CMPPSrri, CMPPSrri_alt...
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 5:
    // BOUNDS16rm
    printi32mem(MI, 1, O);
    return;
    break;
  case 6:
    // BOUNDS32rm
    printi64mem(MI, 1, O);
    return;
    break;
  case 7:
    // CMPPDrmi, CMPPSrmi, VCMPPDZ128rmi, VCMPPDrmi, VCMPPSZ128rmi, VCMPPSrmi...
    printf128mem(MI, 2, O);
    SStream_concat0(O, ", ");
    break;
  case 8:
    // CMPSB
    printSrcIdx8(MI, 1, O);
    return;
    break;
  case 9:
    // CMPSDrm, CMPSDrm_Int, VCMPPDZ128rmbi, VCMPPDZ256rmbi, VCMPPDZrmbi, VCM...
    printf64mem(MI, 2, O);
    break;
  case 10:
    // CMPSL
    printSrcIdx32(MI, 1, O);
    return;
    break;
  case 11:
    // CMPSQ
    printSrcIdx64(MI, 1, O);
    return;
    break;
  case 12:
    // CMPSSrm, CMPSSrm_Int, VCMPPSZ128rmbi, VCMPPSZ256rmbi, VCMPPSZrmbi, VCM...
    printf32mem(MI, 2, O);
    break;
  case 13:
    // CMPSW
    printSrcIdx16(MI, 1, O);
    return;
    break;
  case 14:
    // EXTRACTPSmr, VEXTRACTPSZmr, VEXTRACTPSmr
    printf32mem(MI, 0, O);
    return;
    break;
  case 15:
    // EXTRQI
    printU8Imm(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    return;
    break;
  case 16:
    // INSERTQI
    printU8Imm(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    return;
    break;
  case 17:
    // PEXTRBmr, RCL8mi, RCR8mi, ROL8mi, ROR8mi, SAR8mi, SHL8mi, SHR8mi, VPEX...
    printi8mem(MI, 0, O);
    return;
    break;
  case 18:
    // PEXTRDmr, RCL32mi, RCR32mi, ROL32mi, ROR32mi, SAR32mi, SHL32mi, SHLD32...
    printi32mem(MI, 0, O);
    return;
    break;
  case 19:
    // PEXTRQmr, RCL64mi, RCR64mi, ROL64mi, ROR64mi, SAR64mi, SHL64mi, SHLD64...
    printi64mem(MI, 0, O);
    return;
    break;
  case 20:
    // PEXTRWmr, RCL16mi, RCR16mi, ROL16mi, ROR16mi, SAR16mi, SHL16mi, SHLD16...
    printi16mem(MI, 0, O);
    return;
    break;
  case 21:
    // VADDPDZ128rmbk, VADDPDZ256rmbk, VADDPDZrmbk, VADDPSZ128rmbk, VADDPSZ25...
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    break;
  case 22:
    // VALIGNDZ128rmbi, VALIGNDZ128rmbik, VALIGNDZ128rmbikz, VALIGNQZ256rmbi,...
    SStream_concat0(O, "{1to4}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_4);
    break;
  case 23:
    // VALIGNDZ128rmik, VALIGNDZ256rmik, VALIGNDZrmik, VALIGNQZ128rmik, VALIG...
    SStream_concat0(O, "}");
    return;
    break;
  case 24:
    // VALIGNDZ128rrik, VALIGNDZ256rrik, VALIGNDZrrik, VALIGNQZ128rrik, VALIG...
    printOperand(MI, 4, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 2, O);
    break;
  case 25:
    // VALIGNDZ256rmbi, VALIGNDZ256rmbik, VALIGNDZ256rmbikz, VALIGNQZrmbi, VA...
    SStream_concat0(O, "{1to8}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_8);
    break;
  case 26:
    // VALIGNDZrmbi, VALIGNDZrmbik, VALIGNDZrmbikz, VCMPPSZrmbi_alt, VCMPPSZr...
    SStream_concat0(O, "{1to16}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_16);
    break;
  case 27:
    // VALIGNQZ128rmbi, VALIGNQZ128rmbik, VALIGNQZ128rmbikz, VCMPPDZ128rmbi_a...
    SStream_concat0(O, "{1to2}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_2);
    break;
  case 28:
    // VBROADCASTF32X2Z256rk, VBROADCASTF32X2Z256rkz, VBROADCASTF32X2Zrk, VBR...
    SStream_concat0(O, " {");
    break;
  case 29:
    // VCMPPDYrmi, VCMPPDZ256rmi, VCMPPSYrmi, VCMPPSZ256rmi, VPERMIL2PDYmr, V...
    printf256mem(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 30:
    // VCMPPDZ128rmbik, VCMPPDZ256rmbik, VCMPPDZrmbik, VCMPSDZrm_Intk
    printf64mem(MI, 3, O);
    break;
  case 31:
    // VCMPPDZ128rmik, VCMPPSZ128rmik
    printf128mem(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 1, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 32:
    // VCMPPDZ256rmik, VCMPPSZ256rmik
    printf256mem(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 1, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 33:
    // VCMPPDZrmi, VCMPPSZrmi
    printf512mem(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 34:
    // VCMPPDZrmik, VCMPPSZrmik
    printf512mem(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 1, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 35:
    // VCMPPSZ128rmbik, VCMPPSZ256rmbik, VCMPPSZrmbik, VCMPSSZrm_Intk
    printf32mem(MI, 3, O);
    break;
  case 36:
    // VCVTPS2PHYmr, VCVTPS2PHZ256mr, VCVTPS2PHZ256mrk, VEXTRACTF128mr, VEXTR...
    printf128mem(MI, 0, O);
    break;
  case 37:
    // VCVTPS2PHZ128mr, VCVTPS2PHZ128mrk, VCVTPS2PHmr
    printf64mem(MI, 0, O);
    break;
  case 38:
    // VCVTPS2PHZmr, VCVTPS2PHZmrk, VEXTRACTF32x8Zmr, VEXTRACTF32x8Zmrk, VEXT...
    printf256mem(MI, 0, O);
    break;
  case 39:
    // VEXTRACTI128mr, VEXTRACTI32x4Z256mr, VEXTRACTI32x4Z256mrk, VEXTRACTI32...
    printi128mem(MI, 0, O);
    break;
  case 40:
    // VEXTRACTI32x8Zmr, VEXTRACTI32x8Zmrk, VEXTRACTI64x4Zmr, VEXTRACTI64x4Zm...
    printi256mem(MI, 0, O);
    break;
  case 41:
    // VFIXUPIMMPDZ128rmikz, VFIXUPIMMPDZ256rmikz, VFIXUPIMMPDZrmikz, VFIXUPI...
    SStream_concat0(O, "} {z}");
    op_addAvxZeroOpmask(MI);
    return;
    break;
  case 42:
    // VPCMPBZ128rmi, VPCMPDZ128rmi, VPCMPQZ128rmi, VPCMPUBZ128rmi, VPCMPUDZ1...
    printi128mem(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 43:
    // VPCMPBZ128rmik, VPCMPDZ128rmik, VPCMPQZ128rmik, VPCMPUBZ128rmik, VPCMP...
    printi128mem(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 1, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 44:
    // VPCMPBZ256rmi, VPCMPDZ256rmi, VPCMPQZ256rmi, VPCMPUBZ256rmi, VPCMPUDZ2...
    printi256mem(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 45:
    // VPCMPBZ256rmik, VPCMPDZ256rmik, VPCMPQZ256rmik, VPCMPUBZ256rmik, VPCMP...
    printi256mem(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 1, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 46:
    // VPCMPBZrmi, VPCMPDZrmi, VPCMPQZrmi, VPCMPUBZrmi, VPCMPUDZrmi, VPCMPUQZ...
    printi512mem(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 1, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  case 47:
    // VPCMPBZrmik, VPCMPDZrmik, VPCMPQZrmik, VPCMPUBZrmik, VPCMPUDZrmik, VPC...
    printi512mem(MI, 3, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 2, O);
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    SStream_concat0(O, " {");
    printOperand(MI, 1, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 48:
    // VPCMPDZ128rmib, VPCMPDZ256rmib, VPCMPDZrmib, VPCMPUDZ128rmib, VPCMPUDZ...
    printi32mem(MI, 2, O);
    break;
  case 49:
    // VPCMPDZ128rmibk, VPCMPDZ256rmibk, VPCMPDZrmibk, VPCMPUDZ128rmibk, VPCM...
    printi32mem(MI, 3, O);
    break;
  case 50:
    // VPCMPQZ128rmib, VPCMPQZ256rmib, VPCMPQZrmib, VPCMPUQZ128rmib, VPCMPUQZ...
    printi64mem(MI, 2, O);
    break;
  case 51:
    // VPCMPQZ128rmibk, VPCMPQZ256rmibk, VPCMPQZrmibk, VPCMPUQZ128rmibk, VPCM...
    printi64mem(MI, 3, O);
    break;
  case 52:
    // XADD16rm, XCHG16rm
    printi16mem(MI, 2, O);
    return;
    break;
  case 53:
    // XADD8rm, XCHG8rm
    printi8mem(MI, 2, O);
    return;
    break;
  }


  // Fragment 3 encoded into 4 bits for 15 unique commands.
  // printf("Fragment 3: %"PRIu64"\n", ((Bits >> 34) & 15));
  switch ((Bits >> 34) & 15) {
  default: // unreachable
  case 0:
    // ADC32rm, ADC64rm, ADCX32rm, ADCX64rm, ADD32rm, ADD64rm, ADDSDrm, ADDSD...
    return;
    break;
  case 1:
    // AESKEYGENASSIST128rm, ANDN32rr, ANDN64rr, BEXTR32rm, BEXTR32rr, BEXTR6...
    printOperand(MI, 0, O);
    break;
  case 2:
    // AESKEYGENASSIST128rr, ANDN32rm, ANDN64rm, CMPSDrm, CMPSDrm_Int, CMPSSr...
    SStream_concat0(O, ", ");
    break;
  case 3:
    // VALIGNDZ128rmbi, VALIGNDZ128rri, VALIGNDZ256rmbi, VALIGNDZ256rri, VALI...
    printOperand(MI, 1, O);
    break;
  case 4:
    // VALIGNDZ128rmbik, VALIGNDZ256rmbik, VALIGNDZrmbik, VALIGNQZ128rmbik, V...
    printOperand(MI, 3, O);
    break;
  case 5:
    // VALIGNDZ128rmbikz, VALIGNDZ128rrikz, VALIGNDZ256rmbikz, VALIGNDZ256rri...
    printOperand(MI, 2, O);
    break;
  case 6:
    // VALIGNDZ128rrik, VALIGNDZ256rrik, VALIGNDZrrik, VALIGNQZ128rrik, VALIG...
    SStream_concat0(O, "}");
    return;
    break;
  case 7:
    // VBROADCASTF32X2Z256mk, VBROADCASTF32X2Z256mkz, VBROADCASTF32X2Zmk, VBR...
    SStream_concat0(O, " {");
    break;
  case 8:
    // VCMPPDZ128rmbi, VCMPPDZ128rmbik, VPCMPQZ128rmib, VPCMPQZ128rmibk, VPCM...
    SStream_concat0(O, "{1to2}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_2);
    break;
  case 9:
    // VCMPPDZ256rmbi, VCMPPDZ256rmbik, VCMPPSZ128rmbi, VCMPPSZ128rmbik, VPCM...
    SStream_concat0(O, "{1to4}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_4);
    break;
  case 10:
    // VCMPPDZrmbi, VCMPPDZrmbik, VCMPPSZ256rmbi, VCMPPSZ256rmbik, VPCMPDZ256...
    SStream_concat0(O, "{1to8}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_8);
    break;
  case 11:
    // VCMPPSZrmbi, VCMPPSZrmbik, VPCMPDZrmib, VPCMPDZrmibk, VPCMPUDZrmib, VP...
    SStream_concat0(O, "{1to16}, ");
    op_addAvxBroadcast(MI, X86_AVX_BCAST_16);
    break;
  case 12:
    // VCOMPRESSPDZ128mrk, VCOMPRESSPDZ256mrk, VCOMPRESSPDZmrk, VCOMPRESSPSZ1...
    printOperand(MI, 5, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 13:
    // VFIXUPIMMPDZ128rrikz, VFIXUPIMMPDZ256rrikz, VFIXUPIMMPDZrribkz, VFIXUP...
    SStream_concat0(O, "} {z}");
    op_addAvxZeroOpmask(MI);
    return;
    break;
  case 14:
    // VPSCATTERDDZ128mr, VPSCATTERDDZ256mr, VPSCATTERDDZmr, VPSCATTERDQZ128m...
    printOperand(MI, 6, O);
    SStream_concat0(O, "}");
    return;
    break;
  }


  // Fragment 4 encoded into 4 bits for 10 unique commands.
  // printf("Fragment 4: %"PRIu64"\n", ((Bits >> 38) & 15));
  switch ((Bits >> 38) & 15) {
  default: // unreachable
  case 0:
    // AESKEYGENASSIST128rm, ANDN32rr, ANDN64rr, BEXTR32rm, BEXTR32rr, BEXTR6...
    return;
    break;
  case 1:
    // AESKEYGENASSIST128rr, ANDN32rm, ANDN64rm, CMPSDrm, CMPSDrm_Int, CMPSSr...
    printOperand(MI, 0, O);
    return;
    break;
  case 2:
    // VADDPDZ128rmbk, VADDPDZ128rmbkz, VADDPDZ128rmkz, VADDPDZ128rrkz, VADDP...
    SStream_concat0(O, " {");
    break;
  case 3:
    // VALIGNDZ128rmbi, VALIGNDZ128rmbik, VALIGNDZ128rmbikz, VALIGNDZ128rri, ...
    SStream_concat0(O, ", ");
    break;
  case 4:
    // VBROADCASTF32X2Z256mk, VBROADCASTF32X2Zmk, VBROADCASTI32X2Z128mk, VBRO...
    printOperand(MI, 2, O);
    break;
  case 5:
    // VBROADCASTF32X2Z256mkz, VBROADCASTF32X2Zmkz, VBROADCASTI32X2Z128mkz, V...
    printOperand(MI, 1, O);
    break;
  case 6:
    // VBROADCASTF32X2Z256rk, VBROADCASTF32X2Zrk, VBROADCASTF32X4Z256rmk, VBR...
    SStream_concat0(O, "}");
    return;
    break;
  case 7:
    // VBROADCASTF32X2Z256rkz, VBROADCASTF32X2Zrkz, VBROADCASTF32X4Z256rmkz, ...
    SStream_concat0(O, "} {z}");
    op_addAvxZeroOpmask(MI);
    return;
    break;
  case 8:
    // VCVTPS2PHZ128mrk, VCVTPS2PHZ256mrk, VCVTPS2PHZmrk, VEXTRACTF32x4Z256mr...
    printOperand(MI, 5, O);
    SStream_concat0(O, "}");
    return;
    break;
  case 9:
    // VGATHERQPSZ128rm, VPGATHERQDZ128rm
    printOperand(MI, 3, O);
    SStream_concat0(O, "}");
    return;
    break;
  }


  // Fragment 5 encoded into 3 bits for 6 unique commands.
  // printf("Fragment 5: %"PRIu64"\n", ((Bits >> 42) & 7));
  switch ((Bits >> 42) & 7) {
  default: // unreachable
  case 0:
    // VADDPDZ128rmbk, VADDPDZ256rmbk, VADDPDZrmbk, VADDPSZ128rmbk, VADDPSZ25...
    printOperand(MI, 2, O);
    break;
  case 1:
    // VADDPDZ128rmbkz, VADDPDZ128rmkz, VADDPDZ128rrkz, VADDPDZ256rmbkz, VADD...
    printOperand(MI, 1, O);
    break;
  case 2:
    // VALIGNDZ128rmbi, VALIGNDZ128rmbik, VALIGNDZ128rmbikz, VALIGNDZ128rri, ...
    printOperand(MI, 0, O);
    break;
  case 3:
    // VBROADCASTF32X2Z256mk, VBROADCASTF32X2Zmk, VBROADCASTI32X2Z128mk, VBRO...
    SStream_concat0(O, "}");
    return;
    break;
  case 4:
    // VBROADCASTF32X2Z256mkz, VBROADCASTF32X2Zmkz, VBROADCASTI32X2Z128mkz, V...
    SStream_concat0(O, "} {z}");
    op_addAvxZeroOpmask(MI);
    return;
    break;
  case 5:
    // VCMPPDZ128rmbi, VCMPPDZ128rmbik, VCMPPDZ256rmbi, VCMPPDZ256rmbik, VCMP...
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    break;
  }


  // Fragment 6 encoded into 3 bits for 5 unique commands.
  // printf("Fragment 6: %"PRIu64"\n", ((Bits >> 45) & 7));
  switch ((Bits >> 45) & 7) {
  default: // unreachable
  case 0:
    // VADDPDZ128rmbk, VADDPDZ256rmbk, VADDPDZrmbk, VADDPSZ128rmbk, VADDPSZ25...
    SStream_concat0(O, "}");
    return;
    break;
  case 1:
    // VADDPDZ128rmbkz, VADDPDZ128rmkz, VADDPDZ128rrkz, VADDPDZ256rmbkz, VADD...
    SStream_concat0(O, "} {z}");
    op_addAvxZeroOpmask(MI);
    return;
    break;
  case 2:
    // VALIGNDZ128rmbi, VALIGNDZ128rri, VALIGNDZ256rmbi, VALIGNDZ256rri, VALI...
    return;
    break;
  case 3:
    // VALIGNDZ128rmbik, VALIGNDZ128rmbikz, VALIGNDZ128rrikz, VALIGNDZ256rmbi...
    SStream_concat0(O, " {");
    break;
  case 4:
    // VPERMIL2PDYrr, VPERMIL2PDYrr_REV, VPERMIL2PDrr, VPERMIL2PDrr_REV, VPER...
    SStream_concat0(O, ", ");
    printOperand(MI, 0, O);
    return;
    break;
  }


  // Fragment 7 encoded into 1 bits for 2 unique commands.
  // printf("Fragment 7: %"PRIu64"\n", ((Bits >> 48) & 1));
  if ((Bits >> 48) & 1) {
    // VALIGNDZ128rmbikz, VALIGNDZ128rrikz, VALIGNDZ256rmbikz, VALIGNDZ256rri...
    printOperand(MI, 1, O);
  } else {
    // VALIGNDZ128rmbik, VALIGNDZ256rmbik, VALIGNDZrmbik, VALIGNQZ128rmbik, V...
    printOperand(MI, 2, O);
  }


  // Fragment 8 encoded into 1 bits for 2 unique commands.
  // printf("Fragment 8: %"PRIu64"\n", ((Bits >> 49) & 1));
  if ((Bits >> 49) & 1) {
    // VALIGNDZ128rmbikz, VALIGNDZ128rrikz, VALIGNDZ256rmbikz, VALIGNDZ256rri...
    SStream_concat0(O, "} {z}");
    op_addAvxZeroOpmask(MI);
    return;
  } else {
    // VALIGNDZ128rmbik, VALIGNDZ256rmbik, VALIGNDZrmbik, VALIGNQZ128rmbik, V...
    SStream_concat0(O, "}");
    return;
  }

}



