/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2022, */
/*    Rot127 <unisono@quyllur.org> 2022-2023 */
/* Automatically generated file by Capstone's LLVM TableGen Disassembler Backend. */

/* LLVM-commit: <commit> */
/* LLVM-tag: <tag> */

/* Do not edit. */

/* Capstone's LLVM TableGen Backends: */
/* https://github.com/capstone-engine/llvm-capstone */

{{{ /* TRICORE_PHI (0) - TRICORE_INS_INVALID - PHINODE */
 0
}}},
{{{ /* TRICORE_INLINEASM (1) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_INLINEASM_BR (2) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_CFI_INSTRUCTION (3) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_EH_LABEL (4) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_GC_LABEL (5) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_ANNOTATION_LABEL (6) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_KILL (7) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_EXTRACT_SUBREG (8) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_INSERT_SUBREG (9) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_IMPLICIT_DEF (10) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_SUBREG_TO_REG (11) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_COPY_TO_REGCLASS (12) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_DBG_VALUE (13) - TRICORE_INS_INVALID - DBG_VALUE */
 0
}}},
{{{ /* TRICORE_DBG_VALUE_LIST (14) - TRICORE_INS_INVALID - DBG_VALUE_LIST */
 0
}}},
{{{ /* TRICORE_DBG_INSTR_REF (15) - TRICORE_INS_INVALID - DBG_INSTR_REF */
 0
}}},
{{{ /* TRICORE_DBG_PHI (16) - TRICORE_INS_INVALID - DBG_PHI */
 0
}}},
{{{ /* TRICORE_DBG_LABEL (17) - TRICORE_INS_INVALID - DBG_LABEL */
 0
}}},
{{{ /* TRICORE_REG_SEQUENCE (18) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_COPY (19) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_BUNDLE (20) - TRICORE_INS_INVALID - BUNDLE */
 0
}}},
{{{ /* TRICORE_LIFETIME_START (21) - TRICORE_INS_INVALID - LIFETIME_START */
 0
}}},
{{{ /* TRICORE_LIFETIME_END (22) - TRICORE_INS_INVALID - LIFETIME_END */
 0
}}},
{{{ /* TRICORE_PSEUDO_PROBE (23) - TRICORE_INS_INVALID - PSEUDO_PROBE */
 0
}}},
{{{ /* TRICORE_ARITH_FENCE (24) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_STACKMAP (25) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_FENTRY_CALL (26) - TRICORE_INS_INVALID - # FEntry call */
 0
}}},
{{{ /* TRICORE_PATCHPOINT (27) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_LOAD_STACK_GUARD (28) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_PREALLOCATED_SETUP (29) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_PREALLOCATED_ARG (30) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_STATEPOINT (31) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_LOCAL_ESCAPE (32) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_FAULTING_OP (33) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_PATCHABLE_OP (34) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_PATCHABLE_FUNCTION_ENTER (35) - TRICORE_INS_INVALID - # XRay Function Enter. */
 0
}}},
{{{ /* TRICORE_PATCHABLE_RET (36) - TRICORE_INS_INVALID - # XRay Function Patchable RET. */
 0
}}},
{{{ /* TRICORE_PATCHABLE_FUNCTION_EXIT (37) - TRICORE_INS_INVALID - # XRay Function Exit. */
 0
}}},
{{{ /* TRICORE_PATCHABLE_TAIL_CALL (38) - TRICORE_INS_INVALID - # XRay Tail Call Exit. */
 0
}}},
{{{ /* TRICORE_PATCHABLE_EVENT_CALL (39) - TRICORE_INS_INVALID - # XRay Custom Event Log. */
 0
}}},
{{{ /* TRICORE_PATCHABLE_TYPED_EVENT_CALL (40) - TRICORE_INS_INVALID - # XRay Typed Event Log. */
 0
}}},
{{{ /* TRICORE_ICALL_BRANCH_FUNNEL (41) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_MEMBARRIER (42) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ASSERT_SEXT (43) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ASSERT_ZEXT (44) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ASSERT_ALIGN (45) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ADD (46) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SUB (47) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_MUL (48) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SDIV (49) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UDIV (50) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SREM (51) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UREM (52) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SDIVREM (53) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UDIVREM (54) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_AND (55) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_OR (56) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_XOR (57) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_IMPLICIT_DEF (58) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_PHI (59) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FRAME_INDEX (60) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_GLOBAL_VALUE (61) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_EXTRACT (62) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UNMERGE_VALUES (63) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INSERT (64) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_MERGE_VALUES (65) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BUILD_VECTOR (66) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BUILD_VECTOR_TRUNC (67) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_CONCAT_VECTORS (68) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_PTRTOINT (69) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INTTOPTR (70) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BITCAST (71) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FREEZE (72) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INTRINSIC_FPTRUNC_ROUND (73) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INTRINSIC_TRUNC (74) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INTRINSIC_ROUND (75) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INTRINSIC_LRINT (76) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INTRINSIC_ROUNDEVEN (77) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_READCYCLECOUNTER (78) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_LOAD (79) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SEXTLOAD (80) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ZEXTLOAD (81) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INDEXED_LOAD (82) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INDEXED_SEXTLOAD (83) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INDEXED_ZEXTLOAD (84) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_STORE (85) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INDEXED_STORE (86) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMIC_CMPXCHG_WITH_SUCCESS (87) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMIC_CMPXCHG (88) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_XCHG (89) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_ADD (90) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_SUB (91) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_AND (92) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_NAND (93) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_OR (94) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_XOR (95) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_MAX (96) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_MIN (97) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_UMAX (98) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_UMIN (99) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_FADD (100) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_FSUB (101) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_FMAX (102) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_FMIN (103) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_UINC_WRAP (104) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ATOMICRMW_UDEC_WRAP (105) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FENCE (106) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BRCOND (107) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BRINDIRECT (108) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INVOKE_REGION_START (109) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INTRINSIC (110) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INTRINSIC_W_SIDE_EFFECTS (111) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ANYEXT (112) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_TRUNC (113) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_CONSTANT (114) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FCONSTANT (115) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VASTART (116) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VAARG (117) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SEXT (118) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SEXT_INREG (119) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ZEXT (120) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SHL (121) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_LSHR (122) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ASHR (123) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FSHL (124) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FSHR (125) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ROTR (126) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ROTL (127) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ICMP (128) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FCMP (129) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SELECT (130) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UADDO (131) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UADDE (132) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_USUBO (133) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_USUBE (134) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SADDO (135) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SADDE (136) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SSUBO (137) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SSUBE (138) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UMULO (139) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SMULO (140) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UMULH (141) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SMULH (142) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UADDSAT (143) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SADDSAT (144) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_USUBSAT (145) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SSUBSAT (146) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_USHLSAT (147) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SSHLSAT (148) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SMULFIX (149) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UMULFIX (150) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SMULFIXSAT (151) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UMULFIXSAT (152) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SDIVFIX (153) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UDIVFIX (154) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SDIVFIXSAT (155) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UDIVFIXSAT (156) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FADD (157) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FSUB (158) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMUL (159) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMA (160) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMAD (161) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FDIV (162) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FREM (163) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FPOW (164) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FPOWI (165) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FEXP (166) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FEXP2 (167) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FLOG (168) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FLOG2 (169) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FLOG10 (170) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FNEG (171) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FPEXT (172) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FPTRUNC (173) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FPTOSI (174) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FPTOUI (175) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SITOFP (176) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UITOFP (177) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FABS (178) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FCOPYSIGN (179) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_IS_FPCLASS (180) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FCANONICALIZE (181) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMINNUM (182) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMAXNUM (183) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMINNUM_IEEE (184) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMAXNUM_IEEE (185) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMINIMUM (186) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FMAXIMUM (187) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_PTR_ADD (188) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_PTRMASK (189) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SMIN (190) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SMAX (191) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UMIN (192) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UMAX (193) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ABS (194) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_LROUND (195) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_LLROUND (196) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BR (197) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BRJT (198) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_INSERT_VECTOR_ELT (199) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_EXTRACT_VECTOR_ELT (200) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SHUFFLE_VECTOR (201) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_CTTZ (202) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_CTTZ_ZERO_UNDEF (203) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_CTLZ (204) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_CTLZ_ZERO_UNDEF (205) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_CTPOP (206) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BSWAP (207) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BITREVERSE (208) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FCEIL (209) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FCOS (210) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FSIN (211) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FSQRT (212) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FFLOOR (213) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FRINT (214) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_FNEARBYINT (215) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_ADDRSPACE_CAST (216) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BLOCK_ADDR (217) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_JUMP_TABLE (218) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_DYN_STACKALLOC (219) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_STRICT_FADD (220) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_STRICT_FSUB (221) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_STRICT_FMUL (222) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_STRICT_FDIV (223) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_STRICT_FREM (224) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_STRICT_FMA (225) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_STRICT_FSQRT (226) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_READ_REGISTER (227) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_WRITE_REGISTER (228) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_MEMCPY (229) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_MEMCPY_INLINE (230) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_MEMMOVE (231) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_MEMSET (232) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_BZERO (233) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_SEQ_FADD (234) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_SEQ_FMUL (235) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_FADD (236) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_FMUL (237) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_FMAX (238) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_FMIN (239) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_ADD (240) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_MUL (241) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_AND (242) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_OR (243) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_XOR (244) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_SMAX (245) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_SMIN (246) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_UMAX (247) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_VECREDUCE_UMIN (248) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_SBFX (249) - TRICORE_INS_INVALID -  */
 0
}}},
{{{ /* TRICORE_G_UBFX (250) - TRICORE_INS_INVALID -  */
 0
}}},
{ /* TRICORE_ABSDIFS_B_rr_v110 (251) - TriCore_INS_ABSDIFS_B - absdifs.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSDIFS_H_rr (252) - TriCore_INS_ABSDIFS_H - absdifs.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSDIFS_rc (253) - TriCore_INS_ABSDIFS - absdifs $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSDIFS_rr (254) - TriCore_INS_ABSDIFS - absdifs $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSDIF_B_rr (255) - TriCore_INS_ABSDIF_B - absdif.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSDIF_H_rr (256) - TriCore_INS_ABSDIF_H - absdif.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSDIF_rc (257) - TriCore_INS_ABSDIF - absdif $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_ABSDIF_rr (258) - TriCore_INS_ABSDIF - absdif $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSS_B_rr_v110 (259) - TriCore_INS_ABSS_B - abss.b $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSS_H_rr (260) - TriCore_INS_ABSS_H - abss.h $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABSS_rr (261) - TriCore_INS_ABSS - abss $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABS_B_rr (262) - TriCore_INS_ABS_B - abs.b $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABS_H_rr (263) - TriCore_INS_ABS_H - abs.h $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ABS_rr (264) - TriCore_INS_ABS - abs $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDC_rc (265) - TriCore_INS_ADDC - addc $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_ADDC_rr (266) - TriCore_INS_ADDC - addc $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDIH_A_rlc (267) - TriCore_INS_ADDIH_A - addih.a $d, $s1, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_ADDIH_rlc (268) - TriCore_INS_ADDIH - addih $d, $s1, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_ADDI_rlc (269) - TriCore_INS_ADDI - addi $d, $s1, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_ADDSC_AT_rr (270) - TriCore_INS_ADDSC_AT - addsc.at $d, $s2, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDSC_AT_rr_v110 (271) - TriCore_INS_ADDSC_AT - addsc.at $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDSC_A_rr (272) - TriCore_INS_ADDSC_A - addsc.a $d, $s2, $s1, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_ADDSC_A_rr_v110 (273) - TriCore_INS_ADDSC_A - addsc.a $d, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_ADDSC_A_srrs (274) - TriCore_INS_ADDSC_A - addsc.a $d, $s2, d15, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_ADDSC_A_srrs_v110 (275) - TriCore_INS_ADDSC_A - addsc.a $d, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_ADDS_BU_rr_v110 (276) - TriCore_INS_ADDS_BU - adds.bu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDS_B_rr (277) - TriCore_INS_ADDS_B - adds.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDS_H (278) - TriCore_INS_ADDS_H - adds.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDS_HU (279) - TriCore_INS_ADDS_HU - adds.hu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDS_U (280) - TriCore_INS_ADDS_U - adds.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDS_U_rc (281) - TriCore_INS_ADDS_U - adds.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_ADDS_rc (282) - TriCore_INS_ADDS - adds $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_ADDS_rr (283) - TriCore_INS_ADDS - adds $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDS_srr (284) - TriCore_INS_ADDS - adds $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADDX_rc (285) - TriCore_INS_ADDX - addx $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_ADDX_rr (286) - TriCore_INS_ADDX - addx $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADD_A_rr (287) - TriCore_INS_ADD_A - add.a $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADD_A_src (288) - TriCore_INS_ADD_A - add.a $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_ADD_A_srr (289) - TriCore_INS_ADD_A - add.a $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADD_B_rr (290) - TriCore_INS_ADD_B - add.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADD_F_rrr (291) - TriCore_INS_ADD_F - add.f $d, $s3, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_ADD_H_rr (292) - TriCore_INS_ADD_H - add.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADD_rc (293) - TriCore_INS_ADD - add $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_ADD_rr (294) - TriCore_INS_ADD - add $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADD_src (295) - TriCore_INS_ADD - add $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_ADD_src_15a (296) - TriCore_INS_ADD - add d15, $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_ADD_src_a15 (297) - TriCore_INS_ADD - add $d, d15, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_ADD_srr (298) - TriCore_INS_ADD - add $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADD_srr_15a (299) - TriCore_INS_ADD - add d15, $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ADD_srr_a15 (300) - TriCore_INS_ADD - add $d, d15, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ANDN_T (301) - TriCore_INS_ANDN_T - andn.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_ANDN_rc (302) - TriCore_INS_ANDN - andn $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_ANDN_rr (303) - TriCore_INS_ANDN - andn $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_ANDN_T (304) - TriCore_INS_AND_ANDN_T - and.andn.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_AND_AND_T (305) - TriCore_INS_AND_AND_T - and.and.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_AND_EQ_rc (306) - TriCore_INS_AND_EQ - and.eq $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_AND_EQ_rr (307) - TriCore_INS_AND_EQ - and.eq $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_GE_U_rc (308) - TriCore_INS_AND_GE_U - and.ge.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_AND_GE_U_rr (309) - TriCore_INS_AND_GE_U - and.ge.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_GE_rc (310) - TriCore_INS_AND_GE - and.ge $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_AND_GE_rr (311) - TriCore_INS_AND_GE - and.ge $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_LT_U_rc (312) - TriCore_INS_AND_LT_U - and.lt.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_AND_LT_U_rr (313) - TriCore_INS_AND_LT_U - and.lt.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_LT_rc (314) - TriCore_INS_AND_LT - and.lt $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_AND_LT_rr (315) - TriCore_INS_AND_LT - and.lt $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_NE_rc (316) - TriCore_INS_AND_NE - and.ne $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_AND_NE_rr (317) - TriCore_INS_AND_NE - and.ne $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_NOR_T (318) - TriCore_INS_AND_NOR_T - and.nor.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_AND_OR_T (319) - TriCore_INS_AND_OR_T - and.or.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_AND_T (320) - TriCore_INS_AND_T - and.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_AND_rc (321) - TriCore_INS_AND - and $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_AND_rr (322) - TriCore_INS_AND - and $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_sc (323) - TriCore_INS_AND - and d15, $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_AND_sc_v110 (324) - TriCore_INS_AND - and d15, $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_AND_srr (325) - TriCore_INS_AND - and $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_AND_srr_v110 (326) - TriCore_INS_AND - and $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_BISR_rc (327) - TriCore_INS_BISR - bisr $const9 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_BISR_rc_v161 (328) - TriCore_INS_BISR - bisr $const9 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_BISR_sc (329) - TriCore_INS_BISR - bisr $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_BISR_sc_v110 (330) - TriCore_INS_BISR - bisr $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_BMERGAE_rr_v110 (331) - TriCore_INS_BMERGE - bmerge $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_BMERGE_rr (332) - TriCore_INS_BMERGE - bmerge $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_BSPLIT_rr (333) - TriCore_INS_BSPLIT - bsplit $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_BSPLIT_rr_v110 (334) - TriCore_INS_BSPLIT - bsplit $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CACHEA_I_bo_bso (335) - TriCore_INS_CACHEA_I - cachea.i [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_I_bo_c (336) - TriCore_INS_CACHEA_I - cachea.i [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_I_bo_pos (337) - TriCore_INS_CACHEA_I - cachea.i [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_I_bo_pre (338) - TriCore_INS_CACHEA_I - cachea.i [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_I_bo_r (339) - TriCore_INS_CACHEA_I - cachea.i [${s2}+r] */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CACHEA_WI_bo_bso (340) - TriCore_INS_CACHEA_WI - cachea.wi [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_WI_bo_c (341) - TriCore_INS_CACHEA_WI - cachea.wi [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_WI_bo_pos (342) - TriCore_INS_CACHEA_WI - cachea.wi [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_WI_bo_pre (343) - TriCore_INS_CACHEA_WI - cachea.wi [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_WI_bo_r (344) - TriCore_INS_CACHEA_WI - cachea.wi [${s2}+r] */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CACHEA_W_bo_bso (345) - TriCore_INS_CACHEA_W - cachea.w [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_W_bo_c (346) - TriCore_INS_CACHEA_W - cachea.w [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_W_bo_pos (347) - TriCore_INS_CACHEA_W - cachea.w [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_W_bo_pre (348) - TriCore_INS_CACHEA_W - cachea.w [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEA_W_bo_r (349) - TriCore_INS_CACHEA_W - cachea.w [${s2}+r] */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CACHEI_I_bo_bso (350) - TriCore_INS_CACHEI_I - cachei.i [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEI_I_bo_pos (351) - TriCore_INS_CACHEI_I - cachei.i [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEI_I_bo_pre (352) - TriCore_INS_CACHEI_I - cachei.i [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEI_WI_bo_bso (353) - TriCore_INS_CACHEI_WI - cachei.wi [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEI_WI_bo_pos (354) - TriCore_INS_CACHEI_WI - cachei.wi [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEI_WI_bo_pre (355) - TriCore_INS_CACHEI_WI - cachei.wi [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEI_W_bo_bso (356) - TriCore_INS_CACHEI_W - cachei.w [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEI_W_bo_pos (357) - TriCore_INS_CACHEI_W - cachei.w [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CACHEI_W_bo_pre (358) - TriCore_INS_CACHEI_W - cachei.w [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CADDN_A_rcr_v110 (359) - TriCore_INS_CADDN_A - caddn.a $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_CADDN_A_rrr_v110 (360) - TriCore_INS_CADDN_A - caddn.a $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_CADDN_rcr (361) - TriCore_INS_CADDN - caddn $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_CADDN_rrr (362) - TriCore_INS_CADDN - caddn $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_CADDN_src (363) - TriCore_INS_CADDN - caddn $d, d15, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_CADDN_srr_v110 (364) - TriCore_INS_CADDN - caddn $d, d15, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CADD_A_rcr_v110 (365) - TriCore_INS_CADD_A - cadd.a $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_CADD_A_rrr_v110 (366) - TriCore_INS_CADD_A - cadd.a $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_CADD_rcr (367) - TriCore_INS_CADD - cadd $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_CADD_rrr (368) - TriCore_INS_CADD - cadd $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_CADD_src (369) - TriCore_INS_CADD - cadd $d, d15, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_CADD_srr_v110 (370) - TriCore_INS_CADD - cadd $d, d15, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CALLA_b (371) - TriCore_INS_CALLA - calla $disp24 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp24 */
  { 0 }
}},
{ /* TRICORE_CALLI_rr (372) - TriCore_INS_CALLI - calli $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CALLI_rr_v110 (373) - TriCore_INS_CALLI - calli $s2 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CALL_b (374) - TriCore_INS_CALL - call $disp24 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp24 */
  { 0 }
}},
{ /* TRICORE_CALL_sb (375) - TriCore_INS_CALL - call $disp8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp8 */
  { 0 }
}},
{ /* TRICORE_CLO_B_rr_v110 (376) - TriCore_INS_CLO_B - clo.b $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CLO_H_rr (377) - TriCore_INS_CLO_H - clo.h $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CLO_rr (378) - TriCore_INS_CLO - clo $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CLS_B_rr_v110 (379) - TriCore_INS_CLS_B - cls.b $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CLS_H_rr (380) - TriCore_INS_CLS_H - cls.h $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CLS_rr (381) - TriCore_INS_CLS - cls $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CLZ_B_rr_v110 (382) - TriCore_INS_CLZ_B - clz.b $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CLZ_H_rr (383) - TriCore_INS_CLZ_H - clz.h $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CLZ_rr (384) - TriCore_INS_CLZ - clz $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_CMOVN_src (385) - TriCore_INS_CMOVN - cmovn $d, d15, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_CMOVN_srr (386) - TriCore_INS_CMOVN - cmovn $d, d15, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CMOV_src (387) - TriCore_INS_CMOV - cmov $d, d15, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_CMOV_srr (388) - TriCore_INS_CMOV - cmov $d, d15, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CMPSWAP_W_bo_bso (389) - TriCore_INS_CMPSWAP_W - cmpswap.w [$s2]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CMPSWAP_W_bo_c (390) - TriCore_INS_CMPSWAP_W - cmpswap.w [${s2}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CMPSWAP_W_bo_pos (391) - TriCore_INS_CMPSWAP_W - cmpswap.w [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CMPSWAP_W_bo_pre (392) - TriCore_INS_CMPSWAP_W - cmpswap.w [+$s2]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_CMPSWAP_W_bo_r (393) - TriCore_INS_CMPSWAP_W - cmpswap.w [${s2}+r], $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CMP_F_rr (394) - TriCore_INS_CMP_F - cmp.f $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CRC32B_W_rr (395) - TriCore_INS_CRC32B_W - crc32b.w $d, $s2, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CRC32L_W_rr (396) - TriCore_INS_CRC32L_W - crc32l.w $d, $s2, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CRC32_B_rr (397) - TriCore_INS_CRC32_B - crc32.b $d, $s2, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_CRCN_rrr (398) - TriCore_INS_CRCN - crcn $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_CSUBN_A__rrr_v110 (399) - TriCore_INS_CSUBN_A - csubn.a $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_CSUBN_rrr (400) - TriCore_INS_CSUBN - csubn $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_CSUB_A__rrr_v110 (401) - TriCore_INS_CSUB_A - csub.a $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_CSUB_rrr (402) - TriCore_INS_CSUB - csub $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_DEBUG_sr (403) - TriCore_INS_DEBUG - debug */
{
  { 0 }
}},
{ /* TRICORE_DEBUG_sys (404) - TriCore_INS_DEBUG - debug */
{
  { 0 }
}},
{ /* TRICORE_DEXTR_rrpw (405) - TriCore_INS_DEXTR - dextr $d, $s1, $s2, $pos */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_DEXTR_rrrr (406) - TriCore_INS_DEXTR - dextr $d, $s1, $s2, $s3 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_DIFSC_A_rr_v110 (407) - TriCore_INS_DIFSC_A - difsc.a $d, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_DISABLE_sys (408) - TriCore_INS_DISABLE - disable */
{
  { 0 }
}},
{ /* TRICORE_DISABLE_sys_1 (409) - TriCore_INS_DISABLE - disable $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_DIV_F_rr (410) - TriCore_INS_DIV_F - div.f $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DIV_U_rr (411) - TriCore_INS_DIV_U - div.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DIV_rr (412) - TriCore_INS_DIV - div $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DSYNC_sys (413) - TriCore_INS_DSYNC - dsync */
{
  { 0 }
}},
{ /* TRICORE_DVADJ_rrr (414) - TriCore_INS_DVADJ - dvadj $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_DVADJ_rrr_v110 (415) - TriCore_INS_DVADJ - dvadj $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_DVADJ_srr_v110 (416) - TriCore_INS_DVADJ - dvadj $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_BU_rr (417) - TriCore_INS_DVINIT_BU - dvinit.bu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_BU_rr_v110 (418) - TriCore_INS_DVINIT_BU - dvinit.bu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_B_rr (419) - TriCore_INS_DVINIT_B - dvinit.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_B_rr_v110 (420) - TriCore_INS_DVINIT_B - dvinit.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_HU_rr (421) - TriCore_INS_DVINIT_HU - dvinit.hu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_HU_rr_v110 (422) - TriCore_INS_DVINIT_HU - dvinit.hu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_H_rr (423) - TriCore_INS_DVINIT_H - dvinit.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_H_rr_v110 (424) - TriCore_INS_DVINIT_H - dvinit.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_U_rr (425) - TriCore_INS_DVINIT_U - dvinit.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_U_rr_v110 (426) - TriCore_INS_DVINIT_U - dvinit.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_rr (427) - TriCore_INS_DVINIT - dvinit $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVINIT_rr_v110 (428) - TriCore_INS_DVINIT - dvinit $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVSTEP_U_rrr (429) - TriCore_INS_DVSTEP_U - dvstep.u $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_DVSTEP_U_rrrv110 (430) - TriCore_INS_DVSTEP_U - dvstep.u $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_DVSTEP_Uv110 (431) - TriCore_INS_DVSTEP_U - dvstep.u $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_DVSTEP_rrr (432) - TriCore_INS_DVSTEP - dvstep $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_DVSTEP_rrrv110 (433) - TriCore_INS_DVSTEP - dvstep $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_DVSTEPv110 (434) - TriCore_INS_DVSTEP - dvstep $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_ENABLE_sys (435) - TriCore_INS_ENABLE - enable */
{
  { 0 }
}},
{ /* TRICORE_EQANY_B_rc (436) - TriCore_INS_EQANY_B - eqany.b $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_EQANY_B_rr (437) - TriCore_INS_EQANY_B - eqany.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_EQANY_H_rc (438) - TriCore_INS_EQANY_H - eqany.h $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_EQANY_H_rr (439) - TriCore_INS_EQANY_H - eqany.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_EQZ_A_rr (440) - TriCore_INS_EQZ_A - eqz.a $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_EQ_A_rr (441) - TriCore_INS_EQ_A - eq.a $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_EQ_B_rr (442) - TriCore_INS_EQ_B - eq.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_EQ_H_rr (443) - TriCore_INS_EQ_H - eq.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_EQ_W_rr (444) - TriCore_INS_EQ_W - eq.w $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_EQ_rc (445) - TriCore_INS_EQ - eq $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_EQ_rr (446) - TriCore_INS_EQ - eq $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_EQ_src (447) - TriCore_INS_EQ - eq d15, $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_EQ_srr (448) - TriCore_INS_EQ - eq d15, $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_EXTR_U_rrpw (449) - TriCore_INS_EXTR_U - extr.u $d, $s1, $pos, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_EXTR_U_rrrr (450) - TriCore_INS_EXTR_U - extr.u $d, $s1, $s3 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_EXTR_U_rrrw (451) - TriCore_INS_EXTR_U - extr.u $d, $s1, $s3, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_EXTR_rrpw (452) - TriCore_INS_EXTR - extr $d, $s1, $pos, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_EXTR_rrrr (453) - TriCore_INS_EXTR - extr $d, $s1, $s3 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_EXTR_rrrw (454) - TriCore_INS_EXTR - extr $d, $s1, $s3, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_FCALLA_b (455) - TriCore_INS_FCALLA - fcalla $disp24 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp24 */
  { 0 }
}},
{ /* TRICORE_FCALLA_i (456) - TriCore_INS_FCALLI - fcalli $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_FCALL_b (457) - TriCore_INS_FCALL - fcall $disp24 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp24 */
  { 0 }
}},
{ /* TRICORE_FRET_sr (458) - TriCore_INS_FRET - fret */
{
  { 0 }
}},
{ /* TRICORE_FRET_sys (459) - TriCore_INS_FRET - fret */
{
  { 0 }
}},
{ /* TRICORE_FTOHP_rr (460) - TriCore_INS_FTOHP - ftohp $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_FTOIZ_rr (461) - TriCore_INS_FTOIZ - ftoiz $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_FTOI_rr (462) - TriCore_INS_FTOI - ftoi $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_FTOQ31Z_rr (463) - TriCore_INS_FTOQ31Z - ftoq31z $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_FTOQ31_rr (464) - TriCore_INS_FTOQ31 - ftoq31 $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_FTOUZ_rr (465) - TriCore_INS_FTOUZ - ftouz $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_FTOU_rr (466) - TriCore_INS_FTOU - ftou $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_GE_A_rr (467) - TriCore_INS_GE_A - ge.a $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_GE_U_rc (468) - TriCore_INS_GE_U - ge.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_GE_U_rr (469) - TriCore_INS_GE_U - ge.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_GE_rc (470) - TriCore_INS_GE - ge $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_GE_rr (471) - TriCore_INS_GE - ge $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_HPTOF_rr (472) - TriCore_INS_HPTOF - hptof $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_IMASK_rcpw (473) - TriCore_INS_IMASK - imask $d, $const4, $pos, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_IMASK_rcrw (474) - TriCore_INS_IMASK - imask $d, $const4, $s3, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_IMASK_rrpw (475) - TriCore_INS_IMASK - imask $d, $s2, $pos, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_IMASK_rrrw (476) - TriCore_INS_IMASK - imask $d, $s2, $s3, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_INSERT_rcpw (477) - TriCore_INS_INSERT - insert $d, $s1, $const4, $pos, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_INSERT_rcrr (478) - TriCore_INS_INSERT - insert $d, $s1, $const4, $s3 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_INSERT_rcrw (479) - TriCore_INS_INSERT - insert $d, $s1, $const4, $s3, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_INSERT_rrpw (480) - TriCore_INS_INSERT - insert $d, $s1, $s2, $pos, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_INSERT_rrrr (481) - TriCore_INS_INSERT - insert $d, $s1, $s2, $s3 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_INSERT_rrrw (482) - TriCore_INS_INSERT - insert $d, $s1, $s2, $s3, $width */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* width */
  { 0 }
}},
{ /* TRICORE_INSN_T (483) - TriCore_INS_INSN_T - insn.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_INS_T (484) - TriCore_INS_INS_T - ins.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_ISYNC_sys (485) - TriCore_INS_ISYNC - isync */
{
  { 0 }
}},
{ /* TRICORE_ITOF_rr (486) - TriCore_INS_ITOF - itof $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_IXMAX_U_rrr (487) - TriCore_INS_IXMAX_U - ixmax.u $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_IXMAX_rrr (488) - TriCore_INS_IXMAX - ixmax $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_IXMIN_U_rrr (489) - TriCore_INS_IXMIN_U - ixmin.u $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_IXMIN_rrr (490) - TriCore_INS_IXMIN - ixmin $d, $s3, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_JA_b (491) - TriCore_INS_JA - ja $disp24 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp24 */
  { 0 }
}},
{ /* TRICORE_JEQ_A_brr (492) - TriCore_INS_JEQ_A - jeq.a $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JEQ_brc (493) - TriCore_INS_JEQ - jeq $s1, $const4, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JEQ_brr (494) - TriCore_INS_JEQ - jeq $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JEQ_sbc1 (495) - TriCore_INS_JEQ - jeq d15, $const4, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_JEQ_sbc2 (496) - TriCore_INS_JEQ - jeq d15, $const4, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_JEQ_sbc_v110 (497) - TriCore_INS_JEQ - jeq d15, $const4, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_JEQ_sbr1 (498) - TriCore_INS_JEQ - jeq d15, $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JEQ_sbr2 (499) - TriCore_INS_JEQ - jeq d15, $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JEQ_sbr_v110 (500) - TriCore_INS_JEQ - jeq d15, $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JGEZ_sbr (501) - TriCore_INS_JGEZ - jgez $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JGEZ_sbr_v110 (502) - TriCore_INS_JGEZ - jgez $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JGE_U_brc (503) - TriCore_INS_JGE_U - jge.u $s1, $const4, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JGE_U_brr (504) - TriCore_INS_JGE_U - jge.u $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JGE_brc (505) - TriCore_INS_JGE - jge $s1, $const4, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JGE_brr (506) - TriCore_INS_JGE - jge $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JGTZ_sbr (507) - TriCore_INS_JGTZ - jgtz $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JGTZ_sbr_v110 (508) - TriCore_INS_JGTZ - jgtz $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JI_rr (509) - TriCore_INS_JI - ji $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_JI_rr_v110 (510) - TriCore_INS_JI - ji $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_JI_sbr_v110 (511) - TriCore_INS_JI - ji $s2 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_JI_sr (512) - TriCore_INS_JI - ji $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_JLA_b (513) - TriCore_INS_JLA - jla $disp24 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp24 */
  { 0 }
}},
{ /* TRICORE_JLEZ_sbr (514) - TriCore_INS_JLEZ - jlez $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JLEZ_sbr_v110 (515) - TriCore_INS_JLEZ - jlez $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JLI_rr (516) - TriCore_INS_JLI - jli $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_JLI_rr_v110 (517) - TriCore_INS_JLI - jli $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_JLTZ_sbr (518) - TriCore_INS_JLTZ - jltz $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JLTZ_sbr_v110 (519) - TriCore_INS_JLTZ - jltz $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JLT_U_brc (520) - TriCore_INS_JLT_U - jlt.u $s1, $const4, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JLT_U_brr (521) - TriCore_INS_JLT_U - jlt.u $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JLT_brc (522) - TriCore_INS_JLT - jlt $s1, $const4, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JLT_brr (523) - TriCore_INS_JLT - jlt $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JL_b (524) - TriCore_INS_JL - jl $disp24 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp24 */
  { 0 }
}},
{ /* TRICORE_JNED_brc (525) - TriCore_INS_JNED - jned $s1, $const4, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNED_brr (526) - TriCore_INS_JNED - jned $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNEI_brc (527) - TriCore_INS_JNEI - jnei $s1, $const4, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNEI_brr (528) - TriCore_INS_JNEI - jnei $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNE_A_brr (529) - TriCore_INS_JNE_A - jne.a $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNE_brc (530) - TriCore_INS_JNE - jne $s1, $const4, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNE_brr (531) - TriCore_INS_JNE - jne $s1, $s2, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNE_sbc1 (532) - TriCore_INS_JNE - jne d15, $const4, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_JNE_sbc2 (533) - TriCore_INS_JNE - jne d15, $const4, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_JNE_sbc_v110 (534) - TriCore_INS_JNE - jne d15, $const4, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_JNE_sbr1 (535) - TriCore_INS_JNE - jne d15, $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JNE_sbr2 (536) - TriCore_INS_JNE - jne d15, $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JNE_sbr_v110 (537) - TriCore_INS_JNE - jne d15, $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JNZ_A_brr (538) - TriCore_INS_JNZ_A - jnz.a $s1, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNZ_A_sbr (539) - TriCore_INS_JNZ_A - jnz.a $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JNZ_T_brn (540) - TriCore_INS_JNZ_T - jnz.t $s1, $n, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JNZ_T_sbrn (541) - TriCore_INS_JNZ_T - jnz.t d15, $n, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JNZ_T_sbrn_v110 (542) - TriCore_INS_JNZ_T - jnz.t d15, $n, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JNZ_sb (543) - TriCore_INS_JNZ - jnz d15, $disp8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp8 */
  { 0 }
}},
{ /* TRICORE_JNZ_sb_v110 (544) - TriCore_INS_JNZ - jnz d15, $disp8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp8 */
  { 0 }
}},
{ /* TRICORE_JNZ_sbr (545) - TriCore_INS_JNZ - jnz $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JNZ_sbr_v110 (546) - TriCore_INS_JNZ - jnz $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JZ_A_brr (547) - TriCore_INS_JZ_A - jz.a $s1, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JZ_A_sbr (548) - TriCore_INS_JZ_A - jz.a $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JZ_T_brn (549) - TriCore_INS_JZ_T - jz.t $s1, $n, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_JZ_T_sbrn (550) - TriCore_INS_JZ_T - jz.t d15, $n, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JZ_T_sbrn_v110 (551) - TriCore_INS_JZ_T - jz.t d15, $n, $disp4 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JZ_sb (552) - TriCore_INS_JZ - jz d15, $disp8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp8 */
  { 0 }
}},
{ /* TRICORE_JZ_sb_v110 (553) - TriCore_INS_JZ - jz d15, $disp8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp8 */
  { 0 }
}},
{ /* TRICORE_JZ_sbr (554) - TriCore_INS_JZ - jz $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_JZ_sbr_v110 (555) - TriCore_INS_JZ - jz $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_J_b (556) - TriCore_INS_J - j $disp24 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp24 */
  { 0 }
}},
{ /* TRICORE_J_sb (557) - TriCore_INS_J - j $disp8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp8 */
  { 0 }
}},
{ /* TRICORE_J_sb_v110 (558) - TriCore_INS_J - j $disp8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp8 */
  { 0 }
}},
{ /* TRICORE_LDLCX_abs (559) - TriCore_INS_LDLCX - ldlcx $off18 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LDLCX_bo_bso (560) - TriCore_INS_LDLCX - ldlcx [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LDMST_abs (561) - TriCore_INS_LDMST - ldmst $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LDMST_bo_bso (562) - TriCore_INS_LDMST - ldmst [$s2]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LDMST_bo_c (563) - TriCore_INS_LDMST - ldmst [${s2}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LDMST_bo_pos (564) - TriCore_INS_LDMST - ldmst [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LDMST_bo_pre (565) - TriCore_INS_LDMST - ldmst [+$s2]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LDMST_bo_r (566) - TriCore_INS_LDMST - ldmst [${s2}+r], $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LDUCX_abs (567) - TriCore_INS_LDUCX - lducx $off18 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LDUCX_bo_bso (568) - TriCore_INS_LDUCX - lducx [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_A_abs (569) - TriCore_INS_LD_A - ld.a $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_A_bo_bso (570) - TriCore_INS_LD_A - ld.a $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_A_bo_c (571) - TriCore_INS_LD_A - ld.a $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_A_bo_pos (572) - TriCore_INS_LD_A - ld.a $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_A_bo_pre (573) - TriCore_INS_LD_A - ld.a $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_A_bo_r (574) - TriCore_INS_LD_A - ld.a $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_A_bol (575) - TriCore_INS_LD_A - ld.a $s1, [$s2]$off16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_LD_A_sc (576) - TriCore_INS_LD_A - ld.a a15, [sp]$const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_LD_A_slr (577) - TriCore_INS_LD_A - ld.a $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_A_slr_post (578) - TriCore_INS_LD_A - ld.a $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_A_slr_post_v110 (579) - TriCore_INS_LD_A - ld.a $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_A_slr_v110 (580) - TriCore_INS_LD_A - ld.a $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_A_slro (581) - TriCore_INS_LD_A - ld.a $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_A_slro_v110 (582) - TriCore_INS_LD_A - ld.a $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_A_sro (583) - TriCore_INS_LD_A - ld.a a15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_A_sro_v110 (584) - TriCore_INS_LD_A - ld.a a15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_BU_abs (585) - TriCore_INS_LD_BU - ld.bu $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_BU_bo_bso (586) - TriCore_INS_LD_BU - ld.bu $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_BU_bo_c (587) - TriCore_INS_LD_BU - ld.bu $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_BU_bo_pos (588) - TriCore_INS_LD_BU - ld.bu $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_BU_bo_pre (589) - TriCore_INS_LD_BU - ld.bu $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_BU_bo_r (590) - TriCore_INS_LD_BU - ld.bu $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_BU_bol (591) - TriCore_INS_LD_BU - ld.bu $s1, [$s2]$off16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_LD_BU_slr (592) - TriCore_INS_LD_BU - ld.bu $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_BU_slr_post (593) - TriCore_INS_LD_BU - ld.bu $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_BU_slr_post_v110 (594) - TriCore_INS_LD_BU - ld.bu $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_BU_slr_v110 (595) - TriCore_INS_LD_BU - ld.bu $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_BU_slro (596) - TriCore_INS_LD_BU - ld.bu $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_BU_slro_v110 (597) - TriCore_INS_LD_BU - ld.bu $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_BU_sro (598) - TriCore_INS_LD_BU - ld.bu d15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_BU_sro_v110 (599) - TriCore_INS_LD_BU - ld.bu d15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_B_abs (600) - TriCore_INS_LD_B - ld.b $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_B_bo_bso (601) - TriCore_INS_LD_B - ld.b $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_B_bo_c (602) - TriCore_INS_LD_B - ld.b $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_B_bo_pos (603) - TriCore_INS_LD_B - ld.b $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_B_bo_pre (604) - TriCore_INS_LD_B - ld.b $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_B_bo_r (605) - TriCore_INS_LD_B - ld.b $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_B_bol (606) - TriCore_INS_LD_B - ld.b $s1, [$s2]$off16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_LD_B_slr_post_v110 (607) - TriCore_INS_LD_B - ld.b $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_B_slr_v110 (608) - TriCore_INS_LD_B - ld.b $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_B_slro_v110 (609) - TriCore_INS_LD_B - ld.b $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_B_sro_v110 (610) - TriCore_INS_LD_B - ld.b d15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_DA_abs (611) - TriCore_INS_LD_DA - ld.da $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_DA_bo_bso (612) - TriCore_INS_LD_DA - ld.da $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_DA_bo_c (613) - TriCore_INS_LD_DA - ld.da $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_DA_bo_pos (614) - TriCore_INS_LD_DA - ld.da $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_DA_bo_pre (615) - TriCore_INS_LD_DA - ld.da $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_DA_bo_r (616) - TriCore_INS_LD_DA - ld.da $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_D_abs (617) - TriCore_INS_LD_D - ld.d $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_D_bo_bso (618) - TriCore_INS_LD_D - ld.d $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_D_bo_c (619) - TriCore_INS_LD_D - ld.d $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_D_bo_pos (620) - TriCore_INS_LD_D - ld.d $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_D_bo_pre (621) - TriCore_INS_LD_D - ld.d $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_D_bo_r (622) - TriCore_INS_LD_D - ld.d $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_HU_abs (623) - TriCore_INS_LD_HU - ld.hu $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_HU_bo_bso (624) - TriCore_INS_LD_HU - ld.hu $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_HU_bo_c (625) - TriCore_INS_LD_HU - ld.hu $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_HU_bo_pos (626) - TriCore_INS_LD_HU - ld.hu $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_HU_bo_pre (627) - TriCore_INS_LD_HU - ld.hu $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_HU_bo_r (628) - TriCore_INS_LD_HU - ld.hu $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_HU_bol (629) - TriCore_INS_LD_HU - ld.hu $s1, [$s2]$off16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_LD_H_abs (630) - TriCore_INS_LD_H - ld.h $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_H_bo_bso (631) - TriCore_INS_LD_H - ld.h $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_H_bo_c (632) - TriCore_INS_LD_H - ld.h $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_H_bo_pos (633) - TriCore_INS_LD_H - ld.h $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_H_bo_pre (634) - TriCore_INS_LD_H - ld.h $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_H_bo_r (635) - TriCore_INS_LD_H - ld.h $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_H_bol (636) - TriCore_INS_LD_H - ld.h $s1, [$s2]$off16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_LD_H_slr (637) - TriCore_INS_LD_H - ld.h $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_H_slr_post (638) - TriCore_INS_LD_H - ld.h $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_H_slr_post_v110 (639) - TriCore_INS_LD_H - ld.h $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_H_slr_v110 (640) - TriCore_INS_LD_H - ld.h $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_H_slro (641) - TriCore_INS_LD_H - ld.h $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_H_slro_v110 (642) - TriCore_INS_LD_H - ld.h $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_H_sro (643) - TriCore_INS_LD_H - ld.h d15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_H_sro_v110 (644) - TriCore_INS_LD_H - ld.h d15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_Q_abs (645) - TriCore_INS_LD_Q - ld.q $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_Q_bo_bso (646) - TriCore_INS_LD_Q - ld.q $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_Q_bo_c (647) - TriCore_INS_LD_Q - ld.q $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_Q_bo_pos (648) - TriCore_INS_LD_Q - ld.q $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_Q_bo_pre (649) - TriCore_INS_LD_Q - ld.q $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_Q_bo_r (650) - TriCore_INS_LD_Q - ld.q $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_W_abs (651) - TriCore_INS_LD_W - ld.w $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LD_W_bo_bso (652) - TriCore_INS_LD_W - ld.w $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_W_bo_c (653) - TriCore_INS_LD_W - ld.w $d, [${s2}+c]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_W_bo_pos (654) - TriCore_INS_LD_W - ld.w $s1, [${s2}+]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_W_bo_pre (655) - TriCore_INS_LD_W - ld.w $s1, [+${s2}]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LD_W_bo_r (656) - TriCore_INS_LD_W - ld.w $d, [${s2}+r] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_W_bol (657) - TriCore_INS_LD_W - ld.w $s1, [$s2]$off16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_LD_W_sc (658) - TriCore_INS_LD_W - ld.w d15, [sp]$const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_LD_W_slr (659) - TriCore_INS_LD_W - ld.w $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_W_slr_post (660) - TriCore_INS_LD_W - ld.w $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_W_slr_post_v110 (661) - TriCore_INS_LD_W - ld.w $d, [${s2}+] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_W_slr_v110 (662) - TriCore_INS_LD_W - ld.w $d, [$s2] */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LD_W_slro (663) - TriCore_INS_LD_W - ld.w $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_W_slro_v110 (664) - TriCore_INS_LD_W - ld.w $d, [a15]$off4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_W_sro (665) - TriCore_INS_LD_W - ld.w d15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LD_W_sro_v110 (666) - TriCore_INS_LD_W - ld.w d15, [$s2]$off4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_LEA_abs (667) - TriCore_INS_LEA - lea $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LEA_bo_bso (668) - TriCore_INS_LEA - lea $d, [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_LEA_bol (669) - TriCore_INS_LEA - lea $s1, [$s2]$off16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_LHA_abs (670) - TriCore_INS_LHA - lha $d, $off18 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_LOOPU_brr (671) - TriCore_INS_LOOPU - loopu $disp15 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_LOOP_brr (672) - TriCore_INS_LOOP - loop $s1, $disp15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp15 */
  { 0 }
}},
{ /* TRICORE_LOOP_sbr (673) - TriCore_INS_LOOP - loop $s2, $disp4 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* disp4 */
  { 0 }
}},
{ /* TRICORE_LT_A_rr (674) - TriCore_INS_LT_A - lt.a $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_B (675) - TriCore_INS_LT_B - lt.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_BU (676) - TriCore_INS_LT_BU - lt.bu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_H (677) - TriCore_INS_LT_H - lt.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_HU (678) - TriCore_INS_LT_HU - lt.hu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_U_rc (679) - TriCore_INS_LT_U - lt.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_LT_U_rr (680) - TriCore_INS_LT_U - lt.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_U_srcv110 (681) - TriCore_INS_LT_U - lt.u d15, $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_LT_U_srrv110 (682) - TriCore_INS_LT_U - lt.u d15, $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_W (683) - TriCore_INS_LT_W - lt.w $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_WU (684) - TriCore_INS_LT_WU - lt.wu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_rc (685) - TriCore_INS_LT - lt $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_LT_rr (686) - TriCore_INS_LT - lt $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_LT_src (687) - TriCore_INS_LT - lt d15, $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_LT_srr (688) - TriCore_INS_LT - lt d15, $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MADDMS_H_rrr1_LL (689) - TriCore_INS_MADDMS_H - maddms.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDMS_H_rrr1_LU (690) - TriCore_INS_MADDMS_H - maddms.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDMS_H_rrr1_UL (691) - TriCore_INS_MADDMS_H - maddms.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDMS_H_rrr1_UU (692) - TriCore_INS_MADDMS_H - maddms.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDMS_U_rcr_v110 (693) - TriCore_INS_MADDMS_U - maddms.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADDMS_U_rrr2_v110 (694) - TriCore_INS_MADDMS_U - maddms.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADDMS_rcr_v110 (695) - TriCore_INS_MADDMS - maddms $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADDMS_rrr2_v110 (696) - TriCore_INS_MADDMS - maddms $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADDM_H_rrr1_LL (697) - TriCore_INS_MADDM_H - maddm.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDM_H_rrr1_LU (698) - TriCore_INS_MADDM_H - maddm.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDM_H_rrr1_UL (699) - TriCore_INS_MADDM_H - maddm.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDM_H_rrr1_UU (700) - TriCore_INS_MADDM_H - maddm.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDM_H_rrr1_v110 (701) - TriCore_INS_MADDM_H - maddm.h $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDM_Q_rrr1_v110 (702) - TriCore_INS_MADDM_Q - maddm.q $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDM_U_rcr_v110 (703) - TriCore_INS_MADDM_U - maddm.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADDM_U_rrr2_v110 (704) - TriCore_INS_MADDM_U - maddm.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADDM_rcr_v110 (705) - TriCore_INS_MADDM - maddm $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADDM_rrr2_v110 (706) - TriCore_INS_MADDM - maddm $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADDRS_H_rrr1_LL (707) - TriCore_INS_MADDRS_H - maddrs.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDRS_H_rrr1_LU (708) - TriCore_INS_MADDRS_H - maddrs.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDRS_H_rrr1_UL (709) - TriCore_INS_MADDRS_H - maddrs.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDRS_H_rrr1_UL_2 (710) - TriCore_INS_MADDRS_H - maddrs.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDRS_H_rrr1_UU (711) - TriCore_INS_MADDRS_H - maddrs.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDRS_H_rrr1_v110 (712) - TriCore_INS_MADDRS_H - maddrs.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDRS_Q_rrr1_L_L (713) - TriCore_INS_MADDRS_Q - maddrs.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDRS_Q_rrr1_U_U (714) - TriCore_INS_MADDRS_Q - maddrs.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDRS_Q_rrr1_v110 (715) - TriCore_INS_MADDRS_Q - maddrs.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_H_rrr1_LL (716) - TriCore_INS_MADDR_H - maddr.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_H_rrr1_LU (717) - TriCore_INS_MADDR_H - maddr.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_H_rrr1_UL (718) - TriCore_INS_MADDR_H - maddr.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_H_rrr1_UL_2 (719) - TriCore_INS_MADDR_H - maddr.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_H_rrr1_UU (720) - TriCore_INS_MADDR_H - maddr.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_H_rrr1_v110 (721) - TriCore_INS_MADDR_H - maddr.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_Q_rrr1_L_L (722) - TriCore_INS_MADDR_Q - maddr.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_Q_rrr1_U_U (723) - TriCore_INS_MADDR_Q - maddr.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDR_Q_rrr1_v110 (724) - TriCore_INS_MADDR_Q - maddr.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUMS_H_rrr1_LL (725) - TriCore_INS_MADDSUMS_H - maddsums.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUMS_H_rrr1_LU (726) - TriCore_INS_MADDSUMS_H - maddsums.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUMS_H_rrr1_UL (727) - TriCore_INS_MADDSUMS_H - maddsums.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUMS_H_rrr1_UU (728) - TriCore_INS_MADDSUMS_H - maddsums.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUM_H_rrr1_LL (729) - TriCore_INS_MADDSUM_H - maddsum.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUM_H_rrr1_LU (730) - TriCore_INS_MADDSUM_H - maddsum.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUM_H_rrr1_UL (731) - TriCore_INS_MADDSUM_H - maddsum.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUM_H_rrr1_UU (732) - TriCore_INS_MADDSUM_H - maddsum.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSURS_H_rrr1_LL (733) - TriCore_INS_MADDSURS_H - maddsurs.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSURS_H_rrr1_LU (734) - TriCore_INS_MADDSURS_H - maddsurs.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSURS_H_rrr1_UL (735) - TriCore_INS_MADDSURS_H - maddsurs.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSURS_H_rrr1_UU (736) - TriCore_INS_MADDSURS_H - maddsurs.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUR_H_rrr1_LL (737) - TriCore_INS_MADDSUR_H - maddsur.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUR_H_rrr1_LU (738) - TriCore_INS_MADDSUR_H - maddsur.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUR_H_rrr1_UL (739) - TriCore_INS_MADDSUR_H - maddsur.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUR_H_rrr1_UU (740) - TriCore_INS_MADDSUR_H - maddsur.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUS_H_rrr1_LL (741) - TriCore_INS_MADDSUS_H - maddsus.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUS_H_rrr1_LU (742) - TriCore_INS_MADDSUS_H - maddsus.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUS_H_rrr1_UL (743) - TriCore_INS_MADDSUS_H - maddsus.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSUS_H_rrr1_UU (744) - TriCore_INS_MADDSUS_H - maddsus.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSU_H_rrr1_LL (745) - TriCore_INS_MADDSU_H - maddsu.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSU_H_rrr1_LU (746) - TriCore_INS_MADDSU_H - maddsu.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSU_H_rrr1_UL (747) - TriCore_INS_MADDSU_H - maddsu.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDSU_H_rrr1_UU (748) - TriCore_INS_MADDSU_H - maddsu.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_H_rrr1_LL (749) - TriCore_INS_MADDS_H - madds.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_H_rrr1_LU (750) - TriCore_INS_MADDS_H - madds.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_H_rrr1_UL (751) - TriCore_INS_MADDS_H - madds.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_H_rrr1_UU (752) - TriCore_INS_MADDS_H - madds.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_H_rrr1_v110 (753) - TriCore_INS_MADDS_H - madds.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1 (754) - TriCore_INS_MADDS_Q - madds.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_L (755) - TriCore_INS_MADDS_Q - madds.q $d, $s3, $s1, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_L_L (756) - TriCore_INS_MADDS_Q - madds.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_U (757) - TriCore_INS_MADDS_Q - madds.q $d, $s3, $s1, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_UU2_v110 (758) - TriCore_INS_MADDS_Q - madds.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_U_U (759) - TriCore_INS_MADDS_Q - madds.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_e (760) - TriCore_INS_MADDS_Q - madds.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_e_L (761) - TriCore_INS_MADDS_Q - madds.q $d, $s3, $s1, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_e_L_L (762) - TriCore_INS_MADDS_Q - madds.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_e_U (763) - TriCore_INS_MADDS_Q - madds.q $d, $s3, $s1, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_Q_rrr1_e_U_U (764) - TriCore_INS_MADDS_Q - madds.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADDS_U_rcr (765) - TriCore_INS_MADDS_U - madds.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADDS_U_rcr_e (766) - TriCore_INS_MADDS_U - madds.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADDS_U_rrr2 (767) - TriCore_INS_MADDS_U - madds.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADDS_U_rrr2_e (768) - TriCore_INS_MADDS_U - madds.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADDS_rcr (769) - TriCore_INS_MADDS - madds $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADDS_rcr_e (770) - TriCore_INS_MADDS - madds $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADDS_rrr2 (771) - TriCore_INS_MADDS - madds $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADDS_rrr2_e (772) - TriCore_INS_MADDS - madds $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADD_F_rrr (773) - TriCore_INS_MADD_F - madd.f $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADD_H_rrr1_LL (774) - TriCore_INS_MADD_H - madd.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_H_rrr1_LU (775) - TriCore_INS_MADD_H - madd.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_H_rrr1_UL (776) - TriCore_INS_MADD_H - madd.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_H_rrr1_UU (777) - TriCore_INS_MADD_H - madd.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_H_rrr1_v110 (778) - TriCore_INS_MADD_H - madd.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1 (779) - TriCore_INS_MADD_Q - madd.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_L (780) - TriCore_INS_MADD_Q - madd.q $d, $s3, $s1, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_L_L (781) - TriCore_INS_MADD_Q - madd.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_U (782) - TriCore_INS_MADD_Q - madd.q $d, $s3, $s1, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_UU2_v110 (783) - TriCore_INS_MADD_Q - madd.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_U_U (784) - TriCore_INS_MADD_Q - madd.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_e (785) - TriCore_INS_MADD_Q - madd.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_e_L (786) - TriCore_INS_MADD_Q - madd.q $d, $s3, $s1, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_e_L_L (787) - TriCore_INS_MADD_Q - madd.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_e_U (788) - TriCore_INS_MADD_Q - madd.q $d, $s3, $s1, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_Q_rrr1_e_U_U (789) - TriCore_INS_MADD_Q - madd.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MADD_U_rcr (790) - TriCore_INS_MADD_U - madd.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADD_U_rrr2 (791) - TriCore_INS_MADD_U - madd.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADD_rcr (792) - TriCore_INS_MADD - madd $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADD_rcr_e (793) - TriCore_INS_MADD - madd $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MADD_rrr2 (794) - TriCore_INS_MADD - madd $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MADD_rrr2_e (795) - TriCore_INS_MADD - madd $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MAX_B (796) - TriCore_INS_MAX_B - max.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MAX_BU (797) - TriCore_INS_MAX_BU - max.bu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MAX_H (798) - TriCore_INS_MAX_H - max.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MAX_HU (799) - TriCore_INS_MAX_HU - max.hu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MAX_U_rc (800) - TriCore_INS_MAX_U - max.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MAX_U_rr (801) - TriCore_INS_MAX_U - max.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MAX_rc (802) - TriCore_INS_MAX - max $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MAX_rr (803) - TriCore_INS_MAX - max $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MFCR_rlc (804) - TriCore_INS_MFCR - mfcr $d, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_MIN_B (805) - TriCore_INS_MIN_B - min.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MIN_BU (806) - TriCore_INS_MIN_BU - min.bu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MIN_H (807) - TriCore_INS_MIN_H - min.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MIN_HU (808) - TriCore_INS_MIN_HU - min.hu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MIN_U_rc (809) - TriCore_INS_MIN_U - min.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MIN_U_rr (810) - TriCore_INS_MIN_U - min.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MIN_rc (811) - TriCore_INS_MIN - min $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MIN_rr (812) - TriCore_INS_MIN - min $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOVH_A_rlc (813) - TriCore_INS_MOVH_A - movh.a $d, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_MOVH_rlc (814) - TriCore_INS_MOVH - movh $d, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_MOVZ_A_sr (815) - TriCore_INS_MOVZ_A - movz.a $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_MOV_AA_rr (816) - TriCore_INS_MOV_AA - mov.aa $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_AA_srr_srr (817) - TriCore_INS_MOV_AA - mov.aa $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_AA_srr_srr_v110 (818) - TriCore_INS_MOV_AA - mov.aa $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_A_rr (819) - TriCore_INS_MOV_A - mov.a $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_A_src (820) - TriCore_INS_MOV_A - mov.a $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_MOV_A_srr (821) - TriCore_INS_MOV_A - mov.a $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_A_srr_v110 (822) - TriCore_INS_MOV_A - mov.a $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_D_rr (823) - TriCore_INS_MOV_D - mov.d $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_D_srr_srr (824) - TriCore_INS_MOV_D - mov.d $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_D_srr_srr_v110 (825) - TriCore_INS_MOV_D - mov.d $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_U_rlc (826) - TriCore_INS_MOV_U - mov.u $d, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_MOV_rlc (827) - TriCore_INS_MOV - mov $d, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_MOV_rlc_e (828) - TriCore_INS_MOV - mov $d, $const16 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { 0 }
}},
{ /* TRICORE_MOV_rr (829) - TriCore_INS_MOV - mov $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_rr_e (830) - TriCore_INS_MOV - mov $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_rr_eab (831) - TriCore_INS_MOV - mov $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MOV_sc (832) - TriCore_INS_MOV - mov d15, $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_MOV_sc_v110 (833) - TriCore_INS_MOV - mov d15, $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_MOV_src (834) - TriCore_INS_MOV - mov $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_MOV_src_e (835) - TriCore_INS_MOV - mov $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_MOV_srr (836) - TriCore_INS_MOV - mov $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MSUBADMS_H_rrr1_LL (837) - TriCore_INS_MSUBADMS_H - msubadms.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADMS_H_rrr1_LU (838) - TriCore_INS_MSUBADMS_H - msubadms.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADMS_H_rrr1_UL (839) - TriCore_INS_MSUBADMS_H - msubadms.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADMS_H_rrr1_UU (840) - TriCore_INS_MSUBADMS_H - msubadms.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADM_H_rrr1_LL (841) - TriCore_INS_MSUBADM_H - msubadm.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADM_H_rrr1_LU (842) - TriCore_INS_MSUBADM_H - msubadm.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADM_H_rrr1_UL (843) - TriCore_INS_MSUBADM_H - msubadm.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADM_H_rrr1_UU (844) - TriCore_INS_MSUBADM_H - msubadm.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADRS_H_rrr1_LL (845) - TriCore_INS_MSUBADRS_H - msubadrs.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADRS_H_rrr1_LU (846) - TriCore_INS_MSUBADRS_H - msubadrs.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADRS_H_rrr1_UL (847) - TriCore_INS_MSUBADRS_H - msubadrs.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADRS_H_rrr1_UU (848) - TriCore_INS_MSUBADRS_H - msubadrs.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADRS_H_rrr1_v110 (849) - TriCore_INS_MSUBADRS_H - msubadrs.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADR_H_rrr1_LL (850) - TriCore_INS_MSUBADR_H - msubadr.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADR_H_rrr1_LU (851) - TriCore_INS_MSUBADR_H - msubadr.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADR_H_rrr1_UL (852) - TriCore_INS_MSUBADR_H - msubadr.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADR_H_rrr1_UU (853) - TriCore_INS_MSUBADR_H - msubadr.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADR_H_rrr1_v110 (854) - TriCore_INS_MSUBADR_H - msubadr.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADS_H_rrr1_LL (855) - TriCore_INS_MSUBADS_H - msubads.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADS_H_rrr1_LU (856) - TriCore_INS_MSUBADS_H - msubads.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADS_H_rrr1_UL (857) - TriCore_INS_MSUBADS_H - msubads.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBADS_H_rrr1_UU (858) - TriCore_INS_MSUBADS_H - msubads.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBAD_H_rrr1_LL (859) - TriCore_INS_MSUBAD_H - msubad.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBAD_H_rrr1_LU (860) - TriCore_INS_MSUBAD_H - msubad.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBAD_H_rrr1_UL (861) - TriCore_INS_MSUBAD_H - msubad.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBAD_H_rrr1_UU (862) - TriCore_INS_MSUBAD_H - msubad.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBMS_H_rrr1_LL (863) - TriCore_INS_MSUBMS_H - msubms.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBMS_H_rrr1_LU (864) - TriCore_INS_MSUBMS_H - msubms.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBMS_H_rrr1_UL (865) - TriCore_INS_MSUBMS_H - msubms.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBMS_H_rrr1_UU (866) - TriCore_INS_MSUBMS_H - msubms.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBMS_U_rcrv110 (867) - TriCore_INS_MSUBMS_U - msubms.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUBMS_U_rrr2v110 (868) - TriCore_INS_MSUBMS_U - msubms.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUBMS_rcrv110 (869) - TriCore_INS_MSUBMS - msubms $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUBMS_rrr2v110 (870) - TriCore_INS_MSUBMS - msubms $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUBM_H_rrr1_LL (871) - TriCore_INS_MSUBM_H - msubm.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBM_H_rrr1_LU (872) - TriCore_INS_MSUBM_H - msubm.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBM_H_rrr1_UL (873) - TriCore_INS_MSUBM_H - msubm.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBM_H_rrr1_UU (874) - TriCore_INS_MSUBM_H - msubm.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBM_H_rrr1_v110 (875) - TriCore_INS_MSUBM_H - msubm.h $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBM_Q_rrr1_v110 (876) - TriCore_INS_MSUBM_Q - msubm.q $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBM_U_rcrv110 (877) - TriCore_INS_MSUBM_U - msubm.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUBM_U_rrr2v110 (878) - TriCore_INS_MSUBM_U - msubm.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUBM_rcrv110 (879) - TriCore_INS_MSUBM - msubm $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUBM_rrr2v110 (880) - TriCore_INS_MSUBM - msubm $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUBRS_H_rrr1_LL (881) - TriCore_INS_MSUBRS_H - msubrs.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBRS_H_rrr1_LU (882) - TriCore_INS_MSUBRS_H - msubrs.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBRS_H_rrr1_UL (883) - TriCore_INS_MSUBRS_H - msubrs.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBRS_H_rrr1_UL_2 (884) - TriCore_INS_MSUBRS_H - msubrs.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBRS_H_rrr1_UU (885) - TriCore_INS_MSUBRS_H - msubrs.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBRS_H_rrr1_v110 (886) - TriCore_INS_MSUBRS_H - msubrs.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBRS_Q_rrr1_L_L (887) - TriCore_INS_MSUBRS_Q - msubrs.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBRS_Q_rrr1_U_U (888) - TriCore_INS_MSUBRS_Q - msubrs.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBRS_Q_rrr1_v110 (889) - TriCore_INS_MSUBRS_Q - msubrs.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_H_rrr1_LL (890) - TriCore_INS_MSUBR_H - msubr.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_H_rrr1_LU (891) - TriCore_INS_MSUBR_H - msubr.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_H_rrr1_UL (892) - TriCore_INS_MSUBR_H - msubr.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_H_rrr1_UL_2 (893) - TriCore_INS_MSUBR_H - msubr.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_H_rrr1_UU (894) - TriCore_INS_MSUBR_H - msubr.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_H_rrr1_v110 (895) - TriCore_INS_MSUBR_H - msubr.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_Q_rrr1_L_L (896) - TriCore_INS_MSUBR_Q - msubr.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_Q_rrr1_U_U (897) - TriCore_INS_MSUBR_Q - msubr.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBR_Q_rrr1_v110 (898) - TriCore_INS_MSUBR_Q - msubr.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_H_rrr1_LL (899) - TriCore_INS_MSUBS_H - msubs.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_H_rrr1_LU (900) - TriCore_INS_MSUBS_H - msubs.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_H_rrr1_UL (901) - TriCore_INS_MSUBS_H - msubs.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_H_rrr1_UU (902) - TriCore_INS_MSUBS_H - msubs.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_H_rrr1_v110 (903) - TriCore_INS_MSUBS_H - msubs.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1 (904) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_L (905) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, $s1, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_L_L (906) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_U (907) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, $s1, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_UU2_v110 (908) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_U_U (909) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_e (910) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_e_L (911) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, $s1, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_e_L_L (912) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_e_U (913) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, $s1, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_Q_rrr1_e_U_U (914) - TriCore_INS_MSUBS_Q - msubs.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUBS_U_rcr (915) - TriCore_INS_MSUBS_U - msubs.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUBS_U_rcr_e (916) - TriCore_INS_MSUBS_U - msubs.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUBS_U_rrr2 (917) - TriCore_INS_MSUBS_U - msubs.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUBS_U_rrr2_e (918) - TriCore_INS_MSUBS_U - msubs.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUBS_rcr (919) - TriCore_INS_MSUBS - msubs $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUBS_rcr_e (920) - TriCore_INS_MSUBS - msubs $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUBS_rrr2 (921) - TriCore_INS_MSUBS - msubs $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUBS_rrr2_e (922) - TriCore_INS_MSUBS - msubs $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUB_F_rrr (923) - TriCore_INS_MSUB_F - msub.f $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUB_H_rrr1_LL (924) - TriCore_INS_MSUB_H - msub.h $d, $s3, $s1, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_H_rrr1_LU (925) - TriCore_INS_MSUB_H - msub.h $d, $s3, $s1, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_H_rrr1_UL (926) - TriCore_INS_MSUB_H - msub.h $d, $s3, $s1, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_H_rrr1_UU (927) - TriCore_INS_MSUB_H - msub.h $d, $s3, $s1, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_H_rrr1_v110 (928) - TriCore_INS_MSUB_H - msub.h $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1 (929) - TriCore_INS_MSUB_Q - msub.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_L (930) - TriCore_INS_MSUB_Q - msub.q $d, $s3, $s1, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_L_L (931) - TriCore_INS_MSUB_Q - msub.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_U (932) - TriCore_INS_MSUB_Q - msub.q $d, $s3, $s1, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_UU2_v110 (933) - TriCore_INS_MSUB_Q - msub.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_U_U (934) - TriCore_INS_MSUB_Q - msub.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_e (935) - TriCore_INS_MSUB_Q - msub.q $d, $s3, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_e_L (936) - TriCore_INS_MSUB_Q - msub.q $d, $s3, $s1, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_e_L_L (937) - TriCore_INS_MSUB_Q - msub.q $d, $s3, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_e_U (938) - TriCore_INS_MSUB_Q - msub.q $d, $s3, $s1, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_Q_rrr1_e_U_U (939) - TriCore_INS_MSUB_Q - msub.q $d, $s3, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MSUB_U_rcr (940) - TriCore_INS_MSUB_U - msub.u $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUB_U_rrr2 (941) - TriCore_INS_MSUB_U - msub.u $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUB_rcr (942) - TriCore_INS_MSUB - msub $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUB_rcr_e (943) - TriCore_INS_MSUB - msub $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MSUB_rrr2 (944) - TriCore_INS_MSUB - msub $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MSUB_rrr2_e (945) - TriCore_INS_MSUB - msub $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_MTCR_rlc (946) - TriCore_INS_MTCR - mtcr $const16, $d */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const16 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { 0 }
}},
{ /* TRICORE_MULMS_H_rr1_LL2e (947) - TriCore_INS_MULMS_H - mulms.h $d, ${s1}, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULMS_H_rr1_LU2e (948) - TriCore_INS_MULMS_H - mulms.h $d, ${s1}, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULMS_H_rr1_UL2e (949) - TriCore_INS_MULMS_H - mulms.h $d, ${s1}, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULMS_H_rr1_UU2e (950) - TriCore_INS_MULMS_H - mulms.h $d, ${s1}, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULM_H_rr1_LL2e (951) - TriCore_INS_MULM_H - mulm.h $d, ${s1}, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULM_H_rr1_LU2e (952) - TriCore_INS_MULM_H - mulm.h $d, ${s1}, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULM_H_rr1_UL2e (953) - TriCore_INS_MULM_H - mulm.h $d, ${s1}, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULM_H_rr1_UU2e (954) - TriCore_INS_MULM_H - mulm.h $d, ${s1}, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULM_U_rc (955) - TriCore_INS_MULM_U - mulm.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MULM_U_rr (956) - TriCore_INS_MULM_U - mulm.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MULM_rc (957) - TriCore_INS_MULM - mulm $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MULM_rr (958) - TriCore_INS_MULM - mulm $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MULR_H_rr1_LL2e (959) - TriCore_INS_MULR_H - mulr.h $d, ${s1}, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULR_H_rr1_LU2e (960) - TriCore_INS_MULR_H - mulr.h $d, ${s1}, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULR_H_rr1_UL2e (961) - TriCore_INS_MULR_H - mulr.h $d, ${s1}, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULR_H_rr1_UU2e (962) - TriCore_INS_MULR_H - mulr.h $d, ${s1}, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULR_H_rr_v110 (963) - TriCore_INS_MULR_H - mulr.h $d, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULR_Q_rr1_2LL (964) - TriCore_INS_MULR_Q - mulr.q $d, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULR_Q_rr1_2UU (965) - TriCore_INS_MULR_Q - mulr.q $d, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULR_Q_rr_v110 (966) - TriCore_INS_MULR_Q - mulr.q $d, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MULS_U_rc (967) - TriCore_INS_MULS_U - muls.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MULS_U_rr2 (968) - TriCore_INS_MULS_U - muls.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MULS_U_rr_v110 (969) - TriCore_INS_MULS_U - muls.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MULS_rc (970) - TriCore_INS_MULS - muls $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MULS_rr2 (971) - TriCore_INS_MULS - muls $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MULS_rr_v110 (972) - TriCore_INS_MULS - muls $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MUL_F_rrr (973) - TriCore_INS_MUL_F - mul.f $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MUL_H_rr1_LL2e (974) - TriCore_INS_MUL_H - mul.h $d, ${s1}, ${s2}ll, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_H_rr1_LU2e (975) - TriCore_INS_MUL_H - mul.h $d, ${s1}, ${s2}lu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_H_rr1_UL2e (976) - TriCore_INS_MUL_H - mul.h $d, ${s1}, ${s2}ul, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_H_rr1_UU2e (977) - TriCore_INS_MUL_H - mul.h $d, ${s1}, ${s2}uu, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_H_rr_v110 (978) - TriCore_INS_MUL_H - mul.h $d, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr1_2 (979) - TriCore_INS_MUL_Q - mul.q $d, ${s1}, ${s2}, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr1_2LL (980) - TriCore_INS_MUL_Q - mul.q $d, ${s1}l, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr1_2UU (981) - TriCore_INS_MUL_Q - mul.q $d, ${s1}u, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr1_2_L (982) - TriCore_INS_MUL_Q - mul.q $d, ${s1}, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr1_2_Le (983) - TriCore_INS_MUL_Q - mul.q $d, ${s1}, ${s2}l, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr1_2_U (984) - TriCore_INS_MUL_Q - mul.q $d, ${s1}, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr1_2_Ue (985) - TriCore_INS_MUL_Q - mul.q $d, ${s1}, ${s2}u, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr1_2__e (986) - TriCore_INS_MUL_Q - mul.q $d, ${s1}, ${s2}, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_Q_rr_v110 (987) - TriCore_INS_MUL_Q - mul.q $d, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_MUL_U_rc (988) - TriCore_INS_MUL_U - mul.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MUL_U_rr2 (989) - TriCore_INS_MUL_U - mul.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MUL_rc (990) - TriCore_INS_MUL - mul $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MUL_rc_e (991) - TriCore_INS_MUL - mul $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_MUL_rr2 (992) - TriCore_INS_MUL - mul $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MUL_rr2_e (993) - TriCore_INS_MUL - mul $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MUL_rr_v110 (994) - TriCore_INS_MUL - mul $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_MUL_srr (995) - TriCore_INS_MUL - mul $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_NAND_T (996) - TriCore_INS_NAND_T - nand.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_NAND_rc (997) - TriCore_INS_NAND - nand $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_NAND_rr (998) - TriCore_INS_NAND - nand $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_NEZ_A (999) - TriCore_INS_NEZ_A - nez.a $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_NE_A (1000) - TriCore_INS_NE_A - ne.a $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_NE_rc (1001) - TriCore_INS_NE - ne $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_NE_rr (1002) - TriCore_INS_NE - ne $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_NOP_sr (1003) - TriCore_INS_NOP - nop */
{
  { 0 }
}},
{ /* TRICORE_NOP_sys (1004) - TriCore_INS_NOP - nop */
{
  { 0 }
}},
{ /* TRICORE_NOR_T (1005) - TriCore_INS_NOR_T - nor.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_NOR_rc (1006) - TriCore_INS_NOR - nor $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_NOR_rr (1007) - TriCore_INS_NOR - nor $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_NOR_sr (1008) - TriCore_INS_NOR - nor $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_NOR_sr_v110 (1009) - TriCore_INS_NOR - nor $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_NOT_sr_v162 (1010) - TriCore_INS_NOT - not $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ORN_T (1011) - TriCore_INS_ORN_T - orn.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_ORN_rc (1012) - TriCore_INS_ORN - orn $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_ORN_rr (1013) - TriCore_INS_ORN - orn $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_ANDN_T (1014) - TriCore_INS_OR_ANDN_T - or.andn.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_OR_AND_T (1015) - TriCore_INS_OR_AND_T - or.and.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_OR_EQ_rc (1016) - TriCore_INS_OR_EQ - or.eq $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_OR_EQ_rr (1017) - TriCore_INS_OR_EQ - or.eq $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_GE_U_rc (1018) - TriCore_INS_OR_GE_U - or.ge.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_OR_GE_U_rr (1019) - TriCore_INS_OR_GE_U - or.ge.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_GE_rc (1020) - TriCore_INS_OR_GE - or.ge $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_OR_GE_rr (1021) - TriCore_INS_OR_GE - or.ge $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_LT_U_rc (1022) - TriCore_INS_OR_LT_U - or.lt.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_OR_LT_U_rr (1023) - TriCore_INS_OR_LT_U - or.lt.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_LT_rc (1024) - TriCore_INS_OR_LT - or.lt $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_OR_LT_rr (1025) - TriCore_INS_OR_LT - or.lt $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_NE_rc (1026) - TriCore_INS_OR_NE - or.ne $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_OR_NE_rr (1027) - TriCore_INS_OR_NE - or.ne $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_NOR_T (1028) - TriCore_INS_OR_NOR_T - or.nor.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_OR_OR_T (1029) - TriCore_INS_OR_OR_T - or.or.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_OR_T (1030) - TriCore_INS_OR_T - or.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_OR_rc (1031) - TriCore_INS_OR - or $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_OR_rr (1032) - TriCore_INS_OR - or $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_sc (1033) - TriCore_INS_OR - or d15, $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_OR_sc_v110 (1034) - TriCore_INS_OR - or d15, $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_OR_srr (1035) - TriCore_INS_OR - or $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_OR_srr_v110 (1036) - TriCore_INS_OR - or $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_PACK_rrr (1037) - TriCore_INS_PACK - pack $d, $s3, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_PARITY_rr (1038) - TriCore_INS_PARITY - parity $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_PARITY_rr_v110 (1039) - TriCore_INS_PARITY - parity $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_POPCNT_W_rr (1040) - TriCore_INS_POPCNT_W - popcnt.w $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_Q31TOF_rr (1041) - TriCore_INS_Q31TOF - q31tof $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_QSEED_F_rr (1042) - TriCore_INS_QSEED_F - qseed.f $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_RESTORE_sys (1043) - TriCore_INS_RESTORE - restore $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_RET_sr (1044) - TriCore_INS_RET - ret */
{
  { 0 }
}},
{ /* TRICORE_RET_sys (1045) - TriCore_INS_RET - ret */
{
  { 0 }
}},
{ /* TRICORE_RET_sys_v110 (1046) - TriCore_INS_RET - ret */
{
  { 0 }
}},
{ /* TRICORE_RFE_sr (1047) - TriCore_INS_RFE - rfe */
{
  { 0 }
}},
{ /* TRICORE_RFE_sys_sys (1048) - TriCore_INS_RFE - rfe */
{
  { 0 }
}},
{ /* TRICORE_RFE_sys_sys_v110 (1049) - TriCore_INS_RFE - rfe */
{
  { 0 }
}},
{ /* TRICORE_RFM_sys (1050) - TriCore_INS_RFM - rfm */
{
  { 0 }
}},
{ /* TRICORE_RSLCX_sys (1051) - TriCore_INS_RSLCX - rslcx */
{
  { 0 }
}},
{ /* TRICORE_RSTV_sys (1052) - TriCore_INS_RSTV - rstv */
{
  { 0 }
}},
{ /* TRICORE_RSUBS_U_rc (1053) - TriCore_INS_RSUBS_U - rsubs.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_RSUBS_rc (1054) - TriCore_INS_RSUBS - rsubs $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_RSUB_rc (1055) - TriCore_INS_RSUB - rsub $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_RSUB_sr_sr (1056) - TriCore_INS_RSUB - rsub $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_RSUB_sr_sr_v110 (1057) - TriCore_INS_RSUB - rsub $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_BU_rr (1058) - TriCore_INS_SAT_BU - sat.bu $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_BU_sr (1059) - TriCore_INS_SAT_BU - sat.bu $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_BU_sr_v110 (1060) - TriCore_INS_SAT_BU - sat.bu $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_B_rr (1061) - TriCore_INS_SAT_B - sat.b $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_B_sr (1062) - TriCore_INS_SAT_B - sat.b $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_B_sr_v110 (1063) - TriCore_INS_SAT_B - sat.b $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_HU_rr (1064) - TriCore_INS_SAT_HU - sat.hu $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_HU_sr (1065) - TriCore_INS_SAT_HU - sat.hu $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_HU_sr_v110 (1066) - TriCore_INS_SAT_HU - sat.hu $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_H_rr (1067) - TriCore_INS_SAT_H - sat.h $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_H_sr (1068) - TriCore_INS_SAT_H - sat.h $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SAT_H_sr_v110 (1069) - TriCore_INS_SAT_H - sat.h $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SELN_A_rcr_v110 (1070) - TriCore_INS_SELN_A - seln.a $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SELN_A_rrr_v110 (1071) - TriCore_INS_SELN_A - seln.a $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_SELN_rcr (1072) - TriCore_INS_SELN - seln $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SELN_rrr (1073) - TriCore_INS_SELN - seln $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_SEL_A_rcr_v110 (1074) - TriCore_INS_SEL_A - sel.a $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SEL_A_rrr_v110 (1075) - TriCore_INS_SEL_A - sel.a $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_SEL_rcr (1076) - TriCore_INS_SEL - sel $d, $s3, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SEL_rrr (1077) - TriCore_INS_SEL - sel $d, $s3, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_SHAS_rc (1078) - TriCore_INS_SHAS - shas $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SHAS_rr (1079) - TriCore_INS_SHAS - shas $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SHA_B_rc (1080) - TriCore_INS_SHA_B - sha.b $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SHA_B_rr (1081) - TriCore_INS_SHA_B - sha.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SHA_H_rc (1082) - TriCore_INS_SHA_H - sha.h $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SHA_H_rr (1083) - TriCore_INS_SHA_H - sha.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SHA_rc (1084) - TriCore_INS_SHA - sha $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SHA_rr (1085) - TriCore_INS_SHA - sha $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SHA_src (1086) - TriCore_INS_SHA - sha $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_SHA_src_v110 (1087) - TriCore_INS_SHA - sha $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_SHUFFLE_rc (1088) - TriCore_INS_SHUFFLE - shuffle $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_ANDN_T (1089) - TriCore_INS_SH_ANDN_T - sh.andn.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_SH_AND_T (1090) - TriCore_INS_SH_AND_T - sh.and.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_SH_B_rc (1091) - TriCore_INS_SH_B - sh.b $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_B_rr (1092) - TriCore_INS_SH_B - sh.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_EQ_rc (1093) - TriCore_INS_SH_EQ - sh.eq $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_EQ_rr (1094) - TriCore_INS_SH_EQ - sh.eq $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_GE_U_rc (1095) - TriCore_INS_SH_GE_U - sh.ge.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_GE_U_rr (1096) - TriCore_INS_SH_GE_U - sh.ge.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_GE_rc (1097) - TriCore_INS_SH_GE - sh.ge $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_GE_rr (1098) - TriCore_INS_SH_GE - sh.ge $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_H_rc (1099) - TriCore_INS_SH_H - sh.h $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_H_rr (1100) - TriCore_INS_SH_H - sh.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_LT_U_rc (1101) - TriCore_INS_SH_LT_U - sh.lt.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_LT_U_rr (1102) - TriCore_INS_SH_LT_U - sh.lt.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_LT_rc (1103) - TriCore_INS_SH_LT - sh.lt $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_LT_rr (1104) - TriCore_INS_SH_LT - sh.lt $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_NAND_T (1105) - TriCore_INS_SH_NAND_T - sh.nand.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_SH_NE_rc (1106) - TriCore_INS_SH_NE - sh.ne $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_NE_rr (1107) - TriCore_INS_SH_NE - sh.ne $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_NOR_T (1108) - TriCore_INS_SH_NOR_T - sh.nor.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_SH_ORN_T (1109) - TriCore_INS_SH_ORN_T - sh.orn.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_SH_OR_T (1110) - TriCore_INS_SH_OR_T - sh.or.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_SH_XNOR_T (1111) - TriCore_INS_SH_XNOR_T - sh.xnor.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_SH_XOR_T (1112) - TriCore_INS_SH_XOR_T - sh.xor.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_SH_rc (1113) - TriCore_INS_SH - sh $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_SH_rr (1114) - TriCore_INS_SH - sh $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SH_src (1115) - TriCore_INS_SH - sh $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_SH_src_v110 (1116) - TriCore_INS_SH - sh $d, $const4 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const4 */
  { 0 }
}},
{ /* TRICORE_STLCX_abs (1117) - TriCore_INS_STLCX - stlcx $off18 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_STLCX_bo_bso (1118) - TriCore_INS_STLCX - stlcx [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_STUCX_abs (1119) - TriCore_INS_STUCX - stucx $off18 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_STUCX_bo_bso (1120) - TriCore_INS_STUCX - stucx [$s2]$off10 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_A_abs (1121) - TriCore_INS_ST_A - st.a $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_ST_A_bo_bso (1122) - TriCore_INS_ST_A - st.a [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_A_bo_c (1123) - TriCore_INS_ST_A - st.a [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_A_bo_pos (1124) - TriCore_INS_ST_A - st.a [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_A_bo_pre (1125) - TriCore_INS_ST_A - st.a [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_A_bo_r (1126) - TriCore_INS_ST_A - st.a [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_A_bol (1127) - TriCore_INS_ST_A - st.a [$s2]$off16, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_ST_A_sc (1128) - TriCore_INS_ST_A - st.a [sp]$const8, a15 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_ST_A_sro (1129) - TriCore_INS_ST_A - st.a [$s2]$off4, a15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_A_sro_v110 (1130) - TriCore_INS_ST_A - st.a [$s2]$off4, a15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_A_ssr (1131) - TriCore_INS_ST_A - st.a [$d], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_A_ssr_pos (1132) - TriCore_INS_ST_A - st.a [${d}+], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_A_ssr_pos_v110 (1133) - TriCore_INS_ST_A - st.a [${d}+], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_A_ssr_v110 (1134) - TriCore_INS_ST_A - st.a [$d], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_A_ssro (1135) - TriCore_INS_ST_A - st.a [a15]$off4, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_A_ssro_v110 (1136) - TriCore_INS_ST_A - st.a [a15]$off4, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_B_abs (1137) - TriCore_INS_ST_B - st.b $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_ST_B_bo_bso (1138) - TriCore_INS_ST_B - st.b [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_B_bo_c (1139) - TriCore_INS_ST_B - st.b [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_B_bo_pos (1140) - TriCore_INS_ST_B - st.b [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_B_bo_pre (1141) - TriCore_INS_ST_B - st.b [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_B_bo_r (1142) - TriCore_INS_ST_B - st.b [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_B_bol (1143) - TriCore_INS_ST_B - st.b [$s2]$off16, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_ST_B_sro (1144) - TriCore_INS_ST_B - st.b [$s2]$off4, d15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_B_sro_v110 (1145) - TriCore_INS_ST_B - st.b [$s2]$off4, d15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_B_ssr (1146) - TriCore_INS_ST_B - st.b [$d], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_B_ssr_pos (1147) - TriCore_INS_ST_B - st.b [${d}+], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_B_ssr_pos_v110 (1148) - TriCore_INS_ST_B - st.b [${d}+], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_B_ssr_v110 (1149) - TriCore_INS_ST_B - st.b [$d], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_B_ssro (1150) - TriCore_INS_ST_B - st.b [a15]$off4, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_B_ssro_v110 (1151) - TriCore_INS_ST_B - st.b [a15]$off4, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_DA_abs (1152) - TriCore_INS_ST_DA - st.da $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_ST_DA_bo_bso (1153) - TriCore_INS_ST_DA - st.da [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_DA_bo_c (1154) - TriCore_INS_ST_DA - st.da [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_DA_bo_pos (1155) - TriCore_INS_ST_DA - st.da [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_DA_bo_pre (1156) - TriCore_INS_ST_DA - st.da [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_DA_bo_r (1157) - TriCore_INS_ST_DA - st.da [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_D_abs (1158) - TriCore_INS_ST_D - st.d $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_ST_D_bo_bso (1159) - TriCore_INS_ST_D - st.d [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_D_bo_c (1160) - TriCore_INS_ST_D - st.d [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_D_bo_pos (1161) - TriCore_INS_ST_D - st.d [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_D_bo_pre (1162) - TriCore_INS_ST_D - st.d [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_D_bo_r (1163) - TriCore_INS_ST_D - st.d [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_H_abs (1164) - TriCore_INS_ST_H - st.h $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_ST_H_bo_bso (1165) - TriCore_INS_ST_H - st.h [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_H_bo_c (1166) - TriCore_INS_ST_H - st.h [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_H_bo_pos (1167) - TriCore_INS_ST_H - st.h [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_H_bo_pre (1168) - TriCore_INS_ST_H - st.h [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_H_bo_r (1169) - TriCore_INS_ST_H - st.h [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_H_bol (1170) - TriCore_INS_ST_H - st.h [$s2]$off16, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_ST_H_sro (1171) - TriCore_INS_ST_H - st.h [$s2]$off4, d15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_H_sro_v110 (1172) - TriCore_INS_ST_H - st.h [$s2]$off4, d15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_H_ssr (1173) - TriCore_INS_ST_H - st.h [$d], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_H_ssr_pos (1174) - TriCore_INS_ST_H - st.h [${d}+], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_H_ssr_pos_v110 (1175) - TriCore_INS_ST_H - st.h [${d}+], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_H_ssr_v110 (1176) - TriCore_INS_ST_H - st.h [$d], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_H_ssro (1177) - TriCore_INS_ST_H - st.h [a15]$off4, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_H_ssro_v110 (1178) - TriCore_INS_ST_H - st.h [a15]$off4, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_Q_abs (1179) - TriCore_INS_ST_Q - st.q $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_ST_Q_bo_bso (1180) - TriCore_INS_ST_Q - st.q [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_Q_bo_c (1181) - TriCore_INS_ST_Q - st.q [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_Q_bo_pos (1182) - TriCore_INS_ST_Q - st.q [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_Q_bo_pre (1183) - TriCore_INS_ST_Q - st.q [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_Q_bo_r (1184) - TriCore_INS_ST_Q - st.q [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_T (1185) - TriCore_INS_ST_T - st.t $off18, $bpos3, $b */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* bpos3 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* b */
  { 0 }
}},
{ /* TRICORE_ST_W_abs (1186) - TriCore_INS_ST_W - st.w $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_ST_W_bo_bso (1187) - TriCore_INS_ST_W - st.w [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_W_bo_c (1188) - TriCore_INS_ST_W - st.w [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_W_bo_pos (1189) - TriCore_INS_ST_W - st.w [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_W_bo_pre (1190) - TriCore_INS_ST_W - st.w [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_ST_W_bo_r (1191) - TriCore_INS_ST_W - st.w [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_W_bol (1192) - TriCore_INS_ST_W - st.w [$s2]$off16, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off16 */
  { 0 }
}},
{ /* TRICORE_ST_W_sc (1193) - TriCore_INS_ST_W - st.w [sp]$const8, d15 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_ST_W_sro (1194) - TriCore_INS_ST_W - st.w [$s2]$off4, d15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_W_sro_v110 (1195) - TriCore_INS_ST_W - st.w [$s2]$off4, d15 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_W_ssr (1196) - TriCore_INS_ST_W - st.w [$d], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_W_ssr_pos (1197) - TriCore_INS_ST_W - st.w [${d}+], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_W_ssr_pos_v110 (1198) - TriCore_INS_ST_W - st.w [${d}+], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_W_ssr_v110 (1199) - TriCore_INS_ST_W - st.w [$d], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_ST_W_ssro (1200) - TriCore_INS_ST_W - st.w [a15]$off4, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_ST_W_ssro_v110 (1201) - TriCore_INS_ST_W - st.w [a15]$off4, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off4 */
  { 0 }
}},
{ /* TRICORE_SUBC_rr (1202) - TriCore_INS_SUBC - subc $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUBSC_A_rr (1203) - TriCore_INS_SUBSC_A - subsc.a $d, $s1, $s2, $n */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* n */
  { 0 }
}},
{ /* TRICORE_SUBS_BU_rr (1204) - TriCore_INS_SUBS_BU - subs.bu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUBS_B_rr (1205) - TriCore_INS_SUBS_B - subs.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUBS_HU_rr (1206) - TriCore_INS_SUBS_HU - subs.hu $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUBS_H_rr (1207) - TriCore_INS_SUBS_H - subs.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUBS_U_rr (1208) - TriCore_INS_SUBS_U - subs.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUBS_rr (1209) - TriCore_INS_SUBS - subs $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUBS_srr (1210) - TriCore_INS_SUBS - subs $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUBX_rr (1211) - TriCore_INS_SUBX - subx $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUB_A_rr (1212) - TriCore_INS_SUB_A - sub.a $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUB_A_sc (1213) - TriCore_INS_SUB_A - sub.a sp, $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_SUB_A_sc_v110 (1214) - TriCore_INS_SUB_A - sub.a sp, $const8 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const8 */
  { 0 }
}},
{ /* TRICORE_SUB_B_rr (1215) - TriCore_INS_SUB_B - sub.b $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUB_F_rrr (1216) - TriCore_INS_SUB_F - sub.f $d, $s3, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s3 */
  { 0 }
}},
{ /* TRICORE_SUB_H_rr (1217) - TriCore_INS_SUB_H - sub.h $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUB_rr (1218) - TriCore_INS_SUB - sub $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUB_srr (1219) - TriCore_INS_SUB - sub $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUB_srr_15a (1220) - TriCore_INS_SUB - sub d15, $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SUB_srr_a15 (1221) - TriCore_INS_SUB - sub $d, d15, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_SVLCX_sys (1222) - TriCore_INS_SVLCX - svlcx */
{
  { 0 }
}},
{ /* TRICORE_SWAPMSK_W_bo_bso (1223) - TriCore_INS_SWAPMSK_W - swapmsk.w [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAPMSK_W_bo_c (1224) - TriCore_INS_SWAPMSK_W - swapmsk.w [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAPMSK_W_bo_i (1225) - TriCore_INS_SWAPMSK_W - swapmsk.w [${s1}+i], $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAPMSK_W_bo_pos (1226) - TriCore_INS_SWAPMSK_W - swapmsk.w [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAPMSK_W_bo_pre (1227) - TriCore_INS_SWAPMSK_W - swapmsk.w [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAPMSK_W_bo_r (1228) - TriCore_INS_SWAPMSK_W - swapmsk.w [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SWAP_A_abs (1229) - TriCore_INS_SWAP_A - swap.a $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_SWAP_A_bo_bso (1230) - TriCore_INS_SWAP_A - swap.a [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_A_bo_c (1231) - TriCore_INS_SWAP_A - swap.a [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_A_bo_pos (1232) - TriCore_INS_SWAP_A - swap.a [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_A_bo_pre (1233) - TriCore_INS_SWAP_A - swap.a [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_A_bo_r (1234) - TriCore_INS_SWAP_A - swap.a [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SWAP_W_abs (1235) - TriCore_INS_SWAP_W - swap.w $off18, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off18 */
  { 0 }
}},
{ /* TRICORE_SWAP_W_bo_bso (1236) - TriCore_INS_SWAP_W - swap.w [$s1]$off10, $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_W_bo_c (1237) - TriCore_INS_SWAP_W - swap.w [${d}+c]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_W_bo_i (1238) - TriCore_INS_SWAP_W - swap.w [${s1}+i], $d */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_W_bo_pos (1239) - TriCore_INS_SWAP_W - swap.w [${s2}+]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_W_bo_pre (1240) - TriCore_INS_SWAP_W - swap.w [+${s2}]$off10, $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* off10 */
  { 0 }
}},
{ /* TRICORE_SWAP_W_bo_r (1241) - TriCore_INS_SWAP_W - swap.w [${d}+r], $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_SYSCALL_rc (1242) - TriCore_INS_SYSCALL - syscall $const9 */
{
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_TLBDEMAP_rr (1243) - TriCore_INS_TLBDEMAP - tlbdemap $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_TLBFLUSH_A_rr (1244) - TriCore_INS_TLBFLUSH_A - tlbflush.a */
{
  { 0 }
}},
{ /* TRICORE_TLBFLUSH_B_rr (1245) - TriCore_INS_TLBFLUSH_B - tlbflush.b */
{
  { 0 }
}},
{ /* TRICORE_TLBMAP_rr (1246) - TriCore_INS_TLBMAP - tlbmap $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_TLBPROBE_A_rr (1247) - TriCore_INS_TLBPROBE_A - tlbprobe.a $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_TLBPROBE_I_rr (1248) - TriCore_INS_TLBPROBE_I - tlbprobe.i $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_TRAPSV_sys (1249) - TriCore_INS_TRAPSV - trapsv */
{
  { 0 }
}},
{ /* TRICORE_TRAPV_sys (1250) - TriCore_INS_TRAPV - trapv */
{
  { 0 }
}},
{ /* TRICORE_UNPACK_rr_rr (1251) - TriCore_INS_UNPACK - unpack $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_UNPACK_rr_rr_v110 (1252) - TriCore_INS_UNPACK - unpack $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i64, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_UPDFL_rr (1253) - TriCore_INS_UPDFL - updfl $s1 */
{
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_UTOF_rr (1254) - TriCore_INS_UTOF - utof $d, $s1 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { 0 }
}},
{ /* TRICORE_WAIT_sys (1255) - TriCore_INS_WAIT - wait */
{
  { 0 }
}},
{ /* TRICORE_XNOR_T (1256) - TriCore_INS_XNOR_T - xnor.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_XNOR_rc (1257) - TriCore_INS_XNOR - xnor $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_XNOR_rr (1258) - TriCore_INS_XNOR - xnor $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_XOR_EQ_rc (1259) - TriCore_INS_XOR_EQ - xor.eq $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_XOR_EQ_rr (1260) - TriCore_INS_XOR_EQ - xor.eq $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_XOR_GE_U_rc (1261) - TriCore_INS_XOR_GE_U - xor.ge.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_XOR_GE_U_rr (1262) - TriCore_INS_XOR_GE_U - xor.ge.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_XOR_GE_rc (1263) - TriCore_INS_XOR_GE - xor.ge $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_XOR_GE_rr (1264) - TriCore_INS_XOR_GE - xor.ge $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_XOR_LT_U_rc (1265) - TriCore_INS_XOR_LT_U - xor.lt.u $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_XOR_LT_U_rr (1266) - TriCore_INS_XOR_LT_U - xor.lt.u $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_XOR_LT_rc (1267) - TriCore_INS_XOR_LT - xor.lt $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_XOR_LT_rr (1268) - TriCore_INS_XOR_LT - xor.lt $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_XOR_NE_rc (1269) - TriCore_INS_XOR_NE - xor.ne $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_XOR_NE_rr (1270) - TriCore_INS_XOR_NE - xor.ne $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_XOR_T (1271) - TriCore_INS_XOR_T - xor.t $d, $s1, $pos1, $s2, $pos_r */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* pos_r */
  { 0 }
}},
{ /* TRICORE_XOR_rc (1272) - TriCore_INS_XOR - xor $d, $s1, $const9 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_IMM, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* const9 */
  { 0 }
}},
{ /* TRICORE_XOR_rr (1273) - TriCore_INS_XOR - xor $d, $s1, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s1 */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
{ /* TRICORE_XOR_srr (1274) - TriCore_INS_XOR - xor $d, $s2 */
{
  { CS_OP_REG, CS_AC_WRITE, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* d */
  { CS_OP_REG, CS_AC_READ, { CS_DATA_TYPE_i32, CS_DATA_TYPE_LAST } }, /* s2 */
  { 0 }
}},
