/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

static const unsigned char index_x86DisassemblerOneByteOpcodes[] = {
  1,
  2,
  3,
  4,
  5,
  6,
  7,
  0,
  0,
  0,
  0,
  8,
  9,
  10,
  11,
  12,
  13,
  14,
  0,
  0,
  15,
  16,
  17,
  18,
  19,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86DisassemblerOneByteOpcodes[] = {
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 11 },
    { MODRM_ONEENTRY, 12 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 23 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 34 },
    { MODRM_ONEENTRY, 35 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 46 },
    { MODRM_ONEENTRY, 47 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 96 },
    { MODRM_ONEENTRY, 97 },
    { MODRM_SPLITRM, 98 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 103 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 106 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 211 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 215 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 235 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 237 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 291 },
    { MODRM_ONEENTRY, 292 },
    { MODRM_SPLITRM, 293 },
    { MODRM_SPLITRM, 295 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 442 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 447 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 513 },
    { MODRM_ONEENTRY, 514 },
    { MODRM_ONEENTRY, 515 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 928 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 933 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 935 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1001 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 1022 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1043 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1045 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1051 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1067 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1069 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1071 },
    { MODRM_ONEENTRY, 1072 },
    { MODRM_ONEENTRY, 1073 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1074 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1076 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1078 },
    { MODRM_ONEENTRY, 1079 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1080 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1082 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1084 },
    { MODRM_ONEENTRY, 1085 },
    { MODRM_ONEENTRY, 1086 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1087 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1089 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1091 },
    { MODRM_ONEENTRY, 1092 },
    { MODRM_ONEENTRY, 1093 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1094 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1096 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1098 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1099 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1101 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1103 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1104 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1106 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1108 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1109 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1111 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1113 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1118 },
    { MODRM_ONEENTRY, 1119 },
    { MODRM_SPLITRM, 1120 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1122 },
    { MODRM_SPLITRM, 1123 },
    { MODRM_ONEENTRY, 1125 },
    { MODRM_SPLITRM, 1126 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 1128 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 1129 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1130 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 1146 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1162 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1164 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1166 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1168 },
    { MODRM_SPLITRM, 1170 },
    { MODRM_SPLITRM, 1172 },
    { MODRM_SPLITRM, 1174 },
    { MODRM_SPLITREG, 1176 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1193 },
    { MODRM_ONEENTRY, 1194 },
    { MODRM_ONEENTRY, 1195 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1196 },
    { MODRM_ONEENTRY, 1197 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 1198 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 1199 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1200 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1201 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1202 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1203 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1204 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1205 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1207 },
    { MODRM_ONEENTRY, 1223 },
    { MODRM_ONEENTRY, 1224 },
    { MODRM_SPLITRM, 1225 },
    { MODRM_SPLITRM, 1227 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1229 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 442 },
    { MODRM_ONEENTRY, 1301 },
    { MODRM_ONEENTRY, 1302 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 447 },
    { MODRM_ONEENTRY, 1303 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1304 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1320 },
    { MODRM_ONEENTRY, 513 },
    { MODRM_ONEENTRY, 514 },
    { MODRM_ONEENTRY, 515 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 928 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 1336 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 1337 },
    { MODRM_ONEENTRY, 1338 },
    { MODRM_ONEENTRY, 1339 },
    { MODRM_ONEENTRY, 1340 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 1341 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 1342 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1343 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1359 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 11 },
    { MODRM_ONEENTRY, 12 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 23 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 34 },
    { MODRM_ONEENTRY, 35 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 46 },
    { MODRM_ONEENTRY, 47 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 96 },
    { MODRM_ONEENTRY, 97 },
    { MODRM_SPLITRM, 98 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 103 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 106 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 211 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 215 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 235 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 237 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1375 },
    { MODRM_ONEENTRY, 1376 },
    { MODRM_ONEENTRY, 1377 },
    { MODRM_ONEENTRY, 1378 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 291 },
    { MODRM_ONEENTRY, 292 },
    { MODRM_SPLITRM, 293 },
    { MODRM_SPLITRM, 295 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 442 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 447 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 513 },
    { MODRM_ONEENTRY, 514 },
    { MODRM_ONEENTRY, 515 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1379 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 933 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 935 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1001 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1067 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1069 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1071 },
    { MODRM_ONEENTRY, 1072 },
    { MODRM_ONEENTRY, 1073 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1074 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1076 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1078 },
    { MODRM_ONEENTRY, 1079 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1080 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1082 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1084 },
    { MODRM_ONEENTRY, 1085 },
    { MODRM_ONEENTRY, 1086 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1087 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1089 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1091 },
    { MODRM_ONEENTRY, 1092 },
    { MODRM_ONEENTRY, 1093 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1094 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1096 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1098 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1099 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1101 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1103 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1104 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1106 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1108 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1109 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1111 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1113 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1114 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1115 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1118 },
    { MODRM_ONEENTRY, 1119 },
    { MODRM_SPLITRM, 1120 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1122 },
    { MODRM_SPLITRM, 1123 },
    { MODRM_ONEENTRY, 1125 },
    { MODRM_SPLITRM, 1126 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 1128 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 1129 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1130 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 1146 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1162 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1164 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1166 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1168 },
    { MODRM_SPLITRM, 1170 },
    { MODRM_SPLITRM, 1172 },
    { MODRM_SPLITRM, 1174 },
    { MODRM_SPLITREG, 1176 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1193 },
    { MODRM_ONEENTRY, 1194 },
    { MODRM_ONEENTRY, 1195 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1196 },
    { MODRM_ONEENTRY, 1197 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1375 },
    { MODRM_ONEENTRY, 1380 },
    { MODRM_ONEENTRY, 1377 },
    { MODRM_ONEENTRY, 1381 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1200 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1201 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1202 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1203 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1204 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1205 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1207 },
    { MODRM_ONEENTRY, 1223 },
    { MODRM_ONEENTRY, 1224 },
    { MODRM_SPLITRM, 1225 },
    { MODRM_SPLITRM, 1227 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1229 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 442 },
    { MODRM_ONEENTRY, 1301 },
    { MODRM_ONEENTRY, 1302 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 447 },
    { MODRM_ONEENTRY, 1303 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1304 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1320 },
    { MODRM_ONEENTRY, 513 },
    { MODRM_ONEENTRY, 514 },
    { MODRM_ONEENTRY, 515 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1379 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 1336 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 1337 },
    { MODRM_ONEENTRY, 1338 },
    { MODRM_ONEENTRY, 1339 },
    { MODRM_ONEENTRY, 1340 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 1341 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 1342 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1343 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1359 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 11 },
    { MODRM_ONEENTRY, 12 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 23 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 34 },
    { MODRM_ONEENTRY, 35 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 46 },
    { MODRM_ONEENTRY, 47 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 96 },
    { MODRM_ONEENTRY, 97 },
    { MODRM_SPLITRM, 98 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 103 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 106 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 211 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 215 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 235 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 237 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 291 },
    { MODRM_ONEENTRY, 292 },
    { MODRM_SPLITRM, 293 },
    { MODRM_SPLITRM, 295 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 442 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 447 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 513 },
    { MODRM_ONEENTRY, 514 },
    { MODRM_ONEENTRY, 515 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 928 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 933 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 935 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1001 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 11 },
    { MODRM_ONEENTRY, 12 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 23 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 34 },
    { MODRM_ONEENTRY, 35 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 46 },
    { MODRM_ONEENTRY, 47 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 58 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 69 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 80 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 91 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 92 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 93 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 94 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 95 },
    { MODRM_ONEENTRY, 96 },
    { MODRM_ONEENTRY, 97 },
    { MODRM_SPLITRM, 98 },
    { MODRM_SPLITRM, 100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 103 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 106 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_SPLITREG, 161 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 211 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 215 },
    { MODRM_ONEENTRY, 1382 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 235 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 237 },
    { MODRM_ONEENTRY, 238 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 291 },
    { MODRM_ONEENTRY, 292 },
    { MODRM_SPLITRM, 293 },
    { MODRM_SPLITRM, 295 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 442 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 447 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 513 },
    { MODRM_ONEENTRY, 514 },
    { MODRM_ONEENTRY, 515 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 928 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 933 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 935 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1001 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1383 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1385 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1387 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1388 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1390 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1392 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1393 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1395 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1397 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1398 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1400 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1402 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1403 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1405 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1408 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1410 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1412 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1413 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1415 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1418 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1420 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1422 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 1425 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 1427 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1445 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1461 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1463 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1465 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1467 },
    { MODRM_SPLITRM, 1469 },
    { MODRM_SPLITRM, 1471 },
    { MODRM_SPLITRM, 1473 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1476 },
    { MODRM_ONEENTRY, 1477 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1478 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1479 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1480 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1481 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1482 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1483 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1484 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1485 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1487 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1503 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 1575 },
    { MODRM_ONEENTRY, 1576 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1577 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1578 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1594 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1610 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1626 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1383 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1385 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1387 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1388 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1390 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1392 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1393 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1395 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1397 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1398 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1400 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1402 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1403 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1405 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1408 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1410 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1412 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1413 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1415 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1418 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1420 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1422 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1122 },
    { MODRM_SPLITRM, 1425 },
    { MODRM_ONEENTRY, 1125 },
    { MODRM_SPLITRM, 1427 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 1128 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 1129 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1445 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1461 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1463 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1465 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1467 },
    { MODRM_SPLITRM, 1469 },
    { MODRM_SPLITRM, 1471 },
    { MODRM_SPLITRM, 1473 },
    { MODRM_SPLITREG, 1176 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1476 },
    { MODRM_ONEENTRY, 1477 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1196 },
    { MODRM_ONEENTRY, 1197 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1642 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1643 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1480 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1481 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1482 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1483 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1484 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1485 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1487 },
    { MODRM_ONEENTRY, 1223 },
    { MODRM_ONEENTRY, 1224 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1644 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 1575 },
    { MODRM_ONEENTRY, 1576 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1577 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1578 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1594 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 1336 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 1337 },
    { MODRM_ONEENTRY, 1338 },
    { MODRM_ONEENTRY, 1339 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 1341 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 1342 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1610 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1716 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1067 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1069 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1071 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1074 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1076 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1078 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1080 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1082 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1084 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1087 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1089 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1091 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1094 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1096 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1098 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1099 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1101 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1103 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1104 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1106 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1108 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1109 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1111 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1113 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1122 },
    { MODRM_SPLITRM, 1123 },
    { MODRM_ONEENTRY, 1125 },
    { MODRM_SPLITRM, 1126 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 1128 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 1129 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1130 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1146 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1162 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1164 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1166 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1168 },
    { MODRM_SPLITRM, 1170 },
    { MODRM_SPLITRM, 1172 },
    { MODRM_SPLITRM, 1174 },
    { MODRM_SPLITREG, 1176 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1193 },
    { MODRM_ONEENTRY, 1194 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1196 },
    { MODRM_ONEENTRY, 1197 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1732 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1733 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1200 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1201 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1202 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1203 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1204 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1205 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1207 },
    { MODRM_ONEENTRY, 1223 },
    { MODRM_ONEENTRY, 1224 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1229 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 1301 },
    { MODRM_ONEENTRY, 1302 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1303 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1304 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1320 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 1336 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 1337 },
    { MODRM_ONEENTRY, 1338 },
    { MODRM_ONEENTRY, 1339 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 1341 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 1342 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1343 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1734 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 1022 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 241 },
    { MODRM_ONEENTRY, 242 },
    { MODRM_ONEENTRY, 243 },
    { MODRM_ONEENTRY, 244 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 928 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1051 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1067 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1069 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1071 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1074 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1076 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1078 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1080 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1082 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1084 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1087 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1089 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1091 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1094 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1096 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1098 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1099 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1101 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1103 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1104 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1106 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1108 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1109 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1111 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1113 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1122 },
    { MODRM_SPLITRM, 1123 },
    { MODRM_ONEENTRY, 1125 },
    { MODRM_SPLITRM, 1126 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 1128 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 1129 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1130 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1146 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1162 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1164 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1166 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1168 },
    { MODRM_SPLITRM, 1170 },
    { MODRM_SPLITRM, 1172 },
    { MODRM_SPLITRM, 1174 },
    { MODRM_SPLITREG, 1176 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1192 },
    { MODRM_ONEENTRY, 1193 },
    { MODRM_ONEENTRY, 1194 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1196 },
    { MODRM_ONEENTRY, 1197 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1198 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1199 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1200 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1201 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1202 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1203 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1204 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1205 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_ONEENTRY, 1206 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1207 },
    { MODRM_ONEENTRY, 1223 },
    { MODRM_ONEENTRY, 1224 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1229 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 1301 },
    { MODRM_ONEENTRY, 1302 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1303 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1304 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1320 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 1336 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 1337 },
    { MODRM_ONEENTRY, 1338 },
    { MODRM_ONEENTRY, 1339 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 1341 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 1342 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1343 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1734 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 1022 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1043 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1045 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1051 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 1022 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 1382 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1043 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1045 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1051 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 1022 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1043 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1045 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1051 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 3 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 7 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 10 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 15 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 19 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 22 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 26 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 30 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 33 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 38 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 42 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 45 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 50 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 54 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 57 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 61 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 65 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 68 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 72 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 76 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 79 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 83 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 87 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 90 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 104 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 107 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 177 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 195 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 199 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 203 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 207 },
    { MODRM_SPLITRM, 209 },
    { MODRM_SPLITRM, 1022 },
    { MODRM_SPLITRM, 213 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 1382 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 232 },
    { MODRM_ONEENTRY, 233 },
    { MODRM_ONEENTRY, 234 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1043 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1045 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 246 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 248 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 250 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 252 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 254 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 256 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_ONEENTRY, 258 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 275 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 369 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 443 },
    { MODRM_ONEENTRY, 444 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 448 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 465 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 963 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1051 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1383 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1385 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1387 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1388 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1390 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1392 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1393 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1395 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1397 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1398 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1400 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1402 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1403 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1405 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1408 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1410 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1412 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1413 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1415 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1418 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1420 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1422 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 1425 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 1427 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1445 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1461 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1463 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1465 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1467 },
    { MODRM_SPLITRM, 1469 },
    { MODRM_SPLITRM, 1471 },
    { MODRM_SPLITRM, 1473 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1476 },
    { MODRM_ONEENTRY, 1477 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1478 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1479 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1480 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1481 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1482 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1483 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1484 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1485 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1487 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1503 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 1575 },
    { MODRM_ONEENTRY, 1576 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1577 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1578 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1594 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1610 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1626 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1383 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1385 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1387 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1388 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1390 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1392 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1393 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1395 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1397 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1398 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1400 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1402 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1403 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1405 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1408 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1410 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1412 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1413 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1415 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1418 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1420 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1422 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1018 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 1019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1020 },
    { MODRM_SPLITRM, 1425 },
    { MODRM_ONEENTRY, 1021 },
    { MODRM_SPLITRM, 1427 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 110 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 112 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1445 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1461 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1463 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1465 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1467 },
    { MODRM_SPLITRM, 1469 },
    { MODRM_SPLITRM, 1471 },
    { MODRM_SPLITRM, 1473 },
    { MODRM_SPLITREG, 1024 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1476 },
    { MODRM_ONEENTRY, 1477 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1040 },
    { MODRM_ONEENTRY, 1041 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1478 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1479 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1480 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1481 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1482 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1483 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1484 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1485 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1487 },
    { MODRM_ONEENTRY, 1046 },
    { MODRM_ONEENTRY, 1047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1503 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 1575 },
    { MODRM_ONEENTRY, 1576 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1577 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1578 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1594 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 930 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 932 },
    { MODRM_ONEENTRY, 1050 },
    { MODRM_ONEENTRY, 934 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 938 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 940 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1610 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1626 },
  } },
  { {
    { MODRM_SPLITRM, 1 },
    { MODRM_SPLITRM, 1383 },
    { MODRM_SPLITRM, 5 },
    { MODRM_SPLITRM, 1385 },
    { MODRM_ONEENTRY, 9 },
    { MODRM_ONEENTRY, 1387 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13 },
    { MODRM_SPLITRM, 1388 },
    { MODRM_SPLITRM, 17 },
    { MODRM_SPLITRM, 1390 },
    { MODRM_ONEENTRY, 21 },
    { MODRM_ONEENTRY, 1392 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 24 },
    { MODRM_SPLITRM, 1393 },
    { MODRM_SPLITRM, 28 },
    { MODRM_SPLITRM, 1395 },
    { MODRM_ONEENTRY, 32 },
    { MODRM_ONEENTRY, 1397 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 36 },
    { MODRM_SPLITRM, 1398 },
    { MODRM_SPLITRM, 40 },
    { MODRM_SPLITRM, 1400 },
    { MODRM_ONEENTRY, 44 },
    { MODRM_ONEENTRY, 1402 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 48 },
    { MODRM_SPLITRM, 1403 },
    { MODRM_SPLITRM, 52 },
    { MODRM_SPLITRM, 1405 },
    { MODRM_ONEENTRY, 56 },
    { MODRM_ONEENTRY, 1407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 59 },
    { MODRM_SPLITRM, 1408 },
    { MODRM_SPLITRM, 63 },
    { MODRM_SPLITRM, 1410 },
    { MODRM_ONEENTRY, 67 },
    { MODRM_ONEENTRY, 1412 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 70 },
    { MODRM_SPLITRM, 1413 },
    { MODRM_SPLITRM, 74 },
    { MODRM_SPLITRM, 1415 },
    { MODRM_ONEENTRY, 78 },
    { MODRM_ONEENTRY, 1417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 81 },
    { MODRM_SPLITRM, 1418 },
    { MODRM_SPLITRM, 85 },
    { MODRM_SPLITRM, 1420 },
    { MODRM_ONEENTRY, 89 },
    { MODRM_ONEENTRY, 1422 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1116 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 1117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1122 },
    { MODRM_SPLITRM, 1425 },
    { MODRM_ONEENTRY, 1125 },
    { MODRM_SPLITRM, 1427 },
    { MODRM_ONEENTRY, 109 },
    { MODRM_ONEENTRY, 1128 },
    { MODRM_ONEENTRY, 111 },
    { MODRM_ONEENTRY, 1129 },
    { MODRM_ONEENTRY, 113 },
    { MODRM_ONEENTRY, 114 },
    { MODRM_ONEENTRY, 115 },
    { MODRM_ONEENTRY, 116 },
    { MODRM_ONEENTRY, 117 },
    { MODRM_ONEENTRY, 118 },
    { MODRM_ONEENTRY, 119 },
    { MODRM_ONEENTRY, 120 },
    { MODRM_ONEENTRY, 121 },
    { MODRM_ONEENTRY, 122 },
    { MODRM_ONEENTRY, 123 },
    { MODRM_ONEENTRY, 124 },
    { MODRM_ONEENTRY, 125 },
    { MODRM_ONEENTRY, 126 },
    { MODRM_ONEENTRY, 127 },
    { MODRM_ONEENTRY, 128 },
    { MODRM_SPLITREG, 129 },
    { MODRM_SPLITREG, 1429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1445 },
    { MODRM_SPLITRM, 193 },
    { MODRM_SPLITRM, 1461 },
    { MODRM_SPLITRM, 197 },
    { MODRM_SPLITRM, 1463 },
    { MODRM_SPLITRM, 201 },
    { MODRM_SPLITRM, 1465 },
    { MODRM_SPLITRM, 205 },
    { MODRM_SPLITRM, 1467 },
    { MODRM_SPLITRM, 1469 },
    { MODRM_SPLITRM, 1471 },
    { MODRM_SPLITRM, 1473 },
    { MODRM_SPLITREG, 1176 },
    { MODRM_ONEENTRY, 231 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1475 },
    { MODRM_ONEENTRY, 1476 },
    { MODRM_ONEENTRY, 1477 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 236 },
    { MODRM_ONEENTRY, 1196 },
    { MODRM_ONEENTRY, 1197 },
    { MODRM_ONEENTRY, 239 },
    { MODRM_ONEENTRY, 240 },
    { MODRM_ONEENTRY, 1042 },
    { MODRM_ONEENTRY, 1478 },
    { MODRM_ONEENTRY, 1044 },
    { MODRM_ONEENTRY, 1479 },
    { MODRM_ONEENTRY, 245 },
    { MODRM_ONEENTRY, 1480 },
    { MODRM_ONEENTRY, 247 },
    { MODRM_ONEENTRY, 1481 },
    { MODRM_ONEENTRY, 249 },
    { MODRM_ONEENTRY, 1482 },
    { MODRM_ONEENTRY, 251 },
    { MODRM_ONEENTRY, 1483 },
    { MODRM_ONEENTRY, 253 },
    { MODRM_ONEENTRY, 1484 },
    { MODRM_ONEENTRY, 255 },
    { MODRM_ONEENTRY, 1485 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 257 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_ONEENTRY, 1486 },
    { MODRM_SPLITREG, 259 },
    { MODRM_SPLITREG, 1487 },
    { MODRM_ONEENTRY, 1223 },
    { MODRM_ONEENTRY, 1224 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITMISC, 297 },
    { MODRM_SPLITMISC, 1644 },
    { MODRM_ONEENTRY, 441 },
    { MODRM_ONEENTRY, 1048 },
    { MODRM_ONEENTRY, 1575 },
    { MODRM_ONEENTRY, 1576 },
    { MODRM_ONEENTRY, 445 },
    { MODRM_ONEENTRY, 446 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1577 },
    { MODRM_SPLITREG, 449 },
    { MODRM_SPLITREG, 1578 },
    { MODRM_SPLITREG, 481 },
    { MODRM_SPLITREG, 1594 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 516 },
    { MODRM_SPLITREG, 517 },
    { MODRM_SPLITMISC, 533 },
    { MODRM_SPLITMISC, 605 },
    { MODRM_SPLITMISC, 677 },
    { MODRM_SPLITREG, 749 },
    { MODRM_SPLITREG, 765 },
    { MODRM_SPLITMISC, 781 },
    { MODRM_SPLITMISC, 853 },
    { MODRM_ONEENTRY, 925 },
    { MODRM_ONEENTRY, 926 },
    { MODRM_ONEENTRY, 927 },
    { MODRM_ONEENTRY, 1049 },
    { MODRM_ONEENTRY, 929 },
    { MODRM_ONEENTRY, 1336 },
    { MODRM_ONEENTRY, 931 },
    { MODRM_ONEENTRY, 1337 },
    { MODRM_ONEENTRY, 1338 },
    { MODRM_ONEENTRY, 1339 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 936 },
    { MODRM_ONEENTRY, 937 },
    { MODRM_ONEENTRY, 1341 },
    { MODRM_ONEENTRY, 939 },
    { MODRM_ONEENTRY, 1342 },
    { MODRM_ONEENTRY, 941 },
    { MODRM_ONEENTRY, 942 },
    { MODRM_ONEENTRY, 943 },
    { MODRM_ONEENTRY, 944 },
    { MODRM_ONEENTRY, 945 },
    { MODRM_ONEENTRY, 946 },
    { MODRM_SPLITREG, 947 },
    { MODRM_SPLITREG, 1610 },
    { MODRM_ONEENTRY, 979 },
    { MODRM_ONEENTRY, 980 },
    { MODRM_ONEENTRY, 981 },
    { MODRM_ONEENTRY, 982 },
    { MODRM_ONEENTRY, 983 },
    { MODRM_ONEENTRY, 984 },
    { MODRM_SPLITREG, 985 },
    { MODRM_SPLITREG, 1716 },
  } },
};

static const unsigned char index_x86DisassemblerTwoByteOpcodes[] = {
  1,
  2,
  3,
  4,
  5,
  6,
  7,
  0,
  8,
  0,
  9,
  10,
  11,
  12,
  13,
  14,
  15,
  16,
  0,
  17,
  18,
  19,
  20,
  21,
  22,
  23,
  24,
  25,
  26,
  27,
  28,
  29,
  30,
  31,
  32,
  33,
  34,
  35,
  36,
  37,
  38,
  39,
  40,
  41,
  42,
  43,
  44,
  45,
  46,
  47,
  48,
  49,
  50,
  51,
  52,
  53,
  54,
  55,
  56,
  57,
  58,
  59,
  60,
  61,
  62,
  63,
  64,
  65,
  66,
  67,
  68,
  69,
  70,
  71,
  72,
  73,
  74,
  75,
  76,
  77,
  78,
  79,
  80,
  81,
  82,
  83,
  84,
  85,
  86,
  87,
  88,
  89,
  90,
  91,
  92,
  93,
  94,
  95,
  96,
  97,
  98,
  99,
  100,
  101,
  102,
  103,
  104,
  105,
  106,
  107,
  108,
  109,
  110,
  111,
  112,
  113,
  114,
  115,
  116,
  117,
  118,
  119,
  120,
  121,
  122,
  123,
  124,
  125,
  126,
  127,
  128,
  129,
  130,
  131,
  132,
  133,
  134,
  135,
  136,
  137,
  138,
  139,
  140,
  141,
  142,
  143,
  144,
  145,
  146,
  147,
  148,
  149,
  150,
  151,
  152,
  153,
  154,
  155,
  156,
  157,
  158,
  159,
  160,
  161,
  162,
  163,
  164,
  165,
  166,
  167,
  168,
  169,
  170,
  171,
  172,
  173,
  174,
  175,
  176,
  177,
  178,
  179,
  180,
  181,
  182,
};

static const struct OpcodeDecision x86DisassemblerTwoByteOpcodes[] = {
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 1766 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1865 },
    { MODRM_SPLITRM, 1867 },
    { MODRM_SPLITRM, 1869 },
    { MODRM_SPLITRM, 1871 },
    { MODRM_SPLITRM, 1873 },
    { MODRM_SPLITRM, 1875 },
    { MODRM_SPLITRM, 1877 },
    { MODRM_SPLITRM, 1879 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 1899 },
    { MODRM_SPLITRM, 1901 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 1925 },
    { MODRM_SPLITRM, 1927 },
    { MODRM_SPLITRM, 1929 },
    { MODRM_SPLITRM, 1931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1933 },
    { MODRM_SPLITRM, 1935 },
    { MODRM_SPLITRM, 1937 },
    { MODRM_SPLITRM, 1939 },
    { MODRM_SPLITRM, 1941 },
    { MODRM_SPLITRM, 1943 },
    { MODRM_SPLITRM, 1945 },
    { MODRM_SPLITRM, 1947 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_SPLITRM, 1988 },
    { MODRM_SPLITRM, 1990 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 1996 },
    { MODRM_SPLITRM, 1998 },
    { MODRM_SPLITRM, 2000 },
    { MODRM_SPLITRM, 2002 },
    { MODRM_SPLITRM, 2004 },
    { MODRM_SPLITRM, 2006 },
    { MODRM_SPLITRM, 2008 },
    { MODRM_SPLITRM, 2010 },
    { MODRM_SPLITRM, 2012 },
    { MODRM_SPLITRM, 2014 },
    { MODRM_SPLITRM, 2016 },
    { MODRM_SPLITRM, 2018 },
    { MODRM_SPLITRM, 2020 },
    { MODRM_SPLITRM, 2022 },
    { MODRM_SPLITRM, 2024 },
    { MODRM_SPLITRM, 2026 },
    { MODRM_SPLITRM, 2028 },
    { MODRM_SPLITRM, 2030 },
    { MODRM_SPLITRM, 2032 },
    { MODRM_SPLITRM, 2034 },
    { MODRM_SPLITRM, 2036 },
    { MODRM_SPLITRM, 2038 },
    { MODRM_SPLITRM, 2040 },
    { MODRM_SPLITRM, 2042 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2044 },
    { MODRM_SPLITRM, 2046 },
    { MODRM_SPLITRM, 2048 },
    { MODRM_SPLITREG, 2050 },
    { MODRM_SPLITREG, 2066 },
    { MODRM_SPLITREG, 2082 },
    { MODRM_SPLITRM, 2098 },
    { MODRM_SPLITRM, 2100 },
    { MODRM_SPLITRM, 2102 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 2105 },
    { MODRM_SPLITRM, 2107 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2109 },
    { MODRM_SPLITRM, 2111 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2161 },
    { MODRM_ONEENTRY, 2162 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2314 },
    { MODRM_ONEENTRY, 2315 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITMISC, 2323 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_SPLITRM, 2432 },
    { MODRM_SPLITRM, 2434 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 2444 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 2448 },
    { MODRM_SPLITRM, 2450 },
    { MODRM_SPLITRM, 2452 },
    { MODRM_SPLITREG, 2454 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2471 },
    { MODRM_SPLITRM, 2473 },
    { MODRM_SPLITRM, 2475 },
    { MODRM_SPLITRM, 2477 },
    { MODRM_SPLITRM, 2479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2481 },
    { MODRM_SPLITRM, 2483 },
    { MODRM_SPLITRM, 2485 },
    { MODRM_SPLITRM, 2487 },
    { MODRM_SPLITRM, 2489 },
    { MODRM_SPLITRM, 2491 },
    { MODRM_SPLITRM, 2493 },
    { MODRM_SPLITRM, 2495 },
    { MODRM_SPLITRM, 2497 },
    { MODRM_SPLITRM, 2499 },
    { MODRM_SPLITRM, 2501 },
    { MODRM_SPLITRM, 2503 },
    { MODRM_SPLITRM, 2505 },
    { MODRM_SPLITRM, 2507 },
    { MODRM_SPLITRM, 2509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2511 },
    { MODRM_SPLITRM, 2513 },
    { MODRM_SPLITRM, 2515 },
    { MODRM_SPLITRM, 2517 },
    { MODRM_SPLITRM, 2519 },
    { MODRM_SPLITRM, 2521 },
    { MODRM_SPLITRM, 2523 },
    { MODRM_SPLITRM, 2525 },
    { MODRM_SPLITRM, 2527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2529 },
    { MODRM_SPLITRM, 2531 },
    { MODRM_SPLITRM, 2533 },
    { MODRM_SPLITRM, 2535 },
    { MODRM_SPLITRM, 2537 },
    { MODRM_SPLITRM, 2539 },
    { MODRM_SPLITRM, 2541 },
    { MODRM_SPLITRM, 2543 },
    { MODRM_SPLITRM, 2545 },
    { MODRM_SPLITRM, 2547 },
    { MODRM_SPLITRM, 2549 },
    { MODRM_SPLITRM, 2551 },
    { MODRM_SPLITRM, 2553 },
    { MODRM_SPLITRM, 2555 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 2558 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1865 },
    { MODRM_SPLITRM, 1867 },
    { MODRM_SPLITRM, 1869 },
    { MODRM_SPLITRM, 1871 },
    { MODRM_SPLITRM, 1873 },
    { MODRM_SPLITRM, 1875 },
    { MODRM_SPLITRM, 1877 },
    { MODRM_SPLITRM, 1879 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 1899 },
    { MODRM_SPLITRM, 1901 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1933 },
    { MODRM_SPLITRM, 1935 },
    { MODRM_SPLITRM, 1937 },
    { MODRM_SPLITRM, 1939 },
    { MODRM_SPLITRM, 1941 },
    { MODRM_SPLITRM, 1943 },
    { MODRM_SPLITRM, 1945 },
    { MODRM_SPLITRM, 1947 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_SPLITRM, 1988 },
    { MODRM_SPLITRM, 1990 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 1996 },
    { MODRM_SPLITRM, 1998 },
    { MODRM_SPLITRM, 2000 },
    { MODRM_SPLITRM, 2002 },
    { MODRM_SPLITRM, 2004 },
    { MODRM_SPLITRM, 2006 },
    { MODRM_SPLITRM, 2008 },
    { MODRM_SPLITRM, 2010 },
    { MODRM_SPLITRM, 2012 },
    { MODRM_SPLITRM, 2014 },
    { MODRM_SPLITRM, 2016 },
    { MODRM_SPLITRM, 2018 },
    { MODRM_SPLITRM, 2020 },
    { MODRM_SPLITRM, 2022 },
    { MODRM_SPLITRM, 2024 },
    { MODRM_SPLITRM, 2026 },
    { MODRM_SPLITRM, 2028 },
    { MODRM_SPLITRM, 2030 },
    { MODRM_SPLITRM, 2032 },
    { MODRM_SPLITRM, 2034 },
    { MODRM_SPLITRM, 2036 },
    { MODRM_SPLITRM, 2038 },
    { MODRM_SPLITRM, 2040 },
    { MODRM_SPLITRM, 2042 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2044 },
    { MODRM_SPLITRM, 2046 },
    { MODRM_SPLITRM, 2048 },
    { MODRM_SPLITREG, 2050 },
    { MODRM_SPLITREG, 2066 },
    { MODRM_SPLITREG, 2082 },
    { MODRM_SPLITRM, 2098 },
    { MODRM_SPLITRM, 2100 },
    { MODRM_SPLITRM, 2102 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 2638 },
    { MODRM_SPLITRM, 2640 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2109 },
    { MODRM_SPLITRM, 2111 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITMISC, 2323 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_SPLITRM, 2432 },
    { MODRM_SPLITRM, 2434 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 2444 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 2448 },
    { MODRM_SPLITRM, 2450 },
    { MODRM_SPLITRM, 2452 },
    { MODRM_SPLITREG, 2454 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2471 },
    { MODRM_SPLITRM, 2473 },
    { MODRM_SPLITRM, 2475 },
    { MODRM_SPLITRM, 2477 },
    { MODRM_SPLITRM, 2479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2481 },
    { MODRM_SPLITRM, 2483 },
    { MODRM_SPLITRM, 2485 },
    { MODRM_SPLITRM, 2487 },
    { MODRM_SPLITRM, 2489 },
    { MODRM_SPLITRM, 2491 },
    { MODRM_SPLITRM, 2493 },
    { MODRM_SPLITRM, 2495 },
    { MODRM_SPLITRM, 2497 },
    { MODRM_SPLITRM, 2499 },
    { MODRM_SPLITRM, 2501 },
    { MODRM_SPLITRM, 2503 },
    { MODRM_SPLITRM, 2505 },
    { MODRM_SPLITRM, 2507 },
    { MODRM_SPLITRM, 2509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2511 },
    { MODRM_SPLITRM, 2513 },
    { MODRM_SPLITRM, 2515 },
    { MODRM_SPLITRM, 2517 },
    { MODRM_SPLITRM, 2519 },
    { MODRM_SPLITRM, 2521 },
    { MODRM_SPLITRM, 2523 },
    { MODRM_SPLITRM, 2525 },
    { MODRM_SPLITRM, 2527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2529 },
    { MODRM_SPLITRM, 2531 },
    { MODRM_SPLITRM, 2533 },
    { MODRM_SPLITRM, 2535 },
    { MODRM_SPLITRM, 2537 },
    { MODRM_SPLITRM, 2539 },
    { MODRM_SPLITRM, 2646 },
    { MODRM_SPLITRM, 2543 },
    { MODRM_SPLITRM, 2545 },
    { MODRM_SPLITRM, 2547 },
    { MODRM_SPLITRM, 2549 },
    { MODRM_SPLITRM, 2551 },
    { MODRM_SPLITRM, 2553 },
    { MODRM_SPLITRM, 2555 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 2648 },
    { MODRM_SPLITMISC, 2664 },
    { MODRM_SPLITRM, 2736 },
    { MODRM_SPLITRM, 2738 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2740 },
    { MODRM_SPLITRM, 2742 },
    { MODRM_SPLITRM, 2744 },
    { MODRM_SPLITRM, 2746 },
    { MODRM_SPLITRM, 2748 },
    { MODRM_SPLITRM, 2750 },
    { MODRM_SPLITRM, 2752 },
    { MODRM_SPLITRM, 2754 },
    { MODRM_SPLITREG, 2756 },
    { MODRM_SPLITRM, 2772 },
    { MODRM_SPLITRM, 2774 },
    { MODRM_SPLITRM, 2776 },
    { MODRM_SPLITRM, 2778 },
    { MODRM_SPLITRM, 2780 },
    { MODRM_SPLITRM, 2782 },
    { MODRM_SPLITRM, 2784 },
    { MODRM_SPLITRM, 1925 },
    { MODRM_SPLITRM, 1927 },
    { MODRM_SPLITRM, 1929 },
    { MODRM_SPLITRM, 1931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2786 },
    { MODRM_SPLITRM, 2788 },
    { MODRM_SPLITRM, 2790 },
    { MODRM_SPLITRM, 2792 },
    { MODRM_SPLITRM, 2794 },
    { MODRM_SPLITRM, 2796 },
    { MODRM_SPLITRM, 2798 },
    { MODRM_SPLITRM, 2800 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2802 },
    { MODRM_SPLITRM, 2804 },
    { MODRM_SPLITRM, 2806 },
    { MODRM_SPLITRM, 2808 },
    { MODRM_SPLITRM, 2810 },
    { MODRM_SPLITRM, 2812 },
    { MODRM_SPLITRM, 2814 },
    { MODRM_SPLITRM, 2816 },
    { MODRM_SPLITRM, 2818 },
    { MODRM_SPLITRM, 2820 },
    { MODRM_SPLITRM, 2822 },
    { MODRM_SPLITRM, 2824 },
    { MODRM_SPLITRM, 2826 },
    { MODRM_SPLITRM, 2828 },
    { MODRM_SPLITRM, 2830 },
    { MODRM_SPLITRM, 2832 },
    { MODRM_SPLITRM, 2834 },
    { MODRM_SPLITRM, 2836 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2838 },
    { MODRM_SPLITRM, 2840 },
    { MODRM_SPLITRM, 2842 },
    { MODRM_SPLITRM, 2844 },
    { MODRM_SPLITRM, 2846 },
    { MODRM_SPLITRM, 2848 },
    { MODRM_SPLITRM, 2850 },
    { MODRM_SPLITRM, 2852 },
    { MODRM_SPLITRM, 2854 },
    { MODRM_SPLITRM, 2856 },
    { MODRM_SPLITRM, 2858 },
    { MODRM_SPLITRM, 2860 },
    { MODRM_SPLITRM, 2862 },
    { MODRM_SPLITRM, 2864 },
    { MODRM_SPLITRM, 2866 },
    { MODRM_SPLITRM, 2868 },
    { MODRM_SPLITRM, 2870 },
    { MODRM_SPLITRM, 2872 },
    { MODRM_SPLITRM, 2874 },
    { MODRM_SPLITRM, 2876 },
    { MODRM_SPLITRM, 2878 },
    { MODRM_SPLITRM, 2880 },
    { MODRM_SPLITRM, 2882 },
    { MODRM_SPLITRM, 2884 },
    { MODRM_SPLITRM, 2886 },
    { MODRM_SPLITRM, 2888 },
    { MODRM_SPLITRM, 2890 },
    { MODRM_SPLITRM, 2892 },
    { MODRM_SPLITRM, 2894 },
    { MODRM_SPLITREG, 2896 },
    { MODRM_SPLITREG, 2912 },
    { MODRM_SPLITREG, 2928 },
    { MODRM_SPLITRM, 2944 },
    { MODRM_SPLITRM, 2946 },
    { MODRM_SPLITRM, 2948 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2950 },
    { MODRM_SPLITRM, 2952 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2954 },
    { MODRM_SPLITRM, 2956 },
    { MODRM_SPLITRM, 2958 },
    { MODRM_SPLITRM, 2960 },
    { MODRM_ONEENTRY, 2962 },
    { MODRM_ONEENTRY, 2963 },
    { MODRM_ONEENTRY, 2964 },
    { MODRM_ONEENTRY, 2965 },
    { MODRM_ONEENTRY, 2966 },
    { MODRM_ONEENTRY, 2967 },
    { MODRM_ONEENTRY, 2968 },
    { MODRM_ONEENTRY, 2969 },
    { MODRM_ONEENTRY, 2970 },
    { MODRM_ONEENTRY, 2971 },
    { MODRM_ONEENTRY, 2972 },
    { MODRM_ONEENTRY, 2973 },
    { MODRM_ONEENTRY, 2974 },
    { MODRM_ONEENTRY, 2975 },
    { MODRM_ONEENTRY, 2976 },
    { MODRM_ONEENTRY, 2977 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2978 },
    { MODRM_ONEENTRY, 2979 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2980 },
    { MODRM_SPLITRM, 2982 },
    { MODRM_SPLITRM, 2984 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2986 },
    { MODRM_ONEENTRY, 2987 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2988 },
    { MODRM_SPLITRM, 2990 },
    { MODRM_SPLITRM, 2992 },
    { MODRM_SPLITREG, 2994 },
    { MODRM_SPLITRM, 3010 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3012 },
    { MODRM_SPLITRM, 3014 },
    { MODRM_SPLITRM, 3016 },
    { MODRM_SPLITRM, 3018 },
    { MODRM_SPLITRM, 3020 },
    { MODRM_SPLITRM, 3022 },
    { MODRM_SPLITRM, 3024 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3026 },
    { MODRM_SPLITRM, 3042 },
    { MODRM_SPLITRM, 3044 },
    { MODRM_SPLITRM, 3046 },
    { MODRM_SPLITRM, 3048 },
    { MODRM_SPLITRM, 3050 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3052 },
    { MODRM_SPLITRM, 3054 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3056 },
    { MODRM_SPLITRM, 3058 },
    { MODRM_SPLITRM, 3060 },
    { MODRM_SPLITREG, 3062 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_SPLITRM, 3079 },
    { MODRM_SPLITRM, 3081 },
    { MODRM_SPLITRM, 3083 },
    { MODRM_SPLITRM, 3085 },
    { MODRM_SPLITRM, 3087 },
    { MODRM_SPLITRM, 3089 },
    { MODRM_SPLITRM, 3091 },
    { MODRM_SPLITRM, 3093 },
    { MODRM_SPLITRM, 3095 },
    { MODRM_SPLITRM, 3097 },
    { MODRM_SPLITRM, 3099 },
    { MODRM_SPLITRM, 3101 },
    { MODRM_SPLITRM, 3103 },
    { MODRM_SPLITRM, 3105 },
    { MODRM_SPLITRM, 3107 },
    { MODRM_SPLITRM, 3109 },
    { MODRM_SPLITRM, 3111 },
    { MODRM_SPLITRM, 3113 },
    { MODRM_SPLITRM, 3115 },
    { MODRM_SPLITRM, 3117 },
    { MODRM_SPLITRM, 3119 },
    { MODRM_SPLITRM, 3121 },
    { MODRM_SPLITRM, 3123 },
    { MODRM_SPLITRM, 3125 },
    { MODRM_SPLITRM, 3127 },
    { MODRM_SPLITRM, 3129 },
    { MODRM_SPLITRM, 3131 },
    { MODRM_SPLITRM, 3133 },
    { MODRM_SPLITRM, 3135 },
    { MODRM_SPLITRM, 3137 },
    { MODRM_SPLITRM, 3139 },
    { MODRM_SPLITRM, 3141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3143 },
    { MODRM_SPLITRM, 3145 },
    { MODRM_SPLITRM, 3147 },
    { MODRM_SPLITRM, 3149 },
    { MODRM_SPLITRM, 3151 },
    { MODRM_SPLITRM, 3153 },
    { MODRM_SPLITRM, 3155 },
    { MODRM_SPLITRM, 3157 },
    { MODRM_SPLITRM, 3159 },
    { MODRM_SPLITRM, 3161 },
    { MODRM_SPLITRM, 3163 },
    { MODRM_SPLITRM, 3165 },
    { MODRM_SPLITRM, 3167 },
    { MODRM_SPLITRM, 3169 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 1766 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1865 },
    { MODRM_SPLITRM, 1867 },
    { MODRM_SPLITRM, 1869 },
    { MODRM_SPLITRM, 1871 },
    { MODRM_SPLITRM, 1873 },
    { MODRM_SPLITRM, 1875 },
    { MODRM_SPLITRM, 1877 },
    { MODRM_SPLITRM, 1879 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 1899 },
    { MODRM_SPLITRM, 1901 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 1925 },
    { MODRM_SPLITRM, 1927 },
    { MODRM_SPLITRM, 1929 },
    { MODRM_SPLITRM, 1931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1933 },
    { MODRM_SPLITRM, 1935 },
    { MODRM_SPLITRM, 1937 },
    { MODRM_SPLITRM, 1939 },
    { MODRM_SPLITRM, 1941 },
    { MODRM_SPLITRM, 1943 },
    { MODRM_SPLITRM, 1945 },
    { MODRM_SPLITRM, 1947 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_SPLITRM, 1988 },
    { MODRM_SPLITRM, 1990 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 1996 },
    { MODRM_SPLITRM, 1998 },
    { MODRM_SPLITRM, 2000 },
    { MODRM_SPLITRM, 2002 },
    { MODRM_SPLITRM, 2004 },
    { MODRM_SPLITRM, 2006 },
    { MODRM_SPLITRM, 2008 },
    { MODRM_SPLITRM, 2010 },
    { MODRM_SPLITRM, 2012 },
    { MODRM_SPLITRM, 2014 },
    { MODRM_SPLITRM, 2016 },
    { MODRM_SPLITRM, 2018 },
    { MODRM_SPLITRM, 2020 },
    { MODRM_SPLITRM, 2022 },
    { MODRM_SPLITRM, 2024 },
    { MODRM_SPLITRM, 2026 },
    { MODRM_SPLITRM, 2028 },
    { MODRM_SPLITRM, 2030 },
    { MODRM_SPLITRM, 2032 },
    { MODRM_SPLITRM, 2034 },
    { MODRM_SPLITRM, 2036 },
    { MODRM_SPLITRM, 2038 },
    { MODRM_SPLITRM, 2040 },
    { MODRM_SPLITRM, 2042 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2044 },
    { MODRM_SPLITRM, 2046 },
    { MODRM_SPLITRM, 2048 },
    { MODRM_SPLITREG, 2050 },
    { MODRM_SPLITREG, 2066 },
    { MODRM_SPLITREG, 2082 },
    { MODRM_SPLITRM, 2098 },
    { MODRM_SPLITRM, 2100 },
    { MODRM_SPLITRM, 2102 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 2105 },
    { MODRM_SPLITRM, 2107 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2109 },
    { MODRM_SPLITRM, 2111 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2161 },
    { MODRM_ONEENTRY, 2162 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2314 },
    { MODRM_ONEENTRY, 2315 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITMISC, 2323 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_SPLITRM, 2432 },
    { MODRM_SPLITRM, 2434 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 2444 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 2448 },
    { MODRM_SPLITRM, 2450 },
    { MODRM_SPLITRM, 2452 },
    { MODRM_SPLITREG, 2454 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2471 },
    { MODRM_SPLITRM, 2473 },
    { MODRM_SPLITRM, 2475 },
    { MODRM_SPLITRM, 2477 },
    { MODRM_SPLITRM, 2479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2481 },
    { MODRM_SPLITRM, 2483 },
    { MODRM_SPLITRM, 2485 },
    { MODRM_SPLITRM, 2487 },
    { MODRM_SPLITRM, 2489 },
    { MODRM_SPLITRM, 2491 },
    { MODRM_SPLITRM, 2493 },
    { MODRM_SPLITRM, 2495 },
    { MODRM_SPLITRM, 2497 },
    { MODRM_SPLITRM, 2499 },
    { MODRM_SPLITRM, 2501 },
    { MODRM_SPLITRM, 2503 },
    { MODRM_SPLITRM, 2505 },
    { MODRM_SPLITRM, 2507 },
    { MODRM_SPLITRM, 2509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2511 },
    { MODRM_SPLITRM, 2513 },
    { MODRM_SPLITRM, 2515 },
    { MODRM_SPLITRM, 2517 },
    { MODRM_SPLITRM, 2519 },
    { MODRM_SPLITRM, 2521 },
    { MODRM_SPLITRM, 2523 },
    { MODRM_SPLITRM, 2525 },
    { MODRM_SPLITRM, 2527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2529 },
    { MODRM_SPLITRM, 2531 },
    { MODRM_SPLITRM, 2533 },
    { MODRM_SPLITRM, 2535 },
    { MODRM_SPLITRM, 2537 },
    { MODRM_SPLITRM, 2539 },
    { MODRM_SPLITRM, 2541 },
    { MODRM_SPLITRM, 2543 },
    { MODRM_SPLITRM, 2545 },
    { MODRM_SPLITRM, 2547 },
    { MODRM_SPLITRM, 2549 },
    { MODRM_SPLITRM, 2551 },
    { MODRM_SPLITRM, 2553 },
    { MODRM_SPLITRM, 2555 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 2648 },
    { MODRM_SPLITMISC, 2664 },
    { MODRM_SPLITRM, 2736 },
    { MODRM_SPLITRM, 2738 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2740 },
    { MODRM_SPLITRM, 2742 },
    { MODRM_SPLITRM, 3171 },
    { MODRM_SPLITRM, 2746 },
    { MODRM_SPLITRM, 2748 },
    { MODRM_SPLITRM, 2750 },
    { MODRM_SPLITRM, 3173 },
    { MODRM_SPLITRM, 2754 },
    { MODRM_SPLITREG, 2756 },
    { MODRM_SPLITRM, 2772 },
    { MODRM_SPLITRM, 2774 },
    { MODRM_SPLITRM, 2776 },
    { MODRM_SPLITRM, 2778 },
    { MODRM_SPLITRM, 2780 },
    { MODRM_SPLITRM, 2782 },
    { MODRM_SPLITRM, 2784 },
    { MODRM_SPLITRM, 1925 },
    { MODRM_SPLITRM, 1927 },
    { MODRM_SPLITRM, 1929 },
    { MODRM_SPLITRM, 1931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2786 },
    { MODRM_SPLITRM, 2788 },
    { MODRM_SPLITRM, 2790 },
    { MODRM_SPLITRM, 2792 },
    { MODRM_SPLITRM, 2794 },
    { MODRM_SPLITRM, 2796 },
    { MODRM_SPLITRM, 2798 },
    { MODRM_SPLITRM, 2800 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2802 },
    { MODRM_SPLITRM, 2804 },
    { MODRM_SPLITRM, 2806 },
    { MODRM_SPLITRM, 2808 },
    { MODRM_SPLITRM, 2810 },
    { MODRM_SPLITRM, 2812 },
    { MODRM_SPLITRM, 2814 },
    { MODRM_SPLITRM, 2816 },
    { MODRM_SPLITRM, 2818 },
    { MODRM_SPLITRM, 2820 },
    { MODRM_SPLITRM, 2822 },
    { MODRM_SPLITRM, 2824 },
    { MODRM_SPLITRM, 2826 },
    { MODRM_SPLITRM, 2828 },
    { MODRM_SPLITRM, 2830 },
    { MODRM_SPLITRM, 2832 },
    { MODRM_SPLITRM, 2834 },
    { MODRM_SPLITRM, 2836 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 2838 },
    { MODRM_SPLITRM, 2840 },
    { MODRM_SPLITRM, 2842 },
    { MODRM_SPLITRM, 2844 },
    { MODRM_SPLITRM, 2846 },
    { MODRM_SPLITRM, 2848 },
    { MODRM_SPLITRM, 2850 },
    { MODRM_SPLITRM, 2852 },
    { MODRM_SPLITRM, 2854 },
    { MODRM_SPLITRM, 2856 },
    { MODRM_SPLITRM, 2858 },
    { MODRM_SPLITRM, 2860 },
    { MODRM_SPLITRM, 2862 },
    { MODRM_SPLITRM, 2864 },
    { MODRM_SPLITRM, 2866 },
    { MODRM_SPLITRM, 2868 },
    { MODRM_SPLITRM, 2870 },
    { MODRM_SPLITRM, 2872 },
    { MODRM_SPLITRM, 2874 },
    { MODRM_SPLITRM, 2876 },
    { MODRM_SPLITRM, 2878 },
    { MODRM_SPLITRM, 2880 },
    { MODRM_SPLITRM, 2882 },
    { MODRM_SPLITRM, 2884 },
    { MODRM_SPLITRM, 2886 },
    { MODRM_SPLITRM, 2888 },
    { MODRM_SPLITRM, 2890 },
    { MODRM_SPLITRM, 2892 },
    { MODRM_SPLITRM, 2894 },
    { MODRM_SPLITREG, 2896 },
    { MODRM_SPLITREG, 2912 },
    { MODRM_SPLITREG, 2928 },
    { MODRM_SPLITRM, 2944 },
    { MODRM_SPLITRM, 2946 },
    { MODRM_SPLITRM, 2948 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 3175 },
    { MODRM_SPLITRM, 3177 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2954 },
    { MODRM_SPLITRM, 2956 },
    { MODRM_SPLITRM, 2958 },
    { MODRM_SPLITRM, 2960 },
    { MODRM_ONEENTRY, 2962 },
    { MODRM_ONEENTRY, 2963 },
    { MODRM_ONEENTRY, 2964 },
    { MODRM_ONEENTRY, 2965 },
    { MODRM_ONEENTRY, 2966 },
    { MODRM_ONEENTRY, 2967 },
    { MODRM_ONEENTRY, 2968 },
    { MODRM_ONEENTRY, 2969 },
    { MODRM_ONEENTRY, 2970 },
    { MODRM_ONEENTRY, 2971 },
    { MODRM_ONEENTRY, 2972 },
    { MODRM_ONEENTRY, 2973 },
    { MODRM_ONEENTRY, 2974 },
    { MODRM_ONEENTRY, 2975 },
    { MODRM_ONEENTRY, 2976 },
    { MODRM_ONEENTRY, 2977 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2978 },
    { MODRM_ONEENTRY, 2979 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2980 },
    { MODRM_SPLITRM, 2982 },
    { MODRM_SPLITRM, 2984 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2986 },
    { MODRM_ONEENTRY, 2987 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2988 },
    { MODRM_SPLITRM, 2990 },
    { MODRM_SPLITRM, 2992 },
    { MODRM_SPLITMISC, 3179 },
    { MODRM_SPLITRM, 3010 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3012 },
    { MODRM_SPLITRM, 3014 },
    { MODRM_SPLITRM, 3016 },
    { MODRM_SPLITRM, 3018 },
    { MODRM_SPLITRM, 3020 },
    { MODRM_SPLITRM, 3022 },
    { MODRM_SPLITRM, 3024 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3026 },
    { MODRM_SPLITRM, 3042 },
    { MODRM_SPLITRM, 3044 },
    { MODRM_SPLITRM, 3046 },
    { MODRM_SPLITRM, 3048 },
    { MODRM_SPLITRM, 3050 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3052 },
    { MODRM_SPLITRM, 3054 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 3056 },
    { MODRM_SPLITRM, 3058 },
    { MODRM_SPLITRM, 3060 },
    { MODRM_SPLITREG, 3251 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_SPLITRM, 3079 },
    { MODRM_SPLITRM, 3081 },
    { MODRM_SPLITRM, 3083 },
    { MODRM_SPLITRM, 3085 },
    { MODRM_SPLITRM, 3087 },
    { MODRM_SPLITRM, 3089 },
    { MODRM_SPLITRM, 3091 },
    { MODRM_SPLITRM, 3093 },
    { MODRM_SPLITRM, 3095 },
    { MODRM_SPLITRM, 3097 },
    { MODRM_SPLITRM, 3099 },
    { MODRM_SPLITRM, 3101 },
    { MODRM_SPLITRM, 3103 },
    { MODRM_SPLITRM, 3105 },
    { MODRM_SPLITRM, 3107 },
    { MODRM_SPLITRM, 3109 },
    { MODRM_SPLITRM, 3111 },
    { MODRM_SPLITRM, 3113 },
    { MODRM_SPLITRM, 3115 },
    { MODRM_SPLITRM, 3117 },
    { MODRM_SPLITRM, 3119 },
    { MODRM_SPLITRM, 3121 },
    { MODRM_SPLITRM, 3123 },
    { MODRM_SPLITRM, 3125 },
    { MODRM_SPLITRM, 3127 },
    { MODRM_SPLITRM, 3129 },
    { MODRM_SPLITRM, 3131 },
    { MODRM_SPLITRM, 3133 },
    { MODRM_SPLITRM, 3135 },
    { MODRM_SPLITRM, 3137 },
    { MODRM_SPLITRM, 3139 },
    { MODRM_SPLITRM, 3141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3143 },
    { MODRM_SPLITRM, 3145 },
    { MODRM_SPLITRM, 3147 },
    { MODRM_SPLITRM, 3149 },
    { MODRM_SPLITRM, 3151 },
    { MODRM_SPLITRM, 3153 },
    { MODRM_SPLITRM, 3155 },
    { MODRM_SPLITRM, 3157 },
    { MODRM_SPLITRM, 3159 },
    { MODRM_SPLITRM, 3161 },
    { MODRM_SPLITRM, 3163 },
    { MODRM_SPLITRM, 3165 },
    { MODRM_SPLITRM, 3167 },
    { MODRM_SPLITRM, 3169 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 1766 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3267 },
    { MODRM_SPLITRM, 3269 },
    { MODRM_SPLITRM, 3271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 3273 },
    { MODRM_SPLITRM, 3275 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 1925 },
    { MODRM_SPLITRM, 1927 },
    { MODRM_SPLITRM, 1929 },
    { MODRM_SPLITRM, 1931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3277 },
    { MODRM_SPLITRM, 3279 },
    { MODRM_SPLITRM, 3281 },
    { MODRM_SPLITRM, 3283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3287 },
    { MODRM_SPLITRM, 3289 },
    { MODRM_SPLITRM, 3291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3293 },
    { MODRM_SPLITRM, 3295 },
    { MODRM_SPLITRM, 3297 },
    { MODRM_SPLITRM, 3299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3303 },
    { MODRM_SPLITRM, 3305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3307 },
    { MODRM_SPLITRM, 3309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2161 },
    { MODRM_ONEENTRY, 2162 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2314 },
    { MODRM_ONEENTRY, 2315 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITREG, 3311 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 3327 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 3329 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_SPLITRM, 3345 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3347 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 3353 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 3425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3426 },
    { MODRM_SPLITRM, 3428 },
    { MODRM_SPLITRM, 3430 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3432 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 3434 },
    { MODRM_SPLITRM, 3436 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITMISC, 3438 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 1925 },
    { MODRM_SPLITRM, 1927 },
    { MODRM_SPLITRM, 1929 },
    { MODRM_SPLITRM, 1931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3510 },
    { MODRM_SPLITRM, 3512 },
    { MODRM_SPLITRM, 3514 },
    { MODRM_SPLITRM, 3516 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3518 },
    { MODRM_SPLITRM, 3520 },
    { MODRM_SPLITRM, 3522 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3524 },
    { MODRM_SPLITRM, 3526 },
    { MODRM_SPLITRM, 3528 },
    { MODRM_SPLITRM, 3530 },
    { MODRM_SPLITRM, 3532 },
    { MODRM_SPLITRM, 3534 },
    { MODRM_SPLITRM, 3536 },
    { MODRM_SPLITRM, 3538 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3540 },
    { MODRM_SPLITRM, 3542 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3544 },
    { MODRM_SPLITRM, 3546 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2161 },
    { MODRM_ONEENTRY, 2162 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2314 },
    { MODRM_ONEENTRY, 2315 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITREG, 3548 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_SPLITRM, 3564 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_SPLITRM, 3566 },
    { MODRM_SPLITRM, 3568 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 3570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 3572 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3588 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3590 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3592 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3594 },
    { MODRM_SPLITRM, 3596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 3598 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITREG, 3614 },
    { MODRM_SPLITMISC, 3630 },
    { MODRM_SPLITRM, 3702 },
    { MODRM_SPLITRM, 3704 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 3706 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1865 },
    { MODRM_SPLITRM, 1867 },
    { MODRM_SPLITRM, 1869 },
    { MODRM_SPLITRM, 1871 },
    { MODRM_SPLITRM, 1873 },
    { MODRM_SPLITRM, 1875 },
    { MODRM_SPLITRM, 1877 },
    { MODRM_SPLITRM, 1879 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 1899 },
    { MODRM_SPLITRM, 1901 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 3707 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1933 },
    { MODRM_SPLITRM, 1935 },
    { MODRM_SPLITRM, 1937 },
    { MODRM_SPLITRM, 1939 },
    { MODRM_SPLITRM, 1941 },
    { MODRM_SPLITRM, 1943 },
    { MODRM_SPLITRM, 1945 },
    { MODRM_SPLITRM, 1947 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 3709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3710 },
    { MODRM_SPLITRM, 3712 },
    { MODRM_SPLITRM, 3714 },
    { MODRM_SPLITRM, 3716 },
    { MODRM_SPLITRM, 3718 },
    { MODRM_SPLITRM, 3720 },
    { MODRM_SPLITRM, 3722 },
    { MODRM_SPLITRM, 3724 },
    { MODRM_SPLITRM, 3726 },
    { MODRM_SPLITRM, 3728 },
    { MODRM_SPLITRM, 3730 },
    { MODRM_SPLITRM, 3732 },
    { MODRM_SPLITRM, 3734 },
    { MODRM_SPLITRM, 3736 },
    { MODRM_SPLITRM, 3738 },
    { MODRM_SPLITRM, 3740 },
    { MODRM_SPLITRM, 1988 },
    { MODRM_SPLITRM, 1990 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 1996 },
    { MODRM_SPLITRM, 1998 },
    { MODRM_SPLITRM, 2000 },
    { MODRM_SPLITRM, 2002 },
    { MODRM_SPLITRM, 2004 },
    { MODRM_SPLITRM, 2006 },
    { MODRM_SPLITRM, 2008 },
    { MODRM_SPLITRM, 2010 },
    { MODRM_SPLITRM, 2012 },
    { MODRM_SPLITRM, 2014 },
    { MODRM_SPLITRM, 2016 },
    { MODRM_SPLITRM, 2018 },
    { MODRM_SPLITRM, 2020 },
    { MODRM_SPLITRM, 2022 },
    { MODRM_SPLITRM, 2024 },
    { MODRM_SPLITRM, 2026 },
    { MODRM_SPLITRM, 2028 },
    { MODRM_SPLITRM, 2030 },
    { MODRM_SPLITRM, 2032 },
    { MODRM_SPLITRM, 2034 },
    { MODRM_SPLITRM, 2036 },
    { MODRM_SPLITRM, 2038 },
    { MODRM_SPLITRM, 2040 },
    { MODRM_SPLITRM, 2042 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3742 },
    { MODRM_SPLITRM, 2046 },
    { MODRM_SPLITRM, 2048 },
    { MODRM_SPLITREG, 2050 },
    { MODRM_SPLITREG, 2066 },
    { MODRM_SPLITREG, 2082 },
    { MODRM_SPLITRM, 2098 },
    { MODRM_SPLITRM, 2100 },
    { MODRM_SPLITRM, 2102 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 2638 },
    { MODRM_SPLITRM, 2640 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3744 },
    { MODRM_SPLITRM, 2111 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 3746 },
    { MODRM_SPLITRM, 3748 },
    { MODRM_SPLITRM, 3750 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 3752 },
    { MODRM_SPLITRM, 3754 },
    { MODRM_SPLITRM, 3756 },
    { MODRM_SPLITMISC, 3758 },
    { MODRM_SPLITRM, 3830 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3832 },
    { MODRM_SPLITRM, 3834 },
    { MODRM_SPLITRM, 3836 },
    { MODRM_SPLITRM, 3838 },
    { MODRM_SPLITRM, 3840 },
    { MODRM_SPLITRM, 3842 },
    { MODRM_SPLITRM, 3844 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3846 },
    { MODRM_SPLITRM, 3862 },
    { MODRM_SPLITRM, 3864 },
    { MODRM_SPLITRM, 3866 },
    { MODRM_SPLITRM, 3868 },
    { MODRM_SPLITRM, 3870 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3872 },
    { MODRM_SPLITRM, 2444 },
    { MODRM_SPLITRM, 3874 },
    { MODRM_SPLITRM, 2448 },
    { MODRM_SPLITRM, 2450 },
    { MODRM_SPLITRM, 2452 },
    { MODRM_SPLITREG, 3876 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2471 },
    { MODRM_SPLITRM, 2473 },
    { MODRM_SPLITRM, 2475 },
    { MODRM_SPLITRM, 2477 },
    { MODRM_SPLITRM, 2479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2481 },
    { MODRM_SPLITRM, 2483 },
    { MODRM_SPLITRM, 2485 },
    { MODRM_SPLITRM, 2487 },
    { MODRM_SPLITRM, 2489 },
    { MODRM_SPLITRM, 2491 },
    { MODRM_SPLITRM, 2493 },
    { MODRM_SPLITRM, 2495 },
    { MODRM_SPLITRM, 2497 },
    { MODRM_SPLITRM, 2499 },
    { MODRM_SPLITRM, 2501 },
    { MODRM_SPLITRM, 2503 },
    { MODRM_SPLITRM, 2505 },
    { MODRM_SPLITRM, 2507 },
    { MODRM_SPLITRM, 2509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2511 },
    { MODRM_SPLITRM, 2513 },
    { MODRM_SPLITRM, 2515 },
    { MODRM_SPLITRM, 2517 },
    { MODRM_SPLITRM, 2519 },
    { MODRM_SPLITRM, 2521 },
    { MODRM_SPLITRM, 2523 },
    { MODRM_SPLITRM, 2525 },
    { MODRM_SPLITRM, 2527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2529 },
    { MODRM_SPLITRM, 2531 },
    { MODRM_SPLITRM, 2533 },
    { MODRM_SPLITRM, 2535 },
    { MODRM_SPLITRM, 2537 },
    { MODRM_SPLITRM, 2539 },
    { MODRM_SPLITRM, 2646 },
    { MODRM_SPLITRM, 2543 },
    { MODRM_SPLITRM, 2545 },
    { MODRM_SPLITRM, 2547 },
    { MODRM_SPLITRM, 2549 },
    { MODRM_SPLITRM, 2551 },
    { MODRM_SPLITRM, 2553 },
    { MODRM_SPLITRM, 2555 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 3614 },
    { MODRM_SPLITMISC, 3630 },
    { MODRM_SPLITRM, 3702 },
    { MODRM_SPLITRM, 3704 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 3706 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2740 },
    { MODRM_SPLITRM, 2742 },
    { MODRM_SPLITRM, 3171 },
    { MODRM_SPLITRM, 2746 },
    { MODRM_SPLITRM, 2748 },
    { MODRM_SPLITRM, 2750 },
    { MODRM_SPLITRM, 3173 },
    { MODRM_SPLITRM, 2754 },
    { MODRM_SPLITREG, 2756 },
    { MODRM_SPLITRM, 2772 },
    { MODRM_SPLITRM, 3893 },
    { MODRM_SPLITRM, 3895 },
    { MODRM_SPLITRM, 2778 },
    { MODRM_SPLITRM, 2780 },
    { MODRM_SPLITRM, 2782 },
    { MODRM_SPLITRM, 3707 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2786 },
    { MODRM_SPLITRM, 2788 },
    { MODRM_SPLITRM, 2790 },
    { MODRM_SPLITRM, 2792 },
    { MODRM_SPLITRM, 2794 },
    { MODRM_SPLITRM, 2796 },
    { MODRM_SPLITRM, 2798 },
    { MODRM_SPLITRM, 2800 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 3709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3710 },
    { MODRM_SPLITRM, 3712 },
    { MODRM_SPLITRM, 3714 },
    { MODRM_SPLITRM, 3716 },
    { MODRM_SPLITRM, 3718 },
    { MODRM_SPLITRM, 3720 },
    { MODRM_SPLITRM, 3722 },
    { MODRM_SPLITRM, 3724 },
    { MODRM_SPLITRM, 3726 },
    { MODRM_SPLITRM, 3728 },
    { MODRM_SPLITRM, 3730 },
    { MODRM_SPLITRM, 3732 },
    { MODRM_SPLITRM, 3734 },
    { MODRM_SPLITRM, 3736 },
    { MODRM_SPLITRM, 3738 },
    { MODRM_SPLITRM, 3740 },
    { MODRM_SPLITRM, 2834 },
    { MODRM_SPLITRM, 2836 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 2838 },
    { MODRM_SPLITRM, 2840 },
    { MODRM_SPLITRM, 2842 },
    { MODRM_SPLITRM, 2844 },
    { MODRM_SPLITRM, 2846 },
    { MODRM_SPLITRM, 2848 },
    { MODRM_SPLITRM, 2850 },
    { MODRM_SPLITRM, 2852 },
    { MODRM_SPLITRM, 2854 },
    { MODRM_SPLITRM, 2856 },
    { MODRM_SPLITRM, 2858 },
    { MODRM_SPLITRM, 2860 },
    { MODRM_SPLITRM, 2862 },
    { MODRM_SPLITRM, 2864 },
    { MODRM_SPLITRM, 2866 },
    { MODRM_SPLITRM, 2868 },
    { MODRM_SPLITRM, 2870 },
    { MODRM_SPLITRM, 2872 },
    { MODRM_SPLITRM, 2874 },
    { MODRM_SPLITRM, 2876 },
    { MODRM_SPLITRM, 2878 },
    { MODRM_SPLITRM, 2880 },
    { MODRM_SPLITRM, 2882 },
    { MODRM_SPLITRM, 2884 },
    { MODRM_SPLITRM, 2886 },
    { MODRM_SPLITRM, 2888 },
    { MODRM_SPLITRM, 3742 },
    { MODRM_SPLITRM, 2892 },
    { MODRM_SPLITRM, 2894 },
    { MODRM_SPLITREG, 2896 },
    { MODRM_SPLITREG, 2912 },
    { MODRM_SPLITREG, 2928 },
    { MODRM_SPLITRM, 2944 },
    { MODRM_SPLITRM, 2946 },
    { MODRM_SPLITRM, 2948 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 3897 },
    { MODRM_SPLITRM, 3899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2954 },
    { MODRM_SPLITRM, 2956 },
    { MODRM_SPLITRM, 3744 },
    { MODRM_SPLITRM, 2960 },
    { MODRM_ONEENTRY, 2962 },
    { MODRM_ONEENTRY, 2963 },
    { MODRM_ONEENTRY, 2964 },
    { MODRM_ONEENTRY, 2965 },
    { MODRM_ONEENTRY, 2966 },
    { MODRM_ONEENTRY, 2967 },
    { MODRM_ONEENTRY, 2968 },
    { MODRM_ONEENTRY, 2969 },
    { MODRM_ONEENTRY, 2970 },
    { MODRM_ONEENTRY, 2971 },
    { MODRM_ONEENTRY, 2972 },
    { MODRM_ONEENTRY, 2973 },
    { MODRM_ONEENTRY, 2974 },
    { MODRM_ONEENTRY, 2975 },
    { MODRM_ONEENTRY, 2976 },
    { MODRM_ONEENTRY, 2977 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2978 },
    { MODRM_ONEENTRY, 2979 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 3746 },
    { MODRM_SPLITRM, 3748 },
    { MODRM_SPLITRM, 3750 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2986 },
    { MODRM_ONEENTRY, 2987 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 3752 },
    { MODRM_SPLITRM, 3754 },
    { MODRM_SPLITRM, 3756 },
    { MODRM_SPLITMISC, 3901 },
    { MODRM_SPLITRM, 3830 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3832 },
    { MODRM_SPLITRM, 3834 },
    { MODRM_SPLITRM, 3836 },
    { MODRM_SPLITRM, 3838 },
    { MODRM_SPLITRM, 3840 },
    { MODRM_SPLITRM, 3842 },
    { MODRM_SPLITRM, 3844 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3846 },
    { MODRM_SPLITRM, 3862 },
    { MODRM_SPLITRM, 3864 },
    { MODRM_SPLITRM, 3866 },
    { MODRM_SPLITRM, 3868 },
    { MODRM_SPLITRM, 3870 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3872 },
    { MODRM_SPLITRM, 3054 },
    { MODRM_SPLITRM, 3874 },
    { MODRM_SPLITRM, 3056 },
    { MODRM_SPLITRM, 3058 },
    { MODRM_SPLITRM, 3060 },
    { MODRM_SPLITREG, 3973 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_SPLITRM, 3079 },
    { MODRM_SPLITRM, 3081 },
    { MODRM_SPLITRM, 3083 },
    { MODRM_SPLITRM, 3085 },
    { MODRM_SPLITRM, 3087 },
    { MODRM_SPLITRM, 3089 },
    { MODRM_SPLITRM, 3091 },
    { MODRM_SPLITRM, 3093 },
    { MODRM_SPLITRM, 3095 },
    { MODRM_SPLITRM, 3097 },
    { MODRM_SPLITRM, 3099 },
    { MODRM_SPLITRM, 3101 },
    { MODRM_SPLITRM, 3103 },
    { MODRM_SPLITRM, 3105 },
    { MODRM_SPLITRM, 3107 },
    { MODRM_SPLITRM, 3109 },
    { MODRM_SPLITRM, 3111 },
    { MODRM_SPLITRM, 3113 },
    { MODRM_SPLITRM, 3115 },
    { MODRM_SPLITRM, 3117 },
    { MODRM_SPLITRM, 3119 },
    { MODRM_SPLITRM, 3121 },
    { MODRM_SPLITRM, 3123 },
    { MODRM_SPLITRM, 3125 },
    { MODRM_SPLITRM, 3127 },
    { MODRM_SPLITRM, 3129 },
    { MODRM_SPLITRM, 3131 },
    { MODRM_SPLITRM, 3133 },
    { MODRM_SPLITRM, 3135 },
    { MODRM_SPLITRM, 3137 },
    { MODRM_SPLITRM, 3139 },
    { MODRM_SPLITRM, 3141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3143 },
    { MODRM_SPLITRM, 3145 },
    { MODRM_SPLITRM, 3147 },
    { MODRM_SPLITRM, 3149 },
    { MODRM_SPLITRM, 3151 },
    { MODRM_SPLITRM, 3153 },
    { MODRM_SPLITRM, 3989 },
    { MODRM_SPLITRM, 3157 },
    { MODRM_SPLITRM, 3159 },
    { MODRM_SPLITRM, 3161 },
    { MODRM_SPLITRM, 3163 },
    { MODRM_SPLITRM, 3165 },
    { MODRM_SPLITRM, 3167 },
    { MODRM_SPLITRM, 3169 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 2648 },
    { MODRM_SPLITMISC, 3991 },
    { MODRM_SPLITRM, 2736 },
    { MODRM_SPLITRM, 2738 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2740 },
    { MODRM_SPLITRM, 2742 },
    { MODRM_SPLITRM, 2744 },
    { MODRM_SPLITRM, 2746 },
    { MODRM_SPLITRM, 2748 },
    { MODRM_SPLITRM, 2750 },
    { MODRM_SPLITRM, 2752 },
    { MODRM_SPLITRM, 2754 },
    { MODRM_SPLITREG, 2756 },
    { MODRM_SPLITRM, 2772 },
    { MODRM_SPLITRM, 3893 },
    { MODRM_SPLITRM, 3895 },
    { MODRM_SPLITRM, 2778 },
    { MODRM_SPLITRM, 2780 },
    { MODRM_SPLITRM, 2782 },
    { MODRM_SPLITRM, 2784 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2786 },
    { MODRM_SPLITRM, 2788 },
    { MODRM_SPLITRM, 2790 },
    { MODRM_SPLITRM, 2792 },
    { MODRM_SPLITRM, 2794 },
    { MODRM_SPLITRM, 2796 },
    { MODRM_SPLITRM, 2798 },
    { MODRM_SPLITRM, 2800 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2802 },
    { MODRM_SPLITRM, 2804 },
    { MODRM_SPLITRM, 2806 },
    { MODRM_SPLITRM, 2808 },
    { MODRM_SPLITRM, 2810 },
    { MODRM_SPLITRM, 2812 },
    { MODRM_SPLITRM, 2814 },
    { MODRM_SPLITRM, 2816 },
    { MODRM_SPLITRM, 2818 },
    { MODRM_SPLITRM, 2820 },
    { MODRM_SPLITRM, 2822 },
    { MODRM_SPLITRM, 2824 },
    { MODRM_SPLITRM, 2826 },
    { MODRM_SPLITRM, 2828 },
    { MODRM_SPLITRM, 2830 },
    { MODRM_SPLITRM, 2832 },
    { MODRM_SPLITRM, 2834 },
    { MODRM_SPLITRM, 2836 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2838 },
    { MODRM_SPLITRM, 2840 },
    { MODRM_SPLITRM, 2842 },
    { MODRM_SPLITRM, 2844 },
    { MODRM_SPLITRM, 2846 },
    { MODRM_SPLITRM, 2848 },
    { MODRM_SPLITRM, 2850 },
    { MODRM_SPLITRM, 2852 },
    { MODRM_SPLITRM, 2854 },
    { MODRM_SPLITRM, 2856 },
    { MODRM_SPLITRM, 2858 },
    { MODRM_SPLITRM, 2860 },
    { MODRM_SPLITRM, 2862 },
    { MODRM_SPLITRM, 2864 },
    { MODRM_SPLITRM, 2866 },
    { MODRM_SPLITRM, 2868 },
    { MODRM_SPLITRM, 2870 },
    { MODRM_SPLITRM, 2872 },
    { MODRM_SPLITRM, 2874 },
    { MODRM_SPLITRM, 2876 },
    { MODRM_SPLITRM, 2878 },
    { MODRM_SPLITRM, 2880 },
    { MODRM_SPLITRM, 2882 },
    { MODRM_SPLITRM, 2884 },
    { MODRM_SPLITRM, 2886 },
    { MODRM_SPLITRM, 2888 },
    { MODRM_SPLITRM, 2890 },
    { MODRM_SPLITRM, 2892 },
    { MODRM_SPLITRM, 2894 },
    { MODRM_SPLITREG, 2896 },
    { MODRM_SPLITREG, 2912 },
    { MODRM_SPLITREG, 2928 },
    { MODRM_SPLITRM, 2944 },
    { MODRM_SPLITRM, 2946 },
    { MODRM_SPLITRM, 2948 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2950 },
    { MODRM_SPLITRM, 2952 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2954 },
    { MODRM_SPLITRM, 2956 },
    { MODRM_SPLITRM, 2958 },
    { MODRM_SPLITRM, 2960 },
    { MODRM_ONEENTRY, 2962 },
    { MODRM_ONEENTRY, 2963 },
    { MODRM_ONEENTRY, 2964 },
    { MODRM_ONEENTRY, 2965 },
    { MODRM_ONEENTRY, 2966 },
    { MODRM_ONEENTRY, 2967 },
    { MODRM_ONEENTRY, 2968 },
    { MODRM_ONEENTRY, 2969 },
    { MODRM_ONEENTRY, 2970 },
    { MODRM_ONEENTRY, 2971 },
    { MODRM_ONEENTRY, 2972 },
    { MODRM_ONEENTRY, 2973 },
    { MODRM_ONEENTRY, 2974 },
    { MODRM_ONEENTRY, 2975 },
    { MODRM_ONEENTRY, 2976 },
    { MODRM_ONEENTRY, 2977 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2978 },
    { MODRM_ONEENTRY, 2979 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2980 },
    { MODRM_SPLITRM, 2982 },
    { MODRM_SPLITRM, 2984 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2986 },
    { MODRM_ONEENTRY, 2987 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2988 },
    { MODRM_SPLITRM, 2990 },
    { MODRM_SPLITRM, 2992 },
    { MODRM_SPLITREG, 2994 },
    { MODRM_SPLITRM, 3010 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3012 },
    { MODRM_SPLITRM, 3014 },
    { MODRM_SPLITRM, 3016 },
    { MODRM_SPLITRM, 3018 },
    { MODRM_SPLITRM, 3020 },
    { MODRM_SPLITRM, 3022 },
    { MODRM_SPLITRM, 3024 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3026 },
    { MODRM_SPLITRM, 3042 },
    { MODRM_SPLITRM, 3044 },
    { MODRM_SPLITRM, 3046 },
    { MODRM_SPLITRM, 3048 },
    { MODRM_SPLITRM, 3050 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3052 },
    { MODRM_SPLITRM, 3054 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3056 },
    { MODRM_SPLITRM, 3058 },
    { MODRM_SPLITRM, 3060 },
    { MODRM_SPLITREG, 3062 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_SPLITRM, 3079 },
    { MODRM_SPLITRM, 3081 },
    { MODRM_SPLITRM, 3083 },
    { MODRM_SPLITRM, 3085 },
    { MODRM_SPLITRM, 3087 },
    { MODRM_SPLITRM, 3089 },
    { MODRM_SPLITRM, 3091 },
    { MODRM_SPLITRM, 3093 },
    { MODRM_SPLITRM, 3095 },
    { MODRM_SPLITRM, 3097 },
    { MODRM_SPLITRM, 3099 },
    { MODRM_SPLITRM, 3101 },
    { MODRM_SPLITRM, 3103 },
    { MODRM_SPLITRM, 3105 },
    { MODRM_SPLITRM, 3107 },
    { MODRM_SPLITRM, 3109 },
    { MODRM_SPLITRM, 3111 },
    { MODRM_SPLITRM, 3113 },
    { MODRM_SPLITRM, 3115 },
    { MODRM_SPLITRM, 3117 },
    { MODRM_SPLITRM, 3119 },
    { MODRM_SPLITRM, 3121 },
    { MODRM_SPLITRM, 3123 },
    { MODRM_SPLITRM, 3125 },
    { MODRM_SPLITRM, 3127 },
    { MODRM_SPLITRM, 3129 },
    { MODRM_SPLITRM, 3131 },
    { MODRM_SPLITRM, 3133 },
    { MODRM_SPLITRM, 3135 },
    { MODRM_SPLITRM, 3137 },
    { MODRM_SPLITRM, 3139 },
    { MODRM_SPLITRM, 3141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3143 },
    { MODRM_SPLITRM, 3145 },
    { MODRM_SPLITRM, 3147 },
    { MODRM_SPLITRM, 3149 },
    { MODRM_SPLITRM, 3151 },
    { MODRM_SPLITRM, 3153 },
    { MODRM_SPLITRM, 3989 },
    { MODRM_SPLITRM, 3157 },
    { MODRM_SPLITRM, 3159 },
    { MODRM_SPLITRM, 3161 },
    { MODRM_SPLITRM, 3163 },
    { MODRM_SPLITRM, 3165 },
    { MODRM_SPLITRM, 3167 },
    { MODRM_SPLITRM, 3169 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 2558 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1865 },
    { MODRM_SPLITRM, 1867 },
    { MODRM_SPLITRM, 1869 },
    { MODRM_SPLITRM, 1871 },
    { MODRM_SPLITRM, 1873 },
    { MODRM_SPLITRM, 1875 },
    { MODRM_SPLITRM, 1877 },
    { MODRM_SPLITRM, 1879 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 1899 },
    { MODRM_SPLITRM, 1901 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1933 },
    { MODRM_SPLITRM, 1935 },
    { MODRM_SPLITRM, 1937 },
    { MODRM_SPLITRM, 1939 },
    { MODRM_SPLITRM, 1941 },
    { MODRM_SPLITRM, 1943 },
    { MODRM_SPLITRM, 1945 },
    { MODRM_SPLITRM, 1947 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_SPLITRM, 1988 },
    { MODRM_SPLITRM, 1990 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 1996 },
    { MODRM_SPLITRM, 1998 },
    { MODRM_SPLITRM, 2000 },
    { MODRM_SPLITRM, 2002 },
    { MODRM_SPLITRM, 2004 },
    { MODRM_SPLITRM, 2006 },
    { MODRM_SPLITRM, 2008 },
    { MODRM_SPLITRM, 2010 },
    { MODRM_SPLITRM, 2012 },
    { MODRM_SPLITRM, 2014 },
    { MODRM_SPLITRM, 2016 },
    { MODRM_SPLITRM, 2018 },
    { MODRM_SPLITRM, 2020 },
    { MODRM_SPLITRM, 2022 },
    { MODRM_SPLITRM, 2024 },
    { MODRM_SPLITRM, 2026 },
    { MODRM_SPLITRM, 2028 },
    { MODRM_SPLITRM, 2030 },
    { MODRM_SPLITRM, 2032 },
    { MODRM_SPLITRM, 2034 },
    { MODRM_SPLITRM, 2036 },
    { MODRM_SPLITRM, 2038 },
    { MODRM_SPLITRM, 2040 },
    { MODRM_SPLITRM, 2042 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2044 },
    { MODRM_SPLITRM, 2046 },
    { MODRM_SPLITRM, 2048 },
    { MODRM_SPLITREG, 2050 },
    { MODRM_SPLITREG, 2066 },
    { MODRM_SPLITREG, 2082 },
    { MODRM_SPLITRM, 2098 },
    { MODRM_SPLITRM, 2100 },
    { MODRM_SPLITRM, 2102 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 2638 },
    { MODRM_SPLITRM, 2640 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2109 },
    { MODRM_SPLITRM, 2111 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITMISC, 2323 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_SPLITRM, 2432 },
    { MODRM_SPLITRM, 2434 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 2444 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 2448 },
    { MODRM_SPLITRM, 2450 },
    { MODRM_SPLITRM, 2452 },
    { MODRM_SPLITREG, 2454 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2471 },
    { MODRM_SPLITRM, 2473 },
    { MODRM_SPLITRM, 2475 },
    { MODRM_SPLITRM, 2477 },
    { MODRM_SPLITRM, 2479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2481 },
    { MODRM_SPLITRM, 2483 },
    { MODRM_SPLITRM, 2485 },
    { MODRM_SPLITRM, 2487 },
    { MODRM_SPLITRM, 2489 },
    { MODRM_SPLITRM, 2491 },
    { MODRM_SPLITRM, 2493 },
    { MODRM_SPLITRM, 2495 },
    { MODRM_SPLITRM, 2497 },
    { MODRM_SPLITRM, 2499 },
    { MODRM_SPLITRM, 2501 },
    { MODRM_SPLITRM, 2503 },
    { MODRM_SPLITRM, 2505 },
    { MODRM_SPLITRM, 2507 },
    { MODRM_SPLITRM, 2509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2511 },
    { MODRM_SPLITRM, 2513 },
    { MODRM_SPLITRM, 2515 },
    { MODRM_SPLITRM, 2517 },
    { MODRM_SPLITRM, 2519 },
    { MODRM_SPLITRM, 2521 },
    { MODRM_SPLITRM, 2523 },
    { MODRM_SPLITRM, 2525 },
    { MODRM_SPLITRM, 2527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2529 },
    { MODRM_SPLITRM, 2531 },
    { MODRM_SPLITRM, 2533 },
    { MODRM_SPLITRM, 2535 },
    { MODRM_SPLITRM, 2537 },
    { MODRM_SPLITRM, 2539 },
    { MODRM_SPLITRM, 2646 },
    { MODRM_SPLITRM, 2543 },
    { MODRM_SPLITRM, 2545 },
    { MODRM_SPLITRM, 2547 },
    { MODRM_SPLITRM, 2549 },
    { MODRM_SPLITRM, 2551 },
    { MODRM_SPLITRM, 2553 },
    { MODRM_SPLITRM, 2555 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 2648 },
    { MODRM_SPLITMISC, 3991 },
    { MODRM_SPLITRM, 2736 },
    { MODRM_SPLITRM, 2738 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2740 },
    { MODRM_SPLITRM, 2742 },
    { MODRM_SPLITRM, 3171 },
    { MODRM_SPLITRM, 2746 },
    { MODRM_SPLITRM, 2748 },
    { MODRM_SPLITRM, 2750 },
    { MODRM_SPLITRM, 3173 },
    { MODRM_SPLITRM, 2754 },
    { MODRM_SPLITREG, 2756 },
    { MODRM_SPLITRM, 2772 },
    { MODRM_SPLITRM, 3893 },
    { MODRM_SPLITRM, 3895 },
    { MODRM_SPLITRM, 2778 },
    { MODRM_SPLITRM, 2780 },
    { MODRM_SPLITRM, 2782 },
    { MODRM_SPLITRM, 2784 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2786 },
    { MODRM_SPLITRM, 2788 },
    { MODRM_SPLITRM, 2790 },
    { MODRM_SPLITRM, 2792 },
    { MODRM_SPLITRM, 2794 },
    { MODRM_SPLITRM, 2796 },
    { MODRM_SPLITRM, 2798 },
    { MODRM_SPLITRM, 2800 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2802 },
    { MODRM_SPLITRM, 2804 },
    { MODRM_SPLITRM, 2806 },
    { MODRM_SPLITRM, 2808 },
    { MODRM_SPLITRM, 2810 },
    { MODRM_SPLITRM, 2812 },
    { MODRM_SPLITRM, 2814 },
    { MODRM_SPLITRM, 2816 },
    { MODRM_SPLITRM, 2818 },
    { MODRM_SPLITRM, 2820 },
    { MODRM_SPLITRM, 2822 },
    { MODRM_SPLITRM, 2824 },
    { MODRM_SPLITRM, 2826 },
    { MODRM_SPLITRM, 2828 },
    { MODRM_SPLITRM, 2830 },
    { MODRM_SPLITRM, 2832 },
    { MODRM_SPLITRM, 2834 },
    { MODRM_SPLITRM, 2836 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 2838 },
    { MODRM_SPLITRM, 2840 },
    { MODRM_SPLITRM, 2842 },
    { MODRM_SPLITRM, 2844 },
    { MODRM_SPLITRM, 2846 },
    { MODRM_SPLITRM, 2848 },
    { MODRM_SPLITRM, 2850 },
    { MODRM_SPLITRM, 2852 },
    { MODRM_SPLITRM, 2854 },
    { MODRM_SPLITRM, 2856 },
    { MODRM_SPLITRM, 2858 },
    { MODRM_SPLITRM, 2860 },
    { MODRM_SPLITRM, 2862 },
    { MODRM_SPLITRM, 2864 },
    { MODRM_SPLITRM, 2866 },
    { MODRM_SPLITRM, 2868 },
    { MODRM_SPLITRM, 2870 },
    { MODRM_SPLITRM, 2872 },
    { MODRM_SPLITRM, 2874 },
    { MODRM_SPLITRM, 2876 },
    { MODRM_SPLITRM, 2878 },
    { MODRM_SPLITRM, 2880 },
    { MODRM_SPLITRM, 2882 },
    { MODRM_SPLITRM, 2884 },
    { MODRM_SPLITRM, 2886 },
    { MODRM_SPLITRM, 2888 },
    { MODRM_SPLITRM, 2890 },
    { MODRM_SPLITRM, 2892 },
    { MODRM_SPLITRM, 2894 },
    { MODRM_SPLITREG, 2896 },
    { MODRM_SPLITREG, 2912 },
    { MODRM_SPLITREG, 2928 },
    { MODRM_SPLITRM, 2944 },
    { MODRM_SPLITRM, 2946 },
    { MODRM_SPLITRM, 2948 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 3897 },
    { MODRM_SPLITRM, 3899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2954 },
    { MODRM_SPLITRM, 2956 },
    { MODRM_SPLITRM, 2958 },
    { MODRM_SPLITRM, 2960 },
    { MODRM_ONEENTRY, 2962 },
    { MODRM_ONEENTRY, 2963 },
    { MODRM_ONEENTRY, 2964 },
    { MODRM_ONEENTRY, 2965 },
    { MODRM_ONEENTRY, 2966 },
    { MODRM_ONEENTRY, 2967 },
    { MODRM_ONEENTRY, 2968 },
    { MODRM_ONEENTRY, 2969 },
    { MODRM_ONEENTRY, 2970 },
    { MODRM_ONEENTRY, 2971 },
    { MODRM_ONEENTRY, 2972 },
    { MODRM_ONEENTRY, 2973 },
    { MODRM_ONEENTRY, 2974 },
    { MODRM_ONEENTRY, 2975 },
    { MODRM_ONEENTRY, 2976 },
    { MODRM_ONEENTRY, 2977 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2978 },
    { MODRM_ONEENTRY, 2979 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2980 },
    { MODRM_SPLITRM, 2982 },
    { MODRM_SPLITRM, 2984 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2986 },
    { MODRM_ONEENTRY, 2987 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2988 },
    { MODRM_SPLITRM, 2990 },
    { MODRM_SPLITRM, 2992 },
    { MODRM_SPLITMISC, 3179 },
    { MODRM_SPLITRM, 3010 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3012 },
    { MODRM_SPLITRM, 3014 },
    { MODRM_SPLITRM, 3016 },
    { MODRM_SPLITRM, 3018 },
    { MODRM_SPLITRM, 3020 },
    { MODRM_SPLITRM, 3022 },
    { MODRM_SPLITRM, 3024 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3026 },
    { MODRM_SPLITRM, 3042 },
    { MODRM_SPLITRM, 3044 },
    { MODRM_SPLITRM, 3046 },
    { MODRM_SPLITRM, 3048 },
    { MODRM_SPLITRM, 3050 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3052 },
    { MODRM_SPLITRM, 3054 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 3056 },
    { MODRM_SPLITRM, 3058 },
    { MODRM_SPLITRM, 3060 },
    { MODRM_SPLITREG, 3251 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_ONEENTRY, 3078 },
    { MODRM_SPLITRM, 3079 },
    { MODRM_SPLITRM, 3081 },
    { MODRM_SPLITRM, 3083 },
    { MODRM_SPLITRM, 3085 },
    { MODRM_SPLITRM, 3087 },
    { MODRM_SPLITRM, 3089 },
    { MODRM_SPLITRM, 3091 },
    { MODRM_SPLITRM, 3093 },
    { MODRM_SPLITRM, 3095 },
    { MODRM_SPLITRM, 3097 },
    { MODRM_SPLITRM, 3099 },
    { MODRM_SPLITRM, 3101 },
    { MODRM_SPLITRM, 3103 },
    { MODRM_SPLITRM, 3105 },
    { MODRM_SPLITRM, 3107 },
    { MODRM_SPLITRM, 3109 },
    { MODRM_SPLITRM, 3111 },
    { MODRM_SPLITRM, 3113 },
    { MODRM_SPLITRM, 3115 },
    { MODRM_SPLITRM, 3117 },
    { MODRM_SPLITRM, 3119 },
    { MODRM_SPLITRM, 3121 },
    { MODRM_SPLITRM, 3123 },
    { MODRM_SPLITRM, 3125 },
    { MODRM_SPLITRM, 3127 },
    { MODRM_SPLITRM, 3129 },
    { MODRM_SPLITRM, 3131 },
    { MODRM_SPLITRM, 3133 },
    { MODRM_SPLITRM, 3135 },
    { MODRM_SPLITRM, 3137 },
    { MODRM_SPLITRM, 3139 },
    { MODRM_SPLITRM, 3141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3143 },
    { MODRM_SPLITRM, 3145 },
    { MODRM_SPLITRM, 3147 },
    { MODRM_SPLITRM, 3149 },
    { MODRM_SPLITRM, 3151 },
    { MODRM_SPLITRM, 3153 },
    { MODRM_SPLITRM, 3989 },
    { MODRM_SPLITRM, 3157 },
    { MODRM_SPLITRM, 3159 },
    { MODRM_SPLITRM, 3161 },
    { MODRM_SPLITRM, 3163 },
    { MODRM_SPLITRM, 3165 },
    { MODRM_SPLITRM, 3167 },
    { MODRM_SPLITRM, 3169 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 2558 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3267 },
    { MODRM_SPLITRM, 3269 },
    { MODRM_SPLITRM, 3271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 4063 },
    { MODRM_SPLITRM, 4065 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3277 },
    { MODRM_SPLITRM, 3279 },
    { MODRM_SPLITRM, 3281 },
    { MODRM_SPLITRM, 3283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3287 },
    { MODRM_SPLITRM, 3289 },
    { MODRM_SPLITRM, 3291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3293 },
    { MODRM_SPLITRM, 3295 },
    { MODRM_SPLITRM, 3297 },
    { MODRM_SPLITRM, 3299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3303 },
    { MODRM_SPLITRM, 3305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3307 },
    { MODRM_SPLITRM, 3309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITREG, 3311 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 3327 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 3329 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_SPLITRM, 3345 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3347 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 4067 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 3425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3426 },
    { MODRM_SPLITRM, 3428 },
    { MODRM_SPLITRM, 3430 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3432 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 4139 },
    { MODRM_SPLITRM, 4141 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITMISC, 3438 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3510 },
    { MODRM_SPLITRM, 3512 },
    { MODRM_SPLITRM, 3514 },
    { MODRM_SPLITRM, 3516 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3518 },
    { MODRM_SPLITRM, 3520 },
    { MODRM_SPLITRM, 3522 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3524 },
    { MODRM_SPLITRM, 3526 },
    { MODRM_SPLITRM, 3528 },
    { MODRM_SPLITRM, 3530 },
    { MODRM_SPLITRM, 3532 },
    { MODRM_SPLITRM, 3534 },
    { MODRM_SPLITRM, 3536 },
    { MODRM_SPLITRM, 3538 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3540 },
    { MODRM_SPLITRM, 3542 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3544 },
    { MODRM_SPLITRM, 3546 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITREG, 4143 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_SPLITRM, 3564 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_SPLITRM, 3566 },
    { MODRM_SPLITRM, 3568 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 3570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 4159 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3588 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3590 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3592 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3594 },
    { MODRM_SPLITRM, 3596 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 2558 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3267 },
    { MODRM_SPLITRM, 3269 },
    { MODRM_SPLITRM, 3271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 4063 },
    { MODRM_SPLITRM, 4065 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3277 },
    { MODRM_SPLITRM, 3279 },
    { MODRM_SPLITRM, 3281 },
    { MODRM_SPLITRM, 3283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3287 },
    { MODRM_SPLITRM, 3289 },
    { MODRM_SPLITRM, 3291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3293 },
    { MODRM_SPLITRM, 3295 },
    { MODRM_SPLITRM, 3297 },
    { MODRM_SPLITRM, 3299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3303 },
    { MODRM_SPLITRM, 3305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3307 },
    { MODRM_SPLITRM, 3309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITREG, 3311 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 3327 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 3329 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_SPLITRM, 3345 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3347 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 1750 },
    { MODRM_SPLITMISC, 4067 },
    { MODRM_SPLITRM, 1838 },
    { MODRM_SPLITRM, 1840 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 1844 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 3425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3426 },
    { MODRM_SPLITRM, 3428 },
    { MODRM_SPLITRM, 3430 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3432 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 4139 },
    { MODRM_SPLITRM, 4141 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITMISC, 3438 },
    { MODRM_SPLITRM, 1923 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3510 },
    { MODRM_SPLITRM, 3512 },
    { MODRM_SPLITRM, 3514 },
    { MODRM_SPLITRM, 3516 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 1954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1956 },
    { MODRM_SPLITRM, 1958 },
    { MODRM_SPLITRM, 1960 },
    { MODRM_SPLITRM, 1962 },
    { MODRM_SPLITRM, 1964 },
    { MODRM_SPLITRM, 1966 },
    { MODRM_SPLITRM, 1968 },
    { MODRM_SPLITRM, 1970 },
    { MODRM_SPLITRM, 1972 },
    { MODRM_SPLITRM, 1974 },
    { MODRM_SPLITRM, 1976 },
    { MODRM_SPLITRM, 1978 },
    { MODRM_SPLITRM, 1980 },
    { MODRM_SPLITRM, 1982 },
    { MODRM_SPLITRM, 1984 },
    { MODRM_SPLITRM, 1986 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3518 },
    { MODRM_SPLITRM, 3520 },
    { MODRM_SPLITRM, 3522 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3524 },
    { MODRM_SPLITRM, 3526 },
    { MODRM_SPLITRM, 3528 },
    { MODRM_SPLITRM, 3530 },
    { MODRM_SPLITRM, 3532 },
    { MODRM_SPLITRM, 3534 },
    { MODRM_SPLITRM, 3536 },
    { MODRM_SPLITRM, 3538 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3540 },
    { MODRM_SPLITRM, 3542 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3544 },
    { MODRM_SPLITRM, 3546 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 2164 },
    { MODRM_SPLITRM, 2166 },
    { MODRM_SPLITRM, 2168 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 2317 },
    { MODRM_SPLITRM, 2319 },
    { MODRM_SPLITRM, 2321 },
    { MODRM_SPLITREG, 4175 },
    { MODRM_SPLITRM, 2395 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 2399 },
    { MODRM_SPLITRM, 2401 },
    { MODRM_SPLITRM, 2403 },
    { MODRM_SPLITRM, 2405 },
    { MODRM_SPLITRM, 2407 },
    { MODRM_SPLITRM, 2409 },
    { MODRM_SPLITRM, 2411 },
    { MODRM_SPLITRM, 3564 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 2414 },
    { MODRM_SPLITRM, 2430 },
    { MODRM_SPLITRM, 3566 },
    { MODRM_SPLITRM, 3568 },
    { MODRM_SPLITRM, 2436 },
    { MODRM_SPLITRM, 2438 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 2442 },
    { MODRM_SPLITRM, 3570 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 4159 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 2470 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3588 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3590 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 3614 },
    { MODRM_SPLITMISC, 4191 },
    { MODRM_SPLITRM, 3702 },
    { MODRM_SPLITRM, 3704 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 3706 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 3425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3426 },
    { MODRM_SPLITRM, 3428 },
    { MODRM_SPLITRM, 3430 },
    { MODRM_SPLITRM, 1871 },
    { MODRM_SPLITRM, 1873 },
    { MODRM_SPLITRM, 1875 },
    { MODRM_SPLITRM, 3432 },
    { MODRM_SPLITRM, 1879 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 4139 },
    { MODRM_SPLITRM, 4141 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITMISC, 4263 },
    { MODRM_SPLITRM, 3707 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1933 },
    { MODRM_SPLITRM, 1935 },
    { MODRM_SPLITRM, 4335 },
    { MODRM_SPLITRM, 3512 },
    { MODRM_SPLITRM, 4337 },
    { MODRM_SPLITRM, 4339 },
    { MODRM_SPLITRM, 1945 },
    { MODRM_SPLITRM, 1947 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 3709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3710 },
    { MODRM_SPLITRM, 3712 },
    { MODRM_SPLITRM, 3714 },
    { MODRM_SPLITRM, 3716 },
    { MODRM_SPLITRM, 3718 },
    { MODRM_SPLITRM, 3720 },
    { MODRM_SPLITRM, 3722 },
    { MODRM_SPLITRM, 3724 },
    { MODRM_SPLITRM, 3726 },
    { MODRM_SPLITRM, 3728 },
    { MODRM_SPLITRM, 3730 },
    { MODRM_SPLITRM, 3732 },
    { MODRM_SPLITRM, 3734 },
    { MODRM_SPLITRM, 3736 },
    { MODRM_SPLITRM, 3738 },
    { MODRM_SPLITRM, 3740 },
    { MODRM_SPLITRM, 1988 },
    { MODRM_SPLITRM, 3518 },
    { MODRM_SPLITRM, 3520 },
    { MODRM_SPLITRM, 3522 },
    { MODRM_SPLITRM, 1996 },
    { MODRM_SPLITRM, 1998 },
    { MODRM_SPLITRM, 2000 },
    { MODRM_SPLITRM, 2002 },
    { MODRM_SPLITRM, 3524 },
    { MODRM_SPLITRM, 3526 },
    { MODRM_SPLITRM, 3528 },
    { MODRM_SPLITRM, 3530 },
    { MODRM_SPLITRM, 3532 },
    { MODRM_SPLITRM, 3534 },
    { MODRM_SPLITRM, 3536 },
    { MODRM_SPLITRM, 3538 },
    { MODRM_SPLITRM, 2020 },
    { MODRM_SPLITRM, 2022 },
    { MODRM_SPLITRM, 2024 },
    { MODRM_SPLITRM, 2026 },
    { MODRM_SPLITRM, 2028 },
    { MODRM_SPLITRM, 2030 },
    { MODRM_SPLITRM, 2032 },
    { MODRM_SPLITRM, 2034 },
    { MODRM_SPLITRM, 2036 },
    { MODRM_SPLITRM, 2038 },
    { MODRM_SPLITRM, 2040 },
    { MODRM_SPLITRM, 2042 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2044 },
    { MODRM_SPLITRM, 3540 },
    { MODRM_SPLITRM, 3542 },
    { MODRM_SPLITREG, 2050 },
    { MODRM_SPLITREG, 2066 },
    { MODRM_SPLITREG, 2082 },
    { MODRM_SPLITRM, 2098 },
    { MODRM_SPLITRM, 2100 },
    { MODRM_SPLITRM, 2102 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 2638 },
    { MODRM_SPLITRM, 2640 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3544 },
    { MODRM_SPLITRM, 3546 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 3746 },
    { MODRM_SPLITRM, 3748 },
    { MODRM_SPLITRM, 3750 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 3752 },
    { MODRM_SPLITRM, 3754 },
    { MODRM_SPLITRM, 3756 },
    { MODRM_SPLITMISC, 4341 },
    { MODRM_SPLITRM, 3830 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3832 },
    { MODRM_SPLITRM, 3834 },
    { MODRM_SPLITRM, 3836 },
    { MODRM_SPLITRM, 3838 },
    { MODRM_SPLITRM, 3840 },
    { MODRM_SPLITRM, 3842 },
    { MODRM_SPLITRM, 3844 },
    { MODRM_SPLITRM, 4413 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3846 },
    { MODRM_SPLITRM, 3862 },
    { MODRM_SPLITRM, 4415 },
    { MODRM_SPLITRM, 4417 },
    { MODRM_SPLITRM, 3868 },
    { MODRM_SPLITRM, 3870 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3872 },
    { MODRM_SPLITRM, 3570 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 2448 },
    { MODRM_SPLITRM, 2450 },
    { MODRM_SPLITRM, 2452 },
    { MODRM_SPLITREG, 4419 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2471 },
    { MODRM_SPLITRM, 2473 },
    { MODRM_SPLITRM, 2475 },
    { MODRM_SPLITRM, 2477 },
    { MODRM_SPLITRM, 2479 },
    { MODRM_SPLITRM, 3588 },
    { MODRM_SPLITRM, 2481 },
    { MODRM_SPLITRM, 2483 },
    { MODRM_SPLITRM, 2485 },
    { MODRM_SPLITRM, 2487 },
    { MODRM_SPLITRM, 2489 },
    { MODRM_SPLITRM, 2491 },
    { MODRM_SPLITRM, 2493 },
    { MODRM_SPLITRM, 2495 },
    { MODRM_SPLITRM, 2497 },
    { MODRM_SPLITRM, 2499 },
    { MODRM_SPLITRM, 2501 },
    { MODRM_SPLITRM, 2503 },
    { MODRM_SPLITRM, 2505 },
    { MODRM_SPLITRM, 2507 },
    { MODRM_SPLITRM, 2509 },
    { MODRM_SPLITRM, 3590 },
    { MODRM_SPLITRM, 2511 },
    { MODRM_SPLITRM, 2513 },
    { MODRM_SPLITRM, 2515 },
    { MODRM_SPLITRM, 2517 },
    { MODRM_SPLITRM, 2519 },
    { MODRM_SPLITRM, 2521 },
    { MODRM_SPLITRM, 2523 },
    { MODRM_SPLITRM, 2525 },
    { MODRM_SPLITRM, 2527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2529 },
    { MODRM_SPLITRM, 2531 },
    { MODRM_SPLITRM, 2533 },
    { MODRM_SPLITRM, 2535 },
    { MODRM_SPLITRM, 2537 },
    { MODRM_SPLITRM, 2539 },
    { MODRM_SPLITRM, 2646 },
    { MODRM_SPLITRM, 2543 },
    { MODRM_SPLITRM, 2545 },
    { MODRM_SPLITRM, 2547 },
    { MODRM_SPLITRM, 2549 },
    { MODRM_SPLITRM, 2551 },
    { MODRM_SPLITRM, 2553 },
    { MODRM_SPLITRM, 2555 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 3614 },
    { MODRM_SPLITMISC, 3630 },
    { MODRM_SPLITRM, 3702 },
    { MODRM_SPLITRM, 3704 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 3706 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3267 },
    { MODRM_SPLITRM, 3269 },
    { MODRM_SPLITRM, 3271 },
    { MODRM_SPLITRM, 1871 },
    { MODRM_SPLITRM, 1873 },
    { MODRM_SPLITRM, 1875 },
    { MODRM_SPLITRM, 1877 },
    { MODRM_SPLITRM, 1879 },
    { MODRM_SPLITREG, 1881 },
    { MODRM_SPLITRM, 1897 },
    { MODRM_SPLITRM, 4063 },
    { MODRM_SPLITRM, 4065 },
    { MODRM_SPLITREG, 1903 },
    { MODRM_SPLITRM, 1919 },
    { MODRM_SPLITRM, 1921 },
    { MODRM_SPLITRM, 3707 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 1933 },
    { MODRM_SPLITRM, 1935 },
    { MODRM_SPLITRM, 4435 },
    { MODRM_SPLITRM, 3279 },
    { MODRM_SPLITRM, 4437 },
    { MODRM_SPLITRM, 4439 },
    { MODRM_SPLITRM, 1945 },
    { MODRM_SPLITRM, 1947 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 3709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3710 },
    { MODRM_SPLITRM, 3712 },
    { MODRM_SPLITRM, 3714 },
    { MODRM_SPLITRM, 3716 },
    { MODRM_SPLITRM, 3718 },
    { MODRM_SPLITRM, 3720 },
    { MODRM_SPLITRM, 3722 },
    { MODRM_SPLITRM, 3724 },
    { MODRM_SPLITRM, 3726 },
    { MODRM_SPLITRM, 3728 },
    { MODRM_SPLITRM, 3730 },
    { MODRM_SPLITRM, 3732 },
    { MODRM_SPLITRM, 3734 },
    { MODRM_SPLITRM, 3736 },
    { MODRM_SPLITRM, 3738 },
    { MODRM_SPLITRM, 3740 },
    { MODRM_SPLITRM, 1988 },
    { MODRM_SPLITRM, 3285 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 1996 },
    { MODRM_SPLITRM, 1998 },
    { MODRM_SPLITRM, 2000 },
    { MODRM_SPLITRM, 2002 },
    { MODRM_SPLITRM, 3287 },
    { MODRM_SPLITRM, 3289 },
    { MODRM_SPLITRM, 3291 },
    { MODRM_SPLITRM, 2010 },
    { MODRM_SPLITRM, 3293 },
    { MODRM_SPLITRM, 3295 },
    { MODRM_SPLITRM, 3297 },
    { MODRM_SPLITRM, 3299 },
    { MODRM_SPLITRM, 2020 },
    { MODRM_SPLITRM, 2022 },
    { MODRM_SPLITRM, 2024 },
    { MODRM_SPLITRM, 2026 },
    { MODRM_SPLITRM, 2028 },
    { MODRM_SPLITRM, 2030 },
    { MODRM_SPLITRM, 2032 },
    { MODRM_SPLITRM, 2034 },
    { MODRM_SPLITRM, 2036 },
    { MODRM_SPLITRM, 2038 },
    { MODRM_SPLITRM, 2040 },
    { MODRM_SPLITRM, 2042 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2044 },
    { MODRM_SPLITRM, 2046 },
    { MODRM_SPLITRM, 3301 },
    { MODRM_SPLITREG, 2050 },
    { MODRM_SPLITREG, 2066 },
    { MODRM_SPLITREG, 2082 },
    { MODRM_SPLITRM, 2098 },
    { MODRM_SPLITRM, 2100 },
    { MODRM_SPLITRM, 2102 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 4441 },
    { MODRM_SPLITRM, 4443 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3307 },
    { MODRM_SPLITRM, 3309 },
    { MODRM_SPLITRM, 2109 },
    { MODRM_SPLITRM, 2111 },
    { MODRM_ONEENTRY, 2113 },
    { MODRM_ONEENTRY, 2114 },
    { MODRM_ONEENTRY, 2115 },
    { MODRM_ONEENTRY, 2116 },
    { MODRM_ONEENTRY, 2117 },
    { MODRM_ONEENTRY, 2118 },
    { MODRM_ONEENTRY, 2119 },
    { MODRM_ONEENTRY, 2120 },
    { MODRM_ONEENTRY, 2121 },
    { MODRM_ONEENTRY, 2122 },
    { MODRM_ONEENTRY, 2123 },
    { MODRM_ONEENTRY, 2124 },
    { MODRM_ONEENTRY, 2125 },
    { MODRM_ONEENTRY, 2126 },
    { MODRM_ONEENTRY, 2127 },
    { MODRM_ONEENTRY, 2128 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2642 },
    { MODRM_ONEENTRY, 2643 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 3746 },
    { MODRM_SPLITRM, 3748 },
    { MODRM_SPLITRM, 3750 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2644 },
    { MODRM_ONEENTRY, 2645 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 3752 },
    { MODRM_SPLITRM, 3754 },
    { MODRM_SPLITRM, 3756 },
    { MODRM_SPLITMISC, 4445 },
    { MODRM_SPLITRM, 3830 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3832 },
    { MODRM_SPLITRM, 3834 },
    { MODRM_SPLITRM, 3836 },
    { MODRM_SPLITRM, 3838 },
    { MODRM_SPLITRM, 3840 },
    { MODRM_SPLITRM, 3842 },
    { MODRM_SPLITRM, 3844 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3846 },
    { MODRM_SPLITRM, 3862 },
    { MODRM_SPLITRM, 2432 },
    { MODRM_SPLITRM, 2434 },
    { MODRM_SPLITRM, 3868 },
    { MODRM_SPLITRM, 3870 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3872 },
    { MODRM_SPLITRM, 3327 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 2448 },
    { MODRM_SPLITRM, 2450 },
    { MODRM_SPLITRM, 2452 },
    { MODRM_SPLITREG, 4517 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_SPLITRM, 3345 },
    { MODRM_SPLITRM, 2471 },
    { MODRM_SPLITRM, 2473 },
    { MODRM_SPLITRM, 2475 },
    { MODRM_SPLITRM, 2477 },
    { MODRM_SPLITRM, 2479 },
    { MODRM_SPLITRM, 3347 },
    { MODRM_SPLITRM, 2481 },
    { MODRM_SPLITRM, 2483 },
    { MODRM_SPLITRM, 2485 },
    { MODRM_SPLITRM, 2487 },
    { MODRM_SPLITRM, 2489 },
    { MODRM_SPLITRM, 2491 },
    { MODRM_SPLITRM, 2493 },
    { MODRM_SPLITRM, 2495 },
    { MODRM_SPLITRM, 2497 },
    { MODRM_SPLITRM, 2499 },
    { MODRM_SPLITRM, 2501 },
    { MODRM_SPLITRM, 2503 },
    { MODRM_SPLITRM, 2505 },
    { MODRM_SPLITRM, 2507 },
    { MODRM_SPLITRM, 2509 },
    { MODRM_SPLITRM, 3349 },
    { MODRM_SPLITRM, 2511 },
    { MODRM_SPLITRM, 2513 },
    { MODRM_SPLITRM, 2515 },
    { MODRM_SPLITRM, 2517 },
    { MODRM_SPLITRM, 2519 },
    { MODRM_SPLITRM, 2521 },
    { MODRM_SPLITRM, 2523 },
    { MODRM_SPLITRM, 2525 },
    { MODRM_SPLITRM, 2527 },
    { MODRM_SPLITRM, 3351 },
    { MODRM_SPLITRM, 2529 },
    { MODRM_SPLITRM, 2531 },
    { MODRM_SPLITRM, 2533 },
    { MODRM_SPLITRM, 2535 },
    { MODRM_SPLITRM, 2537 },
    { MODRM_SPLITRM, 2539 },
    { MODRM_SPLITRM, 2646 },
    { MODRM_SPLITRM, 2543 },
    { MODRM_SPLITRM, 2545 },
    { MODRM_SPLITRM, 2547 },
    { MODRM_SPLITRM, 2549 },
    { MODRM_SPLITRM, 2551 },
    { MODRM_SPLITRM, 2553 },
    { MODRM_SPLITRM, 2555 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_SPLITREG, 3614 },
    { MODRM_SPLITMISC, 3630 },
    { MODRM_SPLITRM, 3702 },
    { MODRM_SPLITRM, 3704 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1842 },
    { MODRM_ONEENTRY, 1843 },
    { MODRM_ONEENTRY, 3706 },
    { MODRM_ONEENTRY, 1845 },
    { MODRM_ONEENTRY, 1846 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 1848 },
    { MODRM_ONEENTRY, 1864 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2740 },
    { MODRM_SPLITRM, 2742 },
    { MODRM_SPLITRM, 3171 },
    { MODRM_SPLITRM, 2746 },
    { MODRM_SPLITRM, 2748 },
    { MODRM_SPLITRM, 2750 },
    { MODRM_SPLITRM, 3173 },
    { MODRM_SPLITRM, 2754 },
    { MODRM_SPLITREG, 2756 },
    { MODRM_SPLITRM, 2772 },
    { MODRM_SPLITRM, 3893 },
    { MODRM_SPLITRM, 3895 },
    { MODRM_SPLITRM, 2778 },
    { MODRM_SPLITRM, 2780 },
    { MODRM_SPLITRM, 2782 },
    { MODRM_SPLITRM, 3707 },
    { MODRM_SPLITRM, 2630 },
    { MODRM_SPLITRM, 2632 },
    { MODRM_SPLITRM, 2634 },
    { MODRM_SPLITRM, 2636 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2786 },
    { MODRM_SPLITRM, 2788 },
    { MODRM_SPLITRM, 2790 },
    { MODRM_SPLITRM, 2792 },
    { MODRM_SPLITRM, 2794 },
    { MODRM_SPLITRM, 2796 },
    { MODRM_SPLITRM, 2798 },
    { MODRM_SPLITRM, 2800 },
    { MODRM_ONEENTRY, 1949 },
    { MODRM_ONEENTRY, 1950 },
    { MODRM_ONEENTRY, 1951 },
    { MODRM_ONEENTRY, 1952 },
    { MODRM_ONEENTRY, 1953 },
    { MODRM_ONEENTRY, 3709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 1955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3710 },
    { MODRM_SPLITRM, 3712 },
    { MODRM_SPLITRM, 3714 },
    { MODRM_SPLITRM, 3716 },
    { MODRM_SPLITRM, 3718 },
    { MODRM_SPLITRM, 3720 },
    { MODRM_SPLITRM, 3722 },
    { MODRM_SPLITRM, 3724 },
    { MODRM_SPLITRM, 3726 },
    { MODRM_SPLITRM, 3728 },
    { MODRM_SPLITRM, 3730 },
    { MODRM_SPLITRM, 3732 },
    { MODRM_SPLITRM, 3734 },
    { MODRM_SPLITRM, 3736 },
    { MODRM_SPLITRM, 3738 },
    { MODRM_SPLITRM, 3740 },
    { MODRM_SPLITRM, 2834 },
    { MODRM_SPLITRM, 2836 },
    { MODRM_SPLITRM, 1992 },
    { MODRM_SPLITRM, 1994 },
    { MODRM_SPLITRM, 2838 },
    { MODRM_SPLITRM, 2840 },
    { MODRM_SPLITRM, 2842 },
    { MODRM_SPLITRM, 2844 },
    { MODRM_SPLITRM, 2846 },
    { MODRM_SPLITRM, 2848 },
    { MODRM_SPLITRM, 2850 },
    { MODRM_SPLITRM, 2852 },
    { MODRM_SPLITRM, 2854 },
    { MODRM_SPLITRM, 2856 },
    { MODRM_SPLITRM, 2858 },
    { MODRM_SPLITRM, 2860 },
    { MODRM_SPLITRM, 2862 },
    { MODRM_SPLITRM, 2864 },
    { MODRM_SPLITRM, 2866 },
    { MODRM_SPLITRM, 2868 },
    { MODRM_SPLITRM, 2870 },
    { MODRM_SPLITRM, 2872 },
    { MODRM_SPLITRM, 2874 },
    { MODRM_SPLITRM, 2876 },
    { MODRM_SPLITRM, 2878 },
    { MODRM_SPLITRM, 2880 },
    { MODRM_SPLITRM, 2882 },
    { MODRM_SPLITRM, 2884 },
    { MODRM_SPLITRM, 2886 },
    { MODRM_SPLITRM, 2888 },
    { MODRM_SPLITRM, 4533 },
    { MODRM_SPLITRM, 2892 },
    { MODRM_SPLITRM, 2894 },
    { MODRM_SPLITREG, 2896 },
    { MODRM_SPLITREG, 2912 },
    { MODRM_SPLITREG, 2928 },
    { MODRM_SPLITRM, 2944 },
    { MODRM_SPLITRM, 2946 },
    { MODRM_SPLITRM, 2948 },
    { MODRM_ONEENTRY, 2104 },
    { MODRM_SPLITRM, 3897 },
    { MODRM_SPLITRM, 3899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 2954 },
    { MODRM_SPLITRM, 2956 },
    { MODRM_SPLITRM, 4535 },
    { MODRM_SPLITRM, 2960 },
    { MODRM_ONEENTRY, 2962 },
    { MODRM_ONEENTRY, 2963 },
    { MODRM_ONEENTRY, 2964 },
    { MODRM_ONEENTRY, 2965 },
    { MODRM_ONEENTRY, 2966 },
    { MODRM_ONEENTRY, 2967 },
    { MODRM_ONEENTRY, 2968 },
    { MODRM_ONEENTRY, 2969 },
    { MODRM_ONEENTRY, 2970 },
    { MODRM_ONEENTRY, 2971 },
    { MODRM_ONEENTRY, 2972 },
    { MODRM_ONEENTRY, 2973 },
    { MODRM_ONEENTRY, 2974 },
    { MODRM_ONEENTRY, 2975 },
    { MODRM_ONEENTRY, 2976 },
    { MODRM_ONEENTRY, 2977 },
    { MODRM_SPLITRM, 2129 },
    { MODRM_SPLITRM, 2131 },
    { MODRM_SPLITRM, 2133 },
    { MODRM_SPLITRM, 2135 },
    { MODRM_SPLITRM, 2137 },
    { MODRM_SPLITRM, 2139 },
    { MODRM_SPLITRM, 2141 },
    { MODRM_SPLITRM, 2143 },
    { MODRM_SPLITRM, 2145 },
    { MODRM_SPLITRM, 2147 },
    { MODRM_SPLITRM, 2149 },
    { MODRM_SPLITRM, 2151 },
    { MODRM_SPLITRM, 2153 },
    { MODRM_SPLITRM, 2155 },
    { MODRM_SPLITRM, 2157 },
    { MODRM_SPLITRM, 2159 },
    { MODRM_ONEENTRY, 2978 },
    { MODRM_ONEENTRY, 2979 },
    { MODRM_ONEENTRY, 2163 },
    { MODRM_SPLITRM, 3746 },
    { MODRM_SPLITRM, 3748 },
    { MODRM_SPLITRM, 3750 },
    { MODRM_SPLITMISC, 2170 },
    { MODRM_SPLITMISC, 2242 },
    { MODRM_ONEENTRY, 2986 },
    { MODRM_ONEENTRY, 2987 },
    { MODRM_ONEENTRY, 2316 },
    { MODRM_SPLITRM, 3752 },
    { MODRM_SPLITRM, 3754 },
    { MODRM_SPLITRM, 3756 },
    { MODRM_SPLITMISC, 4537 },
    { MODRM_SPLITRM, 3830 },
    { MODRM_SPLITRM, 2397 },
    { MODRM_SPLITRM, 3832 },
    { MODRM_SPLITRM, 3834 },
    { MODRM_SPLITRM, 3836 },
    { MODRM_SPLITRM, 3838 },
    { MODRM_SPLITRM, 3840 },
    { MODRM_SPLITRM, 3842 },
    { MODRM_SPLITRM, 3844 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 2413 },
    { MODRM_SPLITREG, 3846 },
    { MODRM_SPLITRM, 3862 },
    { MODRM_SPLITRM, 3044 },
    { MODRM_SPLITRM, 3046 },
    { MODRM_SPLITRM, 3868 },
    { MODRM_SPLITRM, 3870 },
    { MODRM_SPLITRM, 2440 },
    { MODRM_SPLITRM, 3872 },
    { MODRM_SPLITRM, 3054 },
    { MODRM_SPLITRM, 2446 },
    { MODRM_SPLITRM, 3056 },
    { MODRM_SPLITRM, 3058 },
    { MODRM_SPLITRM, 3060 },
    { MODRM_SPLITREG, 4609 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_ONEENTRY, 3892 },
    { MODRM_SPLITRM, 3079 },
    { MODRM_SPLITRM, 3081 },
    { MODRM_SPLITRM, 3083 },
    { MODRM_SPLITRM, 3085 },
    { MODRM_SPLITRM, 3087 },
    { MODRM_SPLITRM, 3089 },
    { MODRM_SPLITRM, 3091 },
    { MODRM_SPLITRM, 3093 },
    { MODRM_SPLITRM, 3095 },
    { MODRM_SPLITRM, 3097 },
    { MODRM_SPLITRM, 3099 },
    { MODRM_SPLITRM, 3101 },
    { MODRM_SPLITRM, 3103 },
    { MODRM_SPLITRM, 3105 },
    { MODRM_SPLITRM, 3107 },
    { MODRM_SPLITRM, 3109 },
    { MODRM_SPLITRM, 3111 },
    { MODRM_SPLITRM, 3113 },
    { MODRM_SPLITRM, 3115 },
    { MODRM_SPLITRM, 3117 },
    { MODRM_SPLITRM, 3119 },
    { MODRM_SPLITRM, 3121 },
    { MODRM_SPLITRM, 3123 },
    { MODRM_SPLITRM, 3125 },
    { MODRM_SPLITRM, 3127 },
    { MODRM_SPLITRM, 3129 },
    { MODRM_SPLITRM, 3131 },
    { MODRM_SPLITRM, 3133 },
    { MODRM_SPLITRM, 3135 },
    { MODRM_SPLITRM, 3137 },
    { MODRM_SPLITRM, 3139 },
    { MODRM_SPLITRM, 3141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 3143 },
    { MODRM_SPLITRM, 3145 },
    { MODRM_SPLITRM, 3147 },
    { MODRM_SPLITRM, 3149 },
    { MODRM_SPLITRM, 3151 },
    { MODRM_SPLITRM, 3153 },
    { MODRM_SPLITRM, 3989 },
    { MODRM_SPLITRM, 3157 },
    { MODRM_SPLITRM, 3159 },
    { MODRM_SPLITRM, 3161 },
    { MODRM_SPLITRM, 3163 },
    { MODRM_SPLITRM, 3165 },
    { MODRM_SPLITRM, 3167 },
    { MODRM_SPLITRM, 3169 },
    { MODRM_ONEENTRY, 2557 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4625 },
    { MODRM_SPLITRM, 4627 },
    { MODRM_SPLITRM, 4629 },
    { MODRM_SPLITRM, 4631 },
    { MODRM_SPLITRM, 4633 },
    { MODRM_SPLITRM, 4635 },
    { MODRM_SPLITRM, 4637 },
    { MODRM_SPLITRM, 4639 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4641 },
    { MODRM_SPLITRM, 4643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4645 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4647 },
    { MODRM_SPLITRM, 4649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4651 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4653 },
    { MODRM_SPLITRM, 4655 },
    { MODRM_SPLITRM, 4657 },
    { MODRM_SPLITRM, 4659 },
    { MODRM_SPLITRM, 4661 },
    { MODRM_SPLITRM, 4663 },
    { MODRM_SPLITRM, 4665 },
    { MODRM_SPLITRM, 4667 },
    { MODRM_SPLITRM, 4669 },
    { MODRM_SPLITRM, 4671 },
    { MODRM_SPLITRM, 4673 },
    { MODRM_SPLITRM, 4675 },
    { MODRM_SPLITRM, 4677 },
    { MODRM_SPLITRM, 4679 },
    { MODRM_SPLITRM, 4681 },
    { MODRM_SPLITRM, 4683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 4685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4686 },
    { MODRM_SPLITRM, 4688 },
    { MODRM_SPLITRM, 4690 },
    { MODRM_SPLITRM, 4692 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4694 },
    { MODRM_SPLITRM, 4696 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 4698 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4714 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4716 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4718 },
    { MODRM_SPLITRM, 4720 },
    { MODRM_SPLITRM, 4722 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4724 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4726 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4728 },
    { MODRM_SPLITRM, 4730 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4732 },
    { MODRM_SPLITRM, 4734 },
    { MODRM_SPLITRM, 4736 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4738 },
    { MODRM_SPLITRM, 4740 },
    { MODRM_SPLITRM, 4742 },
    { MODRM_SPLITRM, 4744 },
    { MODRM_SPLITRM, 4746 },
    { MODRM_SPLITRM, 4748 },
    { MODRM_SPLITRM, 4750 },
    { MODRM_SPLITRM, 4752 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4754 },
    { MODRM_SPLITRM, 4756 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4758 },
    { MODRM_SPLITRM, 4760 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4762 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4764 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4766 },
    { MODRM_SPLITRM, 4768 },
    { MODRM_SPLITRM, 4770 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4772 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4774 },
    { MODRM_SPLITRM, 4776 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4778 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4780 },
    { MODRM_SPLITRM, 4782 },
    { MODRM_SPLITRM, 4784 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4786 },
    { MODRM_SPLITRM, 4788 },
    { MODRM_SPLITRM, 4790 },
    { MODRM_SPLITRM, 4792 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4794 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4796 },
    { MODRM_SPLITRM, 4798 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4800 },
    { MODRM_SPLITRM, 4802 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4804 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4806 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4808 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4810 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4812 },
    { MODRM_SPLITRM, 4814 },
    { MODRM_SPLITRM, 4816 },
    { MODRM_SPLITRM, 4818 },
    { MODRM_SPLITRM, 4820 },
    { MODRM_SPLITRM, 4822 },
    { MODRM_SPLITRM, 4824 },
    { MODRM_SPLITRM, 4826 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4828 },
    { MODRM_SPLITRM, 4830 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4832 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4834 },
    { MODRM_SPLITRM, 4836 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4838 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4840 },
    { MODRM_SPLITRM, 4842 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4844 },
    { MODRM_SPLITRM, 4846 },
    { MODRM_SPLITRM, 4848 },
    { MODRM_SPLITRM, 4850 },
    { MODRM_SPLITRM, 4852 },
    { MODRM_SPLITRM, 4854 },
    { MODRM_SPLITRM, 4856 },
    { MODRM_SPLITRM, 4858 },
    { MODRM_SPLITRM, 4860 },
    { MODRM_SPLITRM, 4862 },
    { MODRM_SPLITRM, 4864 },
    { MODRM_SPLITRM, 4866 },
    { MODRM_SPLITRM, 4868 },
    { MODRM_SPLITRM, 4870 },
    { MODRM_SPLITRM, 4872 },
    { MODRM_SPLITRM, 4874 },
    { MODRM_SPLITRM, 4876 },
    { MODRM_SPLITRM, 4878 },
    { MODRM_SPLITRM, 4880 },
    { MODRM_SPLITRM, 4882 },
    { MODRM_SPLITRM, 4884 },
    { MODRM_SPLITRM, 4886 },
    { MODRM_SPLITRM, 4888 },
    { MODRM_SPLITRM, 4890 },
    { MODRM_SPLITRM, 4892 },
    { MODRM_SPLITRM, 4894 },
    { MODRM_SPLITRM, 4896 },
    { MODRM_SPLITRM, 4898 },
    { MODRM_SPLITRM, 4900 },
    { MODRM_SPLITREG, 4902 },
    { MODRM_SPLITREG, 4918 },
    { MODRM_SPLITREG, 4934 },
    { MODRM_SPLITRM, 4950 },
    { MODRM_SPLITRM, 4952 },
    { MODRM_SPLITRM, 4954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4956 },
    { MODRM_SPLITRM, 4958 },
    { MODRM_SPLITRM, 4960 },
    { MODRM_SPLITRM, 4962 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4964 },
    { MODRM_SPLITRM, 4966 },
    { MODRM_SPLITRM, 4968 },
    { MODRM_SPLITRM, 4970 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4972 },
    { MODRM_SPLITRM, 4974 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4976 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4978 },
    { MODRM_SPLITRM, 4980 },
    { MODRM_SPLITRM, 4982 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4984 },
    { MODRM_SPLITRM, 4986 },
    { MODRM_SPLITRM, 4988 },
    { MODRM_SPLITRM, 4990 },
    { MODRM_SPLITRM, 4992 },
    { MODRM_SPLITRM, 4994 },
    { MODRM_SPLITRM, 4996 },
    { MODRM_SPLITRM, 4998 },
    { MODRM_SPLITRM, 5000 },
    { MODRM_SPLITRM, 5002 },
    { MODRM_SPLITRM, 5004 },
    { MODRM_SPLITRM, 5006 },
    { MODRM_SPLITRM, 5008 },
    { MODRM_SPLITRM, 5010 },
    { MODRM_SPLITRM, 5012 },
    { MODRM_SPLITRM, 5014 },
    { MODRM_SPLITRM, 5016 },
    { MODRM_SPLITRM, 5018 },
    { MODRM_SPLITRM, 5020 },
    { MODRM_SPLITRM, 5022 },
    { MODRM_SPLITRM, 5024 },
    { MODRM_SPLITRM, 5026 },
    { MODRM_SPLITRM, 5028 },
    { MODRM_SPLITRM, 5030 },
    { MODRM_SPLITRM, 5032 },
    { MODRM_SPLITRM, 5034 },
    { MODRM_SPLITRM, 5036 },
    { MODRM_SPLITRM, 5038 },
    { MODRM_SPLITRM, 5040 },
    { MODRM_SPLITRM, 5042 },
    { MODRM_SPLITRM, 5044 },
    { MODRM_SPLITRM, 5046 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5048 },
    { MODRM_SPLITRM, 5050 },
    { MODRM_SPLITRM, 5052 },
    { MODRM_SPLITRM, 5054 },
    { MODRM_SPLITRM, 5056 },
    { MODRM_SPLITRM, 5058 },
    { MODRM_SPLITRM, 5060 },
    { MODRM_SPLITRM, 5062 },
    { MODRM_SPLITRM, 5064 },
    { MODRM_SPLITRM, 5066 },
    { MODRM_SPLITRM, 5068 },
    { MODRM_SPLITRM, 5070 },
    { MODRM_SPLITRM, 5072 },
    { MODRM_SPLITRM, 5074 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4625 },
    { MODRM_SPLITRM, 4627 },
    { MODRM_SPLITRM, 4629 },
    { MODRM_SPLITRM, 4631 },
    { MODRM_SPLITRM, 4633 },
    { MODRM_SPLITRM, 4635 },
    { MODRM_SPLITRM, 4637 },
    { MODRM_SPLITRM, 4639 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4641 },
    { MODRM_SPLITRM, 4643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4645 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4647 },
    { MODRM_SPLITRM, 4649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5076 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4653 },
    { MODRM_SPLITRM, 4655 },
    { MODRM_SPLITRM, 4657 },
    { MODRM_SPLITRM, 4659 },
    { MODRM_SPLITRM, 4661 },
    { MODRM_SPLITRM, 4663 },
    { MODRM_SPLITRM, 4665 },
    { MODRM_SPLITRM, 4667 },
    { MODRM_SPLITRM, 4669 },
    { MODRM_SPLITRM, 4671 },
    { MODRM_SPLITRM, 4673 },
    { MODRM_SPLITRM, 4675 },
    { MODRM_SPLITRM, 4677 },
    { MODRM_SPLITRM, 4679 },
    { MODRM_SPLITRM, 4681 },
    { MODRM_SPLITRM, 4683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 4685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5078 },
    { MODRM_SPLITRM, 5080 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5082 },
    { MODRM_SPLITRM, 5084 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 4698 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4714 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4716 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4718 },
    { MODRM_SPLITRM, 4720 },
    { MODRM_SPLITRM, 4722 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4724 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5086 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5088 },
    { MODRM_SPLITRM, 5090 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4732 },
    { MODRM_SPLITRM, 4734 },
    { MODRM_SPLITRM, 4736 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4738 },
    { MODRM_SPLITRM, 4740 },
    { MODRM_SPLITRM, 4742 },
    { MODRM_SPLITRM, 4744 },
    { MODRM_SPLITRM, 4746 },
    { MODRM_SPLITRM, 4748 },
    { MODRM_SPLITRM, 4750 },
    { MODRM_SPLITRM, 4752 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4754 },
    { MODRM_SPLITRM, 4756 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4758 },
    { MODRM_SPLITRM, 4760 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4762 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4764 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4766 },
    { MODRM_SPLITRM, 4768 },
    { MODRM_SPLITRM, 4770 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5092 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5094 },
    { MODRM_SPLITRM, 5096 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4778 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4780 },
    { MODRM_SPLITRM, 4782 },
    { MODRM_SPLITRM, 4784 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4786 },
    { MODRM_SPLITRM, 4788 },
    { MODRM_SPLITRM, 4790 },
    { MODRM_SPLITRM, 4792 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4794 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4796 },
    { MODRM_SPLITRM, 4798 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5098 },
    { MODRM_SPLITRM, 5100 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4804 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4806 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4808 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4810 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4812 },
    { MODRM_SPLITRM, 4814 },
    { MODRM_SPLITRM, 4816 },
    { MODRM_SPLITRM, 4818 },
    { MODRM_SPLITRM, 4820 },
    { MODRM_SPLITRM, 4822 },
    { MODRM_SPLITRM, 4824 },
    { MODRM_SPLITRM, 4826 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4828 },
    { MODRM_SPLITRM, 4830 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4832 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4834 },
    { MODRM_SPLITRM, 4836 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5102 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4840 },
    { MODRM_SPLITRM, 4842 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4844 },
    { MODRM_SPLITRM, 4846 },
    { MODRM_SPLITRM, 4848 },
    { MODRM_SPLITRM, 4850 },
    { MODRM_SPLITRM, 4852 },
    { MODRM_SPLITRM, 4854 },
    { MODRM_SPLITRM, 4856 },
    { MODRM_SPLITRM, 4858 },
    { MODRM_SPLITRM, 4860 },
    { MODRM_SPLITRM, 4862 },
    { MODRM_SPLITRM, 4864 },
    { MODRM_SPLITRM, 4866 },
    { MODRM_SPLITRM, 4868 },
    { MODRM_SPLITRM, 4870 },
    { MODRM_SPLITRM, 4872 },
    { MODRM_SPLITRM, 4874 },
    { MODRM_SPLITRM, 4876 },
    { MODRM_SPLITRM, 4878 },
    { MODRM_SPLITRM, 4880 },
    { MODRM_SPLITRM, 4882 },
    { MODRM_SPLITRM, 4884 },
    { MODRM_SPLITRM, 4886 },
    { MODRM_SPLITRM, 4888 },
    { MODRM_SPLITRM, 4890 },
    { MODRM_SPLITRM, 4892 },
    { MODRM_SPLITRM, 4894 },
    { MODRM_SPLITRM, 5104 },
    { MODRM_SPLITRM, 4898 },
    { MODRM_SPLITRM, 4900 },
    { MODRM_SPLITREG, 4902 },
    { MODRM_SPLITREG, 4918 },
    { MODRM_SPLITREG, 4934 },
    { MODRM_SPLITRM, 4950 },
    { MODRM_SPLITRM, 4952 },
    { MODRM_SPLITRM, 4954 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4956 },
    { MODRM_SPLITRM, 4958 },
    { MODRM_SPLITRM, 5106 },
    { MODRM_SPLITRM, 4962 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5108 },
    { MODRM_SPLITRM, 5110 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5112 },
    { MODRM_SPLITRM, 5114 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4976 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4982 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4984 },
    { MODRM_SPLITRM, 4986 },
    { MODRM_SPLITRM, 4988 },
    { MODRM_SPLITRM, 4990 },
    { MODRM_SPLITRM, 4992 },
    { MODRM_SPLITRM, 4994 },
    { MODRM_SPLITRM, 4996 },
    { MODRM_SPLITRM, 4998 },
    { MODRM_SPLITRM, 5000 },
    { MODRM_SPLITRM, 5002 },
    { MODRM_SPLITRM, 5004 },
    { MODRM_SPLITRM, 5006 },
    { MODRM_SPLITRM, 5008 },
    { MODRM_SPLITRM, 5010 },
    { MODRM_SPLITRM, 5012 },
    { MODRM_SPLITRM, 5014 },
    { MODRM_SPLITRM, 5016 },
    { MODRM_SPLITRM, 5018 },
    { MODRM_SPLITRM, 5020 },
    { MODRM_SPLITRM, 5022 },
    { MODRM_SPLITRM, 5024 },
    { MODRM_SPLITRM, 5026 },
    { MODRM_SPLITRM, 5028 },
    { MODRM_SPLITRM, 5030 },
    { MODRM_SPLITRM, 5032 },
    { MODRM_SPLITRM, 5034 },
    { MODRM_SPLITRM, 5036 },
    { MODRM_SPLITRM, 5038 },
    { MODRM_SPLITRM, 5040 },
    { MODRM_SPLITRM, 5042 },
    { MODRM_SPLITRM, 5044 },
    { MODRM_SPLITRM, 5046 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5048 },
    { MODRM_SPLITRM, 5050 },
    { MODRM_SPLITRM, 5052 },
    { MODRM_SPLITRM, 5054 },
    { MODRM_SPLITRM, 5056 },
    { MODRM_SPLITRM, 5058 },
    { MODRM_SPLITRM, 5060 },
    { MODRM_SPLITRM, 5062 },
    { MODRM_SPLITRM, 5064 },
    { MODRM_SPLITRM, 5066 },
    { MODRM_SPLITRM, 5068 },
    { MODRM_SPLITRM, 5070 },
    { MODRM_SPLITRM, 5072 },
    { MODRM_SPLITRM, 5074 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5116 },
    { MODRM_SPLITRM, 5118 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5120 },
    { MODRM_SPLITRM, 5122 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5124 },
    { MODRM_SPLITRM, 5126 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5128 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4647 },
    { MODRM_SPLITRM, 4649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5130 },
    { MODRM_SPLITRM, 5132 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5134 },
    { MODRM_SPLITRM, 5136 },
    { MODRM_SPLITRM, 5138 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5140 },
    { MODRM_SPLITRM, 5142 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5144 },
    { MODRM_SPLITRM, 5146 },
    { MODRM_SPLITRM, 5148 },
    { MODRM_SPLITRM, 5150 },
    { MODRM_SPLITRM, 5152 },
    { MODRM_SPLITRM, 5154 },
    { MODRM_SPLITRM, 5156 },
    { MODRM_SPLITRM, 5158 },
    { MODRM_SPLITRM, 5160 },
    { MODRM_SPLITRM, 5162 },
    { MODRM_SPLITRM, 5164 },
    { MODRM_SPLITRM, 5166 },
    { MODRM_SPLITRM, 5168 },
    { MODRM_SPLITRM, 5170 },
    { MODRM_SPLITRM, 5172 },
    { MODRM_SPLITRM, 5174 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 5176 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5177 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5179 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4718 },
    { MODRM_SPLITRM, 4720 },
    { MODRM_SPLITRM, 5181 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4726 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4728 },
    { MODRM_SPLITRM, 4730 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4732 },
    { MODRM_SPLITRM, 4734 },
    { MODRM_SPLITRM, 4736 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4738 },
    { MODRM_SPLITRM, 4740 },
    { MODRM_SPLITRM, 4742 },
    { MODRM_SPLITRM, 5185 },
    { MODRM_SPLITRM, 4746 },
    { MODRM_SPLITRM, 4748 },
    { MODRM_SPLITRM, 4750 },
    { MODRM_SPLITRM, 4752 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5187 },
    { MODRM_SPLITRM, 5189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5191 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4762 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4766 },
    { MODRM_SPLITRM, 4768 },
    { MODRM_SPLITRM, 5195 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4772 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4774 },
    { MODRM_SPLITRM, 4776 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4778 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4780 },
    { MODRM_SPLITRM, 4782 },
    { MODRM_SPLITRM, 4784 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4786 },
    { MODRM_SPLITRM, 4788 },
    { MODRM_SPLITRM, 4790 },
    { MODRM_SPLITRM, 4792 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5199 },
    { MODRM_SPLITRM, 5201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4804 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5203 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5209 },
    { MODRM_SPLITRM, 5211 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5213 },
    { MODRM_SPLITRM, 5215 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5217 },
    { MODRM_SPLITRM, 5219 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5221 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4834 },
    { MODRM_SPLITRM, 4836 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5223 },
    { MODRM_SPLITRM, 5225 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5227 },
    { MODRM_SPLITRM, 5229 },
    { MODRM_SPLITRM, 5231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5233 },
    { MODRM_SPLITRM, 5235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5237 },
    { MODRM_SPLITRM, 5239 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5241 },
    { MODRM_SPLITRM, 5243 },
    { MODRM_SPLITRM, 5245 },
    { MODRM_SPLITRM, 5247 },
    { MODRM_SPLITRM, 5249 },
    { MODRM_SPLITRM, 5251 },
    { MODRM_SPLITRM, 5253 },
    { MODRM_SPLITRM, 5255 },
    { MODRM_SPLITRM, 5257 },
    { MODRM_SPLITRM, 5259 },
    { MODRM_SPLITRM, 5261 },
    { MODRM_SPLITRM, 5263 },
    { MODRM_SPLITRM, 5265 },
    { MODRM_SPLITRM, 5267 },
    { MODRM_SPLITRM, 5269 },
    { MODRM_SPLITRM, 5271 },
    { MODRM_SPLITRM, 5273 },
    { MODRM_SPLITRM, 5275 },
    { MODRM_SPLITRM, 5277 },
    { MODRM_SPLITRM, 5279 },
    { MODRM_SPLITRM, 5281 },
    { MODRM_SPLITRM, 5283 },
    { MODRM_SPLITRM, 5285 },
    { MODRM_SPLITRM, 5287 },
    { MODRM_SPLITRM, 5289 },
    { MODRM_SPLITRM, 5291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5293 },
    { MODRM_SPLITRM, 5295 },
    { MODRM_SPLITREG, 5297 },
    { MODRM_SPLITREG, 5313 },
    { MODRM_SPLITREG, 5329 },
    { MODRM_SPLITRM, 5345 },
    { MODRM_SPLITRM, 5347 },
    { MODRM_SPLITRM, 5349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5351 },
    { MODRM_SPLITRM, 5353 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5355 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5357 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5359 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5361 },
    { MODRM_SPLITRM, 5363 },
    { MODRM_SPLITRM, 5365 },
    { MODRM_SPLITRM, 5367 },
    { MODRM_SPLITRM, 5369 },
    { MODRM_SPLITRM, 5371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5373 },
    { MODRM_SPLITRM, 5375 },
    { MODRM_SPLITRM, 5377 },
    { MODRM_SPLITRM, 5379 },
    { MODRM_SPLITRM, 5381 },
    { MODRM_SPLITRM, 5383 },
    { MODRM_SPLITRM, 5385 },
    { MODRM_SPLITRM, 5387 },
    { MODRM_SPLITRM, 5389 },
    { MODRM_SPLITRM, 5391 },
    { MODRM_SPLITRM, 5393 },
    { MODRM_SPLITRM, 5395 },
    { MODRM_SPLITRM, 5397 },
    { MODRM_SPLITRM, 5399 },
    { MODRM_SPLITRM, 5401 },
    { MODRM_SPLITRM, 5403 },
    { MODRM_SPLITRM, 5405 },
    { MODRM_SPLITRM, 5407 },
    { MODRM_SPLITRM, 5409 },
    { MODRM_SPLITRM, 5411 },
    { MODRM_SPLITRM, 5413 },
    { MODRM_SPLITRM, 5415 },
    { MODRM_SPLITRM, 5417 },
    { MODRM_SPLITRM, 5419 },
    { MODRM_SPLITRM, 5421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5423 },
    { MODRM_SPLITRM, 5425 },
    { MODRM_SPLITRM, 5427 },
    { MODRM_SPLITRM, 5429 },
    { MODRM_SPLITRM, 5431 },
    { MODRM_SPLITRM, 5433 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5435 },
    { MODRM_SPLITRM, 5437 },
    { MODRM_SPLITRM, 5439 },
    { MODRM_SPLITRM, 5441 },
    { MODRM_SPLITRM, 5443 },
    { MODRM_SPLITRM, 5445 },
    { MODRM_SPLITRM, 5447 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5116 },
    { MODRM_SPLITRM, 5118 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5120 },
    { MODRM_SPLITRM, 5122 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5124 },
    { MODRM_SPLITRM, 5126 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5128 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4647 },
    { MODRM_SPLITRM, 4649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5449 },
    { MODRM_SPLITRM, 5451 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5453 },
    { MODRM_SPLITRM, 5455 },
    { MODRM_SPLITRM, 5457 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5459 },
    { MODRM_SPLITRM, 5461 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5144 },
    { MODRM_SPLITRM, 5146 },
    { MODRM_SPLITRM, 5148 },
    { MODRM_SPLITRM, 5150 },
    { MODRM_SPLITRM, 5152 },
    { MODRM_SPLITRM, 5154 },
    { MODRM_SPLITRM, 5156 },
    { MODRM_SPLITRM, 5158 },
    { MODRM_SPLITRM, 5160 },
    { MODRM_SPLITRM, 5162 },
    { MODRM_SPLITRM, 5164 },
    { MODRM_SPLITRM, 5166 },
    { MODRM_SPLITRM, 5168 },
    { MODRM_SPLITRM, 5170 },
    { MODRM_SPLITRM, 5172 },
    { MODRM_SPLITRM, 5174 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 5176 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5177 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5179 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4718 },
    { MODRM_SPLITRM, 4720 },
    { MODRM_SPLITRM, 5181 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5086 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5088 },
    { MODRM_SPLITRM, 5090 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4732 },
    { MODRM_SPLITRM, 4734 },
    { MODRM_SPLITRM, 4736 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4738 },
    { MODRM_SPLITRM, 4740 },
    { MODRM_SPLITRM, 4742 },
    { MODRM_SPLITRM, 5185 },
    { MODRM_SPLITRM, 4746 },
    { MODRM_SPLITRM, 4748 },
    { MODRM_SPLITRM, 4750 },
    { MODRM_SPLITRM, 4752 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5187 },
    { MODRM_SPLITRM, 5189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5191 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4762 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4766 },
    { MODRM_SPLITRM, 4768 },
    { MODRM_SPLITRM, 5195 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5092 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5094 },
    { MODRM_SPLITRM, 5096 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4778 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4780 },
    { MODRM_SPLITRM, 4782 },
    { MODRM_SPLITRM, 4784 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4786 },
    { MODRM_SPLITRM, 4788 },
    { MODRM_SPLITRM, 4790 },
    { MODRM_SPLITRM, 4792 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5199 },
    { MODRM_SPLITRM, 5201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4804 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5203 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5209 },
    { MODRM_SPLITRM, 5211 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5213 },
    { MODRM_SPLITRM, 5215 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5217 },
    { MODRM_SPLITRM, 5219 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5221 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 4834 },
    { MODRM_SPLITRM, 4836 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5463 },
    { MODRM_SPLITRM, 5465 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5467 },
    { MODRM_SPLITRM, 5469 },
    { MODRM_SPLITRM, 5471 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5473 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5237 },
    { MODRM_SPLITRM, 5239 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5241 },
    { MODRM_SPLITRM, 5243 },
    { MODRM_SPLITRM, 5245 },
    { MODRM_SPLITRM, 5247 },
    { MODRM_SPLITRM, 5249 },
    { MODRM_SPLITRM, 5251 },
    { MODRM_SPLITRM, 5253 },
    { MODRM_SPLITRM, 5255 },
    { MODRM_SPLITRM, 5257 },
    { MODRM_SPLITRM, 5259 },
    { MODRM_SPLITRM, 5261 },
    { MODRM_SPLITRM, 5263 },
    { MODRM_SPLITRM, 5265 },
    { MODRM_SPLITRM, 5267 },
    { MODRM_SPLITRM, 5269 },
    { MODRM_SPLITRM, 5271 },
    { MODRM_SPLITRM, 5273 },
    { MODRM_SPLITRM, 5275 },
    { MODRM_SPLITRM, 5277 },
    { MODRM_SPLITRM, 5279 },
    { MODRM_SPLITRM, 5281 },
    { MODRM_SPLITRM, 5283 },
    { MODRM_SPLITRM, 5285 },
    { MODRM_SPLITRM, 5287 },
    { MODRM_SPLITRM, 5289 },
    { MODRM_SPLITRM, 5291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5293 },
    { MODRM_SPLITRM, 5295 },
    { MODRM_SPLITREG, 5297 },
    { MODRM_SPLITREG, 5313 },
    { MODRM_SPLITREG, 5329 },
    { MODRM_SPLITRM, 5345 },
    { MODRM_SPLITRM, 5347 },
    { MODRM_SPLITRM, 5349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5351 },
    { MODRM_SPLITRM, 5353 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5355 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5357 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5359 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5361 },
    { MODRM_SPLITRM, 5363 },
    { MODRM_SPLITRM, 5365 },
    { MODRM_SPLITRM, 5367 },
    { MODRM_SPLITRM, 5369 },
    { MODRM_SPLITRM, 5371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5373 },
    { MODRM_SPLITRM, 5375 },
    { MODRM_SPLITRM, 5377 },
    { MODRM_SPLITRM, 5379 },
    { MODRM_SPLITRM, 5381 },
    { MODRM_SPLITRM, 5383 },
    { MODRM_SPLITRM, 5385 },
    { MODRM_SPLITRM, 5387 },
    { MODRM_SPLITRM, 5389 },
    { MODRM_SPLITRM, 5391 },
    { MODRM_SPLITRM, 5393 },
    { MODRM_SPLITRM, 5395 },
    { MODRM_SPLITRM, 5397 },
    { MODRM_SPLITRM, 5399 },
    { MODRM_SPLITRM, 5401 },
    { MODRM_SPLITRM, 5403 },
    { MODRM_SPLITRM, 5405 },
    { MODRM_SPLITRM, 5407 },
    { MODRM_SPLITRM, 5409 },
    { MODRM_SPLITRM, 5411 },
    { MODRM_SPLITRM, 5413 },
    { MODRM_SPLITRM, 5415 },
    { MODRM_SPLITRM, 5417 },
    { MODRM_SPLITRM, 5419 },
    { MODRM_SPLITRM, 5421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5423 },
    { MODRM_SPLITRM, 5425 },
    { MODRM_SPLITRM, 5427 },
    { MODRM_SPLITRM, 5429 },
    { MODRM_SPLITRM, 5431 },
    { MODRM_SPLITRM, 5433 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5435 },
    { MODRM_SPLITRM, 5437 },
    { MODRM_SPLITRM, 5439 },
    { MODRM_SPLITRM, 5441 },
    { MODRM_SPLITRM, 5443 },
    { MODRM_SPLITRM, 5445 },
    { MODRM_SPLITRM, 5447 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5475 },
    { MODRM_SPLITRM, 5477 },
    { MODRM_SPLITRM, 5479 },
    { MODRM_SPLITRM, 5481 },
    { MODRM_SPLITRM, 5483 },
    { MODRM_SPLITRM, 5485 },
    { MODRM_SPLITRM, 5487 },
    { MODRM_SPLITRM, 5489 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5491 },
    { MODRM_SPLITRM, 5493 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5497 },
    { MODRM_SPLITRM, 5499 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5501 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5503 },
    { MODRM_SPLITRM, 5505 },
    { MODRM_SPLITRM, 5507 },
    { MODRM_SPLITRM, 5509 },
    { MODRM_SPLITRM, 5511 },
    { MODRM_SPLITRM, 5513 },
    { MODRM_SPLITRM, 5515 },
    { MODRM_SPLITRM, 5517 },
    { MODRM_SPLITRM, 5519 },
    { MODRM_SPLITRM, 5521 },
    { MODRM_SPLITRM, 5523 },
    { MODRM_SPLITRM, 5525 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5527 },
    { MODRM_SPLITRM, 5529 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5531 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5533 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5535 },
    { MODRM_SPLITRM, 5537 },
    { MODRM_SPLITRM, 5539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5541 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5545 },
    { MODRM_SPLITRM, 5547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5551 },
    { MODRM_SPLITRM, 5553 },
    { MODRM_SPLITRM, 5555 },
    { MODRM_SPLITRM, 5557 },
    { MODRM_SPLITRM, 5559 },
    { MODRM_SPLITRM, 5561 },
    { MODRM_SPLITRM, 5563 },
    { MODRM_SPLITRM, 5565 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5567 },
    { MODRM_SPLITRM, 5569 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5571 },
    { MODRM_SPLITRM, 5573 },
    { MODRM_SPLITRM, 5575 },
    { MODRM_SPLITRM, 5577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5581 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5583 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5587 },
    { MODRM_SPLITRM, 5589 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5591 },
    { MODRM_SPLITRM, 5593 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5595 },
    { MODRM_SPLITRM, 5597 },
    { MODRM_SPLITRM, 5599 },
    { MODRM_SPLITRM, 5601 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5603 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5605 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5607 },
    { MODRM_SPLITRM, 5609 },
    { MODRM_SPLITRM, 5611 },
    { MODRM_SPLITRM, 5613 },
    { MODRM_SPLITRM, 5615 },
    { MODRM_SPLITRM, 5617 },
    { MODRM_SPLITRM, 5619 },
    { MODRM_SPLITRM, 5621 },
    { MODRM_SPLITRM, 5623 },
    { MODRM_SPLITRM, 5625 },
    { MODRM_SPLITRM, 5627 },
    { MODRM_SPLITRM, 5629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5631 },
    { MODRM_SPLITRM, 5633 },
    { MODRM_SPLITRM, 5635 },
    { MODRM_SPLITREG, 5637 },
    { MODRM_SPLITREG, 5653 },
    { MODRM_SPLITREG, 5669 },
    { MODRM_SPLITRM, 5685 },
    { MODRM_SPLITRM, 5687 },
    { MODRM_SPLITRM, 5689 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5691 },
    { MODRM_SPLITRM, 5693 },
    { MODRM_SPLITRM, 5695 },
    { MODRM_SPLITRM, 5697 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5699 },
    { MODRM_SPLITRM, 5701 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5703 },
    { MODRM_SPLITRM, 5705 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5707 },
    { MODRM_SPLITRM, 5709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5711 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5713 },
    { MODRM_SPLITRM, 5715 },
    { MODRM_SPLITRM, 5717 },
    { MODRM_SPLITRM, 5719 },
    { MODRM_SPLITRM, 5721 },
    { MODRM_SPLITRM, 5723 },
    { MODRM_SPLITRM, 5725 },
    { MODRM_SPLITRM, 5727 },
    { MODRM_SPLITRM, 5729 },
    { MODRM_SPLITRM, 5731 },
    { MODRM_SPLITRM, 5733 },
    { MODRM_SPLITRM, 5735 },
    { MODRM_SPLITRM, 5737 },
    { MODRM_SPLITRM, 5739 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5741 },
    { MODRM_SPLITRM, 5743 },
    { MODRM_SPLITRM, 5745 },
    { MODRM_SPLITRM, 5747 },
    { MODRM_SPLITRM, 5749 },
    { MODRM_SPLITRM, 5751 },
    { MODRM_SPLITRM, 5753 },
    { MODRM_SPLITRM, 5755 },
    { MODRM_SPLITRM, 5757 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5759 },
    { MODRM_SPLITRM, 5761 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5763 },
    { MODRM_SPLITRM, 5765 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5767 },
    { MODRM_SPLITRM, 5769 },
    { MODRM_SPLITRM, 5771 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5773 },
    { MODRM_SPLITRM, 5775 },
    { MODRM_SPLITRM, 5777 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5779 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5781 },
    { MODRM_SPLITRM, 5783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5787 },
    { MODRM_SPLITRM, 5789 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5791 },
    { MODRM_SPLITRM, 5569 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5793 },
    { MODRM_SPLITRM, 5795 },
    { MODRM_SPLITRM, 5797 },
    { MODRM_SPLITRM, 5799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5801 },
    { MODRM_SPLITRM, 5803 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5805 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5807 },
    { MODRM_SPLITRM, 5809 },
    { MODRM_SPLITRM, 5811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5813 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5815 },
    { MODRM_SPLITRM, 5817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5819 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5821 },
    { MODRM_SPLITRM, 5823 },
    { MODRM_SPLITRM, 5825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5827 },
    { MODRM_SPLITRM, 5829 },
    { MODRM_SPLITRM, 5831 },
    { MODRM_SPLITRM, 5833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5835 },
    { MODRM_SPLITRM, 5593 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5837 },
    { MODRM_SPLITRM, 5839 },
    { MODRM_SPLITRM, 5841 },
    { MODRM_SPLITRM, 5843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5849 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5851 },
    { MODRM_SPLITRM, 5853 },
    { MODRM_SPLITRM, 5855 },
    { MODRM_SPLITRM, 5857 },
    { MODRM_SPLITRM, 5859 },
    { MODRM_SPLITRM, 5861 },
    { MODRM_SPLITRM, 5863 },
    { MODRM_SPLITRM, 5865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5867 },
    { MODRM_SPLITRM, 5869 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5873 },
    { MODRM_SPLITRM, 5875 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5877 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5879 },
    { MODRM_SPLITRM, 5881 },
    { MODRM_SPLITRM, 5883 },
    { MODRM_SPLITRM, 5885 },
    { MODRM_SPLITRM, 5887 },
    { MODRM_SPLITRM, 5889 },
    { MODRM_SPLITRM, 5891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5893 },
    { MODRM_SPLITRM, 5895 },
    { MODRM_SPLITRM, 5897 },
    { MODRM_SPLITRM, 5899 },
    { MODRM_SPLITRM, 5607 },
    { MODRM_SPLITRM, 5609 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5613 },
    { MODRM_SPLITRM, 5615 },
    { MODRM_SPLITRM, 5617 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5621 },
    { MODRM_SPLITRM, 5623 },
    { MODRM_SPLITRM, 5625 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5901 },
    { MODRM_SPLITRM, 5903 },
    { MODRM_SPLITRM, 5905 },
    { MODRM_SPLITRM, 5907 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 5637 },
    { MODRM_SPLITREG, 5909 },
    { MODRM_SPLITREG, 5925 },
    { MODRM_SPLITRM, 5685 },
    { MODRM_SPLITRM, 5687 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5941 },
    { MODRM_SPLITRM, 5943 },
    { MODRM_SPLITRM, 5945 },
    { MODRM_SPLITRM, 5947 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5949 },
    { MODRM_SPLITRM, 5951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5703 },
    { MODRM_SPLITRM, 5705 },
    { MODRM_SPLITRM, 5955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5957 },
    { MODRM_SPLITRM, 5959 },
    { MODRM_SPLITRM, 5711 },
    { MODRM_SPLITRM, 5961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5713 },
    { MODRM_SPLITRM, 5715 },
    { MODRM_SPLITRM, 5717 },
    { MODRM_SPLITRM, 5963 },
    { MODRM_SPLITRM, 5721 },
    { MODRM_SPLITRM, 5723 },
    { MODRM_SPLITRM, 5725 },
    { MODRM_SPLITRM, 5965 },
    { MODRM_SPLITRM, 5729 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5967 },
    { MODRM_SPLITRM, 5735 },
    { MODRM_SPLITRM, 5737 },
    { MODRM_SPLITRM, 5739 },
    { MODRM_SPLITRM, 5969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5743 },
    { MODRM_SPLITRM, 5745 },
    { MODRM_SPLITRM, 5747 },
    { MODRM_SPLITRM, 5971 },
    { MODRM_SPLITRM, 5751 },
    { MODRM_SPLITRM, 5753 },
    { MODRM_SPLITRM, 5755 },
    { MODRM_SPLITRM, 5973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5975 },
    { MODRM_SPLITRM, 5977 },
    { MODRM_SPLITRM, 5763 },
    { MODRM_SPLITRM, 5765 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5767 },
    { MODRM_SPLITRM, 5769 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5979 },
    { MODRM_SPLITRM, 5773 },
    { MODRM_SPLITRM, 5775 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5981 },
    { MODRM_SPLITRM, 5983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5985 },
    { MODRM_SPLITRM, 5987 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5989 },
    { MODRM_SPLITRM, 5991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5497 },
    { MODRM_SPLITRM, 5499 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5995 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5997 },
    { MODRM_SPLITRM, 5999 },
    { MODRM_SPLITRM, 6001 },
    { MODRM_SPLITRM, 6003 },
    { MODRM_SPLITRM, 6005 },
    { MODRM_SPLITRM, 6007 },
    { MODRM_SPLITRM, 6009 },
    { MODRM_SPLITRM, 6011 },
    { MODRM_SPLITRM, 6013 },
    { MODRM_SPLITRM, 6015 },
    { MODRM_SPLITRM, 6017 },
    { MODRM_SPLITRM, 6019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6021 },
    { MODRM_SPLITRM, 6023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6027 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5535 },
    { MODRM_SPLITRM, 5537 },
    { MODRM_SPLITRM, 6029 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6031 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5545 },
    { MODRM_SPLITRM, 5547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5551 },
    { MODRM_SPLITRM, 5553 },
    { MODRM_SPLITRM, 5555 },
    { MODRM_SPLITRM, 6033 },
    { MODRM_SPLITRM, 5559 },
    { MODRM_SPLITRM, 5561 },
    { MODRM_SPLITRM, 5563 },
    { MODRM_SPLITRM, 5565 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6035 },
    { MODRM_SPLITRM, 6037 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5571 },
    { MODRM_SPLITRM, 5573 },
    { MODRM_SPLITRM, 6039 },
    { MODRM_SPLITRM, 5577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6043 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5587 },
    { MODRM_SPLITRM, 5589 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6045 },
    { MODRM_SPLITRM, 6047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5595 },
    { MODRM_SPLITRM, 5597 },
    { MODRM_SPLITRM, 6049 },
    { MODRM_SPLITRM, 5601 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6055 },
    { MODRM_SPLITRM, 6057 },
    { MODRM_SPLITRM, 6059 },
    { MODRM_SPLITRM, 6061 },
    { MODRM_SPLITRM, 6063 },
    { MODRM_SPLITRM, 6065 },
    { MODRM_SPLITRM, 6067 },
    { MODRM_SPLITRM, 6069 },
    { MODRM_SPLITRM, 6071 },
    { MODRM_SPLITRM, 6073 },
    { MODRM_SPLITRM, 6075 },
    { MODRM_SPLITRM, 6077 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6079 },
    { MODRM_SPLITRM, 6081 },
    { MODRM_SPLITREG, 6083 },
    { MODRM_SPLITREG, 6099 },
    { MODRM_SPLITREG, 6115 },
    { MODRM_SPLITRM, 6131 },
    { MODRM_SPLITRM, 6133 },
    { MODRM_SPLITRM, 6135 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6137 },
    { MODRM_SPLITRM, 6139 },
    { MODRM_SPLITRM, 6141 },
    { MODRM_SPLITRM, 6143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6147 },
    { MODRM_SPLITRM, 6149 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6153 },
    { MODRM_SPLITRM, 6155 },
    { MODRM_SPLITRM, 6157 },
    { MODRM_SPLITRM, 6159 },
    { MODRM_SPLITRM, 6161 },
    { MODRM_SPLITRM, 6163 },
    { MODRM_SPLITRM, 6165 },
    { MODRM_SPLITRM, 6167 },
    { MODRM_SPLITRM, 6169 },
    { MODRM_SPLITRM, 6171 },
    { MODRM_SPLITRM, 6173 },
    { MODRM_SPLITRM, 6175 },
    { MODRM_SPLITRM, 6177 },
    { MODRM_SPLITRM, 6179 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6181 },
    { MODRM_SPLITRM, 6183 },
    { MODRM_SPLITRM, 6185 },
    { MODRM_SPLITRM, 6187 },
    { MODRM_SPLITRM, 6189 },
    { MODRM_SPLITRM, 6191 },
    { MODRM_SPLITRM, 6193 },
    { MODRM_SPLITRM, 6195 },
    { MODRM_SPLITRM, 6197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6199 },
    { MODRM_SPLITRM, 6201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6203 },
    { MODRM_SPLITRM, 6205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6207 },
    { MODRM_SPLITRM, 6209 },
    { MODRM_SPLITRM, 6211 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6213 },
    { MODRM_SPLITRM, 6215 },
    { MODRM_SPLITRM, 6217 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6219 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6221 },
    { MODRM_SPLITRM, 6223 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5787 },
    { MODRM_SPLITRM, 5789 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6225 },
    { MODRM_SPLITRM, 6037 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5793 },
    { MODRM_SPLITRM, 5795 },
    { MODRM_SPLITRM, 6227 },
    { MODRM_SPLITRM, 5799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5807 },
    { MODRM_SPLITRM, 5809 },
    { MODRM_SPLITRM, 6233 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5813 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5815 },
    { MODRM_SPLITRM, 5817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5819 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5821 },
    { MODRM_SPLITRM, 5823 },
    { MODRM_SPLITRM, 5825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5827 },
    { MODRM_SPLITRM, 5829 },
    { MODRM_SPLITRM, 5831 },
    { MODRM_SPLITRM, 5833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6235 },
    { MODRM_SPLITRM, 6047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5837 },
    { MODRM_SPLITRM, 5839 },
    { MODRM_SPLITRM, 6237 },
    { MODRM_SPLITRM, 5843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6239 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6241 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6243 },
    { MODRM_SPLITRM, 6245 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6247 },
    { MODRM_SPLITRM, 6249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6251 },
    { MODRM_SPLITRM, 6253 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5873 },
    { MODRM_SPLITRM, 5875 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6259 },
    { MODRM_SPLITRM, 6261 },
    { MODRM_SPLITRM, 6263 },
    { MODRM_SPLITRM, 6265 },
    { MODRM_SPLITRM, 6267 },
    { MODRM_SPLITRM, 6269 },
    { MODRM_SPLITRM, 6271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6273 },
    { MODRM_SPLITRM, 6275 },
    { MODRM_SPLITRM, 6277 },
    { MODRM_SPLITRM, 6279 },
    { MODRM_SPLITRM, 6055 },
    { MODRM_SPLITRM, 6057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6061 },
    { MODRM_SPLITRM, 6063 },
    { MODRM_SPLITRM, 6065 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6069 },
    { MODRM_SPLITRM, 6071 },
    { MODRM_SPLITRM, 6073 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6281 },
    { MODRM_SPLITRM, 6283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 6083 },
    { MODRM_SPLITREG, 6287 },
    { MODRM_SPLITREG, 6303 },
    { MODRM_SPLITRM, 6131 },
    { MODRM_SPLITRM, 6133 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6319 },
    { MODRM_SPLITRM, 6321 },
    { MODRM_SPLITRM, 6323 },
    { MODRM_SPLITRM, 6325 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6327 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6329 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6331 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6333 },
    { MODRM_SPLITRM, 6335 },
    { MODRM_SPLITRM, 6151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6153 },
    { MODRM_SPLITRM, 6155 },
    { MODRM_SPLITRM, 6157 },
    { MODRM_SPLITRM, 6337 },
    { MODRM_SPLITRM, 6161 },
    { MODRM_SPLITRM, 6163 },
    { MODRM_SPLITRM, 6165 },
    { MODRM_SPLITRM, 6339 },
    { MODRM_SPLITRM, 6169 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6341 },
    { MODRM_SPLITRM, 6175 },
    { MODRM_SPLITRM, 6177 },
    { MODRM_SPLITRM, 6179 },
    { MODRM_SPLITRM, 6343 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6183 },
    { MODRM_SPLITRM, 6185 },
    { MODRM_SPLITRM, 6187 },
    { MODRM_SPLITRM, 6345 },
    { MODRM_SPLITRM, 6191 },
    { MODRM_SPLITRM, 6193 },
    { MODRM_SPLITRM, 6195 },
    { MODRM_SPLITRM, 6347 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6349 },
    { MODRM_SPLITRM, 6351 },
    { MODRM_SPLITRM, 6203 },
    { MODRM_SPLITRM, 6205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6207 },
    { MODRM_SPLITRM, 6209 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6353 },
    { MODRM_SPLITRM, 6213 },
    { MODRM_SPLITRM, 6215 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6355 },
    { MODRM_SPLITRM, 6357 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6359 },
    { MODRM_SPLITRM, 6361 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6363 },
    { MODRM_SPLITRM, 6365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6367 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5497 },
    { MODRM_SPLITRM, 5499 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6369 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6371 },
    { MODRM_SPLITRM, 6373 },
    { MODRM_SPLITRM, 6375 },
    { MODRM_SPLITRM, 6377 },
    { MODRM_SPLITRM, 6379 },
    { MODRM_SPLITRM, 6381 },
    { MODRM_SPLITRM, 6383 },
    { MODRM_SPLITRM, 6385 },
    { MODRM_SPLITRM, 6387 },
    { MODRM_SPLITRM, 6389 },
    { MODRM_SPLITRM, 6391 },
    { MODRM_SPLITRM, 6393 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6395 },
    { MODRM_SPLITRM, 6397 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6399 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6401 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5535 },
    { MODRM_SPLITRM, 5537 },
    { MODRM_SPLITRM, 6403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6405 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5545 },
    { MODRM_SPLITRM, 5547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5551 },
    { MODRM_SPLITRM, 5553 },
    { MODRM_SPLITRM, 5555 },
    { MODRM_SPLITRM, 6407 },
    { MODRM_SPLITRM, 5559 },
    { MODRM_SPLITRM, 5561 },
    { MODRM_SPLITRM, 5563 },
    { MODRM_SPLITRM, 5565 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6409 },
    { MODRM_SPLITRM, 6411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5571 },
    { MODRM_SPLITRM, 5573 },
    { MODRM_SPLITRM, 6413 },
    { MODRM_SPLITRM, 5577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5587 },
    { MODRM_SPLITRM, 5589 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6419 },
    { MODRM_SPLITRM, 6421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5595 },
    { MODRM_SPLITRM, 5597 },
    { MODRM_SPLITRM, 6423 },
    { MODRM_SPLITRM, 5601 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6429 },
    { MODRM_SPLITRM, 6431 },
    { MODRM_SPLITRM, 6433 },
    { MODRM_SPLITRM, 6435 },
    { MODRM_SPLITRM, 6437 },
    { MODRM_SPLITRM, 6439 },
    { MODRM_SPLITRM, 6441 },
    { MODRM_SPLITRM, 6443 },
    { MODRM_SPLITRM, 6445 },
    { MODRM_SPLITRM, 6447 },
    { MODRM_SPLITRM, 6449 },
    { MODRM_SPLITRM, 6451 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6453 },
    { MODRM_SPLITRM, 6455 },
    { MODRM_SPLITREG, 6457 },
    { MODRM_SPLITREG, 6473 },
    { MODRM_SPLITREG, 6489 },
    { MODRM_SPLITRM, 6505 },
    { MODRM_SPLITRM, 6507 },
    { MODRM_SPLITRM, 6509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6511 },
    { MODRM_SPLITRM, 6513 },
    { MODRM_SPLITRM, 6515 },
    { MODRM_SPLITRM, 6517 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6519 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6521 },
    { MODRM_SPLITRM, 6523 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6525 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6527 },
    { MODRM_SPLITRM, 6529 },
    { MODRM_SPLITRM, 6531 },
    { MODRM_SPLITRM, 6533 },
    { MODRM_SPLITRM, 6535 },
    { MODRM_SPLITRM, 6537 },
    { MODRM_SPLITRM, 6539 },
    { MODRM_SPLITRM, 6541 },
    { MODRM_SPLITRM, 6543 },
    { MODRM_SPLITRM, 6545 },
    { MODRM_SPLITRM, 6547 },
    { MODRM_SPLITRM, 6549 },
    { MODRM_SPLITRM, 6551 },
    { MODRM_SPLITRM, 6553 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6555 },
    { MODRM_SPLITRM, 6557 },
    { MODRM_SPLITRM, 6559 },
    { MODRM_SPLITRM, 6561 },
    { MODRM_SPLITRM, 6563 },
    { MODRM_SPLITRM, 6565 },
    { MODRM_SPLITRM, 6567 },
    { MODRM_SPLITRM, 6569 },
    { MODRM_SPLITRM, 6571 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6573 },
    { MODRM_SPLITRM, 6575 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6577 },
    { MODRM_SPLITRM, 6579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6581 },
    { MODRM_SPLITRM, 6583 },
    { MODRM_SPLITRM, 6585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6587 },
    { MODRM_SPLITRM, 6589 },
    { MODRM_SPLITRM, 6591 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6593 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6595 },
    { MODRM_SPLITRM, 6597 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5787 },
    { MODRM_SPLITRM, 5789 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6599 },
    { MODRM_SPLITRM, 6411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5793 },
    { MODRM_SPLITRM, 5795 },
    { MODRM_SPLITRM, 6601 },
    { MODRM_SPLITRM, 5799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6603 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6605 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5807 },
    { MODRM_SPLITRM, 5809 },
    { MODRM_SPLITRM, 6607 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5813 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5815 },
    { MODRM_SPLITRM, 5817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5819 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5821 },
    { MODRM_SPLITRM, 5823 },
    { MODRM_SPLITRM, 5825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5827 },
    { MODRM_SPLITRM, 5829 },
    { MODRM_SPLITRM, 5831 },
    { MODRM_SPLITRM, 5833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6609 },
    { MODRM_SPLITRM, 6421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5837 },
    { MODRM_SPLITRM, 5839 },
    { MODRM_SPLITRM, 6611 },
    { MODRM_SPLITRM, 5843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6613 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6615 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6617 },
    { MODRM_SPLITRM, 6619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6621 },
    { MODRM_SPLITRM, 6623 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6625 },
    { MODRM_SPLITRM, 6627 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 5873 },
    { MODRM_SPLITRM, 5875 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6631 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6633 },
    { MODRM_SPLITRM, 6635 },
    { MODRM_SPLITRM, 6637 },
    { MODRM_SPLITRM, 6639 },
    { MODRM_SPLITRM, 6641 },
    { MODRM_SPLITRM, 6643 },
    { MODRM_SPLITRM, 6645 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6647 },
    { MODRM_SPLITRM, 6649 },
    { MODRM_SPLITRM, 6651 },
    { MODRM_SPLITRM, 6653 },
    { MODRM_SPLITRM, 6429 },
    { MODRM_SPLITRM, 6431 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6435 },
    { MODRM_SPLITRM, 6437 },
    { MODRM_SPLITRM, 6439 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6443 },
    { MODRM_SPLITRM, 6445 },
    { MODRM_SPLITRM, 6447 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6655 },
    { MODRM_SPLITRM, 6657 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 6457 },
    { MODRM_SPLITREG, 6661 },
    { MODRM_SPLITREG, 6677 },
    { MODRM_SPLITRM, 6505 },
    { MODRM_SPLITRM, 6507 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6693 },
    { MODRM_SPLITRM, 6695 },
    { MODRM_SPLITRM, 6697 },
    { MODRM_SPLITRM, 6699 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6701 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6703 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6705 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6707 },
    { MODRM_SPLITRM, 6709 },
    { MODRM_SPLITRM, 6525 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6527 },
    { MODRM_SPLITRM, 6529 },
    { MODRM_SPLITRM, 6531 },
    { MODRM_SPLITRM, 6711 },
    { MODRM_SPLITRM, 6535 },
    { MODRM_SPLITRM, 6537 },
    { MODRM_SPLITRM, 6539 },
    { MODRM_SPLITRM, 6713 },
    { MODRM_SPLITRM, 6543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6715 },
    { MODRM_SPLITRM, 6549 },
    { MODRM_SPLITRM, 6551 },
    { MODRM_SPLITRM, 6553 },
    { MODRM_SPLITRM, 6717 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6557 },
    { MODRM_SPLITRM, 6559 },
    { MODRM_SPLITRM, 6561 },
    { MODRM_SPLITRM, 6719 },
    { MODRM_SPLITRM, 6565 },
    { MODRM_SPLITRM, 6567 },
    { MODRM_SPLITRM, 6569 },
    { MODRM_SPLITRM, 6721 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6723 },
    { MODRM_SPLITRM, 6725 },
    { MODRM_SPLITRM, 6577 },
    { MODRM_SPLITRM, 6579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6581 },
    { MODRM_SPLITRM, 6583 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6727 },
    { MODRM_SPLITRM, 6587 },
    { MODRM_SPLITRM, 6589 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6729 },
    { MODRM_SPLITRM, 6731 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6733 },
    { MODRM_SPLITRM, 6735 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6737 },
    { MODRM_SPLITRM, 6739 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6741 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6743 },
    { MODRM_SPLITRM, 6745 },
    { MODRM_SPLITRM, 6747 },
    { MODRM_SPLITRM, 6749 },
    { MODRM_SPLITRM, 6751 },
    { MODRM_SPLITRM, 6753 },
    { MODRM_SPLITRM, 6755 },
    { MODRM_SPLITRM, 6757 },
    { MODRM_SPLITRM, 6759 },
    { MODRM_SPLITRM, 6761 },
    { MODRM_SPLITRM, 6763 },
    { MODRM_SPLITRM, 6765 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6767 },
    { MODRM_SPLITRM, 6769 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6771 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6773 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6775 },
    { MODRM_SPLITRM, 6777 },
    { MODRM_SPLITRM, 6779 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6781 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6785 },
    { MODRM_SPLITRM, 6787 },
    { MODRM_SPLITRM, 6789 },
    { MODRM_SPLITRM, 6791 },
    { MODRM_SPLITRM, 6793 },
    { MODRM_SPLITRM, 6795 },
    { MODRM_SPLITRM, 6797 },
    { MODRM_SPLITRM, 6799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6801 },
    { MODRM_SPLITRM, 6803 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6805 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6813 },
    { MODRM_SPLITRM, 6815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6819 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6823 },
    { MODRM_SPLITRM, 6825 },
    { MODRM_SPLITRM, 6827 },
    { MODRM_SPLITRM, 6829 },
    { MODRM_SPLITRM, 6831 },
    { MODRM_SPLITRM, 6833 },
    { MODRM_SPLITRM, 6835 },
    { MODRM_SPLITRM, 6837 },
    { MODRM_SPLITRM, 6839 },
    { MODRM_SPLITRM, 6841 },
    { MODRM_SPLITRM, 6843 },
    { MODRM_SPLITRM, 6845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6847 },
    { MODRM_SPLITRM, 6849 },
    { MODRM_SPLITREG, 6851 },
    { MODRM_SPLITREG, 6867 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6883 },
    { MODRM_SPLITRM, 6885 },
    { MODRM_SPLITRM, 6887 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6889 },
    { MODRM_SPLITRM, 6891 },
    { MODRM_SPLITRM, 6893 },
    { MODRM_SPLITRM, 6895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6899 },
    { MODRM_SPLITRM, 6901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6905 },
    { MODRM_SPLITRM, 6907 },
    { MODRM_SPLITRM, 6909 },
    { MODRM_SPLITRM, 6911 },
    { MODRM_SPLITRM, 6913 },
    { MODRM_SPLITRM, 6915 },
    { MODRM_SPLITRM, 6917 },
    { MODRM_SPLITRM, 6919 },
    { MODRM_SPLITRM, 6921 },
    { MODRM_SPLITRM, 6923 },
    { MODRM_SPLITRM, 6925 },
    { MODRM_SPLITRM, 6927 },
    { MODRM_SPLITRM, 6929 },
    { MODRM_SPLITRM, 6931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6933 },
    { MODRM_SPLITRM, 6935 },
    { MODRM_SPLITRM, 6937 },
    { MODRM_SPLITRM, 6939 },
    { MODRM_SPLITRM, 6941 },
    { MODRM_SPLITRM, 6943 },
    { MODRM_SPLITRM, 6945 },
    { MODRM_SPLITRM, 6947 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6949 },
    { MODRM_SPLITRM, 6951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6955 },
    { MODRM_SPLITRM, 6957 },
    { MODRM_SPLITRM, 6959 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6961 },
    { MODRM_SPLITRM, 6963 },
    { MODRM_SPLITRM, 6965 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6969 },
    { MODRM_SPLITRM, 6971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6973 },
    { MODRM_SPLITRM, 6803 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6979 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6981 },
    { MODRM_SPLITRM, 6983 },
    { MODRM_SPLITRM, 6985 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6987 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6989 },
    { MODRM_SPLITRM, 6991 },
    { MODRM_SPLITRM, 6993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6995 },
    { MODRM_SPLITRM, 6997 },
    { MODRM_SPLITRM, 6999 },
    { MODRM_SPLITRM, 7001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7003 },
    { MODRM_SPLITRM, 6815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7007 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7011 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7013 },
    { MODRM_SPLITRM, 7015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7017 },
    { MODRM_SPLITRM, 7019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7021 },
    { MODRM_SPLITRM, 7023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7027 },
    { MODRM_SPLITRM, 7029 },
    { MODRM_SPLITRM, 7031 },
    { MODRM_SPLITRM, 7033 },
    { MODRM_SPLITRM, 7035 },
    { MODRM_SPLITRM, 7037 },
    { MODRM_SPLITRM, 7039 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7041 },
    { MODRM_SPLITRM, 7043 },
    { MODRM_SPLITRM, 7045 },
    { MODRM_SPLITRM, 7047 },
    { MODRM_SPLITRM, 6823 },
    { MODRM_SPLITRM, 6825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6829 },
    { MODRM_SPLITRM, 6831 },
    { MODRM_SPLITRM, 6833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6837 },
    { MODRM_SPLITRM, 6839 },
    { MODRM_SPLITRM, 6841 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7049 },
    { MODRM_SPLITRM, 7051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 6851 },
    { MODRM_SPLITREG, 7055 },
    { MODRM_SPLITREG, 7071 },
    { MODRM_SPLITRM, 6883 },
    { MODRM_SPLITRM, 6885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7087 },
    { MODRM_SPLITRM, 7089 },
    { MODRM_SPLITRM, 7091 },
    { MODRM_SPLITRM, 7093 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7095 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7097 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7099 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7101 },
    { MODRM_SPLITRM, 7103 },
    { MODRM_SPLITRM, 6903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6905 },
    { MODRM_SPLITRM, 6907 },
    { MODRM_SPLITRM, 6909 },
    { MODRM_SPLITRM, 7105 },
    { MODRM_SPLITRM, 6913 },
    { MODRM_SPLITRM, 6915 },
    { MODRM_SPLITRM, 6917 },
    { MODRM_SPLITRM, 7107 },
    { MODRM_SPLITRM, 6921 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7109 },
    { MODRM_SPLITRM, 6927 },
    { MODRM_SPLITRM, 6929 },
    { MODRM_SPLITRM, 6931 },
    { MODRM_SPLITRM, 7111 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6933 },
    { MODRM_SPLITRM, 6935 },
    { MODRM_SPLITRM, 6937 },
    { MODRM_SPLITRM, 7113 },
    { MODRM_SPLITRM, 6941 },
    { MODRM_SPLITRM, 6943 },
    { MODRM_SPLITRM, 6945 },
    { MODRM_SPLITRM, 7115 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7117 },
    { MODRM_SPLITRM, 7119 },
    { MODRM_SPLITRM, 6953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6955 },
    { MODRM_SPLITRM, 6957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7121 },
    { MODRM_SPLITRM, 6961 },
    { MODRM_SPLITRM, 6963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7123 },
    { MODRM_SPLITRM, 7125 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7127 },
    { MODRM_SPLITRM, 7129 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7131 },
    { MODRM_SPLITRM, 7133 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7135 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7137 },
    { MODRM_SPLITRM, 7139 },
    { MODRM_SPLITRM, 7141 },
    { MODRM_SPLITRM, 7143 },
    { MODRM_SPLITRM, 7145 },
    { MODRM_SPLITRM, 7147 },
    { MODRM_SPLITRM, 7149 },
    { MODRM_SPLITRM, 7151 },
    { MODRM_SPLITRM, 7153 },
    { MODRM_SPLITRM, 7155 },
    { MODRM_SPLITRM, 7157 },
    { MODRM_SPLITRM, 7159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7161 },
    { MODRM_SPLITRM, 7163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7165 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7167 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6775 },
    { MODRM_SPLITRM, 6777 },
    { MODRM_SPLITRM, 7169 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7171 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6785 },
    { MODRM_SPLITRM, 6787 },
    { MODRM_SPLITRM, 6789 },
    { MODRM_SPLITRM, 7173 },
    { MODRM_SPLITRM, 6793 },
    { MODRM_SPLITRM, 6795 },
    { MODRM_SPLITRM, 6797 },
    { MODRM_SPLITRM, 6799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7175 },
    { MODRM_SPLITRM, 7177 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7179 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7181 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7185 },
    { MODRM_SPLITRM, 7187 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7191 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7195 },
    { MODRM_SPLITRM, 7197 },
    { MODRM_SPLITRM, 7199 },
    { MODRM_SPLITRM, 7201 },
    { MODRM_SPLITRM, 7203 },
    { MODRM_SPLITRM, 7205 },
    { MODRM_SPLITRM, 7207 },
    { MODRM_SPLITRM, 7209 },
    { MODRM_SPLITRM, 7211 },
    { MODRM_SPLITRM, 7213 },
    { MODRM_SPLITRM, 7215 },
    { MODRM_SPLITRM, 7217 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7219 },
    { MODRM_SPLITRM, 7221 },
    { MODRM_SPLITREG, 7223 },
    { MODRM_SPLITREG, 7239 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7255 },
    { MODRM_SPLITRM, 7257 },
    { MODRM_SPLITRM, 7259 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7261 },
    { MODRM_SPLITRM, 7263 },
    { MODRM_SPLITRM, 7265 },
    { MODRM_SPLITRM, 7267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7269 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7271 },
    { MODRM_SPLITRM, 7273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7275 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7277 },
    { MODRM_SPLITRM, 7279 },
    { MODRM_SPLITRM, 7281 },
    { MODRM_SPLITRM, 7283 },
    { MODRM_SPLITRM, 7285 },
    { MODRM_SPLITRM, 7287 },
    { MODRM_SPLITRM, 7289 },
    { MODRM_SPLITRM, 7291 },
    { MODRM_SPLITRM, 7293 },
    { MODRM_SPLITRM, 7295 },
    { MODRM_SPLITRM, 7297 },
    { MODRM_SPLITRM, 7299 },
    { MODRM_SPLITRM, 7301 },
    { MODRM_SPLITRM, 7303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7305 },
    { MODRM_SPLITRM, 7307 },
    { MODRM_SPLITRM, 7309 },
    { MODRM_SPLITRM, 7311 },
    { MODRM_SPLITRM, 7313 },
    { MODRM_SPLITRM, 7315 },
    { MODRM_SPLITRM, 7317 },
    { MODRM_SPLITRM, 7319 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7321 },
    { MODRM_SPLITRM, 7323 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7325 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7327 },
    { MODRM_SPLITRM, 7329 },
    { MODRM_SPLITRM, 7331 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7333 },
    { MODRM_SPLITRM, 7335 },
    { MODRM_SPLITRM, 7337 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7339 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7341 },
    { MODRM_SPLITRM, 7343 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7345 },
    { MODRM_SPLITRM, 7177 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7347 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6981 },
    { MODRM_SPLITRM, 6983 },
    { MODRM_SPLITRM, 7353 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6987 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6989 },
    { MODRM_SPLITRM, 6991 },
    { MODRM_SPLITRM, 6993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6995 },
    { MODRM_SPLITRM, 6997 },
    { MODRM_SPLITRM, 6999 },
    { MODRM_SPLITRM, 7001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7355 },
    { MODRM_SPLITRM, 7187 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7357 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7359 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7361 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7363 },
    { MODRM_SPLITRM, 7365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7367 },
    { MODRM_SPLITRM, 7369 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7371 },
    { MODRM_SPLITRM, 7373 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7375 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7377 },
    { MODRM_SPLITRM, 7379 },
    { MODRM_SPLITRM, 7381 },
    { MODRM_SPLITRM, 7383 },
    { MODRM_SPLITRM, 7385 },
    { MODRM_SPLITRM, 7387 },
    { MODRM_SPLITRM, 7389 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7391 },
    { MODRM_SPLITRM, 7393 },
    { MODRM_SPLITRM, 7395 },
    { MODRM_SPLITRM, 7397 },
    { MODRM_SPLITRM, 7195 },
    { MODRM_SPLITRM, 7197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7201 },
    { MODRM_SPLITRM, 7203 },
    { MODRM_SPLITRM, 7205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7209 },
    { MODRM_SPLITRM, 7211 },
    { MODRM_SPLITRM, 7213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7399 },
    { MODRM_SPLITRM, 7401 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 7223 },
    { MODRM_SPLITREG, 7405 },
    { MODRM_SPLITREG, 7421 },
    { MODRM_SPLITRM, 7255 },
    { MODRM_SPLITRM, 7257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7437 },
    { MODRM_SPLITRM, 7439 },
    { MODRM_SPLITRM, 7441 },
    { MODRM_SPLITRM, 7443 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7445 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7447 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7449 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7451 },
    { MODRM_SPLITRM, 7453 },
    { MODRM_SPLITRM, 7275 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7277 },
    { MODRM_SPLITRM, 7279 },
    { MODRM_SPLITRM, 7281 },
    { MODRM_SPLITRM, 7455 },
    { MODRM_SPLITRM, 7285 },
    { MODRM_SPLITRM, 7287 },
    { MODRM_SPLITRM, 7289 },
    { MODRM_SPLITRM, 7457 },
    { MODRM_SPLITRM, 7293 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7459 },
    { MODRM_SPLITRM, 7299 },
    { MODRM_SPLITRM, 7301 },
    { MODRM_SPLITRM, 7303 },
    { MODRM_SPLITRM, 7461 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7305 },
    { MODRM_SPLITRM, 7307 },
    { MODRM_SPLITRM, 7309 },
    { MODRM_SPLITRM, 7463 },
    { MODRM_SPLITRM, 7313 },
    { MODRM_SPLITRM, 7315 },
    { MODRM_SPLITRM, 7317 },
    { MODRM_SPLITRM, 7465 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7467 },
    { MODRM_SPLITRM, 7469 },
    { MODRM_SPLITRM, 7325 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7327 },
    { MODRM_SPLITRM, 7329 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7471 },
    { MODRM_SPLITRM, 7333 },
    { MODRM_SPLITRM, 7335 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7473 },
    { MODRM_SPLITRM, 7475 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7477 },
    { MODRM_SPLITRM, 7479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7481 },
    { MODRM_SPLITRM, 7483 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7487 },
    { MODRM_SPLITRM, 7489 },
    { MODRM_SPLITRM, 7491 },
    { MODRM_SPLITRM, 7493 },
    { MODRM_SPLITRM, 7495 },
    { MODRM_SPLITRM, 7497 },
    { MODRM_SPLITRM, 7499 },
    { MODRM_SPLITRM, 7501 },
    { MODRM_SPLITRM, 7503 },
    { MODRM_SPLITRM, 7505 },
    { MODRM_SPLITRM, 7507 },
    { MODRM_SPLITRM, 7509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7511 },
    { MODRM_SPLITRM, 7513 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7517 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6775 },
    { MODRM_SPLITRM, 6777 },
    { MODRM_SPLITRM, 7519 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7521 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6785 },
    { MODRM_SPLITRM, 6787 },
    { MODRM_SPLITRM, 6789 },
    { MODRM_SPLITRM, 7523 },
    { MODRM_SPLITRM, 6793 },
    { MODRM_SPLITRM, 6795 },
    { MODRM_SPLITRM, 6797 },
    { MODRM_SPLITRM, 6799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7525 },
    { MODRM_SPLITRM, 7527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7529 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7531 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7533 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7535 },
    { MODRM_SPLITRM, 7537 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7541 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7545 },
    { MODRM_SPLITRM, 7547 },
    { MODRM_SPLITRM, 7549 },
    { MODRM_SPLITRM, 7551 },
    { MODRM_SPLITRM, 7553 },
    { MODRM_SPLITRM, 7555 },
    { MODRM_SPLITRM, 7557 },
    { MODRM_SPLITRM, 7559 },
    { MODRM_SPLITRM, 7561 },
    { MODRM_SPLITRM, 7563 },
    { MODRM_SPLITRM, 7565 },
    { MODRM_SPLITRM, 7567 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7569 },
    { MODRM_SPLITRM, 7571 },
    { MODRM_SPLITREG, 7573 },
    { MODRM_SPLITREG, 7589 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7605 },
    { MODRM_SPLITRM, 7607 },
    { MODRM_SPLITRM, 7609 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7611 },
    { MODRM_SPLITRM, 7613 },
    { MODRM_SPLITRM, 7615 },
    { MODRM_SPLITRM, 7617 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7621 },
    { MODRM_SPLITRM, 7623 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7625 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7627 },
    { MODRM_SPLITRM, 7629 },
    { MODRM_SPLITRM, 7631 },
    { MODRM_SPLITRM, 7633 },
    { MODRM_SPLITRM, 7635 },
    { MODRM_SPLITRM, 7637 },
    { MODRM_SPLITRM, 7639 },
    { MODRM_SPLITRM, 7641 },
    { MODRM_SPLITRM, 7643 },
    { MODRM_SPLITRM, 7645 },
    { MODRM_SPLITRM, 7647 },
    { MODRM_SPLITRM, 7649 },
    { MODRM_SPLITRM, 7651 },
    { MODRM_SPLITRM, 7653 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7655 },
    { MODRM_SPLITRM, 7657 },
    { MODRM_SPLITRM, 7659 },
    { MODRM_SPLITRM, 7661 },
    { MODRM_SPLITRM, 7663 },
    { MODRM_SPLITRM, 7665 },
    { MODRM_SPLITRM, 7667 },
    { MODRM_SPLITRM, 7669 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7671 },
    { MODRM_SPLITRM, 7673 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7675 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7677 },
    { MODRM_SPLITRM, 7679 },
    { MODRM_SPLITRM, 7681 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7683 },
    { MODRM_SPLITRM, 7685 },
    { MODRM_SPLITRM, 7687 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7689 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7691 },
    { MODRM_SPLITRM, 7693 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7695 },
    { MODRM_SPLITRM, 7527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7697 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7699 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7701 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6981 },
    { MODRM_SPLITRM, 6983 },
    { MODRM_SPLITRM, 7703 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6987 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6989 },
    { MODRM_SPLITRM, 6991 },
    { MODRM_SPLITRM, 6993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 6995 },
    { MODRM_SPLITRM, 6997 },
    { MODRM_SPLITRM, 6999 },
    { MODRM_SPLITRM, 7001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7705 },
    { MODRM_SPLITRM, 7537 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7707 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7711 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7713 },
    { MODRM_SPLITRM, 7715 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7717 },
    { MODRM_SPLITRM, 7719 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7721 },
    { MODRM_SPLITRM, 7723 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7725 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7727 },
    { MODRM_SPLITRM, 7729 },
    { MODRM_SPLITRM, 7731 },
    { MODRM_SPLITRM, 7733 },
    { MODRM_SPLITRM, 7735 },
    { MODRM_SPLITRM, 7737 },
    { MODRM_SPLITRM, 7739 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7741 },
    { MODRM_SPLITRM, 7743 },
    { MODRM_SPLITRM, 7745 },
    { MODRM_SPLITRM, 7747 },
    { MODRM_SPLITRM, 7545 },
    { MODRM_SPLITRM, 7547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7551 },
    { MODRM_SPLITRM, 7553 },
    { MODRM_SPLITRM, 7555 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7559 },
    { MODRM_SPLITRM, 7561 },
    { MODRM_SPLITRM, 7563 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7749 },
    { MODRM_SPLITRM, 7751 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7753 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 7573 },
    { MODRM_SPLITREG, 7755 },
    { MODRM_SPLITREG, 7771 },
    { MODRM_SPLITRM, 7605 },
    { MODRM_SPLITRM, 7607 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7787 },
    { MODRM_SPLITRM, 7789 },
    { MODRM_SPLITRM, 7791 },
    { MODRM_SPLITRM, 7793 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7795 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7797 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7801 },
    { MODRM_SPLITRM, 7803 },
    { MODRM_SPLITRM, 7625 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7627 },
    { MODRM_SPLITRM, 7629 },
    { MODRM_SPLITRM, 7631 },
    { MODRM_SPLITRM, 7805 },
    { MODRM_SPLITRM, 7635 },
    { MODRM_SPLITRM, 7637 },
    { MODRM_SPLITRM, 7639 },
    { MODRM_SPLITRM, 7807 },
    { MODRM_SPLITRM, 7643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7809 },
    { MODRM_SPLITRM, 7649 },
    { MODRM_SPLITRM, 7651 },
    { MODRM_SPLITRM, 7653 },
    { MODRM_SPLITRM, 7811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7655 },
    { MODRM_SPLITRM, 7657 },
    { MODRM_SPLITRM, 7659 },
    { MODRM_SPLITRM, 7813 },
    { MODRM_SPLITRM, 7663 },
    { MODRM_SPLITRM, 7665 },
    { MODRM_SPLITRM, 7667 },
    { MODRM_SPLITRM, 7815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7817 },
    { MODRM_SPLITRM, 7819 },
    { MODRM_SPLITRM, 7675 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7677 },
    { MODRM_SPLITRM, 7679 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7821 },
    { MODRM_SPLITRM, 7683 },
    { MODRM_SPLITRM, 7685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7823 },
    { MODRM_SPLITRM, 7825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7827 },
    { MODRM_SPLITRM, 7829 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7833 },
    { MODRM_SPLITRM, 7835 },
    { MODRM_SPLITRM, 7837 },
    { MODRM_SPLITRM, 7839 },
    { MODRM_SPLITRM, 7841 },
    { MODRM_SPLITRM, 7843 },
    { MODRM_SPLITRM, 7845 },
    { MODRM_SPLITRM, 7847 },
    { MODRM_SPLITRM, 7849 },
    { MODRM_SPLITRM, 7851 },
    { MODRM_SPLITRM, 7853 },
    { MODRM_SPLITRM, 7855 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7857 },
    { MODRM_SPLITRM, 7859 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7867 },
    { MODRM_SPLITRM, 7869 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7873 },
    { MODRM_SPLITRM, 7875 },
    { MODRM_SPLITRM, 7877 },
    { MODRM_SPLITRM, 7879 },
    { MODRM_SPLITRM, 7881 },
    { MODRM_SPLITRM, 7883 },
    { MODRM_SPLITRM, 7885 },
    { MODRM_SPLITRM, 7887 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7889 },
    { MODRM_SPLITRM, 7891 },
    { MODRM_SPLITRM, 7893 },
    { MODRM_SPLITRM, 7895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7903 },
    { MODRM_SPLITRM, 7905 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7907 },
    { MODRM_SPLITRM, 7909 },
    { MODRM_SPLITRM, 7911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7917 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7919 },
    { MODRM_SPLITRM, 7921 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 7925 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7943 },
    { MODRM_SPLITRM, 7945 },
    { MODRM_SPLITRM, 7947 },
    { MODRM_SPLITRM, 7949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7959 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7961 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7965 },
    { MODRM_SPLITRM, 7967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7971 },
    { MODRM_SPLITRM, 7973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7975 },
    { MODRM_SPLITRM, 7977 },
    { MODRM_SPLITRM, 7979 },
    { MODRM_SPLITRM, 7981 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7985 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7987 },
    { MODRM_SPLITRM, 7989 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7993 },
    { MODRM_SPLITRM, 7995 },
    { MODRM_SPLITRM, 7997 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7999 },
    { MODRM_SPLITRM, 8001 },
    { MODRM_SPLITRM, 8003 },
    { MODRM_SPLITRM, 8005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8007 },
    { MODRM_SPLITRM, 8009 },
    { MODRM_SPLITRM, 8011 },
    { MODRM_SPLITRM, 8013 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8019 },
    { MODRM_SPLITRM, 8021 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8023 },
    { MODRM_SPLITRM, 8025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8027 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8029 },
    { MODRM_SPLITRM, 8031 },
    { MODRM_SPLITRM, 8033 },
    { MODRM_SPLITRM, 8035 },
    { MODRM_SPLITRM, 8037 },
    { MODRM_SPLITRM, 8039 },
    { MODRM_SPLITRM, 8041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8043 },
    { MODRM_SPLITRM, 8045 },
    { MODRM_SPLITRM, 8047 },
    { MODRM_SPLITRM, 8049 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8051 },
    { MODRM_SPLITRM, 8053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8055 },
    { MODRM_SPLITREG, 8071 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8087 },
    { MODRM_SPLITRM, 8089 },
    { MODRM_SPLITRM, 8091 },
    { MODRM_SPLITRM, 8093 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8095 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8097 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8099 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8101 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8103 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8105 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8107 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8109 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8111 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8113 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8115 },
    { MODRM_SPLITRM, 8117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7827 },
    { MODRM_SPLITRM, 7829 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8119 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8121 },
    { MODRM_SPLITRM, 8123 },
    { MODRM_SPLITRM, 8125 },
    { MODRM_SPLITRM, 8127 },
    { MODRM_SPLITRM, 8129 },
    { MODRM_SPLITRM, 8131 },
    { MODRM_SPLITRM, 8133 },
    { MODRM_SPLITRM, 8135 },
    { MODRM_SPLITRM, 8137 },
    { MODRM_SPLITRM, 8139 },
    { MODRM_SPLITRM, 8141 },
    { MODRM_SPLITRM, 8143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8145 },
    { MODRM_SPLITRM, 8147 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8149 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7867 },
    { MODRM_SPLITRM, 7869 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7873 },
    { MODRM_SPLITRM, 7875 },
    { MODRM_SPLITRM, 7877 },
    { MODRM_SPLITRM, 8153 },
    { MODRM_SPLITRM, 7881 },
    { MODRM_SPLITRM, 7883 },
    { MODRM_SPLITRM, 7885 },
    { MODRM_SPLITRM, 7887 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7889 },
    { MODRM_SPLITRM, 7891 },
    { MODRM_SPLITRM, 8155 },
    { MODRM_SPLITRM, 7895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8157 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7903 },
    { MODRM_SPLITRM, 7905 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7907 },
    { MODRM_SPLITRM, 7909 },
    { MODRM_SPLITRM, 8159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8161 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8165 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8167 },
    { MODRM_SPLITRM, 8169 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8171 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8173 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8191 },
    { MODRM_SPLITRM, 8193 },
    { MODRM_SPLITRM, 8195 },
    { MODRM_SPLITRM, 8197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8199 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8203 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8209 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8211 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8213 },
    { MODRM_SPLITRM, 8215 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7971 },
    { MODRM_SPLITRM, 7973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7975 },
    { MODRM_SPLITRM, 7977 },
    { MODRM_SPLITRM, 8217 },
    { MODRM_SPLITRM, 7981 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8219 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7985 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7987 },
    { MODRM_SPLITRM, 7989 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7993 },
    { MODRM_SPLITRM, 7995 },
    { MODRM_SPLITRM, 7997 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7999 },
    { MODRM_SPLITRM, 8001 },
    { MODRM_SPLITRM, 8003 },
    { MODRM_SPLITRM, 8005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8007 },
    { MODRM_SPLITRM, 8009 },
    { MODRM_SPLITRM, 8221 },
    { MODRM_SPLITRM, 8013 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8223 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8225 },
    { MODRM_SPLITRM, 8227 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8023 },
    { MODRM_SPLITRM, 8025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8231 },
    { MODRM_SPLITRM, 8233 },
    { MODRM_SPLITRM, 8235 },
    { MODRM_SPLITRM, 8237 },
    { MODRM_SPLITRM, 8239 },
    { MODRM_SPLITRM, 8241 },
    { MODRM_SPLITRM, 8243 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8245 },
    { MODRM_SPLITRM, 8247 },
    { MODRM_SPLITRM, 8249 },
    { MODRM_SPLITRM, 8251 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8253 },
    { MODRM_SPLITRM, 8255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8257 },
    { MODRM_SPLITREG, 8273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8289 },
    { MODRM_SPLITRM, 8291 },
    { MODRM_SPLITRM, 8293 },
    { MODRM_SPLITRM, 8295 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8297 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8307 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8311 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8313 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8315 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8317 },
    { MODRM_SPLITRM, 8319 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7827 },
    { MODRM_SPLITRM, 7829 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8321 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8323 },
    { MODRM_SPLITRM, 8325 },
    { MODRM_SPLITRM, 8327 },
    { MODRM_SPLITRM, 8329 },
    { MODRM_SPLITRM, 8331 },
    { MODRM_SPLITRM, 8333 },
    { MODRM_SPLITRM, 8335 },
    { MODRM_SPLITRM, 8337 },
    { MODRM_SPLITRM, 8339 },
    { MODRM_SPLITRM, 8341 },
    { MODRM_SPLITRM, 8343 },
    { MODRM_SPLITRM, 8345 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8347 },
    { MODRM_SPLITRM, 8349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8353 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7867 },
    { MODRM_SPLITRM, 7869 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7873 },
    { MODRM_SPLITRM, 7875 },
    { MODRM_SPLITRM, 7877 },
    { MODRM_SPLITRM, 8355 },
    { MODRM_SPLITRM, 7881 },
    { MODRM_SPLITRM, 7883 },
    { MODRM_SPLITRM, 7885 },
    { MODRM_SPLITRM, 7887 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7889 },
    { MODRM_SPLITRM, 7891 },
    { MODRM_SPLITRM, 8357 },
    { MODRM_SPLITRM, 7895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8359 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7903 },
    { MODRM_SPLITRM, 7905 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7907 },
    { MODRM_SPLITRM, 7909 },
    { MODRM_SPLITRM, 8361 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8363 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8367 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8369 },
    { MODRM_SPLITRM, 8371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8373 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8375 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8391 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8393 },
    { MODRM_SPLITRM, 8395 },
    { MODRM_SPLITRM, 8397 },
    { MODRM_SPLITRM, 8399 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8401 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8405 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8409 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8411 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8413 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8415 },
    { MODRM_SPLITRM, 8417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7971 },
    { MODRM_SPLITRM, 7973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7975 },
    { MODRM_SPLITRM, 7977 },
    { MODRM_SPLITRM, 8419 },
    { MODRM_SPLITRM, 7981 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7985 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7987 },
    { MODRM_SPLITRM, 7989 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7993 },
    { MODRM_SPLITRM, 7995 },
    { MODRM_SPLITRM, 7997 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 7999 },
    { MODRM_SPLITRM, 8001 },
    { MODRM_SPLITRM, 8003 },
    { MODRM_SPLITRM, 8005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8007 },
    { MODRM_SPLITRM, 8009 },
    { MODRM_SPLITRM, 8423 },
    { MODRM_SPLITRM, 8013 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8427 },
    { MODRM_SPLITRM, 8429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8023 },
    { MODRM_SPLITRM, 8025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8431 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8433 },
    { MODRM_SPLITRM, 8435 },
    { MODRM_SPLITRM, 8437 },
    { MODRM_SPLITRM, 8439 },
    { MODRM_SPLITRM, 8441 },
    { MODRM_SPLITRM, 8443 },
    { MODRM_SPLITRM, 8445 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8447 },
    { MODRM_SPLITRM, 8449 },
    { MODRM_SPLITRM, 8451 },
    { MODRM_SPLITRM, 8453 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8455 },
    { MODRM_SPLITRM, 8457 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8459 },
    { MODRM_SPLITREG, 8475 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8491 },
    { MODRM_SPLITRM, 8493 },
    { MODRM_SPLITRM, 8495 },
    { MODRM_SPLITRM, 8497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8499 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8501 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8503 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8505 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8507 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8511 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8513 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8517 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8519 },
    { MODRM_SPLITRM, 8521 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8523 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8525 },
    { MODRM_SPLITRM, 8527 },
    { MODRM_SPLITRM, 8529 },
    { MODRM_SPLITRM, 8531 },
    { MODRM_SPLITRM, 8533 },
    { MODRM_SPLITRM, 8535 },
    { MODRM_SPLITRM, 8537 },
    { MODRM_SPLITRM, 8539 },
    { MODRM_SPLITRM, 8541 },
    { MODRM_SPLITRM, 8543 },
    { MODRM_SPLITRM, 8545 },
    { MODRM_SPLITRM, 8547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8549 },
    { MODRM_SPLITRM, 8551 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8553 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8555 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8557 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8559 },
    { MODRM_SPLITRM, 8561 },
    { MODRM_SPLITRM, 8563 },
    { MODRM_SPLITRM, 8565 },
    { MODRM_SPLITRM, 8567 },
    { MODRM_SPLITRM, 8569 },
    { MODRM_SPLITRM, 8571 },
    { MODRM_SPLITRM, 8573 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8575 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8581 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8583 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8587 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8589 },
    { MODRM_SPLITRM, 8591 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8593 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8595 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8611 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8613 },
    { MODRM_SPLITRM, 8615 },
    { MODRM_SPLITRM, 8617 },
    { MODRM_SPLITRM, 8619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8623 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8625 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8627 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8631 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8633 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8635 },
    { MODRM_SPLITRM, 8637 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8639 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8641 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8645 },
    { MODRM_SPLITRM, 8647 },
    { MODRM_SPLITRM, 8649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8651 },
    { MODRM_SPLITRM, 8653 },
    { MODRM_SPLITRM, 8655 },
    { MODRM_SPLITRM, 8657 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8661 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8663 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8665 },
    { MODRM_SPLITRM, 8667 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8669 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8671 },
    { MODRM_SPLITRM, 8673 },
    { MODRM_SPLITRM, 8675 },
    { MODRM_SPLITRM, 8677 },
    { MODRM_SPLITRM, 8679 },
    { MODRM_SPLITRM, 8681 },
    { MODRM_SPLITRM, 8683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8685 },
    { MODRM_SPLITRM, 8687 },
    { MODRM_SPLITRM, 8689 },
    { MODRM_SPLITRM, 8691 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8693 },
    { MODRM_SPLITRM, 8695 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8697 },
    { MODRM_SPLITREG, 8713 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8729 },
    { MODRM_SPLITRM, 8731 },
    { MODRM_SPLITRM, 8733 },
    { MODRM_SPLITRM, 8735 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8737 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8739 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8741 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8743 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8745 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8747 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8749 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8751 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8753 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8755 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8757 },
    { MODRM_SPLITRM, 8759 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8761 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8763 },
    { MODRM_SPLITRM, 8765 },
    { MODRM_SPLITRM, 8767 },
    { MODRM_SPLITRM, 8769 },
    { MODRM_SPLITRM, 8771 },
    { MODRM_SPLITRM, 8773 },
    { MODRM_SPLITRM, 8775 },
    { MODRM_SPLITRM, 8777 },
    { MODRM_SPLITRM, 8779 },
    { MODRM_SPLITRM, 8781 },
    { MODRM_SPLITRM, 8783 },
    { MODRM_SPLITRM, 8785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8787 },
    { MODRM_SPLITRM, 8789 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8791 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8793 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8557 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8559 },
    { MODRM_SPLITRM, 8561 },
    { MODRM_SPLITRM, 8563 },
    { MODRM_SPLITRM, 8795 },
    { MODRM_SPLITRM, 8567 },
    { MODRM_SPLITRM, 8569 },
    { MODRM_SPLITRM, 8571 },
    { MODRM_SPLITRM, 8573 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8797 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8803 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8805 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8809 },
    { MODRM_SPLITRM, 8811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8813 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8833 },
    { MODRM_SPLITRM, 8835 },
    { MODRM_SPLITRM, 8837 },
    { MODRM_SPLITRM, 8839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8841 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8849 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8851 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8853 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8855 },
    { MODRM_SPLITRM, 8857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8859 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8645 },
    { MODRM_SPLITRM, 8647 },
    { MODRM_SPLITRM, 8649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8651 },
    { MODRM_SPLITRM, 8653 },
    { MODRM_SPLITRM, 8655 },
    { MODRM_SPLITRM, 8657 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8661 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8867 },
    { MODRM_SPLITRM, 8869 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8873 },
    { MODRM_SPLITRM, 8875 },
    { MODRM_SPLITRM, 8877 },
    { MODRM_SPLITRM, 8879 },
    { MODRM_SPLITRM, 8881 },
    { MODRM_SPLITRM, 8883 },
    { MODRM_SPLITRM, 8885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8887 },
    { MODRM_SPLITRM, 8889 },
    { MODRM_SPLITRM, 8891 },
    { MODRM_SPLITRM, 8893 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8895 },
    { MODRM_SPLITRM, 8897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 8899 },
    { MODRM_SPLITREG, 8915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8931 },
    { MODRM_SPLITRM, 8933 },
    { MODRM_SPLITRM, 8935 },
    { MODRM_SPLITRM, 8937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8947 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8959 },
    { MODRM_SPLITRM, 8961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8965 },
    { MODRM_SPLITRM, 8967 },
    { MODRM_SPLITRM, 8969 },
    { MODRM_SPLITRM, 8971 },
    { MODRM_SPLITRM, 8973 },
    { MODRM_SPLITRM, 8975 },
    { MODRM_SPLITRM, 8977 },
    { MODRM_SPLITRM, 8979 },
    { MODRM_SPLITRM, 8981 },
    { MODRM_SPLITRM, 8983 },
    { MODRM_SPLITRM, 8985 },
    { MODRM_SPLITRM, 8987 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8989 },
    { MODRM_SPLITRM, 8991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8995 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8557 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8559 },
    { MODRM_SPLITRM, 8561 },
    { MODRM_SPLITRM, 8563 },
    { MODRM_SPLITRM, 8997 },
    { MODRM_SPLITRM, 8567 },
    { MODRM_SPLITRM, 8569 },
    { MODRM_SPLITRM, 8571 },
    { MODRM_SPLITRM, 8573 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9007 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9011 },
    { MODRM_SPLITRM, 9013 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9033 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9035 },
    { MODRM_SPLITRM, 9037 },
    { MODRM_SPLITRM, 9039 },
    { MODRM_SPLITRM, 9041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9043 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9045 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9049 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9053 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9055 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9057 },
    { MODRM_SPLITRM, 9059 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9063 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8645 },
    { MODRM_SPLITRM, 8647 },
    { MODRM_SPLITRM, 8649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8651 },
    { MODRM_SPLITRM, 8653 },
    { MODRM_SPLITRM, 8655 },
    { MODRM_SPLITRM, 8657 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9065 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 8661 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9067 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9069 },
    { MODRM_SPLITRM, 9071 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9073 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9075 },
    { MODRM_SPLITRM, 9077 },
    { MODRM_SPLITRM, 9079 },
    { MODRM_SPLITRM, 9081 },
    { MODRM_SPLITRM, 9083 },
    { MODRM_SPLITRM, 9085 },
    { MODRM_SPLITRM, 9087 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9089 },
    { MODRM_SPLITRM, 9091 },
    { MODRM_SPLITRM, 9093 },
    { MODRM_SPLITRM, 9095 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9097 },
    { MODRM_SPLITRM, 9099 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9101 },
    { MODRM_SPLITREG, 9117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9133 },
    { MODRM_SPLITRM, 9135 },
    { MODRM_SPLITRM, 9137 },
    { MODRM_SPLITRM, 9139 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9147 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9149 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9153 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9155 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9157 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9161 },
    { MODRM_SPLITRM, 9163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9165 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9167 },
    { MODRM_SPLITRM, 9169 },
    { MODRM_SPLITRM, 9171 },
    { MODRM_SPLITRM, 9173 },
    { MODRM_SPLITRM, 9175 },
    { MODRM_SPLITRM, 9177 },
    { MODRM_SPLITRM, 9179 },
    { MODRM_SPLITRM, 9181 },
    { MODRM_SPLITRM, 9183 },
    { MODRM_SPLITRM, 9185 },
    { MODRM_SPLITRM, 9187 },
    { MODRM_SPLITRM, 9189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9191 },
    { MODRM_SPLITRM, 9193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9195 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9199 },
    { MODRM_SPLITRM, 9201 },
    { MODRM_SPLITRM, 9203 },
    { MODRM_SPLITRM, 9205 },
    { MODRM_SPLITRM, 9207 },
    { MODRM_SPLITRM, 9209 },
    { MODRM_SPLITRM, 9211 },
    { MODRM_SPLITRM, 9213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9215 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9217 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9219 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9221 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9223 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9225 },
    { MODRM_SPLITRM, 9227 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9247 },
    { MODRM_SPLITRM, 9249 },
    { MODRM_SPLITRM, 9251 },
    { MODRM_SPLITRM, 9253 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9259 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9261 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9263 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9265 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9269 },
    { MODRM_SPLITRM, 9271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9275 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9277 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9279 },
    { MODRM_SPLITRM, 9281 },
    { MODRM_SPLITRM, 9283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9285 },
    { MODRM_SPLITRM, 9287 },
    { MODRM_SPLITRM, 9289 },
    { MODRM_SPLITRM, 9291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9293 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9295 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9297 },
    { MODRM_SPLITRM, 9299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9303 },
    { MODRM_SPLITRM, 9305 },
    { MODRM_SPLITRM, 9307 },
    { MODRM_SPLITRM, 9309 },
    { MODRM_SPLITRM, 9311 },
    { MODRM_SPLITRM, 9313 },
    { MODRM_SPLITRM, 9315 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9317 },
    { MODRM_SPLITRM, 9319 },
    { MODRM_SPLITRM, 9321 },
    { MODRM_SPLITRM, 9323 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9325 },
    { MODRM_SPLITRM, 9327 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9329 },
    { MODRM_SPLITREG, 9345 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9361 },
    { MODRM_SPLITRM, 9363 },
    { MODRM_SPLITRM, 9365 },
    { MODRM_SPLITRM, 9367 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9369 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9373 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9375 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9377 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9379 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9381 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9383 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9385 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9387 },
    { MODRM_SPLITRM, 9389 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9391 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9393 },
    { MODRM_SPLITRM, 9395 },
    { MODRM_SPLITRM, 9397 },
    { MODRM_SPLITRM, 9399 },
    { MODRM_SPLITRM, 9401 },
    { MODRM_SPLITRM, 9403 },
    { MODRM_SPLITRM, 9405 },
    { MODRM_SPLITRM, 9407 },
    { MODRM_SPLITRM, 9409 },
    { MODRM_SPLITRM, 9411 },
    { MODRM_SPLITRM, 9413 },
    { MODRM_SPLITRM, 9415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9417 },
    { MODRM_SPLITRM, 9419 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9199 },
    { MODRM_SPLITRM, 9201 },
    { MODRM_SPLITRM, 9203 },
    { MODRM_SPLITRM, 9423 },
    { MODRM_SPLITRM, 9207 },
    { MODRM_SPLITRM, 9209 },
    { MODRM_SPLITRM, 9211 },
    { MODRM_SPLITRM, 9213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9431 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9433 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9435 },
    { MODRM_SPLITRM, 9437 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9439 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9441 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9457 },
    { MODRM_SPLITRM, 9459 },
    { MODRM_SPLITRM, 9461 },
    { MODRM_SPLITRM, 9463 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9465 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9467 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9469 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9471 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9473 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9475 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9477 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9479 },
    { MODRM_SPLITRM, 9481 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9483 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9277 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9279 },
    { MODRM_SPLITRM, 9281 },
    { MODRM_SPLITRM, 9283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9285 },
    { MODRM_SPLITRM, 9287 },
    { MODRM_SPLITRM, 9289 },
    { MODRM_SPLITRM, 9291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9487 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9489 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9491 },
    { MODRM_SPLITRM, 9493 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9497 },
    { MODRM_SPLITRM, 9499 },
    { MODRM_SPLITRM, 9501 },
    { MODRM_SPLITRM, 9503 },
    { MODRM_SPLITRM, 9505 },
    { MODRM_SPLITRM, 9507 },
    { MODRM_SPLITRM, 9509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9511 },
    { MODRM_SPLITRM, 9513 },
    { MODRM_SPLITRM, 9515 },
    { MODRM_SPLITRM, 9517 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9519 },
    { MODRM_SPLITRM, 9521 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9523 },
    { MODRM_SPLITREG, 9539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9555 },
    { MODRM_SPLITRM, 9557 },
    { MODRM_SPLITRM, 9559 },
    { MODRM_SPLITRM, 9561 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9563 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9565 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9567 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9569 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9571 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9573 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9575 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9581 },
    { MODRM_SPLITRM, 9583 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9587 },
    { MODRM_SPLITRM, 9589 },
    { MODRM_SPLITRM, 9591 },
    { MODRM_SPLITRM, 9593 },
    { MODRM_SPLITRM, 9595 },
    { MODRM_SPLITRM, 9597 },
    { MODRM_SPLITRM, 9599 },
    { MODRM_SPLITRM, 9601 },
    { MODRM_SPLITRM, 9603 },
    { MODRM_SPLITRM, 9605 },
    { MODRM_SPLITRM, 9607 },
    { MODRM_SPLITRM, 9609 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9611 },
    { MODRM_SPLITRM, 9613 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9615 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9199 },
    { MODRM_SPLITRM, 9201 },
    { MODRM_SPLITRM, 9203 },
    { MODRM_SPLITRM, 9617 },
    { MODRM_SPLITRM, 9207 },
    { MODRM_SPLITRM, 9209 },
    { MODRM_SPLITRM, 9211 },
    { MODRM_SPLITRM, 9213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9623 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9625 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9627 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9629 },
    { MODRM_SPLITRM, 9631 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9633 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9651 },
    { MODRM_SPLITRM, 9653 },
    { MODRM_SPLITRM, 9655 },
    { MODRM_SPLITRM, 9657 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9661 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9663 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9665 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9667 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9669 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9671 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9673 },
    { MODRM_SPLITRM, 9675 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9677 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9679 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9277 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9279 },
    { MODRM_SPLITRM, 9281 },
    { MODRM_SPLITRM, 9283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9285 },
    { MODRM_SPLITRM, 9287 },
    { MODRM_SPLITRM, 9289 },
    { MODRM_SPLITRM, 9291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9681 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9685 },
    { MODRM_SPLITRM, 9687 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9689 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9691 },
    { MODRM_SPLITRM, 9693 },
    { MODRM_SPLITRM, 9695 },
    { MODRM_SPLITRM, 9697 },
    { MODRM_SPLITRM, 9699 },
    { MODRM_SPLITRM, 9701 },
    { MODRM_SPLITRM, 9703 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9705 },
    { MODRM_SPLITRM, 9707 },
    { MODRM_SPLITRM, 9709 },
    { MODRM_SPLITRM, 9711 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9713 },
    { MODRM_SPLITRM, 9715 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9717 },
    { MODRM_SPLITREG, 9733 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9749 },
    { MODRM_SPLITRM, 9751 },
    { MODRM_SPLITRM, 9753 },
    { MODRM_SPLITRM, 9755 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9757 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9759 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9761 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9763 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9765 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9767 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9769 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9771 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9773 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9775 },
    { MODRM_SPLITRM, 9777 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9779 },
    { MODRM_SPLITRM, 9781 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9783 },
    { MODRM_SPLITRM, 9785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9789 },
    { MODRM_SPLITRM, 9791 },
    { MODRM_SPLITRM, 9793 },
    { MODRM_SPLITRM, 9795 },
    { MODRM_SPLITRM, 9797 },
    { MODRM_SPLITRM, 9799 },
    { MODRM_SPLITRM, 9801 },
    { MODRM_SPLITRM, 9803 },
    { MODRM_SPLITRM, 9805 },
    { MODRM_SPLITRM, 9807 },
    { MODRM_SPLITRM, 9809 },
    { MODRM_SPLITRM, 9811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9813 },
    { MODRM_SPLITRM, 9815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9819 },
    { MODRM_SPLITRM, 9821 },
    { MODRM_SPLITRM, 9823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9829 },
    { MODRM_SPLITRM, 9831 },
    { MODRM_SPLITRM, 9833 },
    { MODRM_SPLITRM, 9835 },
    { MODRM_SPLITRM, 9837 },
    { MODRM_SPLITRM, 9839 },
    { MODRM_SPLITRM, 9841 },
    { MODRM_SPLITRM, 9843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9845 },
    { MODRM_SPLITRM, 9847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9849 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9851 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9853 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9855 },
    { MODRM_SPLITRM, 9857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9859 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9865 },
    { MODRM_SPLITRM, 9867 },
    { MODRM_SPLITRM, 9869 },
    { MODRM_SPLITRM, 9871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9873 },
    { MODRM_SPLITRM, 9875 },
    { MODRM_SPLITRM, 9877 },
    { MODRM_SPLITRM, 9879 },
    { MODRM_SPLITRM, 9881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9883 },
    { MODRM_SPLITRM, 9885 },
    { MODRM_SPLITREG, 9887 },
    { MODRM_SPLITREG, 9903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9919 },
    { MODRM_SPLITRM, 9921 },
    { MODRM_SPLITRM, 9923 },
    { MODRM_SPLITRM, 9925 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9927 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9929 },
    { MODRM_SPLITRM, 9931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9935 },
    { MODRM_SPLITRM, 9937 },
    { MODRM_SPLITRM, 9939 },
    { MODRM_SPLITRM, 9941 },
    { MODRM_SPLITRM, 9943 },
    { MODRM_SPLITRM, 9945 },
    { MODRM_SPLITRM, 9947 },
    { MODRM_SPLITRM, 9949 },
    { MODRM_SPLITRM, 9951 },
    { MODRM_SPLITRM, 9953 },
    { MODRM_SPLITRM, 9955 },
    { MODRM_SPLITRM, 9957 },
    { MODRM_SPLITRM, 9959 },
    { MODRM_SPLITRM, 9961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9963 },
    { MODRM_SPLITRM, 9965 },
    { MODRM_SPLITRM, 9967 },
    { MODRM_SPLITRM, 9969 },
    { MODRM_SPLITRM, 9971 },
    { MODRM_SPLITRM, 9973 },
    { MODRM_SPLITRM, 9975 },
    { MODRM_SPLITRM, 9977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9979 },
    { MODRM_SPLITRM, 9981 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9985 },
    { MODRM_SPLITRM, 9987 },
    { MODRM_SPLITRM, 9989 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9991 },
    { MODRM_SPLITRM, 9993 },
    { MODRM_SPLITRM, 9995 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9997 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9999 },
    { MODRM_SPLITRM, 10001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10003 },
    { MODRM_SPLITRM, 9847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10007 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10011 },
    { MODRM_SPLITRM, 10013 },
    { MODRM_SPLITRM, 10015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10019 },
    { MODRM_SPLITRM, 10021 },
    { MODRM_SPLITRM, 10023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10025 },
    { MODRM_SPLITRM, 10027 },
    { MODRM_SPLITRM, 10029 },
    { MODRM_SPLITRM, 10031 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10033 },
    { MODRM_SPLITRM, 9857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10035 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10037 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10039 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10041 },
    { MODRM_SPLITRM, 10043 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10045 },
    { MODRM_SPLITRM, 10047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10049 },
    { MODRM_SPLITRM, 10051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10055 },
    { MODRM_SPLITRM, 10057 },
    { MODRM_SPLITRM, 10059 },
    { MODRM_SPLITRM, 10061 },
    { MODRM_SPLITRM, 10063 },
    { MODRM_SPLITRM, 10065 },
    { MODRM_SPLITRM, 10067 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10069 },
    { MODRM_SPLITRM, 10071 },
    { MODRM_SPLITRM, 10073 },
    { MODRM_SPLITRM, 10075 },
    { MODRM_SPLITRM, 9865 },
    { MODRM_SPLITRM, 9867 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9873 },
    { MODRM_SPLITRM, 9875 },
    { MODRM_SPLITRM, 9877 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10077 },
    { MODRM_SPLITRM, 10079 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10081 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 9887 },
    { MODRM_SPLITREG, 10083 },
    { MODRM_SPLITREG, 10099 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10115 },
    { MODRM_SPLITRM, 10117 },
    { MODRM_SPLITRM, 10119 },
    { MODRM_SPLITRM, 10121 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10123 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10125 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10127 },
    { MODRM_SPLITRM, 10129 },
    { MODRM_SPLITRM, 9933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9935 },
    { MODRM_SPLITRM, 9937 },
    { MODRM_SPLITRM, 9939 },
    { MODRM_SPLITRM, 10131 },
    { MODRM_SPLITRM, 9943 },
    { MODRM_SPLITRM, 9945 },
    { MODRM_SPLITRM, 9947 },
    { MODRM_SPLITRM, 10133 },
    { MODRM_SPLITRM, 9951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10135 },
    { MODRM_SPLITRM, 9957 },
    { MODRM_SPLITRM, 9959 },
    { MODRM_SPLITRM, 9961 },
    { MODRM_SPLITRM, 10137 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9963 },
    { MODRM_SPLITRM, 9965 },
    { MODRM_SPLITRM, 9967 },
    { MODRM_SPLITRM, 10139 },
    { MODRM_SPLITRM, 9971 },
    { MODRM_SPLITRM, 9973 },
    { MODRM_SPLITRM, 9975 },
    { MODRM_SPLITRM, 10141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10143 },
    { MODRM_SPLITRM, 10145 },
    { MODRM_SPLITRM, 9983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9985 },
    { MODRM_SPLITRM, 9987 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10147 },
    { MODRM_SPLITRM, 9991 },
    { MODRM_SPLITRM, 9993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10149 },
    { MODRM_SPLITRM, 10151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10153 },
    { MODRM_SPLITRM, 10155 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10157 },
    { MODRM_SPLITRM, 10159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10161 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10163 },
    { MODRM_SPLITRM, 10165 },
    { MODRM_SPLITRM, 10167 },
    { MODRM_SPLITRM, 10169 },
    { MODRM_SPLITRM, 10171 },
    { MODRM_SPLITRM, 10173 },
    { MODRM_SPLITRM, 10175 },
    { MODRM_SPLITRM, 10177 },
    { MODRM_SPLITRM, 10179 },
    { MODRM_SPLITRM, 10181 },
    { MODRM_SPLITRM, 10183 },
    { MODRM_SPLITRM, 10185 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10187 },
    { MODRM_SPLITRM, 10189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10191 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9819 },
    { MODRM_SPLITRM, 9821 },
    { MODRM_SPLITRM, 10193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10195 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9829 },
    { MODRM_SPLITRM, 9831 },
    { MODRM_SPLITRM, 9833 },
    { MODRM_SPLITRM, 10197 },
    { MODRM_SPLITRM, 9837 },
    { MODRM_SPLITRM, 9839 },
    { MODRM_SPLITRM, 9841 },
    { MODRM_SPLITRM, 9843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10199 },
    { MODRM_SPLITRM, 10201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10203 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10209 },
    { MODRM_SPLITRM, 10211 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10215 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10217 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10219 },
    { MODRM_SPLITRM, 10221 },
    { MODRM_SPLITRM, 10223 },
    { MODRM_SPLITRM, 10225 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10227 },
    { MODRM_SPLITRM, 10229 },
    { MODRM_SPLITRM, 10231 },
    { MODRM_SPLITRM, 10233 },
    { MODRM_SPLITRM, 10235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10237 },
    { MODRM_SPLITRM, 10239 },
    { MODRM_SPLITREG, 10241 },
    { MODRM_SPLITREG, 10257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10273 },
    { MODRM_SPLITRM, 10275 },
    { MODRM_SPLITRM, 10277 },
    { MODRM_SPLITRM, 10279 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10281 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10283 },
    { MODRM_SPLITRM, 10285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10287 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10289 },
    { MODRM_SPLITRM, 10291 },
    { MODRM_SPLITRM, 10293 },
    { MODRM_SPLITRM, 10295 },
    { MODRM_SPLITRM, 10297 },
    { MODRM_SPLITRM, 10299 },
    { MODRM_SPLITRM, 10301 },
    { MODRM_SPLITRM, 10303 },
    { MODRM_SPLITRM, 10305 },
    { MODRM_SPLITRM, 10307 },
    { MODRM_SPLITRM, 10309 },
    { MODRM_SPLITRM, 10311 },
    { MODRM_SPLITRM, 10313 },
    { MODRM_SPLITRM, 10315 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10317 },
    { MODRM_SPLITRM, 10319 },
    { MODRM_SPLITRM, 10321 },
    { MODRM_SPLITRM, 10323 },
    { MODRM_SPLITRM, 10325 },
    { MODRM_SPLITRM, 10327 },
    { MODRM_SPLITRM, 10329 },
    { MODRM_SPLITRM, 10331 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10333 },
    { MODRM_SPLITRM, 10335 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10337 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10339 },
    { MODRM_SPLITRM, 10341 },
    { MODRM_SPLITRM, 10343 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10345 },
    { MODRM_SPLITRM, 10347 },
    { MODRM_SPLITRM, 10349 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10353 },
    { MODRM_SPLITRM, 10355 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10357 },
    { MODRM_SPLITRM, 10201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10359 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10361 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10363 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10011 },
    { MODRM_SPLITRM, 10013 },
    { MODRM_SPLITRM, 10365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10019 },
    { MODRM_SPLITRM, 10021 },
    { MODRM_SPLITRM, 10023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10025 },
    { MODRM_SPLITRM, 10027 },
    { MODRM_SPLITRM, 10029 },
    { MODRM_SPLITRM, 10031 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10367 },
    { MODRM_SPLITRM, 10211 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10369 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10373 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10375 },
    { MODRM_SPLITRM, 10377 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10379 },
    { MODRM_SPLITRM, 10381 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10383 },
    { MODRM_SPLITRM, 10385 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10387 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10389 },
    { MODRM_SPLITRM, 10391 },
    { MODRM_SPLITRM, 10393 },
    { MODRM_SPLITRM, 10395 },
    { MODRM_SPLITRM, 10397 },
    { MODRM_SPLITRM, 10399 },
    { MODRM_SPLITRM, 10401 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10403 },
    { MODRM_SPLITRM, 10405 },
    { MODRM_SPLITRM, 10407 },
    { MODRM_SPLITRM, 10409 },
    { MODRM_SPLITRM, 10219 },
    { MODRM_SPLITRM, 10221 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10225 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10227 },
    { MODRM_SPLITRM, 10229 },
    { MODRM_SPLITRM, 10231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10411 },
    { MODRM_SPLITRM, 10413 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 10241 },
    { MODRM_SPLITREG, 10417 },
    { MODRM_SPLITREG, 10433 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10449 },
    { MODRM_SPLITRM, 10451 },
    { MODRM_SPLITRM, 10453 },
    { MODRM_SPLITRM, 10455 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10457 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10459 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10461 },
    { MODRM_SPLITRM, 10463 },
    { MODRM_SPLITRM, 10287 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10289 },
    { MODRM_SPLITRM, 10291 },
    { MODRM_SPLITRM, 10293 },
    { MODRM_SPLITRM, 10465 },
    { MODRM_SPLITRM, 10297 },
    { MODRM_SPLITRM, 10299 },
    { MODRM_SPLITRM, 10301 },
    { MODRM_SPLITRM, 10467 },
    { MODRM_SPLITRM, 10305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10469 },
    { MODRM_SPLITRM, 10311 },
    { MODRM_SPLITRM, 10313 },
    { MODRM_SPLITRM, 10315 },
    { MODRM_SPLITRM, 10471 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10317 },
    { MODRM_SPLITRM, 10319 },
    { MODRM_SPLITRM, 10321 },
    { MODRM_SPLITRM, 10473 },
    { MODRM_SPLITRM, 10325 },
    { MODRM_SPLITRM, 10327 },
    { MODRM_SPLITRM, 10329 },
    { MODRM_SPLITRM, 10475 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10477 },
    { MODRM_SPLITRM, 10479 },
    { MODRM_SPLITRM, 10337 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10339 },
    { MODRM_SPLITRM, 10341 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10481 },
    { MODRM_SPLITRM, 10345 },
    { MODRM_SPLITRM, 10347 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10483 },
    { MODRM_SPLITRM, 10485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10487 },
    { MODRM_SPLITRM, 10489 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10491 },
    { MODRM_SPLITRM, 10493 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10497 },
    { MODRM_SPLITRM, 10499 },
    { MODRM_SPLITRM, 10501 },
    { MODRM_SPLITRM, 10503 },
    { MODRM_SPLITRM, 10505 },
    { MODRM_SPLITRM, 10507 },
    { MODRM_SPLITRM, 10509 },
    { MODRM_SPLITRM, 10511 },
    { MODRM_SPLITRM, 10513 },
    { MODRM_SPLITRM, 10515 },
    { MODRM_SPLITRM, 10517 },
    { MODRM_SPLITRM, 10519 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10521 },
    { MODRM_SPLITRM, 10523 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10525 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9819 },
    { MODRM_SPLITRM, 9821 },
    { MODRM_SPLITRM, 10527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10529 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 9829 },
    { MODRM_SPLITRM, 9831 },
    { MODRM_SPLITRM, 9833 },
    { MODRM_SPLITRM, 10531 },
    { MODRM_SPLITRM, 9837 },
    { MODRM_SPLITRM, 9839 },
    { MODRM_SPLITRM, 9841 },
    { MODRM_SPLITRM, 9843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10533 },
    { MODRM_SPLITRM, 10535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10537 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10541 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10543 },
    { MODRM_SPLITRM, 10545 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10551 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10553 },
    { MODRM_SPLITRM, 10555 },
    { MODRM_SPLITRM, 10557 },
    { MODRM_SPLITRM, 10559 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10561 },
    { MODRM_SPLITRM, 10563 },
    { MODRM_SPLITRM, 10565 },
    { MODRM_SPLITRM, 10567 },
    { MODRM_SPLITRM, 10569 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10571 },
    { MODRM_SPLITRM, 10573 },
    { MODRM_SPLITREG, 10575 },
    { MODRM_SPLITREG, 10591 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10607 },
    { MODRM_SPLITRM, 10609 },
    { MODRM_SPLITRM, 10611 },
    { MODRM_SPLITRM, 10613 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10615 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10617 },
    { MODRM_SPLITRM, 10619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10623 },
    { MODRM_SPLITRM, 10625 },
    { MODRM_SPLITRM, 10627 },
    { MODRM_SPLITRM, 10629 },
    { MODRM_SPLITRM, 10631 },
    { MODRM_SPLITRM, 10633 },
    { MODRM_SPLITRM, 10635 },
    { MODRM_SPLITRM, 10637 },
    { MODRM_SPLITRM, 10639 },
    { MODRM_SPLITRM, 10641 },
    { MODRM_SPLITRM, 10643 },
    { MODRM_SPLITRM, 10645 },
    { MODRM_SPLITRM, 10647 },
    { MODRM_SPLITRM, 10649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10651 },
    { MODRM_SPLITRM, 10653 },
    { MODRM_SPLITRM, 10655 },
    { MODRM_SPLITRM, 10657 },
    { MODRM_SPLITRM, 10659 },
    { MODRM_SPLITRM, 10661 },
    { MODRM_SPLITRM, 10663 },
    { MODRM_SPLITRM, 10665 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10667 },
    { MODRM_SPLITRM, 10669 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10671 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10673 },
    { MODRM_SPLITRM, 10675 },
    { MODRM_SPLITRM, 10677 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10679 },
    { MODRM_SPLITRM, 10681 },
    { MODRM_SPLITRM, 10683 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10687 },
    { MODRM_SPLITRM, 10689 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10691 },
    { MODRM_SPLITRM, 10535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10693 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10695 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10697 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10011 },
    { MODRM_SPLITRM, 10013 },
    { MODRM_SPLITRM, 10699 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10019 },
    { MODRM_SPLITRM, 10021 },
    { MODRM_SPLITRM, 10023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10025 },
    { MODRM_SPLITRM, 10027 },
    { MODRM_SPLITRM, 10029 },
    { MODRM_SPLITRM, 10031 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10701 },
    { MODRM_SPLITRM, 10545 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10703 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10705 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10707 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10709 },
    { MODRM_SPLITRM, 10711 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10713 },
    { MODRM_SPLITRM, 10715 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10717 },
    { MODRM_SPLITRM, 10719 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10721 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10723 },
    { MODRM_SPLITRM, 10725 },
    { MODRM_SPLITRM, 10727 },
    { MODRM_SPLITRM, 10729 },
    { MODRM_SPLITRM, 10731 },
    { MODRM_SPLITRM, 10733 },
    { MODRM_SPLITRM, 10735 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10737 },
    { MODRM_SPLITRM, 10739 },
    { MODRM_SPLITRM, 10741 },
    { MODRM_SPLITRM, 10743 },
    { MODRM_SPLITRM, 10553 },
    { MODRM_SPLITRM, 10555 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10559 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10561 },
    { MODRM_SPLITRM, 10563 },
    { MODRM_SPLITRM, 10565 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10745 },
    { MODRM_SPLITRM, 10747 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10749 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 10575 },
    { MODRM_SPLITREG, 10751 },
    { MODRM_SPLITREG, 10767 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10783 },
    { MODRM_SPLITRM, 10785 },
    { MODRM_SPLITRM, 10787 },
    { MODRM_SPLITRM, 10789 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10791 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10793 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10795 },
    { MODRM_SPLITRM, 10797 },
    { MODRM_SPLITRM, 10621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10623 },
    { MODRM_SPLITRM, 10625 },
    { MODRM_SPLITRM, 10627 },
    { MODRM_SPLITRM, 10799 },
    { MODRM_SPLITRM, 10631 },
    { MODRM_SPLITRM, 10633 },
    { MODRM_SPLITRM, 10635 },
    { MODRM_SPLITRM, 10801 },
    { MODRM_SPLITRM, 10639 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10803 },
    { MODRM_SPLITRM, 10645 },
    { MODRM_SPLITRM, 10647 },
    { MODRM_SPLITRM, 10649 },
    { MODRM_SPLITRM, 10805 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10651 },
    { MODRM_SPLITRM, 10653 },
    { MODRM_SPLITRM, 10655 },
    { MODRM_SPLITRM, 10807 },
    { MODRM_SPLITRM, 10659 },
    { MODRM_SPLITRM, 10661 },
    { MODRM_SPLITRM, 10663 },
    { MODRM_SPLITRM, 10809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10811 },
    { MODRM_SPLITRM, 10813 },
    { MODRM_SPLITRM, 10671 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10673 },
    { MODRM_SPLITRM, 10675 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10815 },
    { MODRM_SPLITRM, 10679 },
    { MODRM_SPLITRM, 10681 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

static const unsigned char index_x86DisassemblerThreeByte38Opcodes[] = {
  1,
  2,
  3,
  4,
  5,
  6,
  7,
  8,
  0,
  0,
  0,
  9,
  10,
  11,
  12,
  13,
  14,
  15,
  16,
  0,
  17,
  18,
  19,
  20,
  21,
  22,
  23,
  24,
  25,
  26,
  27,
  28,
  29,
  0,
  0,
  0,
  30,
  0,
  0,
  0,
  31,
  0,
  32,
  33,
  34,
  0,
  35,
  0,
  36,
  0,
  37,
  0,
  38,
  0,
  39,
  0,
  40,
  0,
  41,
  42,
  43,
  0,
  44,
  0,
  45,
  0,
  46,
  47,
  48,
  0,
  49,
  0,
  50,
  0,
  51,
  0,
  52,
  0,
  53,
  0,
  54,
  0,
  55,
  56,
  57,
  0,
  58,
  0,
  59,
  0,
  60,
  0,
  61,
  0,
  62,
  0,
  63,
  0,
  64,
  0,
  65,
  0,
  66,
  0,
  67,
  0,
  68,
  0,
  69,
  0,
  70,
  0,
  71,
  0,
  72,
  0,
  73,
  0,
  74,
  0,
  75,
  0,
  76,
  0,
  77,
  0,
  78,
  0,
  79,
  0,
  80,
  0,
  81,
  0,
  82,
  0,
  83,
  0,
  0,
  0,
  84,
  0,
  0,
  0,
  85,
  0,
  0,
  0,
  86,
  0,
  0,
  0,
  87,
  0,
  0,
  0,
  88,
  0,
  0,
  0,
  89,
  0,
  90,
  91,
  92,
  0,
  0,
  0,
  93,
  0,
  94,
  0,
  95,
  0,
  0,
  0,
  96,
  0,
  97,
  98,
  99,
  0,
  0,
  0,
  100,
};

static const struct OpcodeDecision x86DisassemblerThreeByte38Opcodes[] = {
  { {
    { MODRM_SPLITRM, 10817 },
    { MODRM_SPLITRM, 10819 },
    { MODRM_SPLITRM, 10821 },
    { MODRM_SPLITRM, 10823 },
    { MODRM_SPLITRM, 10825 },
    { MODRM_SPLITRM, 10827 },
    { MODRM_SPLITRM, 10829 },
    { MODRM_SPLITRM, 10831 },
    { MODRM_SPLITRM, 10833 },
    { MODRM_SPLITRM, 10835 },
    { MODRM_SPLITRM, 10837 },
    { MODRM_SPLITRM, 10839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10841 },
    { MODRM_SPLITRM, 10843 },
    { MODRM_SPLITRM, 10845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10859 },
    { MODRM_SPLITRM, 10861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10817 },
    { MODRM_SPLITRM, 10819 },
    { MODRM_SPLITRM, 10821 },
    { MODRM_SPLITRM, 10823 },
    { MODRM_SPLITRM, 10825 },
    { MODRM_SPLITRM, 10827 },
    { MODRM_SPLITRM, 10829 },
    { MODRM_SPLITRM, 10831 },
    { MODRM_SPLITRM, 10833 },
    { MODRM_SPLITRM, 10835 },
    { MODRM_SPLITRM, 10837 },
    { MODRM_SPLITRM, 10839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10841 },
    { MODRM_SPLITRM, 10843 },
    { MODRM_SPLITRM, 10845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10859 },
    { MODRM_SPLITRM, 10861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10867 },
    { MODRM_SPLITRM, 10869 },
    { MODRM_SPLITRM, 10871 },
    { MODRM_SPLITRM, 10873 },
    { MODRM_SPLITRM, 10875 },
    { MODRM_SPLITRM, 10877 },
    { MODRM_SPLITRM, 10879 },
    { MODRM_SPLITRM, 10881 },
    { MODRM_SPLITRM, 10883 },
    { MODRM_SPLITRM, 10885 },
    { MODRM_SPLITRM, 10887 },
    { MODRM_SPLITRM, 10889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10893 },
    { MODRM_SPLITRM, 10895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10899 },
    { MODRM_SPLITRM, 10901 },
    { MODRM_SPLITRM, 10903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10905 },
    { MODRM_SPLITRM, 10907 },
    { MODRM_SPLITRM, 10909 },
    { MODRM_SPLITRM, 10911 },
    { MODRM_SPLITRM, 10913 },
    { MODRM_SPLITRM, 10915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10917 },
    { MODRM_SPLITRM, 10919 },
    { MODRM_SPLITRM, 10921 },
    { MODRM_SPLITRM, 10923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10925 },
    { MODRM_SPLITRM, 10927 },
    { MODRM_SPLITRM, 10929 },
    { MODRM_SPLITRM, 10931 },
    { MODRM_SPLITRM, 10933 },
    { MODRM_SPLITRM, 10935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10937 },
    { MODRM_SPLITRM, 10939 },
    { MODRM_SPLITRM, 10941 },
    { MODRM_SPLITRM, 10943 },
    { MODRM_SPLITRM, 10945 },
    { MODRM_SPLITRM, 10947 },
    { MODRM_SPLITRM, 10949 },
    { MODRM_SPLITRM, 10951 },
    { MODRM_SPLITRM, 10953 },
    { MODRM_SPLITRM, 10955 },
    { MODRM_SPLITRM, 10957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10959 },
    { MODRM_SPLITRM, 10961 },
    { MODRM_SPLITRM, 10963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10967 },
    { MODRM_SPLITRM, 10969 },
    { MODRM_SPLITRM, 10971 },
    { MODRM_SPLITRM, 10973 },
    { MODRM_SPLITRM, 10975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10977 },
    { MODRM_SPLITRM, 10979 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10981 },
    { MODRM_SPLITRM, 10983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10985 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10817 },
    { MODRM_SPLITRM, 10819 },
    { MODRM_SPLITRM, 10821 },
    { MODRM_SPLITRM, 10823 },
    { MODRM_SPLITRM, 10825 },
    { MODRM_SPLITRM, 10827 },
    { MODRM_SPLITRM, 10829 },
    { MODRM_SPLITRM, 10831 },
    { MODRM_SPLITRM, 10833 },
    { MODRM_SPLITRM, 10835 },
    { MODRM_SPLITRM, 10837 },
    { MODRM_SPLITRM, 10839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10841 },
    { MODRM_SPLITRM, 10843 },
    { MODRM_SPLITRM, 10845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10859 },
    { MODRM_SPLITRM, 10861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10867 },
    { MODRM_SPLITRM, 10869 },
    { MODRM_SPLITRM, 10871 },
    { MODRM_SPLITRM, 10873 },
    { MODRM_SPLITRM, 10875 },
    { MODRM_SPLITRM, 10877 },
    { MODRM_SPLITRM, 10879 },
    { MODRM_SPLITRM, 10881 },
    { MODRM_SPLITRM, 10883 },
    { MODRM_SPLITRM, 10885 },
    { MODRM_SPLITRM, 10887 },
    { MODRM_SPLITRM, 10889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10893 },
    { MODRM_SPLITRM, 10895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10899 },
    { MODRM_SPLITRM, 10901 },
    { MODRM_SPLITRM, 10903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10905 },
    { MODRM_SPLITRM, 10907 },
    { MODRM_SPLITRM, 10909 },
    { MODRM_SPLITRM, 10911 },
    { MODRM_SPLITRM, 10913 },
    { MODRM_SPLITRM, 10915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10917 },
    { MODRM_SPLITRM, 10919 },
    { MODRM_SPLITRM, 10921 },
    { MODRM_SPLITRM, 10923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10925 },
    { MODRM_SPLITRM, 10927 },
    { MODRM_SPLITRM, 10929 },
    { MODRM_SPLITRM, 10931 },
    { MODRM_SPLITRM, 10933 },
    { MODRM_SPLITRM, 10935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10937 },
    { MODRM_SPLITRM, 10939 },
    { MODRM_SPLITRM, 10941 },
    { MODRM_SPLITRM, 10943 },
    { MODRM_SPLITRM, 10945 },
    { MODRM_SPLITRM, 10947 },
    { MODRM_SPLITRM, 10949 },
    { MODRM_SPLITRM, 10951 },
    { MODRM_SPLITRM, 10953 },
    { MODRM_SPLITRM, 10955 },
    { MODRM_SPLITRM, 10957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10959 },
    { MODRM_SPLITRM, 10961 },
    { MODRM_SPLITRM, 10963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10967 },
    { MODRM_SPLITRM, 10969 },
    { MODRM_SPLITRM, 10971 },
    { MODRM_SPLITRM, 10973 },
    { MODRM_SPLITRM, 10975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10977 },
    { MODRM_SPLITRM, 10979 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10981 },
    { MODRM_SPLITRM, 10983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10987 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10989 },
    { MODRM_SPLITRM, 10991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10995 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10817 },
    { MODRM_SPLITRM, 10819 },
    { MODRM_SPLITRM, 10821 },
    { MODRM_SPLITRM, 10823 },
    { MODRM_SPLITRM, 10825 },
    { MODRM_SPLITRM, 10827 },
    { MODRM_SPLITRM, 10829 },
    { MODRM_SPLITRM, 10831 },
    { MODRM_SPLITRM, 10833 },
    { MODRM_SPLITRM, 10835 },
    { MODRM_SPLITRM, 10837 },
    { MODRM_SPLITRM, 10839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10841 },
    { MODRM_SPLITRM, 10843 },
    { MODRM_SPLITRM, 10845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10997 },
    { MODRM_SPLITRM, 10999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10867 },
    { MODRM_SPLITRM, 10869 },
    { MODRM_SPLITRM, 10871 },
    { MODRM_SPLITRM, 10873 },
    { MODRM_SPLITRM, 10875 },
    { MODRM_SPLITRM, 10877 },
    { MODRM_SPLITRM, 10879 },
    { MODRM_SPLITRM, 10881 },
    { MODRM_SPLITRM, 10883 },
    { MODRM_SPLITRM, 10885 },
    { MODRM_SPLITRM, 10887 },
    { MODRM_SPLITRM, 10889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10893 },
    { MODRM_SPLITRM, 10895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10899 },
    { MODRM_SPLITRM, 10901 },
    { MODRM_SPLITRM, 10903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10905 },
    { MODRM_SPLITRM, 10907 },
    { MODRM_SPLITRM, 10909 },
    { MODRM_SPLITRM, 10911 },
    { MODRM_SPLITRM, 10913 },
    { MODRM_SPLITRM, 10915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10917 },
    { MODRM_SPLITRM, 10919 },
    { MODRM_SPLITRM, 10921 },
    { MODRM_SPLITRM, 10923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10925 },
    { MODRM_SPLITRM, 10927 },
    { MODRM_SPLITRM, 10929 },
    { MODRM_SPLITRM, 10931 },
    { MODRM_SPLITRM, 10933 },
    { MODRM_SPLITRM, 10935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10937 },
    { MODRM_SPLITRM, 10939 },
    { MODRM_SPLITRM, 10941 },
    { MODRM_SPLITRM, 10943 },
    { MODRM_SPLITRM, 10945 },
    { MODRM_SPLITRM, 10947 },
    { MODRM_SPLITRM, 10949 },
    { MODRM_SPLITRM, 10951 },
    { MODRM_SPLITRM, 10953 },
    { MODRM_SPLITRM, 10955 },
    { MODRM_SPLITRM, 10957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11005 },
    { MODRM_SPLITRM, 11007 },
    { MODRM_SPLITRM, 11009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10967 },
    { MODRM_SPLITRM, 10969 },
    { MODRM_SPLITRM, 10971 },
    { MODRM_SPLITRM, 10973 },
    { MODRM_SPLITRM, 10975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10997 },
    { MODRM_SPLITRM, 10999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10981 },
    { MODRM_SPLITRM, 11011 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10985 },
    { MODRM_SPLITRM, 11003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10867 },
    { MODRM_SPLITRM, 10869 },
    { MODRM_SPLITRM, 10871 },
    { MODRM_SPLITRM, 10873 },
    { MODRM_SPLITRM, 10875 },
    { MODRM_SPLITRM, 10877 },
    { MODRM_SPLITRM, 10879 },
    { MODRM_SPLITRM, 10881 },
    { MODRM_SPLITRM, 10883 },
    { MODRM_SPLITRM, 10885 },
    { MODRM_SPLITRM, 10887 },
    { MODRM_SPLITRM, 10889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10893 },
    { MODRM_SPLITRM, 10895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10899 },
    { MODRM_SPLITRM, 10901 },
    { MODRM_SPLITRM, 10903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10905 },
    { MODRM_SPLITRM, 10907 },
    { MODRM_SPLITRM, 10909 },
    { MODRM_SPLITRM, 10911 },
    { MODRM_SPLITRM, 10913 },
    { MODRM_SPLITRM, 10915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10917 },
    { MODRM_SPLITRM, 10919 },
    { MODRM_SPLITRM, 10921 },
    { MODRM_SPLITRM, 10923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10925 },
    { MODRM_SPLITRM, 10927 },
    { MODRM_SPLITRM, 10929 },
    { MODRM_SPLITRM, 10931 },
    { MODRM_SPLITRM, 10933 },
    { MODRM_SPLITRM, 10935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10937 },
    { MODRM_SPLITRM, 10939 },
    { MODRM_SPLITRM, 10941 },
    { MODRM_SPLITRM, 10943 },
    { MODRM_SPLITRM, 10945 },
    { MODRM_SPLITRM, 10947 },
    { MODRM_SPLITRM, 10949 },
    { MODRM_SPLITRM, 10951 },
    { MODRM_SPLITRM, 10953 },
    { MODRM_SPLITRM, 10955 },
    { MODRM_SPLITRM, 10957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11005 },
    { MODRM_SPLITRM, 11007 },
    { MODRM_SPLITRM, 11009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10967 },
    { MODRM_SPLITRM, 10969 },
    { MODRM_SPLITRM, 10971 },
    { MODRM_SPLITRM, 10973 },
    { MODRM_SPLITRM, 10975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10977 },
    { MODRM_SPLITRM, 10979 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10981 },
    { MODRM_SPLITRM, 10983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11013 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10817 },
    { MODRM_SPLITRM, 10819 },
    { MODRM_SPLITRM, 10821 },
    { MODRM_SPLITRM, 10823 },
    { MODRM_SPLITRM, 10825 },
    { MODRM_SPLITRM, 10827 },
    { MODRM_SPLITRM, 10829 },
    { MODRM_SPLITRM, 10831 },
    { MODRM_SPLITRM, 10833 },
    { MODRM_SPLITRM, 10835 },
    { MODRM_SPLITRM, 10837 },
    { MODRM_SPLITRM, 10839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10841 },
    { MODRM_SPLITRM, 10843 },
    { MODRM_SPLITRM, 10845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10859 },
    { MODRM_SPLITRM, 10861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10867 },
    { MODRM_SPLITRM, 10869 },
    { MODRM_SPLITRM, 10871 },
    { MODRM_SPLITRM, 10873 },
    { MODRM_SPLITRM, 10875 },
    { MODRM_SPLITRM, 10877 },
    { MODRM_SPLITRM, 10879 },
    { MODRM_SPLITRM, 10881 },
    { MODRM_SPLITRM, 10883 },
    { MODRM_SPLITRM, 10885 },
    { MODRM_SPLITRM, 10887 },
    { MODRM_SPLITRM, 10889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10893 },
    { MODRM_SPLITRM, 10895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10899 },
    { MODRM_SPLITRM, 10901 },
    { MODRM_SPLITRM, 10903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10905 },
    { MODRM_SPLITRM, 10907 },
    { MODRM_SPLITRM, 10909 },
    { MODRM_SPLITRM, 10911 },
    { MODRM_SPLITRM, 10913 },
    { MODRM_SPLITRM, 10915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10917 },
    { MODRM_SPLITRM, 10919 },
    { MODRM_SPLITRM, 10921 },
    { MODRM_SPLITRM, 10923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10925 },
    { MODRM_SPLITRM, 10927 },
    { MODRM_SPLITRM, 10929 },
    { MODRM_SPLITRM, 10931 },
    { MODRM_SPLITRM, 10933 },
    { MODRM_SPLITRM, 10935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10937 },
    { MODRM_SPLITRM, 10939 },
    { MODRM_SPLITRM, 10941 },
    { MODRM_SPLITRM, 10943 },
    { MODRM_SPLITRM, 10945 },
    { MODRM_SPLITRM, 10947 },
    { MODRM_SPLITRM, 10949 },
    { MODRM_SPLITRM, 10951 },
    { MODRM_SPLITRM, 10953 },
    { MODRM_SPLITRM, 10955 },
    { MODRM_SPLITRM, 10957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11005 },
    { MODRM_SPLITRM, 11007 },
    { MODRM_SPLITRM, 11009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10967 },
    { MODRM_SPLITRM, 10969 },
    { MODRM_SPLITRM, 10971 },
    { MODRM_SPLITRM, 10973 },
    { MODRM_SPLITRM, 10975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10977 },
    { MODRM_SPLITRM, 10979 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10981 },
    { MODRM_SPLITRM, 10983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10985 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10989 },
    { MODRM_SPLITRM, 10991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10995 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10989 },
    { MODRM_SPLITRM, 10991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10817 },
    { MODRM_SPLITRM, 10819 },
    { MODRM_SPLITRM, 10821 },
    { MODRM_SPLITRM, 10823 },
    { MODRM_SPLITRM, 10825 },
    { MODRM_SPLITRM, 10827 },
    { MODRM_SPLITRM, 10829 },
    { MODRM_SPLITRM, 10831 },
    { MODRM_SPLITRM, 10833 },
    { MODRM_SPLITRM, 10835 },
    { MODRM_SPLITRM, 10837 },
    { MODRM_SPLITRM, 10839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10841 },
    { MODRM_SPLITRM, 10843 },
    { MODRM_SPLITRM, 10845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10859 },
    { MODRM_SPLITRM, 10861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10817 },
    { MODRM_SPLITRM, 10819 },
    { MODRM_SPLITRM, 10821 },
    { MODRM_SPLITRM, 10823 },
    { MODRM_SPLITRM, 10825 },
    { MODRM_SPLITRM, 10827 },
    { MODRM_SPLITRM, 10829 },
    { MODRM_SPLITRM, 10831 },
    { MODRM_SPLITRM, 10833 },
    { MODRM_SPLITRM, 10835 },
    { MODRM_SPLITRM, 10837 },
    { MODRM_SPLITRM, 10839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10841 },
    { MODRM_SPLITRM, 10843 },
    { MODRM_SPLITRM, 10845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11017 },
    { MODRM_SPLITRM, 11019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 10867 },
    { MODRM_SPLITRM, 10869 },
    { MODRM_SPLITRM, 10871 },
    { MODRM_SPLITRM, 10873 },
    { MODRM_SPLITRM, 10875 },
    { MODRM_SPLITRM, 10877 },
    { MODRM_SPLITRM, 10879 },
    { MODRM_SPLITRM, 10881 },
    { MODRM_SPLITRM, 10883 },
    { MODRM_SPLITRM, 10885 },
    { MODRM_SPLITRM, 10887 },
    { MODRM_SPLITRM, 10889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10893 },
    { MODRM_SPLITRM, 10895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10899 },
    { MODRM_SPLITRM, 10901 },
    { MODRM_SPLITRM, 10903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10905 },
    { MODRM_SPLITRM, 10907 },
    { MODRM_SPLITRM, 10909 },
    { MODRM_SPLITRM, 10911 },
    { MODRM_SPLITRM, 10913 },
    { MODRM_SPLITRM, 10915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10917 },
    { MODRM_SPLITRM, 10919 },
    { MODRM_SPLITRM, 10921 },
    { MODRM_SPLITRM, 10923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10925 },
    { MODRM_SPLITRM, 10927 },
    { MODRM_SPLITRM, 10929 },
    { MODRM_SPLITRM, 10931 },
    { MODRM_SPLITRM, 10933 },
    { MODRM_SPLITRM, 10935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10937 },
    { MODRM_SPLITRM, 10939 },
    { MODRM_SPLITRM, 10941 },
    { MODRM_SPLITRM, 10943 },
    { MODRM_SPLITRM, 10945 },
    { MODRM_SPLITRM, 10947 },
    { MODRM_SPLITRM, 10949 },
    { MODRM_SPLITRM, 10951 },
    { MODRM_SPLITRM, 10953 },
    { MODRM_SPLITRM, 10955 },
    { MODRM_SPLITRM, 10957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11005 },
    { MODRM_SPLITRM, 11007 },
    { MODRM_SPLITRM, 11009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10847 },
    { MODRM_SPLITRM, 10849 },
    { MODRM_SPLITRM, 10851 },
    { MODRM_SPLITRM, 10853 },
    { MODRM_SPLITRM, 10855 },
    { MODRM_SPLITRM, 10857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10967 },
    { MODRM_SPLITRM, 10969 },
    { MODRM_SPLITRM, 10971 },
    { MODRM_SPLITRM, 10973 },
    { MODRM_SPLITRM, 10975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 10977 },
    { MODRM_SPLITRM, 10979 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11021 },
    { MODRM_SPLITRM, 11023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11013 },
    { MODRM_SPLITRM, 11003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11025 },
    { MODRM_SPLITREG, 11027 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11043 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11045 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11049 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11051 },
    { MODRM_SPLITRM, 11053 },
    { MODRM_SPLITRM, 11055 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 11057 },
    { MODRM_SPLITRM, 11059 },
    { MODRM_SPLITRM, 11061 },
    { MODRM_SPLITRM, 11063 },
    { MODRM_SPLITRM, 11065 },
    { MODRM_SPLITRM, 11067 },
    { MODRM_SPLITRM, 11069 },
    { MODRM_SPLITRM, 11071 },
    { MODRM_SPLITRM, 11073 },
    { MODRM_SPLITRM, 11075 },
    { MODRM_SPLITRM, 11077 },
    { MODRM_SPLITRM, 11079 },
    { MODRM_SPLITRM, 11081 },
    { MODRM_SPLITRM, 11083 },
    { MODRM_SPLITRM, 11085 },
    { MODRM_SPLITRM, 11087 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11089 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11091 },
    { MODRM_SPLITRM, 11093 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11095 },
    { MODRM_SPLITRM, 11097 },
    { MODRM_SPLITRM, 11099 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11101 },
    { MODRM_SPLITRM, 11103 },
    { MODRM_SPLITRM, 11105 },
    { MODRM_SPLITRM, 11107 },
    { MODRM_SPLITRM, 11109 },
    { MODRM_SPLITRM, 11111 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11113 },
    { MODRM_SPLITRM, 11115 },
    { MODRM_SPLITRM, 11117 },
    { MODRM_SPLITRM, 11119 },
    { MODRM_SPLITRM, 11121 },
    { MODRM_SPLITRM, 11123 },
    { MODRM_SPLITRM, 11125 },
    { MODRM_SPLITRM, 11127 },
    { MODRM_SPLITRM, 11129 },
    { MODRM_SPLITRM, 11131 },
    { MODRM_SPLITRM, 11133 },
    { MODRM_SPLITRM, 11135 },
    { MODRM_SPLITRM, 11137 },
    { MODRM_SPLITRM, 11139 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11141 },
    { MODRM_SPLITRM, 11143 },
    { MODRM_SPLITRM, 11145 },
    { MODRM_SPLITRM, 11147 },
    { MODRM_SPLITRM, 11149 },
    { MODRM_SPLITRM, 11151 },
    { MODRM_SPLITRM, 11153 },
    { MODRM_SPLITRM, 11155 },
    { MODRM_SPLITRM, 11157 },
    { MODRM_SPLITRM, 11159 },
    { MODRM_SPLITRM, 11161 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11163 },
    { MODRM_SPLITRM, 11165 },
    { MODRM_SPLITRM, 11167 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11169 },
    { MODRM_SPLITRM, 11171 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11173 },
    { MODRM_SPLITRM, 11175 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11177 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11179 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11181 },
    { MODRM_SPLITRM, 11183 },
    { MODRM_SPLITRM, 11185 },
    { MODRM_SPLITRM, 11187 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11189 },
    { MODRM_SPLITRM, 11191 },
    { MODRM_SPLITRM, 11193 },
    { MODRM_SPLITRM, 11195 },
    { MODRM_SPLITRM, 11197 },
    { MODRM_SPLITRM, 11199 },
    { MODRM_SPLITRM, 11201 },
    { MODRM_SPLITRM, 11203 },
    { MODRM_SPLITRM, 11205 },
    { MODRM_SPLITRM, 11207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11209 },
    { MODRM_SPLITRM, 11211 },
    { MODRM_SPLITRM, 11213 },
    { MODRM_SPLITRM, 11215 },
    { MODRM_SPLITRM, 11217 },
    { MODRM_SPLITRM, 11219 },
    { MODRM_SPLITRM, 11221 },
    { MODRM_SPLITRM, 11223 },
    { MODRM_SPLITRM, 11225 },
    { MODRM_SPLITRM, 11227 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11229 },
    { MODRM_SPLITRM, 11231 },
    { MODRM_SPLITRM, 11233 },
    { MODRM_SPLITRM, 11235 },
    { MODRM_SPLITRM, 11237 },
    { MODRM_SPLITRM, 11239 },
    { MODRM_SPLITRM, 11241 },
    { MODRM_SPLITRM, 11243 },
    { MODRM_SPLITRM, 11245 },
    { MODRM_SPLITRM, 11247 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11251 },
    { MODRM_SPLITRM, 11253 },
    { MODRM_SPLITRM, 11255 },
    { MODRM_SPLITRM, 11257 },
    { MODRM_SPLITRM, 11259 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11261 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11263 },
    { MODRM_SPLITREG, 11265 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11281 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11287 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11289 },
    { MODRM_SPLITRM, 11291 },
    { MODRM_SPLITRM, 11293 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 11057 },
    { MODRM_SPLITRM, 11059 },
    { MODRM_SPLITRM, 11061 },
    { MODRM_SPLITRM, 11063 },
    { MODRM_SPLITRM, 11065 },
    { MODRM_SPLITRM, 11067 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11071 },
    { MODRM_SPLITRM, 11073 },
    { MODRM_SPLITRM, 11075 },
    { MODRM_SPLITRM, 11077 },
    { MODRM_SPLITRM, 11079 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11091 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11095 },
    { MODRM_SPLITRM, 11097 },
    { MODRM_SPLITRM, 11099 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11101 },
    { MODRM_SPLITRM, 11103 },
    { MODRM_SPLITRM, 11105 },
    { MODRM_SPLITRM, 11107 },
    { MODRM_SPLITRM, 11109 },
    { MODRM_SPLITRM, 11111 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11113 },
    { MODRM_SPLITRM, 11115 },
    { MODRM_SPLITRM, 11117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11129 },
    { MODRM_SPLITRM, 11131 },
    { MODRM_SPLITRM, 11133 },
    { MODRM_SPLITRM, 11135 },
    { MODRM_SPLITRM, 11137 },
    { MODRM_SPLITRM, 11139 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11141 },
    { MODRM_SPLITRM, 11143 },
    { MODRM_SPLITRM, 11145 },
    { MODRM_SPLITRM, 11147 },
    { MODRM_SPLITRM, 11149 },
    { MODRM_SPLITRM, 11151 },
    { MODRM_SPLITRM, 11153 },
    { MODRM_SPLITRM, 11155 },
    { MODRM_SPLITRM, 11157 },
    { MODRM_SPLITRM, 11159 },
    { MODRM_SPLITRM, 11161 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11295 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11297 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11303 },
    { MODRM_SPLITRM, 11305 },
    { MODRM_SPLITRM, 11307 },
    { MODRM_SPLITRM, 11309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11311 },
    { MODRM_SPLITRM, 11313 },
    { MODRM_SPLITRM, 11315 },
    { MODRM_SPLITRM, 11317 },
    { MODRM_SPLITRM, 11319 },
    { MODRM_SPLITRM, 11321 },
    { MODRM_SPLITRM, 11323 },
    { MODRM_SPLITRM, 11325 },
    { MODRM_SPLITRM, 11327 },
    { MODRM_SPLITRM, 11329 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11331 },
    { MODRM_SPLITRM, 11333 },
    { MODRM_SPLITRM, 11335 },
    { MODRM_SPLITRM, 11337 },
    { MODRM_SPLITRM, 11339 },
    { MODRM_SPLITRM, 11341 },
    { MODRM_SPLITRM, 11343 },
    { MODRM_SPLITRM, 11345 },
    { MODRM_SPLITRM, 11347 },
    { MODRM_SPLITRM, 11349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11351 },
    { MODRM_SPLITRM, 11353 },
    { MODRM_SPLITRM, 11355 },
    { MODRM_SPLITRM, 11357 },
    { MODRM_SPLITRM, 11359 },
    { MODRM_SPLITRM, 11361 },
    { MODRM_SPLITRM, 11363 },
    { MODRM_SPLITRM, 11365 },
    { MODRM_SPLITRM, 11367 },
    { MODRM_SPLITRM, 11369 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11251 },
    { MODRM_SPLITRM, 11253 },
    { MODRM_SPLITRM, 11255 },
    { MODRM_SPLITRM, 11257 },
    { MODRM_SPLITRM, 11259 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 11373 },
    { MODRM_SPLITRM, 11375 },
    { MODRM_SPLITRM, 11377 },
    { MODRM_SPLITRM, 11379 },
    { MODRM_SPLITRM, 11381 },
    { MODRM_SPLITRM, 11383 },
    { MODRM_SPLITRM, 11385 },
    { MODRM_SPLITRM, 11387 },
    { MODRM_SPLITRM, 11389 },
    { MODRM_SPLITRM, 11391 },
    { MODRM_SPLITRM, 11393 },
    { MODRM_SPLITRM, 11395 },
    { MODRM_SPLITRM, 11397 },
    { MODRM_SPLITRM, 11399 },
    { MODRM_SPLITRM, 11401 },
    { MODRM_SPLITRM, 11403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11405 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11407 },
    { MODRM_SPLITRM, 11409 },
    { MODRM_SPLITRM, 11411 },
    { MODRM_SPLITRM, 11413 },
    { MODRM_SPLITRM, 11415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11417 },
    { MODRM_SPLITRM, 11419 },
    { MODRM_SPLITRM, 11421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11423 },
    { MODRM_SPLITRM, 11425 },
    { MODRM_SPLITRM, 11427 },
    { MODRM_SPLITRM, 11429 },
    { MODRM_SPLITRM, 11431 },
    { MODRM_SPLITRM, 11433 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11435 },
    { MODRM_SPLITRM, 11437 },
    { MODRM_SPLITRM, 11439 },
    { MODRM_SPLITRM, 11441 },
    { MODRM_SPLITRM, 11443 },
    { MODRM_SPLITRM, 11445 },
    { MODRM_SPLITRM, 11447 },
    { MODRM_SPLITRM, 11449 },
    { MODRM_SPLITRM, 11451 },
    { MODRM_SPLITRM, 11453 },
    { MODRM_SPLITRM, 11455 },
    { MODRM_SPLITRM, 11457 },
    { MODRM_SPLITRM, 11459 },
    { MODRM_SPLITRM, 11461 },
    { MODRM_SPLITRM, 11463 },
    { MODRM_SPLITRM, 11465 },
    { MODRM_SPLITRM, 11467 },
    { MODRM_SPLITRM, 11469 },
    { MODRM_SPLITRM, 11471 },
    { MODRM_SPLITRM, 11473 },
    { MODRM_SPLITRM, 11475 },
    { MODRM_SPLITRM, 11477 },
    { MODRM_SPLITRM, 11479 },
    { MODRM_SPLITRM, 11481 },
    { MODRM_SPLITRM, 11483 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11485 },
    { MODRM_SPLITRM, 11487 },
    { MODRM_SPLITRM, 11489 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11491 },
    { MODRM_SPLITRM, 11493 },
    { MODRM_SPLITRM, 11495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11497 },
    { MODRM_SPLITRM, 11499 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11501 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11503 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11505 },
    { MODRM_SPLITRM, 11507 },
    { MODRM_SPLITRM, 11509 },
    { MODRM_SPLITRM, 11511 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11513 },
    { MODRM_SPLITRM, 11515 },
    { MODRM_SPLITRM, 11517 },
    { MODRM_SPLITRM, 11195 },
    { MODRM_SPLITRM, 11519 },
    { MODRM_SPLITRM, 11199 },
    { MODRM_SPLITRM, 11521 },
    { MODRM_SPLITRM, 11203 },
    { MODRM_SPLITRM, 11523 },
    { MODRM_SPLITRM, 11207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11525 },
    { MODRM_SPLITRM, 11527 },
    { MODRM_SPLITRM, 11529 },
    { MODRM_SPLITRM, 11215 },
    { MODRM_SPLITRM, 11531 },
    { MODRM_SPLITRM, 11219 },
    { MODRM_SPLITRM, 11533 },
    { MODRM_SPLITRM, 11223 },
    { MODRM_SPLITRM, 11535 },
    { MODRM_SPLITRM, 11227 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11537 },
    { MODRM_SPLITRM, 11539 },
    { MODRM_SPLITRM, 11541 },
    { MODRM_SPLITRM, 11235 },
    { MODRM_SPLITRM, 11543 },
    { MODRM_SPLITRM, 11239 },
    { MODRM_SPLITRM, 11545 },
    { MODRM_SPLITRM, 11243 },
    { MODRM_SPLITRM, 11547 },
    { MODRM_SPLITRM, 11247 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11551 },
    { MODRM_SPLITRM, 11553 },
    { MODRM_SPLITRM, 11555 },
    { MODRM_SPLITRM, 11557 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 11373 },
    { MODRM_SPLITRM, 11375 },
    { MODRM_SPLITRM, 11377 },
    { MODRM_SPLITRM, 11379 },
    { MODRM_SPLITRM, 11381 },
    { MODRM_SPLITRM, 11383 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11387 },
    { MODRM_SPLITRM, 11389 },
    { MODRM_SPLITRM, 11391 },
    { MODRM_SPLITRM, 11393 },
    { MODRM_SPLITRM, 11395 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11409 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11417 },
    { MODRM_SPLITRM, 11419 },
    { MODRM_SPLITRM, 11421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11423 },
    { MODRM_SPLITRM, 11425 },
    { MODRM_SPLITRM, 11427 },
    { MODRM_SPLITRM, 11429 },
    { MODRM_SPLITRM, 11431 },
    { MODRM_SPLITRM, 11433 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11435 },
    { MODRM_SPLITRM, 11437 },
    { MODRM_SPLITRM, 11439 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11451 },
    { MODRM_SPLITRM, 11453 },
    { MODRM_SPLITRM, 11455 },
    { MODRM_SPLITRM, 11457 },
    { MODRM_SPLITRM, 11459 },
    { MODRM_SPLITRM, 11461 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11465 },
    { MODRM_SPLITRM, 11467 },
    { MODRM_SPLITRM, 11469 },
    { MODRM_SPLITRM, 11471 },
    { MODRM_SPLITRM, 11473 },
    { MODRM_SPLITRM, 11475 },
    { MODRM_SPLITRM, 11477 },
    { MODRM_SPLITRM, 11479 },
    { MODRM_SPLITRM, 11481 },
    { MODRM_SPLITRM, 11483 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11559 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11561 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11563 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11565 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11567 },
    { MODRM_SPLITRM, 11569 },
    { MODRM_SPLITRM, 11571 },
    { MODRM_SPLITRM, 11573 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11575 },
    { MODRM_SPLITRM, 11577 },
    { MODRM_SPLITRM, 11579 },
    { MODRM_SPLITRM, 11317 },
    { MODRM_SPLITRM, 11581 },
    { MODRM_SPLITRM, 11321 },
    { MODRM_SPLITRM, 11583 },
    { MODRM_SPLITRM, 11325 },
    { MODRM_SPLITRM, 11585 },
    { MODRM_SPLITRM, 11329 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11587 },
    { MODRM_SPLITRM, 11589 },
    { MODRM_SPLITRM, 11591 },
    { MODRM_SPLITRM, 11337 },
    { MODRM_SPLITRM, 11593 },
    { MODRM_SPLITRM, 11341 },
    { MODRM_SPLITRM, 11595 },
    { MODRM_SPLITRM, 11345 },
    { MODRM_SPLITRM, 11597 },
    { MODRM_SPLITRM, 11349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11599 },
    { MODRM_SPLITRM, 11601 },
    { MODRM_SPLITRM, 11603 },
    { MODRM_SPLITRM, 11357 },
    { MODRM_SPLITRM, 11605 },
    { MODRM_SPLITRM, 11361 },
    { MODRM_SPLITRM, 11607 },
    { MODRM_SPLITRM, 11365 },
    { MODRM_SPLITRM, 11609 },
    { MODRM_SPLITRM, 11369 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11551 },
    { MODRM_SPLITRM, 11553 },
    { MODRM_SPLITRM, 11555 },
    { MODRM_SPLITRM, 11557 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11611 },
    { MODRM_SPLITRM, 11613 },
    { MODRM_SPLITRM, 11615 },
    { MODRM_SPLITRM, 11617 },
    { MODRM_SPLITRM, 11619 },
    { MODRM_SPLITRM, 11621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11623 },
    { MODRM_SPLITRM, 11625 },
    { MODRM_SPLITRM, 11627 },
    { MODRM_SPLITRM, 11629 },
    { MODRM_SPLITRM, 11631 },
    { MODRM_SPLITRM, 11633 },
    { MODRM_SPLITRM, 11635 },
    { MODRM_SPLITRM, 11637 },
    { MODRM_SPLITRM, 11639 },
    { MODRM_SPLITRM, 11641 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11643 },
    { MODRM_SPLITRM, 11645 },
    { MODRM_SPLITRM, 11647 },
    { MODRM_SPLITRM, 11649 },
    { MODRM_SPLITRM, 11651 },
    { MODRM_SPLITRM, 11653 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11655 },
    { MODRM_SPLITRM, 11657 },
    { MODRM_SPLITRM, 11659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11661 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11663 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 11665 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11667 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11669 },
    { MODRM_SPLITRM, 11671 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11673 },
    { MODRM_SPLITRM, 11675 },
    { MODRM_SPLITRM, 11677 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11679 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11681 },
    { MODRM_SPLITRM, 11683 },
    { MODRM_SPLITRM, 11685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11687 },
    { MODRM_SPLITRM, 11689 },
    { MODRM_SPLITRM, 11691 },
    { MODRM_SPLITRM, 11693 },
    { MODRM_SPLITRM, 11695 },
    { MODRM_SPLITRM, 11697 },
    { MODRM_SPLITRM, 11699 },
    { MODRM_SPLITRM, 11701 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11703 },
    { MODRM_SPLITRM, 11705 },
    { MODRM_SPLITRM, 11707 },
    { MODRM_SPLITRM, 11709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11711 },
    { MODRM_SPLITRM, 11713 },
    { MODRM_SPLITRM, 11715 },
    { MODRM_SPLITRM, 11717 },
    { MODRM_SPLITRM, 11719 },
    { MODRM_SPLITRM, 11721 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11723 },
    { MODRM_SPLITRM, 11725 },
    { MODRM_SPLITRM, 11727 },
    { MODRM_SPLITRM, 11729 },
    { MODRM_SPLITRM, 11731 },
    { MODRM_SPLITRM, 11733 },
    { MODRM_SPLITRM, 11735 },
    { MODRM_SPLITRM, 11737 },
    { MODRM_SPLITRM, 11739 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11741 },
    { MODRM_SPLITRM, 11743 },
    { MODRM_SPLITRM, 11745 },
    { MODRM_SPLITRM, 11747 },
    { MODRM_SPLITRM, 11749 },
    { MODRM_SPLITRM, 11751 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11753 },
    { MODRM_SPLITRM, 11755 },
    { MODRM_SPLITRM, 11757 },
    { MODRM_SPLITRM, 11759 },
    { MODRM_SPLITRM, 11761 },
    { MODRM_SPLITRM, 11763 },
    { MODRM_SPLITRM, 11765 },
    { MODRM_SPLITRM, 11767 },
    { MODRM_SPLITRM, 11769 },
    { MODRM_SPLITRM, 11771 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11773 },
    { MODRM_SPLITRM, 11775 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11777 },
    { MODRM_SPLITRM, 11779 },
    { MODRM_SPLITRM, 11781 },
    { MODRM_SPLITRM, 11783 },
    { MODRM_SPLITRM, 11785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11789 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11791 },
    { MODRM_SPLITRM, 11793 },
    { MODRM_SPLITRM, 11795 },
    { MODRM_SPLITRM, 11797 },
    { MODRM_SPLITRM, 11799 },
    { MODRM_SPLITRM, 11801 },
    { MODRM_SPLITRM, 11803 },
    { MODRM_SPLITRM, 11805 },
    { MODRM_SPLITRM, 11807 },
    { MODRM_SPLITRM, 11809 },
    { MODRM_SPLITRM, 11811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11813 },
    { MODRM_SPLITRM, 11815 },
    { MODRM_SPLITRM, 11817 },
    { MODRM_SPLITRM, 11819 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11825 },
    { MODRM_SPLITRM, 11827 },
    { MODRM_SPLITRM, 11829 },
    { MODRM_SPLITRM, 11831 },
    { MODRM_SPLITRM, 11833 },
    { MODRM_SPLITRM, 11835 },
    { MODRM_SPLITRM, 11837 },
    { MODRM_SPLITRM, 11839 },
    { MODRM_SPLITRM, 11841 },
    { MODRM_SPLITRM, 11843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11845 },
    { MODRM_SPLITRM, 11847 },
    { MODRM_SPLITRM, 11849 },
    { MODRM_SPLITRM, 11851 },
    { MODRM_SPLITRM, 11853 },
    { MODRM_SPLITRM, 11855 },
    { MODRM_SPLITRM, 11857 },
    { MODRM_SPLITRM, 11859 },
    { MODRM_SPLITRM, 11861 },
    { MODRM_SPLITRM, 11863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11865 },
    { MODRM_SPLITRM, 11867 },
    { MODRM_SPLITRM, 11869 },
    { MODRM_SPLITRM, 11871 },
    { MODRM_SPLITRM, 11873 },
    { MODRM_SPLITRM, 11875 },
    { MODRM_SPLITRM, 11877 },
    { MODRM_SPLITRM, 11879 },
    { MODRM_SPLITRM, 11881 },
    { MODRM_SPLITRM, 11883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11887 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11893 },
    { MODRM_SPLITRM, 11895 },
    { MODRM_SPLITRM, 11897 },
    { MODRM_SPLITRM, 11899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11901 },
    { MODRM_SPLITRM, 11903 },
    { MODRM_SPLITRM, 11905 },
    { MODRM_SPLITRM, 11907 },
    { MODRM_SPLITRM, 11909 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11911 },
    { MODRM_SPLITRM, 11913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 11665 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11667 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11669 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11917 },
    { MODRM_SPLITRM, 11919 },
    { MODRM_SPLITRM, 11921 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11923 },
    { MODRM_SPLITRM, 11925 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11681 },
    { MODRM_SPLITRM, 11683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11927 },
    { MODRM_SPLITRM, 11687 },
    { MODRM_SPLITRM, 11689 },
    { MODRM_SPLITRM, 11691 },
    { MODRM_SPLITRM, 11693 },
    { MODRM_SPLITRM, 11695 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11929 },
    { MODRM_SPLITRM, 11931 },
    { MODRM_SPLITRM, 11933 },
    { MODRM_SPLITRM, 11935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11937 },
    { MODRM_SPLITRM, 11939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11711 },
    { MODRM_SPLITRM, 11713 },
    { MODRM_SPLITRM, 11715 },
    { MODRM_SPLITRM, 11717 },
    { MODRM_SPLITRM, 11719 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11941 },
    { MODRM_SPLITRM, 11723 },
    { MODRM_SPLITRM, 11943 },
    { MODRM_SPLITRM, 11727 },
    { MODRM_SPLITRM, 11945 },
    { MODRM_SPLITRM, 11731 },
    { MODRM_SPLITRM, 11947 },
    { MODRM_SPLITRM, 11735 },
    { MODRM_SPLITRM, 11949 },
    { MODRM_SPLITRM, 11951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11953 },
    { MODRM_SPLITRM, 11955 },
    { MODRM_SPLITRM, 11957 },
    { MODRM_SPLITRM, 11959 },
    { MODRM_SPLITRM, 11961 },
    { MODRM_SPLITRM, 11963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11965 },
    { MODRM_SPLITRM, 11967 },
    { MODRM_SPLITRM, 11969 },
    { MODRM_SPLITRM, 11971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11973 },
    { MODRM_SPLITRM, 11975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11979 },
    { MODRM_SPLITRM, 11981 },
    { MODRM_SPLITRM, 11983 },
    { MODRM_SPLITRM, 11985 },
    { MODRM_SPLITRM, 11987 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11989 },
    { MODRM_SPLITRM, 11991 },
    { MODRM_SPLITRM, 11993 },
    { MODRM_SPLITRM, 11995 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11997 },
    { MODRM_SPLITRM, 11999 },
    { MODRM_SPLITRM, 12001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12003 },
    { MODRM_SPLITRM, 12005 },
    { MODRM_SPLITRM, 12007 },
    { MODRM_SPLITRM, 12009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12011 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12013 },
    { MODRM_SPLITRM, 12015 },
    { MODRM_SPLITRM, 12017 },
    { MODRM_SPLITRM, 12019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12021 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12023 },
    { MODRM_SPLITRM, 12025 },
    { MODRM_SPLITRM, 12027 },
    { MODRM_SPLITRM, 12029 },
    { MODRM_SPLITRM, 12031 },
    { MODRM_SPLITRM, 12033 },
    { MODRM_SPLITRM, 12035 },
    { MODRM_SPLITRM, 12037 },
    { MODRM_SPLITRM, 12039 },
    { MODRM_SPLITRM, 12041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12043 },
    { MODRM_SPLITRM, 12045 },
    { MODRM_SPLITRM, 12047 },
    { MODRM_SPLITRM, 12049 },
    { MODRM_SPLITRM, 12051 },
    { MODRM_SPLITRM, 12053 },
    { MODRM_SPLITRM, 12055 },
    { MODRM_SPLITRM, 12057 },
    { MODRM_SPLITRM, 12059 },
    { MODRM_SPLITRM, 12061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12063 },
    { MODRM_SPLITRM, 12065 },
    { MODRM_SPLITRM, 12067 },
    { MODRM_SPLITRM, 12069 },
    { MODRM_SPLITRM, 12071 },
    { MODRM_SPLITRM, 12073 },
    { MODRM_SPLITRM, 12075 },
    { MODRM_SPLITRM, 12077 },
    { MODRM_SPLITRM, 12079 },
    { MODRM_SPLITRM, 12081 },
    { MODRM_SPLITRM, 12083 },
    { MODRM_SPLITRM, 12085 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12087 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12089 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12091 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 11893 },
    { MODRM_SPLITRM, 11895 },
    { MODRM_SPLITRM, 11897 },
    { MODRM_SPLITRM, 11899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12093 },
    { MODRM_SPLITRM, 12095 },
    { MODRM_SPLITRM, 12097 },
    { MODRM_SPLITRM, 12099 },
    { MODRM_SPLITRM, 12101 },
    { MODRM_SPLITRM, 12103 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12105 },
    { MODRM_SPLITRM, 12107 },
    { MODRM_SPLITRM, 12109 },
    { MODRM_SPLITRM, 12111 },
    { MODRM_SPLITRM, 12113 },
    { MODRM_SPLITRM, 12115 },
    { MODRM_SPLITRM, 12117 },
    { MODRM_SPLITRM, 12119 },
    { MODRM_SPLITRM, 12121 },
    { MODRM_SPLITRM, 12123 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12125 },
    { MODRM_SPLITRM, 12127 },
    { MODRM_SPLITRM, 12129 },
    { MODRM_SPLITRM, 12131 },
    { MODRM_SPLITRM, 12133 },
    { MODRM_SPLITRM, 12135 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12137 },
    { MODRM_SPLITRM, 12139 },
    { MODRM_SPLITRM, 12141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 12143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12147 },
    { MODRM_SPLITRM, 12149 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12151 },
    { MODRM_SPLITRM, 12153 },
    { MODRM_SPLITRM, 12155 },
    { MODRM_SPLITRM, 12157 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12159 },
    { MODRM_SPLITRM, 12161 },
    { MODRM_SPLITRM, 12163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12165 },
    { MODRM_SPLITRM, 12167 },
    { MODRM_SPLITRM, 12169 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12171 },
    { MODRM_SPLITRM, 12173 },
    { MODRM_SPLITRM, 12175 },
    { MODRM_SPLITRM, 12177 },
    { MODRM_SPLITRM, 12179 },
    { MODRM_SPLITRM, 12181 },
    { MODRM_SPLITRM, 12183 },
    { MODRM_SPLITRM, 12185 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12187 },
    { MODRM_SPLITRM, 12189 },
    { MODRM_SPLITRM, 12191 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12193 },
    { MODRM_SPLITRM, 12195 },
    { MODRM_SPLITRM, 12197 },
    { MODRM_SPLITRM, 12199 },
    { MODRM_SPLITRM, 12201 },
    { MODRM_SPLITRM, 12203 },
    { MODRM_SPLITRM, 12205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12207 },
    { MODRM_SPLITRM, 12209 },
    { MODRM_SPLITRM, 12211 },
    { MODRM_SPLITRM, 12213 },
    { MODRM_SPLITRM, 12215 },
    { MODRM_SPLITRM, 12217 },
    { MODRM_SPLITRM, 12219 },
    { MODRM_SPLITRM, 12221 },
    { MODRM_SPLITRM, 12223 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12225 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12227 },
    { MODRM_SPLITRM, 12229 },
    { MODRM_SPLITRM, 12231 },
    { MODRM_SPLITRM, 12233 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12237 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12239 },
    { MODRM_SPLITRM, 12241 },
    { MODRM_SPLITRM, 12243 },
    { MODRM_SPLITRM, 12245 },
    { MODRM_SPLITRM, 12247 },
    { MODRM_SPLITRM, 12249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12251 },
    { MODRM_SPLITRM, 12253 },
    { MODRM_SPLITRM, 12255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12257 },
    { MODRM_SPLITRM, 12259 },
    { MODRM_SPLITRM, 12261 },
    { MODRM_SPLITRM, 12263 },
    { MODRM_SPLITRM, 12265 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12269 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12271 },
    { MODRM_SPLITRM, 12273 },
    { MODRM_SPLITRM, 12275 },
    { MODRM_SPLITRM, 12277 },
    { MODRM_SPLITRM, 12279 },
    { MODRM_SPLITRM, 12281 },
    { MODRM_SPLITRM, 12283 },
    { MODRM_SPLITRM, 12285 },
    { MODRM_SPLITRM, 12287 },
    { MODRM_SPLITRM, 12289 },
    { MODRM_SPLITRM, 12291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12293 },
    { MODRM_SPLITRM, 12295 },
    { MODRM_SPLITRM, 12297 },
    { MODRM_SPLITRM, 12299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12305 },
    { MODRM_SPLITRM, 12307 },
    { MODRM_SPLITRM, 12309 },
    { MODRM_SPLITRM, 11831 },
    { MODRM_SPLITRM, 12311 },
    { MODRM_SPLITRM, 11835 },
    { MODRM_SPLITRM, 12313 },
    { MODRM_SPLITRM, 11839 },
    { MODRM_SPLITRM, 12315 },
    { MODRM_SPLITRM, 11843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12317 },
    { MODRM_SPLITRM, 12319 },
    { MODRM_SPLITRM, 12321 },
    { MODRM_SPLITRM, 11851 },
    { MODRM_SPLITRM, 12323 },
    { MODRM_SPLITRM, 11855 },
    { MODRM_SPLITRM, 12325 },
    { MODRM_SPLITRM, 11859 },
    { MODRM_SPLITRM, 12327 },
    { MODRM_SPLITRM, 11863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12329 },
    { MODRM_SPLITRM, 12331 },
    { MODRM_SPLITRM, 12333 },
    { MODRM_SPLITRM, 11871 },
    { MODRM_SPLITRM, 12335 },
    { MODRM_SPLITRM, 11875 },
    { MODRM_SPLITRM, 12337 },
    { MODRM_SPLITRM, 11879 },
    { MODRM_SPLITRM, 12339 },
    { MODRM_SPLITRM, 11883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12341 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12343 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12345 },
    { MODRM_SPLITRM, 12347 },
    { MODRM_SPLITRM, 12349 },
    { MODRM_SPLITRM, 12351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12353 },
    { MODRM_SPLITRM, 12355 },
    { MODRM_SPLITRM, 12357 },
    { MODRM_SPLITRM, 12359 },
    { MODRM_SPLITRM, 12361 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12363 },
    { MODRM_SPLITRM, 12365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 12143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12147 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12367 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12369 },
    { MODRM_SPLITRM, 12371 },
    { MODRM_SPLITRM, 12373 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12375 },
    { MODRM_SPLITRM, 12377 },
    { MODRM_SPLITRM, 12379 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12381 },
    { MODRM_SPLITRM, 12383 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12165 },
    { MODRM_SPLITRM, 12167 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12385 },
    { MODRM_SPLITRM, 12171 },
    { MODRM_SPLITRM, 12173 },
    { MODRM_SPLITRM, 12175 },
    { MODRM_SPLITRM, 12177 },
    { MODRM_SPLITRM, 12179 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12387 },
    { MODRM_SPLITRM, 12389 },
    { MODRM_SPLITRM, 12391 },
    { MODRM_SPLITRM, 12393 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12395 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12193 },
    { MODRM_SPLITRM, 12195 },
    { MODRM_SPLITRM, 12197 },
    { MODRM_SPLITRM, 12199 },
    { MODRM_SPLITRM, 12201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12397 },
    { MODRM_SPLITRM, 12399 },
    { MODRM_SPLITRM, 12207 },
    { MODRM_SPLITRM, 12401 },
    { MODRM_SPLITRM, 12211 },
    { MODRM_SPLITRM, 12403 },
    { MODRM_SPLITRM, 12215 },
    { MODRM_SPLITRM, 12405 },
    { MODRM_SPLITRM, 12219 },
    { MODRM_SPLITRM, 12407 },
    { MODRM_SPLITRM, 12409 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12413 },
    { MODRM_SPLITRM, 12415 },
    { MODRM_SPLITRM, 12417 },
    { MODRM_SPLITRM, 12419 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12425 },
    { MODRM_SPLITRM, 12427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12429 },
    { MODRM_SPLITRM, 12431 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12433 },
    { MODRM_SPLITRM, 12435 },
    { MODRM_SPLITRM, 12437 },
    { MODRM_SPLITRM, 12439 },
    { MODRM_SPLITRM, 12441 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12443 },
    { MODRM_SPLITRM, 12445 },
    { MODRM_SPLITRM, 12447 },
    { MODRM_SPLITRM, 12449 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12451 },
    { MODRM_SPLITRM, 12453 },
    { MODRM_SPLITRM, 12455 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12457 },
    { MODRM_SPLITRM, 12459 },
    { MODRM_SPLITRM, 12461 },
    { MODRM_SPLITRM, 12463 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12465 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12467 },
    { MODRM_SPLITRM, 12469 },
    { MODRM_SPLITRM, 12471 },
    { MODRM_SPLITRM, 12473 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12475 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12477 },
    { MODRM_SPLITRM, 12479 },
    { MODRM_SPLITRM, 12481 },
    { MODRM_SPLITRM, 12029 },
    { MODRM_SPLITRM, 12483 },
    { MODRM_SPLITRM, 12033 },
    { MODRM_SPLITRM, 12485 },
    { MODRM_SPLITRM, 12037 },
    { MODRM_SPLITRM, 12487 },
    { MODRM_SPLITRM, 12041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12489 },
    { MODRM_SPLITRM, 12491 },
    { MODRM_SPLITRM, 12493 },
    { MODRM_SPLITRM, 12049 },
    { MODRM_SPLITRM, 12495 },
    { MODRM_SPLITRM, 12053 },
    { MODRM_SPLITRM, 12497 },
    { MODRM_SPLITRM, 12057 },
    { MODRM_SPLITRM, 12499 },
    { MODRM_SPLITRM, 12061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12501 },
    { MODRM_SPLITRM, 12503 },
    { MODRM_SPLITRM, 12505 },
    { MODRM_SPLITRM, 12507 },
    { MODRM_SPLITRM, 12509 },
    { MODRM_SPLITRM, 12073 },
    { MODRM_SPLITRM, 12511 },
    { MODRM_SPLITRM, 12077 },
    { MODRM_SPLITRM, 12513 },
    { MODRM_SPLITRM, 12081 },
    { MODRM_SPLITRM, 12515 },
    { MODRM_SPLITRM, 12085 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12517 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12345 },
    { MODRM_SPLITRM, 12347 },
    { MODRM_SPLITRM, 12349 },
    { MODRM_SPLITRM, 12351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12519 },
    { MODRM_SPLITRM, 12521 },
    { MODRM_SPLITRM, 12523 },
    { MODRM_SPLITRM, 12525 },
    { MODRM_SPLITRM, 12527 },
    { MODRM_SPLITRM, 12529 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12531 },
    { MODRM_SPLITRM, 12533 },
    { MODRM_SPLITRM, 12535 },
    { MODRM_SPLITRM, 12537 },
    { MODRM_SPLITRM, 12539 },
    { MODRM_SPLITRM, 12541 },
    { MODRM_SPLITRM, 12543 },
    { MODRM_SPLITRM, 12545 },
    { MODRM_SPLITRM, 12547 },
    { MODRM_SPLITRM, 12549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12551 },
    { MODRM_SPLITRM, 12553 },
    { MODRM_SPLITRM, 12555 },
    { MODRM_SPLITRM, 12557 },
    { MODRM_SPLITRM, 12559 },
    { MODRM_SPLITRM, 12561 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12563 },
    { MODRM_SPLITRM, 12565 },
    { MODRM_SPLITRM, 12567 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12569 },
    { MODRM_SPLITRM, 12571 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12573 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12575 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 12577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12581 },
    { MODRM_SPLITRM, 12583 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12585 },
    { MODRM_SPLITRM, 12587 },
    { MODRM_SPLITRM, 12589 },
    { MODRM_SPLITRM, 12591 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12593 },
    { MODRM_SPLITRM, 12595 },
    { MODRM_SPLITRM, 12597 },
    { MODRM_SPLITRM, 12599 },
    { MODRM_SPLITRM, 12601 },
    { MODRM_SPLITRM, 12603 },
    { MODRM_SPLITRM, 12605 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12607 },
    { MODRM_SPLITRM, 12609 },
    { MODRM_SPLITRM, 12611 },
    { MODRM_SPLITRM, 12613 },
    { MODRM_SPLITRM, 12615 },
    { MODRM_SPLITRM, 12617 },
    { MODRM_SPLITRM, 12619 },
    { MODRM_SPLITRM, 12621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12623 },
    { MODRM_SPLITRM, 12625 },
    { MODRM_SPLITRM, 12627 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12629 },
    { MODRM_SPLITRM, 12631 },
    { MODRM_SPLITRM, 12633 },
    { MODRM_SPLITRM, 12635 },
    { MODRM_SPLITRM, 12637 },
    { MODRM_SPLITRM, 12639 },
    { MODRM_SPLITRM, 12641 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12643 },
    { MODRM_SPLITRM, 12645 },
    { MODRM_SPLITRM, 12647 },
    { MODRM_SPLITRM, 12649 },
    { MODRM_SPLITRM, 12651 },
    { MODRM_SPLITRM, 12653 },
    { MODRM_SPLITRM, 12655 },
    { MODRM_SPLITRM, 12657 },
    { MODRM_SPLITRM, 12659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12661 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12663 },
    { MODRM_SPLITRM, 12665 },
    { MODRM_SPLITRM, 12667 },
    { MODRM_SPLITRM, 12669 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12671 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12673 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12675 },
    { MODRM_SPLITRM, 12677 },
    { MODRM_SPLITRM, 12679 },
    { MODRM_SPLITRM, 12681 },
    { MODRM_SPLITRM, 12683 },
    { MODRM_SPLITRM, 12685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12687 },
    { MODRM_SPLITRM, 12689 },
    { MODRM_SPLITRM, 12691 },
    { MODRM_SPLITRM, 12693 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12695 },
    { MODRM_SPLITRM, 12697 },
    { MODRM_SPLITRM, 12699 },
    { MODRM_SPLITRM, 12701 },
    { MODRM_SPLITRM, 12703 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12705 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12707 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12709 },
    { MODRM_SPLITRM, 12711 },
    { MODRM_SPLITRM, 12713 },
    { MODRM_SPLITRM, 12715 },
    { MODRM_SPLITRM, 12717 },
    { MODRM_SPLITRM, 12719 },
    { MODRM_SPLITRM, 12721 },
    { MODRM_SPLITRM, 12723 },
    { MODRM_SPLITRM, 12725 },
    { MODRM_SPLITRM, 12727 },
    { MODRM_SPLITRM, 12729 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12731 },
    { MODRM_SPLITRM, 12733 },
    { MODRM_SPLITRM, 12735 },
    { MODRM_SPLITRM, 12737 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12739 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12741 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12743 },
    { MODRM_SPLITRM, 12745 },
    { MODRM_SPLITRM, 12747 },
    { MODRM_SPLITRM, 11831 },
    { MODRM_SPLITRM, 12749 },
    { MODRM_SPLITRM, 11835 },
    { MODRM_SPLITRM, 12751 },
    { MODRM_SPLITRM, 11839 },
    { MODRM_SPLITRM, 12753 },
    { MODRM_SPLITRM, 11843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12755 },
    { MODRM_SPLITRM, 12757 },
    { MODRM_SPLITRM, 12759 },
    { MODRM_SPLITRM, 11851 },
    { MODRM_SPLITRM, 12761 },
    { MODRM_SPLITRM, 11855 },
    { MODRM_SPLITRM, 12763 },
    { MODRM_SPLITRM, 11859 },
    { MODRM_SPLITRM, 12765 },
    { MODRM_SPLITRM, 11863 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12767 },
    { MODRM_SPLITRM, 12769 },
    { MODRM_SPLITRM, 12771 },
    { MODRM_SPLITRM, 11871 },
    { MODRM_SPLITRM, 12773 },
    { MODRM_SPLITRM, 11875 },
    { MODRM_SPLITRM, 12775 },
    { MODRM_SPLITRM, 11879 },
    { MODRM_SPLITRM, 12777 },
    { MODRM_SPLITRM, 11883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12779 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12781 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12789 },
    { MODRM_SPLITRM, 12791 },
    { MODRM_SPLITRM, 12793 },
    { MODRM_SPLITRM, 12795 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12797 },
    { MODRM_SPLITRM, 12799 },
    { MODRM_SPLITRM, 12801 },
    { MODRM_SPLITRM, 12803 },
    { MODRM_SPLITRM, 12805 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12807 },
    { MODRM_SPLITRM, 12809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 12577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12581 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12813 },
    { MODRM_SPLITRM, 12815 },
    { MODRM_SPLITRM, 12817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12819 },
    { MODRM_SPLITRM, 12821 },
    { MODRM_SPLITRM, 12823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12825 },
    { MODRM_SPLITRM, 12827 },
    { MODRM_SPLITRM, 12829 },
    { MODRM_SPLITRM, 12601 },
    { MODRM_SPLITRM, 12603 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12831 },
    { MODRM_SPLITRM, 12607 },
    { MODRM_SPLITRM, 12609 },
    { MODRM_SPLITRM, 12611 },
    { MODRM_SPLITRM, 12613 },
    { MODRM_SPLITRM, 12615 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12833 },
    { MODRM_SPLITRM, 12835 },
    { MODRM_SPLITRM, 12837 },
    { MODRM_SPLITRM, 12839 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12841 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12629 },
    { MODRM_SPLITRM, 12631 },
    { MODRM_SPLITRM, 12633 },
    { MODRM_SPLITRM, 12635 },
    { MODRM_SPLITRM, 12637 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12843 },
    { MODRM_SPLITRM, 12845 },
    { MODRM_SPLITRM, 12643 },
    { MODRM_SPLITRM, 12847 },
    { MODRM_SPLITRM, 12647 },
    { MODRM_SPLITRM, 12849 },
    { MODRM_SPLITRM, 12651 },
    { MODRM_SPLITRM, 12851 },
    { MODRM_SPLITRM, 12655 },
    { MODRM_SPLITRM, 12853 },
    { MODRM_SPLITRM, 12855 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12859 },
    { MODRM_SPLITRM, 12861 },
    { MODRM_SPLITRM, 12863 },
    { MODRM_SPLITRM, 12865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12867 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12869 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12871 },
    { MODRM_SPLITRM, 12873 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12875 },
    { MODRM_SPLITRM, 12877 },
    { MODRM_SPLITRM, 12879 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12881 },
    { MODRM_SPLITRM, 12883 },
    { MODRM_SPLITRM, 12885 },
    { MODRM_SPLITRM, 12887 },
    { MODRM_SPLITRM, 12889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12891 },
    { MODRM_SPLITRM, 12893 },
    { MODRM_SPLITRM, 12895 },
    { MODRM_SPLITRM, 12897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12899 },
    { MODRM_SPLITRM, 12901 },
    { MODRM_SPLITRM, 12903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12905 },
    { MODRM_SPLITRM, 12907 },
    { MODRM_SPLITRM, 12909 },
    { MODRM_SPLITRM, 12911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12915 },
    { MODRM_SPLITRM, 12917 },
    { MODRM_SPLITRM, 12919 },
    { MODRM_SPLITRM, 12921 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12925 },
    { MODRM_SPLITRM, 12927 },
    { MODRM_SPLITRM, 12929 },
    { MODRM_SPLITRM, 12029 },
    { MODRM_SPLITRM, 12931 },
    { MODRM_SPLITRM, 12033 },
    { MODRM_SPLITRM, 12933 },
    { MODRM_SPLITRM, 12037 },
    { MODRM_SPLITRM, 12935 },
    { MODRM_SPLITRM, 12041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12937 },
    { MODRM_SPLITRM, 12939 },
    { MODRM_SPLITRM, 12941 },
    { MODRM_SPLITRM, 12049 },
    { MODRM_SPLITRM, 12943 },
    { MODRM_SPLITRM, 12053 },
    { MODRM_SPLITRM, 12945 },
    { MODRM_SPLITRM, 12057 },
    { MODRM_SPLITRM, 12947 },
    { MODRM_SPLITRM, 12061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12949 },
    { MODRM_SPLITRM, 12951 },
    { MODRM_SPLITRM, 12953 },
    { MODRM_SPLITRM, 12955 },
    { MODRM_SPLITRM, 12957 },
    { MODRM_SPLITRM, 12073 },
    { MODRM_SPLITRM, 12959 },
    { MODRM_SPLITRM, 12077 },
    { MODRM_SPLITRM, 12961 },
    { MODRM_SPLITRM, 12081 },
    { MODRM_SPLITRM, 12963 },
    { MODRM_SPLITRM, 12085 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12789 },
    { MODRM_SPLITRM, 12791 },
    { MODRM_SPLITRM, 12793 },
    { MODRM_SPLITRM, 12795 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12973 },
    { MODRM_SPLITRM, 12975 },
    { MODRM_SPLITRM, 12977 },
    { MODRM_SPLITRM, 12979 },
    { MODRM_SPLITRM, 12981 },
    { MODRM_SPLITRM, 12983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 12985 },
    { MODRM_SPLITRM, 12987 },
    { MODRM_SPLITRM, 12989 },
    { MODRM_SPLITRM, 12991 },
    { MODRM_SPLITRM, 12993 },
    { MODRM_SPLITRM, 12995 },
    { MODRM_SPLITRM, 12997 },
    { MODRM_SPLITRM, 12999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13001 },
    { MODRM_SPLITRM, 13003 },
    { MODRM_SPLITRM, 13005 },
    { MODRM_SPLITRM, 13007 },
    { MODRM_SPLITRM, 13009 },
    { MODRM_SPLITRM, 13011 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13013 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 13017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13021 },
    { MODRM_SPLITRM, 13023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13025 },
    { MODRM_SPLITRM, 13027 },
    { MODRM_SPLITRM, 13029 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13031 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13033 },
    { MODRM_SPLITRM, 13035 },
    { MODRM_SPLITRM, 13037 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13039 },
    { MODRM_SPLITRM, 13041 },
    { MODRM_SPLITRM, 13043 },
    { MODRM_SPLITRM, 13045 },
    { MODRM_SPLITRM, 13047 },
    { MODRM_SPLITRM, 13049 },
    { MODRM_SPLITRM, 13051 },
    { MODRM_SPLITRM, 13053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13055 },
    { MODRM_SPLITRM, 13057 },
    { MODRM_SPLITRM, 13059 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13061 },
    { MODRM_SPLITRM, 13063 },
    { MODRM_SPLITRM, 13065 },
    { MODRM_SPLITRM, 13067 },
    { MODRM_SPLITRM, 13069 },
    { MODRM_SPLITRM, 13071 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13073 },
    { MODRM_SPLITRM, 13075 },
    { MODRM_SPLITRM, 13077 },
    { MODRM_SPLITRM, 13079 },
    { MODRM_SPLITRM, 13081 },
    { MODRM_SPLITRM, 13083 },
    { MODRM_SPLITRM, 13085 },
    { MODRM_SPLITRM, 13087 },
    { MODRM_SPLITRM, 13089 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13091 },
    { MODRM_SPLITRM, 13093 },
    { MODRM_SPLITRM, 13095 },
    { MODRM_SPLITRM, 13097 },
    { MODRM_SPLITRM, 13099 },
    { MODRM_SPLITRM, 13101 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13103 },
    { MODRM_SPLITRM, 13105 },
    { MODRM_SPLITRM, 13107 },
    { MODRM_SPLITRM, 13109 },
    { MODRM_SPLITRM, 13111 },
    { MODRM_SPLITRM, 13113 },
    { MODRM_SPLITRM, 13115 },
    { MODRM_SPLITRM, 13117 },
    { MODRM_SPLITRM, 13119 },
    { MODRM_SPLITRM, 13121 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13123 },
    { MODRM_SPLITRM, 13125 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13127 },
    { MODRM_SPLITRM, 13129 },
    { MODRM_SPLITRM, 13131 },
    { MODRM_SPLITRM, 13133 },
    { MODRM_SPLITRM, 13135 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13137 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13139 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13141 },
    { MODRM_SPLITRM, 13143 },
    { MODRM_SPLITRM, 13145 },
    { MODRM_SPLITRM, 13147 },
    { MODRM_SPLITRM, 13149 },
    { MODRM_SPLITRM, 13151 },
    { MODRM_SPLITRM, 13153 },
    { MODRM_SPLITRM, 13155 },
    { MODRM_SPLITRM, 13157 },
    { MODRM_SPLITRM, 13159 },
    { MODRM_SPLITRM, 13161 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13163 },
    { MODRM_SPLITRM, 13165 },
    { MODRM_SPLITRM, 13167 },
    { MODRM_SPLITRM, 13169 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13171 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13173 },
    { MODRM_SPLITRM, 13175 },
    { MODRM_SPLITRM, 13177 },
    { MODRM_SPLITRM, 13179 },
    { MODRM_SPLITRM, 13181 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13183 },
    { MODRM_SPLITRM, 13185 },
    { MODRM_SPLITRM, 13187 },
    { MODRM_SPLITRM, 13189 },
    { MODRM_SPLITRM, 13191 },
    { MODRM_SPLITRM, 13193 },
    { MODRM_SPLITRM, 13195 },
    { MODRM_SPLITRM, 13197 },
    { MODRM_SPLITRM, 13199 },
    { MODRM_SPLITRM, 13201 },
    { MODRM_SPLITRM, 13203 },
    { MODRM_SPLITRM, 13205 },
    { MODRM_SPLITRM, 13207 },
    { MODRM_SPLITRM, 13209 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13211 },
    { MODRM_SPLITRM, 13213 },
    { MODRM_SPLITRM, 13215 },
    { MODRM_SPLITRM, 13217 },
    { MODRM_SPLITRM, 13219 },
    { MODRM_SPLITRM, 13221 },
    { MODRM_SPLITRM, 13223 },
    { MODRM_SPLITRM, 13225 },
    { MODRM_SPLITRM, 13227 },
    { MODRM_SPLITRM, 13229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13231 },
    { MODRM_SPLITRM, 13233 },
    { MODRM_SPLITRM, 13235 },
    { MODRM_SPLITRM, 13237 },
    { MODRM_SPLITRM, 13239 },
    { MODRM_SPLITRM, 13241 },
    { MODRM_SPLITRM, 13243 },
    { MODRM_SPLITRM, 13245 },
    { MODRM_SPLITRM, 13247 },
    { MODRM_SPLITRM, 13249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13251 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13253 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13259 },
    { MODRM_SPLITRM, 13261 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 13017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13021 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13263 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13265 },
    { MODRM_SPLITRM, 13267 },
    { MODRM_SPLITRM, 13269 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13271 },
    { MODRM_SPLITRM, 13273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13033 },
    { MODRM_SPLITRM, 13035 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13275 },
    { MODRM_SPLITRM, 13039 },
    { MODRM_SPLITRM, 13041 },
    { MODRM_SPLITRM, 13043 },
    { MODRM_SPLITRM, 13045 },
    { MODRM_SPLITRM, 13047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13277 },
    { MODRM_SPLITRM, 13279 },
    { MODRM_SPLITRM, 13281 },
    { MODRM_SPLITRM, 13283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13285 },
    { MODRM_SPLITRM, 13287 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13061 },
    { MODRM_SPLITRM, 13063 },
    { MODRM_SPLITRM, 13065 },
    { MODRM_SPLITRM, 13067 },
    { MODRM_SPLITRM, 13069 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13289 },
    { MODRM_SPLITRM, 13073 },
    { MODRM_SPLITRM, 13291 },
    { MODRM_SPLITRM, 13077 },
    { MODRM_SPLITRM, 13293 },
    { MODRM_SPLITRM, 13081 },
    { MODRM_SPLITRM, 13295 },
    { MODRM_SPLITRM, 13085 },
    { MODRM_SPLITRM, 13297 },
    { MODRM_SPLITRM, 13299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13301 },
    { MODRM_SPLITRM, 13303 },
    { MODRM_SPLITRM, 13305 },
    { MODRM_SPLITRM, 13307 },
    { MODRM_SPLITRM, 13309 },
    { MODRM_SPLITRM, 13311 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13313 },
    { MODRM_SPLITRM, 13315 },
    { MODRM_SPLITRM, 13317 },
    { MODRM_SPLITRM, 13319 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13321 },
    { MODRM_SPLITRM, 13323 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13325 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13327 },
    { MODRM_SPLITRM, 13329 },
    { MODRM_SPLITRM, 13331 },
    { MODRM_SPLITRM, 13333 },
    { MODRM_SPLITRM, 13335 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13337 },
    { MODRM_SPLITRM, 13339 },
    { MODRM_SPLITRM, 13341 },
    { MODRM_SPLITRM, 13343 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13345 },
    { MODRM_SPLITRM, 13347 },
    { MODRM_SPLITRM, 13349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13351 },
    { MODRM_SPLITRM, 13353 },
    { MODRM_SPLITRM, 13355 },
    { MODRM_SPLITRM, 13357 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13359 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13361 },
    { MODRM_SPLITRM, 13363 },
    { MODRM_SPLITRM, 13365 },
    { MODRM_SPLITRM, 13367 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13369 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13371 },
    { MODRM_SPLITRM, 13373 },
    { MODRM_SPLITRM, 13375 },
    { MODRM_SPLITRM, 13377 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13379 },
    { MODRM_SPLITRM, 13381 },
    { MODRM_SPLITRM, 13383 },
    { MODRM_SPLITRM, 13385 },
    { MODRM_SPLITRM, 13387 },
    { MODRM_SPLITRM, 13389 },
    { MODRM_SPLITRM, 13391 },
    { MODRM_SPLITRM, 13393 },
    { MODRM_SPLITRM, 13395 },
    { MODRM_SPLITRM, 13397 },
    { MODRM_SPLITRM, 13399 },
    { MODRM_SPLITRM, 13401 },
    { MODRM_SPLITRM, 13403 },
    { MODRM_SPLITRM, 13405 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13407 },
    { MODRM_SPLITRM, 13409 },
    { MODRM_SPLITRM, 13411 },
    { MODRM_SPLITRM, 13413 },
    { MODRM_SPLITRM, 13415 },
    { MODRM_SPLITRM, 13417 },
    { MODRM_SPLITRM, 13419 },
    { MODRM_SPLITRM, 13421 },
    { MODRM_SPLITRM, 13423 },
    { MODRM_SPLITRM, 13425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13427 },
    { MODRM_SPLITRM, 13429 },
    { MODRM_SPLITRM, 13431 },
    { MODRM_SPLITRM, 13433 },
    { MODRM_SPLITRM, 13435 },
    { MODRM_SPLITRM, 13437 },
    { MODRM_SPLITRM, 13439 },
    { MODRM_SPLITRM, 13441 },
    { MODRM_SPLITRM, 13443 },
    { MODRM_SPLITRM, 13445 },
    { MODRM_SPLITRM, 13447 },
    { MODRM_SPLITRM, 13449 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13451 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13453 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13455 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13457 },
    { MODRM_SPLITRM, 13459 },
    { MODRM_SPLITRM, 13461 },
    { MODRM_SPLITRM, 13463 },
    { MODRM_SPLITRM, 13465 },
    { MODRM_SPLITRM, 13467 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13469 },
    { MODRM_SPLITRM, 13471 },
    { MODRM_SPLITRM, 13473 },
    { MODRM_SPLITRM, 13475 },
    { MODRM_SPLITRM, 13477 },
    { MODRM_SPLITRM, 13479 },
    { MODRM_SPLITRM, 13481 },
    { MODRM_SPLITRM, 13483 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13485 },
    { MODRM_SPLITRM, 13487 },
    { MODRM_SPLITRM, 13489 },
    { MODRM_SPLITRM, 13491 },
    { MODRM_SPLITRM, 13493 },
    { MODRM_SPLITRM, 13495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 13497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13499 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13501 },
    { MODRM_SPLITRM, 13503 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13505 },
    { MODRM_SPLITRM, 13507 },
    { MODRM_SPLITRM, 13509 },
    { MODRM_SPLITRM, 13511 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13513 },
    { MODRM_SPLITRM, 13515 },
    { MODRM_SPLITRM, 13517 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13519 },
    { MODRM_SPLITRM, 13521 },
    { MODRM_SPLITRM, 13523 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13525 },
    { MODRM_SPLITRM, 13527 },
    { MODRM_SPLITRM, 13529 },
    { MODRM_SPLITRM, 13531 },
    { MODRM_SPLITRM, 13533 },
    { MODRM_SPLITRM, 13535 },
    { MODRM_SPLITRM, 13537 },
    { MODRM_SPLITRM, 13539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13541 },
    { MODRM_SPLITRM, 13543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13545 },
    { MODRM_SPLITRM, 13547 },
    { MODRM_SPLITRM, 13549 },
    { MODRM_SPLITRM, 13551 },
    { MODRM_SPLITRM, 13553 },
    { MODRM_SPLITRM, 13555 },
    { MODRM_SPLITRM, 13557 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13559 },
    { MODRM_SPLITRM, 13561 },
    { MODRM_SPLITRM, 13563 },
    { MODRM_SPLITRM, 13565 },
    { MODRM_SPLITRM, 13567 },
    { MODRM_SPLITRM, 13569 },
    { MODRM_SPLITRM, 13571 },
    { MODRM_SPLITRM, 13573 },
    { MODRM_SPLITRM, 13575 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13577 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13579 },
    { MODRM_SPLITRM, 13581 },
    { MODRM_SPLITRM, 13583 },
    { MODRM_SPLITRM, 13585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13587 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13589 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13591 },
    { MODRM_SPLITRM, 13593 },
    { MODRM_SPLITRM, 13595 },
    { MODRM_SPLITRM, 13597 },
    { MODRM_SPLITRM, 13599 },
    { MODRM_SPLITRM, 13601 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13603 },
    { MODRM_SPLITRM, 13605 },
    { MODRM_SPLITRM, 13607 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13609 },
    { MODRM_SPLITRM, 13611 },
    { MODRM_SPLITRM, 13613 },
    { MODRM_SPLITRM, 13615 },
    { MODRM_SPLITRM, 13617 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13623 },
    { MODRM_SPLITRM, 13625 },
    { MODRM_SPLITRM, 13627 },
    { MODRM_SPLITRM, 13629 },
    { MODRM_SPLITRM, 13631 },
    { MODRM_SPLITRM, 13633 },
    { MODRM_SPLITRM, 13635 },
    { MODRM_SPLITRM, 13637 },
    { MODRM_SPLITRM, 13639 },
    { MODRM_SPLITRM, 13641 },
    { MODRM_SPLITRM, 13643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13645 },
    { MODRM_SPLITRM, 13647 },
    { MODRM_SPLITRM, 13649 },
    { MODRM_SPLITRM, 13651 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13653 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13655 },
    { MODRM_SPLITRM, 13657 },
    { MODRM_SPLITRM, 13659 },
    { MODRM_SPLITRM, 13661 },
    { MODRM_SPLITRM, 13663 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13665 },
    { MODRM_SPLITRM, 13667 },
    { MODRM_SPLITRM, 13669 },
    { MODRM_SPLITRM, 13189 },
    { MODRM_SPLITRM, 13671 },
    { MODRM_SPLITRM, 13193 },
    { MODRM_SPLITRM, 13673 },
    { MODRM_SPLITRM, 13197 },
    { MODRM_SPLITRM, 13675 },
    { MODRM_SPLITRM, 13201 },
    { MODRM_SPLITRM, 13677 },
    { MODRM_SPLITRM, 13679 },
    { MODRM_SPLITRM, 13681 },
    { MODRM_SPLITRM, 13683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13685 },
    { MODRM_SPLITRM, 13687 },
    { MODRM_SPLITRM, 13689 },
    { MODRM_SPLITRM, 13217 },
    { MODRM_SPLITRM, 13691 },
    { MODRM_SPLITRM, 13221 },
    { MODRM_SPLITRM, 13693 },
    { MODRM_SPLITRM, 13225 },
    { MODRM_SPLITRM, 13695 },
    { MODRM_SPLITRM, 13229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13697 },
    { MODRM_SPLITRM, 13699 },
    { MODRM_SPLITRM, 13701 },
    { MODRM_SPLITRM, 13237 },
    { MODRM_SPLITRM, 13703 },
    { MODRM_SPLITRM, 13241 },
    { MODRM_SPLITRM, 13705 },
    { MODRM_SPLITRM, 13245 },
    { MODRM_SPLITRM, 13707 },
    { MODRM_SPLITRM, 13249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13711 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13713 },
    { MODRM_SPLITRM, 13715 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 13497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13499 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13501 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13717 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13719 },
    { MODRM_SPLITRM, 13721 },
    { MODRM_SPLITRM, 13723 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13725 },
    { MODRM_SPLITRM, 13727 },
    { MODRM_SPLITRM, 13729 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13731 },
    { MODRM_SPLITRM, 13733 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13519 },
    { MODRM_SPLITRM, 13521 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13735 },
    { MODRM_SPLITRM, 13525 },
    { MODRM_SPLITRM, 13527 },
    { MODRM_SPLITRM, 13529 },
    { MODRM_SPLITRM, 13531 },
    { MODRM_SPLITRM, 13533 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13737 },
    { MODRM_SPLITRM, 13739 },
    { MODRM_SPLITRM, 13741 },
    { MODRM_SPLITRM, 13743 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13745 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13545 },
    { MODRM_SPLITRM, 13547 },
    { MODRM_SPLITRM, 13549 },
    { MODRM_SPLITRM, 13551 },
    { MODRM_SPLITRM, 13553 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13747 },
    { MODRM_SPLITRM, 13749 },
    { MODRM_SPLITRM, 13559 },
    { MODRM_SPLITRM, 13751 },
    { MODRM_SPLITRM, 13563 },
    { MODRM_SPLITRM, 13753 },
    { MODRM_SPLITRM, 13567 },
    { MODRM_SPLITRM, 13755 },
    { MODRM_SPLITRM, 13571 },
    { MODRM_SPLITRM, 13757 },
    { MODRM_SPLITRM, 13759 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13761 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13763 },
    { MODRM_SPLITRM, 13765 },
    { MODRM_SPLITRM, 13767 },
    { MODRM_SPLITRM, 13769 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13771 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13773 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13775 },
    { MODRM_SPLITRM, 13777 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13779 },
    { MODRM_SPLITRM, 13781 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13783 },
    { MODRM_SPLITRM, 13785 },
    { MODRM_SPLITRM, 13787 },
    { MODRM_SPLITRM, 13789 },
    { MODRM_SPLITRM, 13791 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13793 },
    { MODRM_SPLITRM, 13795 },
    { MODRM_SPLITRM, 13797 },
    { MODRM_SPLITRM, 13799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13801 },
    { MODRM_SPLITRM, 13803 },
    { MODRM_SPLITRM, 13805 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13807 },
    { MODRM_SPLITRM, 13809 },
    { MODRM_SPLITRM, 13811 },
    { MODRM_SPLITRM, 13813 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13817 },
    { MODRM_SPLITRM, 13819 },
    { MODRM_SPLITRM, 13821 },
    { MODRM_SPLITRM, 13823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13827 },
    { MODRM_SPLITRM, 13829 },
    { MODRM_SPLITRM, 13831 },
    { MODRM_SPLITRM, 13833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13835 },
    { MODRM_SPLITRM, 13837 },
    { MODRM_SPLITRM, 13839 },
    { MODRM_SPLITRM, 13385 },
    { MODRM_SPLITRM, 13841 },
    { MODRM_SPLITRM, 13389 },
    { MODRM_SPLITRM, 13843 },
    { MODRM_SPLITRM, 13393 },
    { MODRM_SPLITRM, 13845 },
    { MODRM_SPLITRM, 13397 },
    { MODRM_SPLITRM, 13847 },
    { MODRM_SPLITRM, 13849 },
    { MODRM_SPLITRM, 13851 },
    { MODRM_SPLITRM, 13853 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13855 },
    { MODRM_SPLITRM, 13857 },
    { MODRM_SPLITRM, 13859 },
    { MODRM_SPLITRM, 13413 },
    { MODRM_SPLITRM, 13861 },
    { MODRM_SPLITRM, 13417 },
    { MODRM_SPLITRM, 13863 },
    { MODRM_SPLITRM, 13421 },
    { MODRM_SPLITRM, 13865 },
    { MODRM_SPLITRM, 13425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13867 },
    { MODRM_SPLITRM, 13869 },
    { MODRM_SPLITRM, 13871 },
    { MODRM_SPLITRM, 13873 },
    { MODRM_SPLITRM, 13875 },
    { MODRM_SPLITRM, 13437 },
    { MODRM_SPLITRM, 13877 },
    { MODRM_SPLITRM, 13441 },
    { MODRM_SPLITRM, 13879 },
    { MODRM_SPLITRM, 13445 },
    { MODRM_SPLITRM, 13881 },
    { MODRM_SPLITRM, 13449 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13885 },
    { MODRM_SPLITRM, 13887 },
    { MODRM_SPLITRM, 13889 },
    { MODRM_SPLITRM, 13891 },
    { MODRM_SPLITRM, 13893 },
    { MODRM_SPLITRM, 13895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13897 },
    { MODRM_SPLITRM, 13899 },
    { MODRM_SPLITRM, 13901 },
    { MODRM_SPLITRM, 13903 },
    { MODRM_SPLITRM, 13905 },
    { MODRM_SPLITRM, 13907 },
    { MODRM_SPLITRM, 13909 },
    { MODRM_SPLITRM, 13911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13913 },
    { MODRM_SPLITRM, 13915 },
    { MODRM_SPLITRM, 13917 },
    { MODRM_SPLITRM, 13919 },
    { MODRM_SPLITRM, 13921 },
    { MODRM_SPLITRM, 13923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13925 },
    { MODRM_SPLITRM, 13927 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13929 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 13933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13937 },
    { MODRM_SPLITRM, 13939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13941 },
    { MODRM_SPLITRM, 13943 },
    { MODRM_SPLITRM, 13945 },
    { MODRM_SPLITRM, 13947 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13949 },
    { MODRM_SPLITRM, 13951 },
    { MODRM_SPLITRM, 13953 },
    { MODRM_SPLITRM, 13955 },
    { MODRM_SPLITRM, 13957 },
    { MODRM_SPLITRM, 13959 },
    { MODRM_SPLITRM, 13961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13963 },
    { MODRM_SPLITRM, 13965 },
    { MODRM_SPLITRM, 13967 },
    { MODRM_SPLITRM, 13969 },
    { MODRM_SPLITRM, 13971 },
    { MODRM_SPLITRM, 13973 },
    { MODRM_SPLITRM, 13975 },
    { MODRM_SPLITRM, 13977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13979 },
    { MODRM_SPLITRM, 13981 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13983 },
    { MODRM_SPLITRM, 13985 },
    { MODRM_SPLITRM, 13987 },
    { MODRM_SPLITRM, 13989 },
    { MODRM_SPLITRM, 13991 },
    { MODRM_SPLITRM, 13993 },
    { MODRM_SPLITRM, 13995 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13997 },
    { MODRM_SPLITRM, 13999 },
    { MODRM_SPLITRM, 14001 },
    { MODRM_SPLITRM, 14003 },
    { MODRM_SPLITRM, 14005 },
    { MODRM_SPLITRM, 14007 },
    { MODRM_SPLITRM, 14009 },
    { MODRM_SPLITRM, 14011 },
    { MODRM_SPLITRM, 14013 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14017 },
    { MODRM_SPLITRM, 14019 },
    { MODRM_SPLITRM, 14021 },
    { MODRM_SPLITRM, 14023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14027 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14029 },
    { MODRM_SPLITRM, 14031 },
    { MODRM_SPLITRM, 14033 },
    { MODRM_SPLITRM, 14035 },
    { MODRM_SPLITRM, 14037 },
    { MODRM_SPLITRM, 14039 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14041 },
    { MODRM_SPLITRM, 14043 },
    { MODRM_SPLITRM, 14045 },
    { MODRM_SPLITRM, 14047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14049 },
    { MODRM_SPLITRM, 14051 },
    { MODRM_SPLITRM, 14053 },
    { MODRM_SPLITRM, 14055 },
    { MODRM_SPLITRM, 14057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14059 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14063 },
    { MODRM_SPLITRM, 14065 },
    { MODRM_SPLITRM, 14067 },
    { MODRM_SPLITRM, 14069 },
    { MODRM_SPLITRM, 14071 },
    { MODRM_SPLITRM, 14073 },
    { MODRM_SPLITRM, 14075 },
    { MODRM_SPLITRM, 14077 },
    { MODRM_SPLITRM, 14079 },
    { MODRM_SPLITRM, 14081 },
    { MODRM_SPLITRM, 14083 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14085 },
    { MODRM_SPLITRM, 14087 },
    { MODRM_SPLITRM, 14089 },
    { MODRM_SPLITRM, 14091 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14093 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14095 },
    { MODRM_SPLITRM, 14097 },
    { MODRM_SPLITRM, 14099 },
    { MODRM_SPLITRM, 14101 },
    { MODRM_SPLITRM, 14103 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14105 },
    { MODRM_SPLITRM, 14107 },
    { MODRM_SPLITRM, 14109 },
    { MODRM_SPLITRM, 13189 },
    { MODRM_SPLITRM, 14111 },
    { MODRM_SPLITRM, 13193 },
    { MODRM_SPLITRM, 14113 },
    { MODRM_SPLITRM, 13197 },
    { MODRM_SPLITRM, 14115 },
    { MODRM_SPLITRM, 13201 },
    { MODRM_SPLITRM, 14117 },
    { MODRM_SPLITRM, 14119 },
    { MODRM_SPLITRM, 14121 },
    { MODRM_SPLITRM, 14123 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14125 },
    { MODRM_SPLITRM, 14127 },
    { MODRM_SPLITRM, 14129 },
    { MODRM_SPLITRM, 13217 },
    { MODRM_SPLITRM, 14131 },
    { MODRM_SPLITRM, 13221 },
    { MODRM_SPLITRM, 14133 },
    { MODRM_SPLITRM, 13225 },
    { MODRM_SPLITRM, 14135 },
    { MODRM_SPLITRM, 13229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14137 },
    { MODRM_SPLITRM, 14139 },
    { MODRM_SPLITRM, 14141 },
    { MODRM_SPLITRM, 13237 },
    { MODRM_SPLITRM, 14143 },
    { MODRM_SPLITRM, 13241 },
    { MODRM_SPLITRM, 14145 },
    { MODRM_SPLITRM, 13245 },
    { MODRM_SPLITRM, 14147 },
    { MODRM_SPLITRM, 13249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14149 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 14151 },
    { MODRM_SPLITREG, 14167 },
    { MODRM_SPLITRM, 14183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14185 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14187 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14191 },
    { MODRM_SPLITRM, 14193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 13933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14195 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14197 },
    { MODRM_SPLITRM, 14199 },
    { MODRM_SPLITRM, 14201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14203 },
    { MODRM_SPLITRM, 14205 },
    { MODRM_SPLITRM, 14207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14209 },
    { MODRM_SPLITRM, 14211 },
    { MODRM_SPLITRM, 14213 },
    { MODRM_SPLITRM, 13957 },
    { MODRM_SPLITRM, 13959 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14215 },
    { MODRM_SPLITRM, 13963 },
    { MODRM_SPLITRM, 13965 },
    { MODRM_SPLITRM, 13967 },
    { MODRM_SPLITRM, 13969 },
    { MODRM_SPLITRM, 13971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14217 },
    { MODRM_SPLITRM, 14219 },
    { MODRM_SPLITRM, 14221 },
    { MODRM_SPLITRM, 14223 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14225 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 13983 },
    { MODRM_SPLITRM, 13985 },
    { MODRM_SPLITRM, 13987 },
    { MODRM_SPLITRM, 13989 },
    { MODRM_SPLITRM, 13991 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14227 },
    { MODRM_SPLITRM, 14229 },
    { MODRM_SPLITRM, 13997 },
    { MODRM_SPLITRM, 14231 },
    { MODRM_SPLITRM, 14001 },
    { MODRM_SPLITRM, 14233 },
    { MODRM_SPLITRM, 14005 },
    { MODRM_SPLITRM, 14235 },
    { MODRM_SPLITRM, 14009 },
    { MODRM_SPLITRM, 14237 },
    { MODRM_SPLITRM, 14239 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14241 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14243 },
    { MODRM_SPLITRM, 14245 },
    { MODRM_SPLITRM, 14247 },
    { MODRM_SPLITRM, 14249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14251 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14253 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14255 },
    { MODRM_SPLITRM, 14257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14259 },
    { MODRM_SPLITRM, 14261 },
    { MODRM_SPLITRM, 14263 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14265 },
    { MODRM_SPLITRM, 14267 },
    { MODRM_SPLITRM, 14269 },
    { MODRM_SPLITRM, 14271 },
    { MODRM_SPLITRM, 14273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14275 },
    { MODRM_SPLITRM, 14277 },
    { MODRM_SPLITRM, 14279 },
    { MODRM_SPLITRM, 14281 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14283 },
    { MODRM_SPLITRM, 14285 },
    { MODRM_SPLITRM, 14287 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14289 },
    { MODRM_SPLITRM, 14291 },
    { MODRM_SPLITRM, 14293 },
    { MODRM_SPLITRM, 14295 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14297 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14299 },
    { MODRM_SPLITRM, 14301 },
    { MODRM_SPLITRM, 14303 },
    { MODRM_SPLITRM, 14305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14307 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14309 },
    { MODRM_SPLITRM, 14311 },
    { MODRM_SPLITRM, 14313 },
    { MODRM_SPLITRM, 14315 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14317 },
    { MODRM_SPLITRM, 14319 },
    { MODRM_SPLITRM, 14321 },
    { MODRM_SPLITRM, 13385 },
    { MODRM_SPLITRM, 14323 },
    { MODRM_SPLITRM, 13389 },
    { MODRM_SPLITRM, 14325 },
    { MODRM_SPLITRM, 13393 },
    { MODRM_SPLITRM, 14327 },
    { MODRM_SPLITRM, 13397 },
    { MODRM_SPLITRM, 14329 },
    { MODRM_SPLITRM, 14331 },
    { MODRM_SPLITRM, 14333 },
    { MODRM_SPLITRM, 14335 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14337 },
    { MODRM_SPLITRM, 14339 },
    { MODRM_SPLITRM, 14341 },
    { MODRM_SPLITRM, 13413 },
    { MODRM_SPLITRM, 14343 },
    { MODRM_SPLITRM, 13417 },
    { MODRM_SPLITRM, 14345 },
    { MODRM_SPLITRM, 13421 },
    { MODRM_SPLITRM, 14347 },
    { MODRM_SPLITRM, 13425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14349 },
    { MODRM_SPLITRM, 14351 },
    { MODRM_SPLITRM, 14353 },
    { MODRM_SPLITRM, 14355 },
    { MODRM_SPLITRM, 14357 },
    { MODRM_SPLITRM, 13437 },
    { MODRM_SPLITRM, 14359 },
    { MODRM_SPLITRM, 13441 },
    { MODRM_SPLITRM, 14361 },
    { MODRM_SPLITRM, 13445 },
    { MODRM_SPLITRM, 14363 },
    { MODRM_SPLITRM, 13449 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 14367 },
    { MODRM_SPLITREG, 14383 },
    { MODRM_SPLITRM, 14399 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14401 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14405 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14409 },
    { MODRM_SPLITRM, 14411 },
    { MODRM_SPLITRM, 14413 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14419 },
    { MODRM_SPLITRM, 14421 },
    { MODRM_SPLITRM, 14423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14431 },
    { MODRM_SPLITRM, 14433 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14435 },
    { MODRM_SPLITRM, 14437 },
    { MODRM_SPLITRM, 14439 },
    { MODRM_SPLITRM, 14441 },
    { MODRM_SPLITRM, 14443 },
    { MODRM_SPLITRM, 14445 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14447 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14449 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14451 },
    { MODRM_SPLITRM, 14453 },
    { MODRM_SPLITRM, 14455 },
    { MODRM_SPLITRM, 14457 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14459 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14461 },
    { MODRM_SPLITRM, 14463 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14465 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14467 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14469 },
    { MODRM_SPLITRM, 14471 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14473 },
    { MODRM_SPLITRM, 14475 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14477 },
    { MODRM_SPLITRM, 14479 },
    { MODRM_SPLITRM, 14481 },
    { MODRM_SPLITRM, 14483 },
    { MODRM_SPLITRM, 14485 },
    { MODRM_SPLITRM, 14487 },
    { MODRM_SPLITRM, 14489 },
    { MODRM_SPLITRM, 14491 },
    { MODRM_SPLITRM, 14493 },
    { MODRM_SPLITRM, 14495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14497 },
    { MODRM_SPLITRM, 14499 },
    { MODRM_SPLITRM, 14501 },
    { MODRM_SPLITRM, 14503 },
    { MODRM_SPLITRM, 14505 },
    { MODRM_SPLITRM, 14507 },
    { MODRM_SPLITRM, 14509 },
    { MODRM_SPLITRM, 14511 },
    { MODRM_SPLITRM, 14513 },
    { MODRM_SPLITRM, 14515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14517 },
    { MODRM_SPLITRM, 14519 },
    { MODRM_SPLITRM, 14521 },
    { MODRM_SPLITRM, 14523 },
    { MODRM_SPLITRM, 14525 },
    { MODRM_SPLITRM, 14527 },
    { MODRM_SPLITRM, 14529 },
    { MODRM_SPLITRM, 14531 },
    { MODRM_SPLITRM, 14533 },
    { MODRM_SPLITRM, 14535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14537 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14541 },
    { MODRM_SPLITRM, 14543 },
    { MODRM_SPLITRM, 14545 },
    { MODRM_SPLITRM, 14547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14551 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14553 },
    { MODRM_SPLITRM, 14555 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14557 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14559 },
    { MODRM_SPLITRM, 14561 },
    { MODRM_SPLITRM, 14563 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14565 },
    { MODRM_SPLITRM, 14567 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14569 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14571 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14573 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14575 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14577 },
    { MODRM_SPLITRM, 14579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14581 },
    { MODRM_SPLITRM, 14583 },
    { MODRM_SPLITRM, 14585 },
    { MODRM_SPLITRM, 14587 },
    { MODRM_SPLITRM, 14589 },
    { MODRM_SPLITRM, 14591 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14593 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14595 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14597 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14599 },
    { MODRM_SPLITRM, 14601 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14603 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14605 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14607 },
    { MODRM_SPLITRM, 14609 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14611 },
    { MODRM_SPLITRM, 14613 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14615 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14617 },
    { MODRM_SPLITRM, 14619 },
    { MODRM_SPLITRM, 14621 },
    { MODRM_SPLITRM, 14623 },
    { MODRM_SPLITRM, 14625 },
    { MODRM_SPLITRM, 14627 },
    { MODRM_SPLITRM, 14629 },
    { MODRM_SPLITRM, 14631 },
    { MODRM_SPLITRM, 14633 },
    { MODRM_SPLITRM, 14635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14637 },
    { MODRM_SPLITRM, 14639 },
    { MODRM_SPLITRM, 14641 },
    { MODRM_SPLITRM, 14643 },
    { MODRM_SPLITRM, 14645 },
    { MODRM_SPLITRM, 14647 },
    { MODRM_SPLITRM, 14649 },
    { MODRM_SPLITRM, 14651 },
    { MODRM_SPLITRM, 14653 },
    { MODRM_SPLITRM, 14655 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14657 },
    { MODRM_SPLITRM, 14659 },
    { MODRM_SPLITRM, 14661 },
    { MODRM_SPLITRM, 14663 },
    { MODRM_SPLITRM, 14665 },
    { MODRM_SPLITRM, 14667 },
    { MODRM_SPLITRM, 14669 },
    { MODRM_SPLITRM, 14671 },
    { MODRM_SPLITRM, 14673 },
    { MODRM_SPLITRM, 14675 },
    { MODRM_SPLITRM, 14677 },
    { MODRM_SPLITRM, 14679 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14681 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14685 },
    { MODRM_SPLITRM, 14687 },
    { MODRM_SPLITRM, 14689 },
    { MODRM_SPLITRM, 14691 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14693 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14695 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14409 },
    { MODRM_SPLITRM, 14697 },
    { MODRM_SPLITRM, 14699 },
    { MODRM_SPLITRM, 14701 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14703 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14705 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14707 },
    { MODRM_SPLITRM, 14709 },
    { MODRM_SPLITRM, 14423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14711 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14713 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14715 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14717 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14719 },
    { MODRM_SPLITRM, 14721 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14723 },
    { MODRM_SPLITRM, 14437 },
    { MODRM_SPLITRM, 14725 },
    { MODRM_SPLITRM, 14727 },
    { MODRM_SPLITRM, 14729 },
    { MODRM_SPLITRM, 14731 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14733 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14735 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14737 },
    { MODRM_SPLITRM, 14739 },
    { MODRM_SPLITRM, 14741 },
    { MODRM_SPLITRM, 14743 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14745 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14747 },
    { MODRM_SPLITRM, 14749 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14751 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14753 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14755 },
    { MODRM_SPLITRM, 14757 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14759 },
    { MODRM_SPLITRM, 14761 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14763 },
    { MODRM_SPLITRM, 14765 },
    { MODRM_SPLITRM, 14767 },
    { MODRM_SPLITRM, 14483 },
    { MODRM_SPLITRM, 14769 },
    { MODRM_SPLITRM, 14487 },
    { MODRM_SPLITRM, 14771 },
    { MODRM_SPLITRM, 14491 },
    { MODRM_SPLITRM, 14773 },
    { MODRM_SPLITRM, 14495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14775 },
    { MODRM_SPLITRM, 14777 },
    { MODRM_SPLITRM, 14779 },
    { MODRM_SPLITRM, 14503 },
    { MODRM_SPLITRM, 14781 },
    { MODRM_SPLITRM, 14507 },
    { MODRM_SPLITRM, 14783 },
    { MODRM_SPLITRM, 14511 },
    { MODRM_SPLITRM, 14785 },
    { MODRM_SPLITRM, 14515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14787 },
    { MODRM_SPLITRM, 14789 },
    { MODRM_SPLITRM, 14791 },
    { MODRM_SPLITRM, 14523 },
    { MODRM_SPLITRM, 14793 },
    { MODRM_SPLITRM, 14527 },
    { MODRM_SPLITRM, 14795 },
    { MODRM_SPLITRM, 14531 },
    { MODRM_SPLITRM, 14797 },
    { MODRM_SPLITRM, 14535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14541 },
    { MODRM_SPLITRM, 14543 },
    { MODRM_SPLITRM, 14545 },
    { MODRM_SPLITRM, 14547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14803 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14805 },
    { MODRM_SPLITRM, 14807 },
    { MODRM_SPLITRM, 14809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14813 },
    { MODRM_SPLITRM, 14815 },
    { MODRM_SPLITRM, 14817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14819 },
    { MODRM_SPLITRM, 14567 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14821 },
    { MODRM_SPLITRM, 14823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14829 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14831 },
    { MODRM_SPLITRM, 14833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14835 },
    { MODRM_SPLITRM, 14583 },
    { MODRM_SPLITRM, 14837 },
    { MODRM_SPLITRM, 14839 },
    { MODRM_SPLITRM, 14841 },
    { MODRM_SPLITRM, 14843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14849 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14851 },
    { MODRM_SPLITRM, 14853 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14855 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14859 },
    { MODRM_SPLITRM, 14861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14863 },
    { MODRM_SPLITRM, 14865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14867 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14869 },
    { MODRM_SPLITRM, 14871 },
    { MODRM_SPLITRM, 14873 },
    { MODRM_SPLITRM, 14623 },
    { MODRM_SPLITRM, 14875 },
    { MODRM_SPLITRM, 14627 },
    { MODRM_SPLITRM, 14877 },
    { MODRM_SPLITRM, 14631 },
    { MODRM_SPLITRM, 14879 },
    { MODRM_SPLITRM, 14635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14881 },
    { MODRM_SPLITRM, 14883 },
    { MODRM_SPLITRM, 14885 },
    { MODRM_SPLITRM, 14643 },
    { MODRM_SPLITRM, 14887 },
    { MODRM_SPLITRM, 14647 },
    { MODRM_SPLITRM, 14889 },
    { MODRM_SPLITRM, 14651 },
    { MODRM_SPLITRM, 14891 },
    { MODRM_SPLITRM, 14655 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14893 },
    { MODRM_SPLITRM, 14895 },
    { MODRM_SPLITRM, 14897 },
    { MODRM_SPLITRM, 14899 },
    { MODRM_SPLITRM, 14901 },
    { MODRM_SPLITRM, 14667 },
    { MODRM_SPLITRM, 14903 },
    { MODRM_SPLITRM, 14671 },
    { MODRM_SPLITRM, 14905 },
    { MODRM_SPLITRM, 14675 },
    { MODRM_SPLITRM, 14907 },
    { MODRM_SPLITRM, 14679 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14909 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14685 },
    { MODRM_SPLITRM, 14687 },
    { MODRM_SPLITRM, 14689 },
    { MODRM_SPLITRM, 14691 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14409 },
    { MODRM_SPLITRM, 14915 },
    { MODRM_SPLITRM, 14917 },
    { MODRM_SPLITRM, 14919 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14921 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14925 },
    { MODRM_SPLITRM, 14927 },
    { MODRM_SPLITRM, 14423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14929 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14937 },
    { MODRM_SPLITRM, 14939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14941 },
    { MODRM_SPLITRM, 14437 },
    { MODRM_SPLITRM, 14943 },
    { MODRM_SPLITRM, 14945 },
    { MODRM_SPLITRM, 14947 },
    { MODRM_SPLITRM, 14949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14955 },
    { MODRM_SPLITRM, 14957 },
    { MODRM_SPLITRM, 14959 },
    { MODRM_SPLITRM, 14961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14965 },
    { MODRM_SPLITRM, 14967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14973 },
    { MODRM_SPLITRM, 14975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14977 },
    { MODRM_SPLITRM, 14979 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14981 },
    { MODRM_SPLITRM, 14983 },
    { MODRM_SPLITRM, 14985 },
    { MODRM_SPLITRM, 14483 },
    { MODRM_SPLITRM, 14987 },
    { MODRM_SPLITRM, 14487 },
    { MODRM_SPLITRM, 14989 },
    { MODRM_SPLITRM, 14491 },
    { MODRM_SPLITRM, 14991 },
    { MODRM_SPLITRM, 14495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 14993 },
    { MODRM_SPLITRM, 14995 },
    { MODRM_SPLITRM, 14997 },
    { MODRM_SPLITRM, 14503 },
    { MODRM_SPLITRM, 14999 },
    { MODRM_SPLITRM, 14507 },
    { MODRM_SPLITRM, 15001 },
    { MODRM_SPLITRM, 14511 },
    { MODRM_SPLITRM, 15003 },
    { MODRM_SPLITRM, 14515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15005 },
    { MODRM_SPLITRM, 15007 },
    { MODRM_SPLITRM, 15009 },
    { MODRM_SPLITRM, 14523 },
    { MODRM_SPLITRM, 15011 },
    { MODRM_SPLITRM, 14527 },
    { MODRM_SPLITRM, 15013 },
    { MODRM_SPLITRM, 14531 },
    { MODRM_SPLITRM, 15015 },
    { MODRM_SPLITRM, 14535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15021 },
    { MODRM_SPLITRM, 14543 },
    { MODRM_SPLITRM, 15023 },
    { MODRM_SPLITRM, 14547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15027 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15029 },
    { MODRM_SPLITRM, 15031 },
    { MODRM_SPLITRM, 15033 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15035 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15037 },
    { MODRM_SPLITRM, 15039 },
    { MODRM_SPLITRM, 15041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15043 },
    { MODRM_SPLITRM, 14567 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15045 },
    { MODRM_SPLITRM, 15047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15049 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15055 },
    { MODRM_SPLITRM, 15057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15059 },
    { MODRM_SPLITRM, 14583 },
    { MODRM_SPLITRM, 15061 },
    { MODRM_SPLITRM, 15063 },
    { MODRM_SPLITRM, 15065 },
    { MODRM_SPLITRM, 15067 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15069 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15071 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15073 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15075 },
    { MODRM_SPLITRM, 15077 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15079 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15081 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15083 },
    { MODRM_SPLITRM, 15085 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15087 },
    { MODRM_SPLITRM, 15089 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15091 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15093 },
    { MODRM_SPLITRM, 15095 },
    { MODRM_SPLITRM, 15097 },
    { MODRM_SPLITRM, 14623 },
    { MODRM_SPLITRM, 15099 },
    { MODRM_SPLITRM, 14627 },
    { MODRM_SPLITRM, 15101 },
    { MODRM_SPLITRM, 14631 },
    { MODRM_SPLITRM, 15103 },
    { MODRM_SPLITRM, 14635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15105 },
    { MODRM_SPLITRM, 15107 },
    { MODRM_SPLITRM, 15109 },
    { MODRM_SPLITRM, 14643 },
    { MODRM_SPLITRM, 15111 },
    { MODRM_SPLITRM, 14647 },
    { MODRM_SPLITRM, 15113 },
    { MODRM_SPLITRM, 14651 },
    { MODRM_SPLITRM, 15115 },
    { MODRM_SPLITRM, 14655 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15117 },
    { MODRM_SPLITRM, 15119 },
    { MODRM_SPLITRM, 15121 },
    { MODRM_SPLITRM, 15123 },
    { MODRM_SPLITRM, 15125 },
    { MODRM_SPLITRM, 14667 },
    { MODRM_SPLITRM, 15127 },
    { MODRM_SPLITRM, 14671 },
    { MODRM_SPLITRM, 15129 },
    { MODRM_SPLITRM, 14675 },
    { MODRM_SPLITRM, 15131 },
    { MODRM_SPLITRM, 14679 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15133 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15135 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15137 },
    { MODRM_SPLITRM, 14687 },
    { MODRM_SPLITRM, 15139 },
    { MODRM_SPLITRM, 14691 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15145 },
    { MODRM_SPLITRM, 15147 },
    { MODRM_SPLITRM, 15149 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15153 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15155 },
    { MODRM_SPLITRM, 15157 },
    { MODRM_SPLITRM, 15159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15161 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15165 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15167 },
    { MODRM_SPLITRM, 15169 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15171 },
    { MODRM_SPLITRM, 15173 },
    { MODRM_SPLITRM, 15175 },
    { MODRM_SPLITRM, 15177 },
    { MODRM_SPLITRM, 15179 },
    { MODRM_SPLITRM, 15181 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15185 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15187 },
    { MODRM_SPLITRM, 15189 },
    { MODRM_SPLITRM, 15191 },
    { MODRM_SPLITRM, 15193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15195 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15197 },
    { MODRM_SPLITRM, 15199 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15203 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15205 },
    { MODRM_SPLITRM, 15207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15209 },
    { MODRM_SPLITRM, 15211 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15213 },
    { MODRM_SPLITRM, 15215 },
    { MODRM_SPLITRM, 15217 },
    { MODRM_SPLITRM, 15219 },
    { MODRM_SPLITRM, 15221 },
    { MODRM_SPLITRM, 15223 },
    { MODRM_SPLITRM, 15225 },
    { MODRM_SPLITRM, 15227 },
    { MODRM_SPLITRM, 15229 },
    { MODRM_SPLITRM, 15231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15233 },
    { MODRM_SPLITRM, 15235 },
    { MODRM_SPLITRM, 15237 },
    { MODRM_SPLITRM, 15239 },
    { MODRM_SPLITRM, 15241 },
    { MODRM_SPLITRM, 15243 },
    { MODRM_SPLITRM, 15245 },
    { MODRM_SPLITRM, 15247 },
    { MODRM_SPLITRM, 15249 },
    { MODRM_SPLITRM, 15251 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15253 },
    { MODRM_SPLITRM, 15255 },
    { MODRM_SPLITRM, 15257 },
    { MODRM_SPLITRM, 15259 },
    { MODRM_SPLITRM, 15261 },
    { MODRM_SPLITRM, 15263 },
    { MODRM_SPLITRM, 15265 },
    { MODRM_SPLITRM, 15267 },
    { MODRM_SPLITRM, 15269 },
    { MODRM_SPLITRM, 15271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15275 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15277 },
    { MODRM_SPLITRM, 15279 },
    { MODRM_SPLITRM, 15281 },
    { MODRM_SPLITRM, 15283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15287 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15289 },
    { MODRM_SPLITRM, 15291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15293 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15295 },
    { MODRM_SPLITRM, 15297 },
    { MODRM_SPLITRM, 15299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15301 },
    { MODRM_SPLITRM, 15303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15307 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15311 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15313 },
    { MODRM_SPLITRM, 15315 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15317 },
    { MODRM_SPLITRM, 15319 },
    { MODRM_SPLITRM, 15321 },
    { MODRM_SPLITRM, 15323 },
    { MODRM_SPLITRM, 15325 },
    { MODRM_SPLITRM, 15327 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15329 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15331 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15335 },
    { MODRM_SPLITRM, 15337 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15339 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15341 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15343 },
    { MODRM_SPLITRM, 15345 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15347 },
    { MODRM_SPLITRM, 15349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15353 },
    { MODRM_SPLITRM, 15355 },
    { MODRM_SPLITRM, 15357 },
    { MODRM_SPLITRM, 15359 },
    { MODRM_SPLITRM, 15361 },
    { MODRM_SPLITRM, 15363 },
    { MODRM_SPLITRM, 15365 },
    { MODRM_SPLITRM, 15367 },
    { MODRM_SPLITRM, 15369 },
    { MODRM_SPLITRM, 15371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15373 },
    { MODRM_SPLITRM, 15375 },
    { MODRM_SPLITRM, 15377 },
    { MODRM_SPLITRM, 15379 },
    { MODRM_SPLITRM, 15381 },
    { MODRM_SPLITRM, 15383 },
    { MODRM_SPLITRM, 15385 },
    { MODRM_SPLITRM, 15387 },
    { MODRM_SPLITRM, 15389 },
    { MODRM_SPLITRM, 15391 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15393 },
    { MODRM_SPLITRM, 15395 },
    { MODRM_SPLITRM, 15397 },
    { MODRM_SPLITRM, 15399 },
    { MODRM_SPLITRM, 15401 },
    { MODRM_SPLITRM, 15403 },
    { MODRM_SPLITRM, 15405 },
    { MODRM_SPLITRM, 15407 },
    { MODRM_SPLITRM, 15409 },
    { MODRM_SPLITRM, 15411 },
    { MODRM_SPLITRM, 15413 },
    { MODRM_SPLITRM, 15415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15419 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15421 },
    { MODRM_SPLITRM, 15423 },
    { MODRM_SPLITRM, 15425 },
    { MODRM_SPLITRM, 15427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15431 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15145 },
    { MODRM_SPLITRM, 15433 },
    { MODRM_SPLITRM, 15435 },
    { MODRM_SPLITRM, 15437 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15439 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15441 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15443 },
    { MODRM_SPLITRM, 15445 },
    { MODRM_SPLITRM, 15159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15447 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15449 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15451 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15453 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15455 },
    { MODRM_SPLITRM, 15457 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15459 },
    { MODRM_SPLITRM, 15173 },
    { MODRM_SPLITRM, 15461 },
    { MODRM_SPLITRM, 15463 },
    { MODRM_SPLITRM, 15465 },
    { MODRM_SPLITRM, 15467 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15469 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15471 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15473 },
    { MODRM_SPLITRM, 15475 },
    { MODRM_SPLITRM, 15477 },
    { MODRM_SPLITRM, 15479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15481 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15483 },
    { MODRM_SPLITRM, 15485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15487 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15489 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15491 },
    { MODRM_SPLITRM, 15493 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15495 },
    { MODRM_SPLITRM, 15497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15499 },
    { MODRM_SPLITRM, 15501 },
    { MODRM_SPLITRM, 15503 },
    { MODRM_SPLITRM, 15219 },
    { MODRM_SPLITRM, 15505 },
    { MODRM_SPLITRM, 15223 },
    { MODRM_SPLITRM, 15507 },
    { MODRM_SPLITRM, 15227 },
    { MODRM_SPLITRM, 15509 },
    { MODRM_SPLITRM, 15231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15511 },
    { MODRM_SPLITRM, 15513 },
    { MODRM_SPLITRM, 15515 },
    { MODRM_SPLITRM, 15239 },
    { MODRM_SPLITRM, 15517 },
    { MODRM_SPLITRM, 15243 },
    { MODRM_SPLITRM, 15519 },
    { MODRM_SPLITRM, 15247 },
    { MODRM_SPLITRM, 15521 },
    { MODRM_SPLITRM, 15251 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15523 },
    { MODRM_SPLITRM, 15525 },
    { MODRM_SPLITRM, 15527 },
    { MODRM_SPLITRM, 15259 },
    { MODRM_SPLITRM, 15529 },
    { MODRM_SPLITRM, 15263 },
    { MODRM_SPLITRM, 15531 },
    { MODRM_SPLITRM, 15267 },
    { MODRM_SPLITRM, 15533 },
    { MODRM_SPLITRM, 15271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15275 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15277 },
    { MODRM_SPLITRM, 15279 },
    { MODRM_SPLITRM, 15281 },
    { MODRM_SPLITRM, 15283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15537 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15541 },
    { MODRM_SPLITRM, 15543 },
    { MODRM_SPLITRM, 15545 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15549 },
    { MODRM_SPLITRM, 15551 },
    { MODRM_SPLITRM, 15553 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15555 },
    { MODRM_SPLITRM, 15303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15557 },
    { MODRM_SPLITRM, 15559 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15561 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15563 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15565 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15567 },
    { MODRM_SPLITRM, 15569 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15571 },
    { MODRM_SPLITRM, 15319 },
    { MODRM_SPLITRM, 15573 },
    { MODRM_SPLITRM, 15575 },
    { MODRM_SPLITRM, 15577 },
    { MODRM_SPLITRM, 15579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15581 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15583 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15587 },
    { MODRM_SPLITRM, 15589 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15591 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15593 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15595 },
    { MODRM_SPLITRM, 15597 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15599 },
    { MODRM_SPLITRM, 15601 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15603 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15605 },
    { MODRM_SPLITRM, 15607 },
    { MODRM_SPLITRM, 15609 },
    { MODRM_SPLITRM, 15359 },
    { MODRM_SPLITRM, 15611 },
    { MODRM_SPLITRM, 15363 },
    { MODRM_SPLITRM, 15613 },
    { MODRM_SPLITRM, 15367 },
    { MODRM_SPLITRM, 15615 },
    { MODRM_SPLITRM, 15371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15617 },
    { MODRM_SPLITRM, 15619 },
    { MODRM_SPLITRM, 15621 },
    { MODRM_SPLITRM, 15379 },
    { MODRM_SPLITRM, 15623 },
    { MODRM_SPLITRM, 15383 },
    { MODRM_SPLITRM, 15625 },
    { MODRM_SPLITRM, 15387 },
    { MODRM_SPLITRM, 15627 },
    { MODRM_SPLITRM, 15391 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15629 },
    { MODRM_SPLITRM, 15631 },
    { MODRM_SPLITRM, 15633 },
    { MODRM_SPLITRM, 15635 },
    { MODRM_SPLITRM, 15637 },
    { MODRM_SPLITRM, 15403 },
    { MODRM_SPLITRM, 15639 },
    { MODRM_SPLITRM, 15407 },
    { MODRM_SPLITRM, 15641 },
    { MODRM_SPLITRM, 15411 },
    { MODRM_SPLITRM, 15643 },
    { MODRM_SPLITRM, 15415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15645 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15419 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15421 },
    { MODRM_SPLITRM, 15423 },
    { MODRM_SPLITRM, 15425 },
    { MODRM_SPLITRM, 15427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15647 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15145 },
    { MODRM_SPLITRM, 15651 },
    { MODRM_SPLITRM, 15653 },
    { MODRM_SPLITRM, 15655 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15657 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15659 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15661 },
    { MODRM_SPLITRM, 15663 },
    { MODRM_SPLITRM, 15159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15665 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15667 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15669 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15671 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15673 },
    { MODRM_SPLITRM, 15675 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15677 },
    { MODRM_SPLITRM, 15173 },
    { MODRM_SPLITRM, 15679 },
    { MODRM_SPLITRM, 15681 },
    { MODRM_SPLITRM, 15683 },
    { MODRM_SPLITRM, 15685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15687 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15689 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15691 },
    { MODRM_SPLITRM, 15693 },
    { MODRM_SPLITRM, 15695 },
    { MODRM_SPLITRM, 15697 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15699 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15701 },
    { MODRM_SPLITRM, 15703 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15705 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15707 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15709 },
    { MODRM_SPLITRM, 15711 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15713 },
    { MODRM_SPLITRM, 15715 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15717 },
    { MODRM_SPLITRM, 15719 },
    { MODRM_SPLITRM, 15721 },
    { MODRM_SPLITRM, 15219 },
    { MODRM_SPLITRM, 15723 },
    { MODRM_SPLITRM, 15223 },
    { MODRM_SPLITRM, 15725 },
    { MODRM_SPLITRM, 15227 },
    { MODRM_SPLITRM, 15727 },
    { MODRM_SPLITRM, 15231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15729 },
    { MODRM_SPLITRM, 15731 },
    { MODRM_SPLITRM, 15733 },
    { MODRM_SPLITRM, 15239 },
    { MODRM_SPLITRM, 15735 },
    { MODRM_SPLITRM, 15243 },
    { MODRM_SPLITRM, 15737 },
    { MODRM_SPLITRM, 15247 },
    { MODRM_SPLITRM, 15739 },
    { MODRM_SPLITRM, 15251 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15741 },
    { MODRM_SPLITRM, 15743 },
    { MODRM_SPLITRM, 15745 },
    { MODRM_SPLITRM, 15259 },
    { MODRM_SPLITRM, 15747 },
    { MODRM_SPLITRM, 15263 },
    { MODRM_SPLITRM, 15749 },
    { MODRM_SPLITRM, 15267 },
    { MODRM_SPLITRM, 15751 },
    { MODRM_SPLITRM, 15271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15753 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15755 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15757 },
    { MODRM_SPLITRM, 15279 },
    { MODRM_SPLITRM, 15759 },
    { MODRM_SPLITRM, 15283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15761 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15763 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15765 },
    { MODRM_SPLITRM, 15767 },
    { MODRM_SPLITRM, 15769 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15771 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15773 },
    { MODRM_SPLITRM, 15775 },
    { MODRM_SPLITRM, 15777 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15779 },
    { MODRM_SPLITRM, 15303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15781 },
    { MODRM_SPLITRM, 15783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15789 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15791 },
    { MODRM_SPLITRM, 15793 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15795 },
    { MODRM_SPLITRM, 15319 },
    { MODRM_SPLITRM, 15797 },
    { MODRM_SPLITRM, 15799 },
    { MODRM_SPLITRM, 15801 },
    { MODRM_SPLITRM, 15803 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15805 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15811 },
    { MODRM_SPLITRM, 15813 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15819 },
    { MODRM_SPLITRM, 15821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15823 },
    { MODRM_SPLITRM, 15825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15829 },
    { MODRM_SPLITRM, 15831 },
    { MODRM_SPLITRM, 15833 },
    { MODRM_SPLITRM, 15359 },
    { MODRM_SPLITRM, 15835 },
    { MODRM_SPLITRM, 15363 },
    { MODRM_SPLITRM, 15837 },
    { MODRM_SPLITRM, 15367 },
    { MODRM_SPLITRM, 15839 },
    { MODRM_SPLITRM, 15371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15841 },
    { MODRM_SPLITRM, 15843 },
    { MODRM_SPLITRM, 15845 },
    { MODRM_SPLITRM, 15379 },
    { MODRM_SPLITRM, 15847 },
    { MODRM_SPLITRM, 15383 },
    { MODRM_SPLITRM, 15849 },
    { MODRM_SPLITRM, 15387 },
    { MODRM_SPLITRM, 15851 },
    { MODRM_SPLITRM, 15391 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15853 },
    { MODRM_SPLITRM, 15855 },
    { MODRM_SPLITRM, 15857 },
    { MODRM_SPLITRM, 15859 },
    { MODRM_SPLITRM, 15861 },
    { MODRM_SPLITRM, 15403 },
    { MODRM_SPLITRM, 15863 },
    { MODRM_SPLITRM, 15407 },
    { MODRM_SPLITRM, 15865 },
    { MODRM_SPLITRM, 15411 },
    { MODRM_SPLITRM, 15867 },
    { MODRM_SPLITRM, 15415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15869 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15873 },
    { MODRM_SPLITRM, 15423 },
    { MODRM_SPLITRM, 15875 },
    { MODRM_SPLITRM, 15427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15877 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15879 },
    { MODRM_SPLITRM, 15881 },
    { MODRM_SPLITRM, 15883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15887 },
    { MODRM_SPLITRM, 15889 },
    { MODRM_SPLITRM, 15891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15893 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15899 },
    { MODRM_SPLITRM, 15901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15903 },
    { MODRM_SPLITRM, 15905 },
    { MODRM_SPLITRM, 15907 },
    { MODRM_SPLITRM, 15909 },
    { MODRM_SPLITRM, 15911 },
    { MODRM_SPLITRM, 15913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15917 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15919 },
    { MODRM_SPLITRM, 15921 },
    { MODRM_SPLITRM, 15923 },
    { MODRM_SPLITRM, 15925 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15927 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15929 },
    { MODRM_SPLITRM, 15931 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15937 },
    { MODRM_SPLITRM, 15939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15941 },
    { MODRM_SPLITRM, 15943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15945 },
    { MODRM_SPLITRM, 15947 },
    { MODRM_SPLITRM, 15949 },
    { MODRM_SPLITRM, 15951 },
    { MODRM_SPLITRM, 15953 },
    { MODRM_SPLITRM, 15955 },
    { MODRM_SPLITRM, 15957 },
    { MODRM_SPLITRM, 15959 },
    { MODRM_SPLITRM, 15961 },
    { MODRM_SPLITRM, 15963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15965 },
    { MODRM_SPLITRM, 15967 },
    { MODRM_SPLITRM, 15969 },
    { MODRM_SPLITRM, 15971 },
    { MODRM_SPLITRM, 15973 },
    { MODRM_SPLITRM, 15975 },
    { MODRM_SPLITRM, 15977 },
    { MODRM_SPLITRM, 15979 },
    { MODRM_SPLITRM, 15981 },
    { MODRM_SPLITRM, 15983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15985 },
    { MODRM_SPLITRM, 15987 },
    { MODRM_SPLITRM, 15989 },
    { MODRM_SPLITRM, 15991 },
    { MODRM_SPLITRM, 15993 },
    { MODRM_SPLITRM, 15995 },
    { MODRM_SPLITRM, 15997 },
    { MODRM_SPLITRM, 15999 },
    { MODRM_SPLITRM, 16001 },
    { MODRM_SPLITRM, 16003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16007 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16009 },
    { MODRM_SPLITRM, 16011 },
    { MODRM_SPLITRM, 16013 },
    { MODRM_SPLITRM, 16015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16019 },
    { MODRM_SPLITRM, 16021 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16023 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16027 },
    { MODRM_SPLITRM, 16029 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16031 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16033 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16035 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16037 },
    { MODRM_SPLITRM, 16039 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16041 },
    { MODRM_SPLITRM, 16043 },
    { MODRM_SPLITRM, 16045 },
    { MODRM_SPLITRM, 16047 },
    { MODRM_SPLITRM, 16049 },
    { MODRM_SPLITRM, 16051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16055 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16059 },
    { MODRM_SPLITRM, 16061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16063 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16065 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16067 },
    { MODRM_SPLITRM, 16069 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16071 },
    { MODRM_SPLITRM, 16073 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16075 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16077 },
    { MODRM_SPLITRM, 16079 },
    { MODRM_SPLITRM, 16081 },
    { MODRM_SPLITRM, 16083 },
    { MODRM_SPLITRM, 16085 },
    { MODRM_SPLITRM, 16087 },
    { MODRM_SPLITRM, 16089 },
    { MODRM_SPLITRM, 16091 },
    { MODRM_SPLITRM, 16093 },
    { MODRM_SPLITRM, 16095 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16097 },
    { MODRM_SPLITRM, 16099 },
    { MODRM_SPLITRM, 16101 },
    { MODRM_SPLITRM, 16103 },
    { MODRM_SPLITRM, 16105 },
    { MODRM_SPLITRM, 16107 },
    { MODRM_SPLITRM, 16109 },
    { MODRM_SPLITRM, 16111 },
    { MODRM_SPLITRM, 16113 },
    { MODRM_SPLITRM, 16115 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16117 },
    { MODRM_SPLITRM, 16119 },
    { MODRM_SPLITRM, 16121 },
    { MODRM_SPLITRM, 16123 },
    { MODRM_SPLITRM, 16125 },
    { MODRM_SPLITRM, 16127 },
    { MODRM_SPLITRM, 16129 },
    { MODRM_SPLITRM, 16131 },
    { MODRM_SPLITRM, 16133 },
    { MODRM_SPLITRM, 16135 },
    { MODRM_SPLITRM, 16137 },
    { MODRM_SPLITRM, 16139 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16145 },
    { MODRM_SPLITRM, 16147 },
    { MODRM_SPLITRM, 16149 },
    { MODRM_SPLITRM, 16151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16153 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15879 },
    { MODRM_SPLITRM, 16155 },
    { MODRM_SPLITRM, 16157 },
    { MODRM_SPLITRM, 16159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16161 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16163 },
    { MODRM_SPLITRM, 16165 },
    { MODRM_SPLITRM, 15891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16167 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16169 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16171 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16173 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16175 },
    { MODRM_SPLITRM, 16177 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16179 },
    { MODRM_SPLITRM, 15905 },
    { MODRM_SPLITRM, 16181 },
    { MODRM_SPLITRM, 16183 },
    { MODRM_SPLITRM, 16185 },
    { MODRM_SPLITRM, 16187 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16191 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16193 },
    { MODRM_SPLITRM, 16195 },
    { MODRM_SPLITRM, 16197 },
    { MODRM_SPLITRM, 16199 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16201 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16203 },
    { MODRM_SPLITRM, 16205 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16209 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16211 },
    { MODRM_SPLITRM, 16213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16215 },
    { MODRM_SPLITRM, 16217 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16219 },
    { MODRM_SPLITRM, 16221 },
    { MODRM_SPLITRM, 16223 },
    { MODRM_SPLITRM, 15951 },
    { MODRM_SPLITRM, 16225 },
    { MODRM_SPLITRM, 15955 },
    { MODRM_SPLITRM, 16227 },
    { MODRM_SPLITRM, 15959 },
    { MODRM_SPLITRM, 16229 },
    { MODRM_SPLITRM, 15963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16231 },
    { MODRM_SPLITRM, 16233 },
    { MODRM_SPLITRM, 16235 },
    { MODRM_SPLITRM, 15971 },
    { MODRM_SPLITRM, 16237 },
    { MODRM_SPLITRM, 15975 },
    { MODRM_SPLITRM, 16239 },
    { MODRM_SPLITRM, 15979 },
    { MODRM_SPLITRM, 16241 },
    { MODRM_SPLITRM, 15983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16243 },
    { MODRM_SPLITRM, 16245 },
    { MODRM_SPLITRM, 16247 },
    { MODRM_SPLITRM, 15991 },
    { MODRM_SPLITRM, 16249 },
    { MODRM_SPLITRM, 15995 },
    { MODRM_SPLITRM, 16251 },
    { MODRM_SPLITRM, 15999 },
    { MODRM_SPLITRM, 16253 },
    { MODRM_SPLITRM, 16003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16007 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16009 },
    { MODRM_SPLITRM, 16011 },
    { MODRM_SPLITRM, 16013 },
    { MODRM_SPLITRM, 16015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16259 },
    { MODRM_SPLITRM, 16261 },
    { MODRM_SPLITRM, 16263 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16265 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16267 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16269 },
    { MODRM_SPLITRM, 16029 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16275 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16277 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16279 },
    { MODRM_SPLITRM, 16281 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16283 },
    { MODRM_SPLITRM, 16043 },
    { MODRM_SPLITRM, 16285 },
    { MODRM_SPLITRM, 16287 },
    { MODRM_SPLITRM, 16289 },
    { MODRM_SPLITRM, 16291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16293 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16295 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16297 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16299 },
    { MODRM_SPLITRM, 16301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16307 },
    { MODRM_SPLITRM, 16309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16311 },
    { MODRM_SPLITRM, 16313 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16315 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16317 },
    { MODRM_SPLITRM, 16319 },
    { MODRM_SPLITRM, 16321 },
    { MODRM_SPLITRM, 16083 },
    { MODRM_SPLITRM, 16323 },
    { MODRM_SPLITRM, 16087 },
    { MODRM_SPLITRM, 16325 },
    { MODRM_SPLITRM, 16091 },
    { MODRM_SPLITRM, 16327 },
    { MODRM_SPLITRM, 16095 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16329 },
    { MODRM_SPLITRM, 16331 },
    { MODRM_SPLITRM, 16333 },
    { MODRM_SPLITRM, 16103 },
    { MODRM_SPLITRM, 16335 },
    { MODRM_SPLITRM, 16107 },
    { MODRM_SPLITRM, 16337 },
    { MODRM_SPLITRM, 16111 },
    { MODRM_SPLITRM, 16339 },
    { MODRM_SPLITRM, 16115 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16341 },
    { MODRM_SPLITRM, 16343 },
    { MODRM_SPLITRM, 16345 },
    { MODRM_SPLITRM, 16347 },
    { MODRM_SPLITRM, 16349 },
    { MODRM_SPLITRM, 16127 },
    { MODRM_SPLITRM, 16351 },
    { MODRM_SPLITRM, 16131 },
    { MODRM_SPLITRM, 16353 },
    { MODRM_SPLITRM, 16135 },
    { MODRM_SPLITRM, 16355 },
    { MODRM_SPLITRM, 16139 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16357 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16145 },
    { MODRM_SPLITRM, 16147 },
    { MODRM_SPLITRM, 16149 },
    { MODRM_SPLITRM, 16151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16359 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 15879 },
    { MODRM_SPLITRM, 16361 },
    { MODRM_SPLITRM, 16363 },
    { MODRM_SPLITRM, 16365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16367 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16369 },
    { MODRM_SPLITRM, 16371 },
    { MODRM_SPLITRM, 15891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16373 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16375 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16377 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16379 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16381 },
    { MODRM_SPLITRM, 16383 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16385 },
    { MODRM_SPLITRM, 15905 },
    { MODRM_SPLITRM, 16387 },
    { MODRM_SPLITRM, 16389 },
    { MODRM_SPLITRM, 16391 },
    { MODRM_SPLITRM, 16393 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16395 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16397 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16399 },
    { MODRM_SPLITRM, 16401 },
    { MODRM_SPLITRM, 16403 },
    { MODRM_SPLITRM, 16405 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16409 },
    { MODRM_SPLITRM, 16411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16413 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16417 },
    { MODRM_SPLITRM, 16419 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16421 },
    { MODRM_SPLITRM, 16423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16425 },
    { MODRM_SPLITRM, 16427 },
    { MODRM_SPLITRM, 16429 },
    { MODRM_SPLITRM, 15951 },
    { MODRM_SPLITRM, 16431 },
    { MODRM_SPLITRM, 15955 },
    { MODRM_SPLITRM, 16433 },
    { MODRM_SPLITRM, 15959 },
    { MODRM_SPLITRM, 16435 },
    { MODRM_SPLITRM, 15963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16437 },
    { MODRM_SPLITRM, 16439 },
    { MODRM_SPLITRM, 16441 },
    { MODRM_SPLITRM, 15971 },
    { MODRM_SPLITRM, 16443 },
    { MODRM_SPLITRM, 15975 },
    { MODRM_SPLITRM, 16445 },
    { MODRM_SPLITRM, 15979 },
    { MODRM_SPLITRM, 16447 },
    { MODRM_SPLITRM, 15983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16449 },
    { MODRM_SPLITRM, 16451 },
    { MODRM_SPLITRM, 16453 },
    { MODRM_SPLITRM, 15991 },
    { MODRM_SPLITRM, 16455 },
    { MODRM_SPLITRM, 15995 },
    { MODRM_SPLITRM, 16457 },
    { MODRM_SPLITRM, 15999 },
    { MODRM_SPLITRM, 16459 },
    { MODRM_SPLITRM, 16003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16461 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16463 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16465 },
    { MODRM_SPLITRM, 16011 },
    { MODRM_SPLITRM, 16467 },
    { MODRM_SPLITRM, 16015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16469 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16471 },
    { MODRM_SPLITRM, 16473 },
    { MODRM_SPLITRM, 16475 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16477 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16481 },
    { MODRM_SPLITRM, 16029 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16483 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16487 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16489 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16491 },
    { MODRM_SPLITRM, 16493 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16495 },
    { MODRM_SPLITRM, 16043 },
    { MODRM_SPLITRM, 16497 },
    { MODRM_SPLITRM, 16499 },
    { MODRM_SPLITRM, 16501 },
    { MODRM_SPLITRM, 16503 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16505 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16507 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16511 },
    { MODRM_SPLITRM, 16513 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16517 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16519 },
    { MODRM_SPLITRM, 16521 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16523 },
    { MODRM_SPLITRM, 16525 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16529 },
    { MODRM_SPLITRM, 16531 },
    { MODRM_SPLITRM, 16533 },
    { MODRM_SPLITRM, 16083 },
    { MODRM_SPLITRM, 16535 },
    { MODRM_SPLITRM, 16087 },
    { MODRM_SPLITRM, 16537 },
    { MODRM_SPLITRM, 16091 },
    { MODRM_SPLITRM, 16539 },
    { MODRM_SPLITRM, 16095 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16541 },
    { MODRM_SPLITRM, 16543 },
    { MODRM_SPLITRM, 16545 },
    { MODRM_SPLITRM, 16103 },
    { MODRM_SPLITRM, 16547 },
    { MODRM_SPLITRM, 16107 },
    { MODRM_SPLITRM, 16549 },
    { MODRM_SPLITRM, 16111 },
    { MODRM_SPLITRM, 16551 },
    { MODRM_SPLITRM, 16115 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16553 },
    { MODRM_SPLITRM, 16555 },
    { MODRM_SPLITRM, 16557 },
    { MODRM_SPLITRM, 16559 },
    { MODRM_SPLITRM, 16561 },
    { MODRM_SPLITRM, 16127 },
    { MODRM_SPLITRM, 16563 },
    { MODRM_SPLITRM, 16131 },
    { MODRM_SPLITRM, 16565 },
    { MODRM_SPLITRM, 16135 },
    { MODRM_SPLITRM, 16567 },
    { MODRM_SPLITRM, 16139 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16569 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16571 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16573 },
    { MODRM_SPLITRM, 16147 },
    { MODRM_SPLITRM, 16575 },
    { MODRM_SPLITRM, 16151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16577 },
    { MODRM_SPLITRM, 16579 },
    { MODRM_SPLITRM, 16581 },
    { MODRM_SPLITRM, 16583 },
    { MODRM_SPLITRM, 16585 },
    { MODRM_SPLITRM, 16587 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16589 },
    { MODRM_SPLITRM, 16591 },
    { MODRM_SPLITRM, 16593 },
    { MODRM_SPLITRM, 16595 },
    { MODRM_SPLITRM, 16597 },
    { MODRM_SPLITRM, 16599 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16601 },
    { MODRM_SPLITRM, 16603 },
    { MODRM_SPLITRM, 16605 },
    { MODRM_SPLITRM, 16607 },
    { MODRM_SPLITRM, 16609 },
    { MODRM_SPLITRM, 16611 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16613 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16615 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 16617 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16621 },
    { MODRM_SPLITRM, 16623 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16625 },
    { MODRM_SPLITRM, 16627 },
    { MODRM_SPLITRM, 16629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16631 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16633 },
    { MODRM_SPLITRM, 16635 },
    { MODRM_SPLITRM, 16637 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16639 },
    { MODRM_SPLITRM, 16641 },
    { MODRM_SPLITRM, 16643 },
    { MODRM_SPLITRM, 16645 },
    { MODRM_SPLITRM, 16647 },
    { MODRM_SPLITRM, 16649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16651 },
    { MODRM_SPLITRM, 16653 },
    { MODRM_SPLITRM, 16655 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16657 },
    { MODRM_SPLITRM, 16659 },
    { MODRM_SPLITRM, 16661 },
    { MODRM_SPLITRM, 16663 },
    { MODRM_SPLITRM, 16665 },
    { MODRM_SPLITRM, 16667 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16669 },
    { MODRM_SPLITRM, 16671 },
    { MODRM_SPLITRM, 16673 },
    { MODRM_SPLITRM, 16675 },
    { MODRM_SPLITRM, 16677 },
    { MODRM_SPLITRM, 16679 },
    { MODRM_SPLITRM, 16681 },
    { MODRM_SPLITRM, 16683 },
    { MODRM_SPLITRM, 16685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16687 },
    { MODRM_SPLITRM, 16689 },
    { MODRM_SPLITRM, 16691 },
    { MODRM_SPLITRM, 16693 },
    { MODRM_SPLITRM, 16695 },
    { MODRM_SPLITRM, 16697 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16699 },
    { MODRM_SPLITRM, 16701 },
    { MODRM_SPLITRM, 16703 },
    { MODRM_SPLITRM, 16705 },
    { MODRM_SPLITRM, 16707 },
    { MODRM_SPLITRM, 16709 },
    { MODRM_SPLITRM, 16711 },
    { MODRM_SPLITRM, 16713 },
    { MODRM_SPLITRM, 16715 },
    { MODRM_SPLITRM, 16717 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16719 },
    { MODRM_SPLITRM, 16721 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16723 },
    { MODRM_SPLITRM, 16725 },
    { MODRM_SPLITRM, 16727 },
    { MODRM_SPLITRM, 16729 },
    { MODRM_SPLITRM, 16731 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16733 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16735 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16737 },
    { MODRM_SPLITRM, 16739 },
    { MODRM_SPLITRM, 16741 },
    { MODRM_SPLITRM, 16743 },
    { MODRM_SPLITRM, 16745 },
    { MODRM_SPLITRM, 16747 },
    { MODRM_SPLITRM, 16749 },
    { MODRM_SPLITRM, 16751 },
    { MODRM_SPLITRM, 16753 },
    { MODRM_SPLITRM, 16755 },
    { MODRM_SPLITRM, 16757 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16759 },
    { MODRM_SPLITRM, 16761 },
    { MODRM_SPLITRM, 16763 },
    { MODRM_SPLITRM, 16765 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16767 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16769 },
    { MODRM_SPLITRM, 16771 },
    { MODRM_SPLITRM, 16773 },
    { MODRM_SPLITRM, 16775 },
    { MODRM_SPLITRM, 16777 },
    { MODRM_SPLITRM, 16779 },
    { MODRM_SPLITRM, 16781 },
    { MODRM_SPLITRM, 16783 },
    { MODRM_SPLITRM, 16785 },
    { MODRM_SPLITRM, 16787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16789 },
    { MODRM_SPLITRM, 16791 },
    { MODRM_SPLITRM, 16793 },
    { MODRM_SPLITRM, 16795 },
    { MODRM_SPLITRM, 16797 },
    { MODRM_SPLITRM, 16799 },
    { MODRM_SPLITRM, 16801 },
    { MODRM_SPLITRM, 16803 },
    { MODRM_SPLITRM, 16805 },
    { MODRM_SPLITRM, 16807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16809 },
    { MODRM_SPLITRM, 16811 },
    { MODRM_SPLITRM, 16813 },
    { MODRM_SPLITRM, 16815 },
    { MODRM_SPLITRM, 16817 },
    { MODRM_SPLITRM, 16819 },
    { MODRM_SPLITRM, 16821 },
    { MODRM_SPLITRM, 16823 },
    { MODRM_SPLITRM, 16825 },
    { MODRM_SPLITRM, 16827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16829 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16835 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 16617 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16837 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16839 },
    { MODRM_SPLITRM, 16841 },
    { MODRM_SPLITRM, 16843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16845 },
    { MODRM_SPLITRM, 16847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16633 },
    { MODRM_SPLITRM, 16635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16849 },
    { MODRM_SPLITRM, 16639 },
    { MODRM_SPLITRM, 16641 },
    { MODRM_SPLITRM, 16643 },
    { MODRM_SPLITRM, 16645 },
    { MODRM_SPLITRM, 16647 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16851 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16853 },
    { MODRM_SPLITRM, 16855 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16657 },
    { MODRM_SPLITRM, 16659 },
    { MODRM_SPLITRM, 16661 },
    { MODRM_SPLITRM, 16663 },
    { MODRM_SPLITRM, 16665 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16669 },
    { MODRM_SPLITRM, 16857 },
    { MODRM_SPLITRM, 16673 },
    { MODRM_SPLITRM, 16859 },
    { MODRM_SPLITRM, 16677 },
    { MODRM_SPLITRM, 16861 },
    { MODRM_SPLITRM, 16681 },
    { MODRM_SPLITRM, 16863 },
    { MODRM_SPLITRM, 16865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16867 },
    { MODRM_SPLITRM, 16869 },
    { MODRM_SPLITRM, 16871 },
    { MODRM_SPLITRM, 16873 },
    { MODRM_SPLITRM, 16875 },
    { MODRM_SPLITRM, 16877 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16879 },
    { MODRM_SPLITRM, 16881 },
    { MODRM_SPLITRM, 16883 },
    { MODRM_SPLITRM, 16885 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16887 },
    { MODRM_SPLITRM, 16889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16893 },
    { MODRM_SPLITRM, 16895 },
    { MODRM_SPLITRM, 16897 },
    { MODRM_SPLITRM, 16899 },
    { MODRM_SPLITRM, 16901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16903 },
    { MODRM_SPLITRM, 16905 },
    { MODRM_SPLITRM, 16907 },
    { MODRM_SPLITRM, 16909 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16911 },
    { MODRM_SPLITRM, 16913 },
    { MODRM_SPLITRM, 16915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16917 },
    { MODRM_SPLITRM, 16919 },
    { MODRM_SPLITRM, 16921 },
    { MODRM_SPLITRM, 16923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16925 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16927 },
    { MODRM_SPLITRM, 16929 },
    { MODRM_SPLITRM, 16931 },
    { MODRM_SPLITRM, 16933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16935 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16937 },
    { MODRM_SPLITRM, 16939 },
    { MODRM_SPLITRM, 16941 },
    { MODRM_SPLITRM, 16943 },
    { MODRM_SPLITRM, 16945 },
    { MODRM_SPLITRM, 16947 },
    { MODRM_SPLITRM, 16949 },
    { MODRM_SPLITRM, 16951 },
    { MODRM_SPLITRM, 16953 },
    { MODRM_SPLITRM, 16955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16957 },
    { MODRM_SPLITRM, 16959 },
    { MODRM_SPLITRM, 16961 },
    { MODRM_SPLITRM, 16963 },
    { MODRM_SPLITRM, 16965 },
    { MODRM_SPLITRM, 16967 },
    { MODRM_SPLITRM, 16969 },
    { MODRM_SPLITRM, 16971 },
    { MODRM_SPLITRM, 16973 },
    { MODRM_SPLITRM, 16975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 16977 },
    { MODRM_SPLITRM, 16979 },
    { MODRM_SPLITRM, 16981 },
    { MODRM_SPLITRM, 16983 },
    { MODRM_SPLITRM, 16985 },
    { MODRM_SPLITRM, 16987 },
    { MODRM_SPLITRM, 16989 },
    { MODRM_SPLITRM, 16991 },
    { MODRM_SPLITRM, 16993 },
    { MODRM_SPLITRM, 16995 },
    { MODRM_SPLITRM, 16997 },
    { MODRM_SPLITRM, 16999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17003 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17007 },
    { MODRM_SPLITRM, 17009 },
    { MODRM_SPLITRM, 17011 },
    { MODRM_SPLITRM, 17013 },
    { MODRM_SPLITRM, 17015 },
    { MODRM_SPLITRM, 17017 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17019 },
    { MODRM_SPLITRM, 17021 },
    { MODRM_SPLITRM, 17023 },
    { MODRM_SPLITRM, 17025 },
    { MODRM_SPLITRM, 17027 },
    { MODRM_SPLITRM, 17029 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17031 },
    { MODRM_SPLITRM, 17033 },
    { MODRM_SPLITRM, 17035 },
    { MODRM_SPLITRM, 17037 },
    { MODRM_SPLITRM, 17039 },
    { MODRM_SPLITRM, 17041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 17043 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17045 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17047 },
    { MODRM_SPLITRM, 17049 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17051 },
    { MODRM_SPLITRM, 17053 },
    { MODRM_SPLITRM, 17055 },
    { MODRM_SPLITRM, 17057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17059 },
    { MODRM_SPLITRM, 17061 },
    { MODRM_SPLITRM, 17063 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17065 },
    { MODRM_SPLITRM, 17067 },
    { MODRM_SPLITRM, 17069 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17071 },
    { MODRM_SPLITRM, 17073 },
    { MODRM_SPLITRM, 17075 },
    { MODRM_SPLITRM, 17077 },
    { MODRM_SPLITRM, 17079 },
    { MODRM_SPLITRM, 17081 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17083 },
    { MODRM_SPLITRM, 17085 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17087 },
    { MODRM_SPLITRM, 17089 },
    { MODRM_SPLITRM, 17091 },
    { MODRM_SPLITRM, 17093 },
    { MODRM_SPLITRM, 17095 },
    { MODRM_SPLITRM, 17097 },
    { MODRM_SPLITRM, 17099 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17101 },
    { MODRM_SPLITRM, 17103 },
    { MODRM_SPLITRM, 17105 },
    { MODRM_SPLITRM, 17107 },
    { MODRM_SPLITRM, 17109 },
    { MODRM_SPLITRM, 17111 },
    { MODRM_SPLITRM, 17113 },
    { MODRM_SPLITRM, 17115 },
    { MODRM_SPLITRM, 17117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17119 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17121 },
    { MODRM_SPLITRM, 17123 },
    { MODRM_SPLITRM, 17125 },
    { MODRM_SPLITRM, 17127 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17129 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17131 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17133 },
    { MODRM_SPLITRM, 17135 },
    { MODRM_SPLITRM, 17137 },
    { MODRM_SPLITRM, 17139 },
    { MODRM_SPLITRM, 17141 },
    { MODRM_SPLITRM, 17143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17145 },
    { MODRM_SPLITRM, 17147 },
    { MODRM_SPLITRM, 17149 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17151 },
    { MODRM_SPLITRM, 17153 },
    { MODRM_SPLITRM, 17155 },
    { MODRM_SPLITRM, 17157 },
    { MODRM_SPLITRM, 17159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17161 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17165 },
    { MODRM_SPLITRM, 17167 },
    { MODRM_SPLITRM, 17169 },
    { MODRM_SPLITRM, 17171 },
    { MODRM_SPLITRM, 17173 },
    { MODRM_SPLITRM, 17175 },
    { MODRM_SPLITRM, 17177 },
    { MODRM_SPLITRM, 17179 },
    { MODRM_SPLITRM, 17181 },
    { MODRM_SPLITRM, 17183 },
    { MODRM_SPLITRM, 17185 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17187 },
    { MODRM_SPLITRM, 17189 },
    { MODRM_SPLITRM, 17191 },
    { MODRM_SPLITRM, 17193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17195 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17197 },
    { MODRM_SPLITRM, 17199 },
    { MODRM_SPLITRM, 17201 },
    { MODRM_SPLITRM, 16775 },
    { MODRM_SPLITRM, 17203 },
    { MODRM_SPLITRM, 16779 },
    { MODRM_SPLITRM, 17205 },
    { MODRM_SPLITRM, 16783 },
    { MODRM_SPLITRM, 17207 },
    { MODRM_SPLITRM, 16787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17209 },
    { MODRM_SPLITRM, 17211 },
    { MODRM_SPLITRM, 17213 },
    { MODRM_SPLITRM, 16795 },
    { MODRM_SPLITRM, 17215 },
    { MODRM_SPLITRM, 16799 },
    { MODRM_SPLITRM, 17217 },
    { MODRM_SPLITRM, 16803 },
    { MODRM_SPLITRM, 17219 },
    { MODRM_SPLITRM, 16807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17221 },
    { MODRM_SPLITRM, 17223 },
    { MODRM_SPLITRM, 17225 },
    { MODRM_SPLITRM, 16815 },
    { MODRM_SPLITRM, 17227 },
    { MODRM_SPLITRM, 16819 },
    { MODRM_SPLITRM, 17229 },
    { MODRM_SPLITRM, 16823 },
    { MODRM_SPLITRM, 17231 },
    { MODRM_SPLITRM, 16827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17233 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 17043 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17045 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17237 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17239 },
    { MODRM_SPLITRM, 17241 },
    { MODRM_SPLITRM, 17243 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17245 },
    { MODRM_SPLITRM, 17247 },
    { MODRM_SPLITRM, 17249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17251 },
    { MODRM_SPLITRM, 17253 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17065 },
    { MODRM_SPLITRM, 17067 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17255 },
    { MODRM_SPLITRM, 17071 },
    { MODRM_SPLITRM, 17073 },
    { MODRM_SPLITRM, 17075 },
    { MODRM_SPLITRM, 17077 },
    { MODRM_SPLITRM, 17079 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17259 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17087 },
    { MODRM_SPLITRM, 17089 },
    { MODRM_SPLITRM, 17091 },
    { MODRM_SPLITRM, 17093 },
    { MODRM_SPLITRM, 17095 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17261 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17101 },
    { MODRM_SPLITRM, 17263 },
    { MODRM_SPLITRM, 17105 },
    { MODRM_SPLITRM, 17265 },
    { MODRM_SPLITRM, 17109 },
    { MODRM_SPLITRM, 17267 },
    { MODRM_SPLITRM, 17113 },
    { MODRM_SPLITRM, 17269 },
    { MODRM_SPLITRM, 17271 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17275 },
    { MODRM_SPLITRM, 17277 },
    { MODRM_SPLITRM, 17279 },
    { MODRM_SPLITRM, 17281 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17287 },
    { MODRM_SPLITRM, 17289 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17291 },
    { MODRM_SPLITRM, 17293 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17295 },
    { MODRM_SPLITRM, 17297 },
    { MODRM_SPLITRM, 17299 },
    { MODRM_SPLITRM, 17301 },
    { MODRM_SPLITRM, 17303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17305 },
    { MODRM_SPLITRM, 17307 },
    { MODRM_SPLITRM, 17309 },
    { MODRM_SPLITRM, 17311 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17313 },
    { MODRM_SPLITRM, 17315 },
    { MODRM_SPLITRM, 17317 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17319 },
    { MODRM_SPLITRM, 17321 },
    { MODRM_SPLITRM, 17323 },
    { MODRM_SPLITRM, 17325 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17327 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17329 },
    { MODRM_SPLITRM, 17331 },
    { MODRM_SPLITRM, 17333 },
    { MODRM_SPLITRM, 17335 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17337 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17339 },
    { MODRM_SPLITRM, 17341 },
    { MODRM_SPLITRM, 17343 },
    { MODRM_SPLITRM, 16943 },
    { MODRM_SPLITRM, 17345 },
    { MODRM_SPLITRM, 16947 },
    { MODRM_SPLITRM, 17347 },
    { MODRM_SPLITRM, 16951 },
    { MODRM_SPLITRM, 17349 },
    { MODRM_SPLITRM, 16955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17351 },
    { MODRM_SPLITRM, 17353 },
    { MODRM_SPLITRM, 17355 },
    { MODRM_SPLITRM, 16963 },
    { MODRM_SPLITRM, 17357 },
    { MODRM_SPLITRM, 16967 },
    { MODRM_SPLITRM, 17359 },
    { MODRM_SPLITRM, 16971 },
    { MODRM_SPLITRM, 17361 },
    { MODRM_SPLITRM, 16975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17363 },
    { MODRM_SPLITRM, 17365 },
    { MODRM_SPLITRM, 17367 },
    { MODRM_SPLITRM, 17369 },
    { MODRM_SPLITRM, 17371 },
    { MODRM_SPLITRM, 16987 },
    { MODRM_SPLITRM, 17373 },
    { MODRM_SPLITRM, 16991 },
    { MODRM_SPLITRM, 17375 },
    { MODRM_SPLITRM, 16995 },
    { MODRM_SPLITRM, 17377 },
    { MODRM_SPLITRM, 16999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17379 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17381 },
    { MODRM_SPLITRM, 17383 },
    { MODRM_SPLITRM, 17385 },
    { MODRM_SPLITRM, 17387 },
    { MODRM_SPLITRM, 17389 },
    { MODRM_SPLITRM, 17391 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17393 },
    { MODRM_SPLITRM, 17395 },
    { MODRM_SPLITRM, 17397 },
    { MODRM_SPLITRM, 17399 },
    { MODRM_SPLITRM, 17401 },
    { MODRM_SPLITRM, 17403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17405 },
    { MODRM_SPLITRM, 17407 },
    { MODRM_SPLITRM, 17409 },
    { MODRM_SPLITRM, 17411 },
    { MODRM_SPLITRM, 17413 },
    { MODRM_SPLITRM, 17415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17417 },
    { MODRM_SPLITRM, 17419 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17421 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17423 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 17425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17429 },
    { MODRM_SPLITRM, 17431 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17433 },
    { MODRM_SPLITRM, 17435 },
    { MODRM_SPLITRM, 17437 },
    { MODRM_SPLITRM, 17439 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17441 },
    { MODRM_SPLITRM, 17443 },
    { MODRM_SPLITRM, 17445 },
    { MODRM_SPLITRM, 17447 },
    { MODRM_SPLITRM, 17449 },
    { MODRM_SPLITRM, 17451 },
    { MODRM_SPLITRM, 17453 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17455 },
    { MODRM_SPLITRM, 17457 },
    { MODRM_SPLITRM, 17459 },
    { MODRM_SPLITRM, 17461 },
    { MODRM_SPLITRM, 17463 },
    { MODRM_SPLITRM, 17465 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17467 },
    { MODRM_SPLITRM, 17469 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17471 },
    { MODRM_SPLITRM, 17473 },
    { MODRM_SPLITRM, 17475 },
    { MODRM_SPLITRM, 17477 },
    { MODRM_SPLITRM, 17479 },
    { MODRM_SPLITRM, 17481 },
    { MODRM_SPLITRM, 17483 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17485 },
    { MODRM_SPLITRM, 17487 },
    { MODRM_SPLITRM, 17489 },
    { MODRM_SPLITRM, 17491 },
    { MODRM_SPLITRM, 17493 },
    { MODRM_SPLITRM, 17495 },
    { MODRM_SPLITRM, 17497 },
    { MODRM_SPLITRM, 17499 },
    { MODRM_SPLITRM, 17501 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17503 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17505 },
    { MODRM_SPLITRM, 17507 },
    { MODRM_SPLITRM, 17509 },
    { MODRM_SPLITRM, 17511 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17513 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17517 },
    { MODRM_SPLITRM, 17519 },
    { MODRM_SPLITRM, 17521 },
    { MODRM_SPLITRM, 17523 },
    { MODRM_SPLITRM, 17525 },
    { MODRM_SPLITRM, 17527 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17529 },
    { MODRM_SPLITRM, 17531 },
    { MODRM_SPLITRM, 17533 },
    { MODRM_SPLITRM, 17535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17537 },
    { MODRM_SPLITRM, 17539 },
    { MODRM_SPLITRM, 17541 },
    { MODRM_SPLITRM, 17543 },
    { MODRM_SPLITRM, 17545 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17547 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17551 },
    { MODRM_SPLITRM, 17553 },
    { MODRM_SPLITRM, 17555 },
    { MODRM_SPLITRM, 17557 },
    { MODRM_SPLITRM, 17559 },
    { MODRM_SPLITRM, 17561 },
    { MODRM_SPLITRM, 17563 },
    { MODRM_SPLITRM, 17565 },
    { MODRM_SPLITRM, 17567 },
    { MODRM_SPLITRM, 17569 },
    { MODRM_SPLITRM, 17571 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17573 },
    { MODRM_SPLITRM, 17575 },
    { MODRM_SPLITRM, 17577 },
    { MODRM_SPLITRM, 17579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17581 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17583 },
    { MODRM_SPLITRM, 17585 },
    { MODRM_SPLITRM, 17587 },
    { MODRM_SPLITRM, 16775 },
    { MODRM_SPLITRM, 17589 },
    { MODRM_SPLITRM, 16779 },
    { MODRM_SPLITRM, 17591 },
    { MODRM_SPLITRM, 16783 },
    { MODRM_SPLITRM, 17593 },
    { MODRM_SPLITRM, 16787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17595 },
    { MODRM_SPLITRM, 17597 },
    { MODRM_SPLITRM, 17599 },
    { MODRM_SPLITRM, 16795 },
    { MODRM_SPLITRM, 17601 },
    { MODRM_SPLITRM, 16799 },
    { MODRM_SPLITRM, 17603 },
    { MODRM_SPLITRM, 16803 },
    { MODRM_SPLITRM, 17605 },
    { MODRM_SPLITRM, 16807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17607 },
    { MODRM_SPLITRM, 17609 },
    { MODRM_SPLITRM, 17611 },
    { MODRM_SPLITRM, 16815 },
    { MODRM_SPLITRM, 17613 },
    { MODRM_SPLITRM, 16819 },
    { MODRM_SPLITRM, 17615 },
    { MODRM_SPLITRM, 16823 },
    { MODRM_SPLITRM, 17617 },
    { MODRM_SPLITRM, 16827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17623 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17625 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17627 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 17425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17631 },
    { MODRM_SPLITRM, 17633 },
    { MODRM_SPLITRM, 17635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17637 },
    { MODRM_SPLITRM, 17639 },
    { MODRM_SPLITRM, 17641 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17643 },
    { MODRM_SPLITRM, 17645 },
    { MODRM_SPLITRM, 17647 },
    { MODRM_SPLITRM, 17449 },
    { MODRM_SPLITRM, 17451 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17649 },
    { MODRM_SPLITRM, 17455 },
    { MODRM_SPLITRM, 17457 },
    { MODRM_SPLITRM, 17459 },
    { MODRM_SPLITRM, 17461 },
    { MODRM_SPLITRM, 17463 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17651 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17653 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17471 },
    { MODRM_SPLITRM, 17473 },
    { MODRM_SPLITRM, 17475 },
    { MODRM_SPLITRM, 17477 },
    { MODRM_SPLITRM, 17479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17655 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17485 },
    { MODRM_SPLITRM, 17657 },
    { MODRM_SPLITRM, 17489 },
    { MODRM_SPLITRM, 17659 },
    { MODRM_SPLITRM, 17493 },
    { MODRM_SPLITRM, 17661 },
    { MODRM_SPLITRM, 17497 },
    { MODRM_SPLITRM, 17663 },
    { MODRM_SPLITRM, 17665 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17667 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17669 },
    { MODRM_SPLITRM, 17671 },
    { MODRM_SPLITRM, 17673 },
    { MODRM_SPLITRM, 17675 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17677 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17679 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17681 },
    { MODRM_SPLITRM, 17683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17685 },
    { MODRM_SPLITRM, 17687 },
    { MODRM_SPLITRM, 17689 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17691 },
    { MODRM_SPLITRM, 17693 },
    { MODRM_SPLITRM, 17695 },
    { MODRM_SPLITRM, 17697 },
    { MODRM_SPLITRM, 17699 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17701 },
    { MODRM_SPLITRM, 17703 },
    { MODRM_SPLITRM, 17705 },
    { MODRM_SPLITRM, 17707 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17709 },
    { MODRM_SPLITRM, 17711 },
    { MODRM_SPLITRM, 17713 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17715 },
    { MODRM_SPLITRM, 17717 },
    { MODRM_SPLITRM, 17719 },
    { MODRM_SPLITRM, 17721 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17723 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17725 },
    { MODRM_SPLITRM, 17727 },
    { MODRM_SPLITRM, 17729 },
    { MODRM_SPLITRM, 17731 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17733 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17735 },
    { MODRM_SPLITRM, 17737 },
    { MODRM_SPLITRM, 17739 },
    { MODRM_SPLITRM, 16943 },
    { MODRM_SPLITRM, 17741 },
    { MODRM_SPLITRM, 16947 },
    { MODRM_SPLITRM, 17743 },
    { MODRM_SPLITRM, 16951 },
    { MODRM_SPLITRM, 17745 },
    { MODRM_SPLITRM, 16955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17747 },
    { MODRM_SPLITRM, 17749 },
    { MODRM_SPLITRM, 17751 },
    { MODRM_SPLITRM, 16963 },
    { MODRM_SPLITRM, 17753 },
    { MODRM_SPLITRM, 16967 },
    { MODRM_SPLITRM, 17755 },
    { MODRM_SPLITRM, 16971 },
    { MODRM_SPLITRM, 17757 },
    { MODRM_SPLITRM, 16975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17759 },
    { MODRM_SPLITRM, 17761 },
    { MODRM_SPLITRM, 17763 },
    { MODRM_SPLITRM, 17765 },
    { MODRM_SPLITRM, 17767 },
    { MODRM_SPLITRM, 16987 },
    { MODRM_SPLITRM, 17769 },
    { MODRM_SPLITRM, 16991 },
    { MODRM_SPLITRM, 17771 },
    { MODRM_SPLITRM, 16995 },
    { MODRM_SPLITRM, 17773 },
    { MODRM_SPLITRM, 16999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17775 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17777 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17779 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17781 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

static const unsigned char index_x86DisassemblerThreeByte3AOpcodes[] = {
  1,
  2,
  3,
  4,
  5,
  6,
  7,
  0,
  0,
  0,
  0,
  8,
  9,
  10,
  11,
  12,
  13,
  14,
  0,
  0,
  15,
  16,
  17,
  18,
  19,
  0,
  0,
  20,
  21,
  0,
  0,
  22,
  23,
  0,
  0,
  0,
  24,
  0,
  0,
  0,
  25,
  0,
  0,
  0,
  26,
  0,
  0,
  0,
  27,
  0,
  0,
  0,
  28,
  0,
  0,
  0,
  29,
  0,
  0,
  0,
  30,
  0,
  0,
  0,
  31,
  0,
  0,
  0,
  32,
  0,
  0,
  0,
  33,
  0,
  0,
  0,
  34,
  0,
  0,
  0,
  35,
  0,
  0,
  0,
  36,
  0,
  0,
  0,
  37,
  0,
  0,
  0,
  38,
  0,
  0,
  0,
  39,
  0,
  0,
  0,
  40,
  0,
  0,
  0,
  41,
  0,
  0,
  0,
  42,
  0,
  0,
  0,
  43,
  0,
  0,
  0,
  44,
  0,
  0,
  0,
  45,
  0,
  0,
  0,
  46,
  0,
  0,
  0,
  47,
  0,
  0,
  0,
  48,
  0,
  0,
  0,
  49,
  0,
  0,
  0,
  50,
  0,
  0,
  0,
  51,
  0,
  0,
  0,
  52,
  0,
  0,
  0,
  53,
  0,
  0,
  0,
  54,
  0,
  0,
  0,
  55,
  0,
  0,
  0,
  56,
  0,
  0,
  0,
  57,
  0,
  0,
  0,
  58,
  0,
  0,
  0,
  59,
  0,
  0,
  0,
  60,
  0,
  0,
  0,
  61,
};

static const struct OpcodeDecision x86DisassemblerThreeByte3AOpcodes[] = {
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17787 },
    { MODRM_SPLITRM, 17789 },
    { MODRM_SPLITRM, 17791 },
    { MODRM_SPLITRM, 17793 },
    { MODRM_SPLITRM, 17795 },
    { MODRM_SPLITRM, 17797 },
    { MODRM_SPLITRM, 17799 },
    { MODRM_SPLITRM, 17801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17803 },
    { MODRM_SPLITRM, 17805 },
    { MODRM_SPLITRM, 17807 },
    { MODRM_SPLITRM, 17809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17811 },
    { MODRM_SPLITRM, 17813 },
    { MODRM_SPLITRM, 17815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17817 },
    { MODRM_SPLITRM, 17819 },
    { MODRM_SPLITRM, 17821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17825 },
    { MODRM_SPLITRM, 17827 },
    { MODRM_SPLITRM, 17829 },
    { MODRM_SPLITRM, 17831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17833 },
    { MODRM_SPLITRM, 17835 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17837 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17787 },
    { MODRM_SPLITRM, 17789 },
    { MODRM_SPLITRM, 17791 },
    { MODRM_SPLITRM, 17793 },
    { MODRM_SPLITRM, 17795 },
    { MODRM_SPLITRM, 17797 },
    { MODRM_SPLITRM, 17799 },
    { MODRM_SPLITRM, 17801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17803 },
    { MODRM_SPLITRM, 17805 },
    { MODRM_SPLITRM, 17807 },
    { MODRM_SPLITRM, 17809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17811 },
    { MODRM_SPLITRM, 17813 },
    { MODRM_SPLITRM, 17815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17817 },
    { MODRM_SPLITRM, 17819 },
    { MODRM_SPLITRM, 17821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17825 },
    { MODRM_SPLITRM, 17827 },
    { MODRM_SPLITRM, 17829 },
    { MODRM_SPLITRM, 17831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17833 },
    { MODRM_SPLITRM, 17835 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17837 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17787 },
    { MODRM_SPLITRM, 17789 },
    { MODRM_SPLITRM, 17791 },
    { MODRM_SPLITRM, 17793 },
    { MODRM_SPLITRM, 17795 },
    { MODRM_SPLITRM, 17797 },
    { MODRM_SPLITRM, 17799 },
    { MODRM_SPLITRM, 17801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17803 },
    { MODRM_SPLITRM, 17805 },
    { MODRM_SPLITRM, 17807 },
    { MODRM_SPLITRM, 17809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17811 },
    { MODRM_SPLITRM, 17813 },
    { MODRM_SPLITRM, 17815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17817 },
    { MODRM_SPLITRM, 17819 },
    { MODRM_SPLITRM, 17821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17825 },
    { MODRM_SPLITRM, 17827 },
    { MODRM_SPLITRM, 17829 },
    { MODRM_SPLITRM, 17831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17833 },
    { MODRM_SPLITRM, 17835 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17837 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17787 },
    { MODRM_SPLITRM, 17789 },
    { MODRM_SPLITRM, 17791 },
    { MODRM_SPLITRM, 17793 },
    { MODRM_SPLITRM, 17795 },
    { MODRM_SPLITRM, 17797 },
    { MODRM_SPLITRM, 17799 },
    { MODRM_SPLITRM, 17801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17803 },
    { MODRM_SPLITRM, 17805 },
    { MODRM_SPLITRM, 17807 },
    { MODRM_SPLITRM, 17809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17811 },
    { MODRM_SPLITRM, 17813 },
    { MODRM_SPLITRM, 17815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17817 },
    { MODRM_SPLITRM, 17819 },
    { MODRM_SPLITRM, 17821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17825 },
    { MODRM_SPLITRM, 17827 },
    { MODRM_SPLITRM, 17829 },
    { MODRM_SPLITRM, 17831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17833 },
    { MODRM_SPLITRM, 17835 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17837 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17787 },
    { MODRM_SPLITRM, 17789 },
    { MODRM_SPLITRM, 17791 },
    { MODRM_SPLITRM, 17793 },
    { MODRM_SPLITRM, 17795 },
    { MODRM_SPLITRM, 17797 },
    { MODRM_SPLITRM, 17799 },
    { MODRM_SPLITRM, 17801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17803 },
    { MODRM_SPLITRM, 17805 },
    { MODRM_SPLITRM, 17807 },
    { MODRM_SPLITRM, 17809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17811 },
    { MODRM_SPLITRM, 17813 },
    { MODRM_SPLITRM, 17815 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17817 },
    { MODRM_SPLITRM, 17819 },
    { MODRM_SPLITRM, 17821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17825 },
    { MODRM_SPLITRM, 17827 },
    { MODRM_SPLITRM, 17829 },
    { MODRM_SPLITRM, 17831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17833 },
    { MODRM_SPLITRM, 17835 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17837 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17787 },
    { MODRM_SPLITRM, 17789 },
    { MODRM_SPLITRM, 17791 },
    { MODRM_SPLITRM, 17793 },
    { MODRM_SPLITRM, 17795 },
    { MODRM_SPLITRM, 17797 },
    { MODRM_SPLITRM, 17799 },
    { MODRM_SPLITRM, 17801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17803 },
    { MODRM_SPLITRM, 17805 },
    { MODRM_SPLITRM, 17839 },
    { MODRM_SPLITRM, 17809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17811 },
    { MODRM_SPLITRM, 17813 },
    { MODRM_SPLITRM, 17841 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17817 },
    { MODRM_SPLITRM, 17819 },
    { MODRM_SPLITRM, 17821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17825 },
    { MODRM_SPLITRM, 17827 },
    { MODRM_SPLITRM, 17829 },
    { MODRM_SPLITRM, 17831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17785 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17833 },
    { MODRM_SPLITRM, 17835 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17837 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17845 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17847 },
    { MODRM_SPLITRM, 17849 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17851 },
    { MODRM_SPLITRM, 17853 },
    { MODRM_SPLITRM, 17855 },
    { MODRM_SPLITRM, 17857 },
    { MODRM_SPLITRM, 17859 },
    { MODRM_SPLITRM, 17861 },
    { MODRM_SPLITRM, 17863 },
    { MODRM_SPLITRM, 17865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17867 },
    { MODRM_SPLITRM, 17869 },
    { MODRM_SPLITRM, 17871 },
    { MODRM_SPLITRM, 17873 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17875 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17877 },
    { MODRM_SPLITRM, 17879 },
    { MODRM_SPLITRM, 17881 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17883 },
    { MODRM_SPLITRM, 17885 },
    { MODRM_SPLITRM, 17887 },
    { MODRM_SPLITRM, 17889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17891 },
    { MODRM_SPLITRM, 17893 },
    { MODRM_SPLITRM, 17895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17899 },
    { MODRM_SPLITRM, 17901 },
    { MODRM_SPLITRM, 17903 },
    { MODRM_SPLITRM, 17905 },
    { MODRM_SPLITRM, 17907 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17909 },
    { MODRM_SPLITRM, 17911 },
    { MODRM_SPLITRM, 17913 },
    { MODRM_SPLITRM, 17915 },
    { MODRM_SPLITRM, 17917 },
    { MODRM_SPLITRM, 17919 },
    { MODRM_SPLITRM, 17921 },
    { MODRM_SPLITRM, 17923 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17925 },
    { MODRM_SPLITRM, 17927 },
    { MODRM_SPLITRM, 17929 },
    { MODRM_SPLITRM, 17931 },
    { MODRM_SPLITRM, 17933 },
    { MODRM_SPLITRM, 17935 },
    { MODRM_SPLITRM, 17937 },
    { MODRM_SPLITRM, 17939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17941 },
    { MODRM_SPLITRM, 17943 },
    { MODRM_SPLITRM, 17945 },
    { MODRM_SPLITRM, 17947 },
    { MODRM_SPLITRM, 17949 },
    { MODRM_SPLITRM, 17951 },
    { MODRM_SPLITRM, 17953 },
    { MODRM_SPLITRM, 17955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17959 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17851 },
    { MODRM_SPLITRM, 17853 },
    { MODRM_SPLITRM, 17855 },
    { MODRM_SPLITRM, 17857 },
    { MODRM_SPLITRM, 17859 },
    { MODRM_SPLITRM, 17861 },
    { MODRM_SPLITRM, 17863 },
    { MODRM_SPLITRM, 17865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17961 },
    { MODRM_SPLITRM, 17873 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17879 },
    { MODRM_SPLITRM, 17963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17965 },
    { MODRM_SPLITRM, 17967 },
    { MODRM_SPLITRM, 17969 },
    { MODRM_SPLITRM, 17971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17891 },
    { MODRM_SPLITRM, 17893 },
    { MODRM_SPLITRM, 17895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17973 },
    { MODRM_SPLITRM, 17975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17977 },
    { MODRM_SPLITRM, 17979 },
    { MODRM_SPLITRM, 17981 },
    { MODRM_SPLITRM, 17983 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17985 },
    { MODRM_SPLITRM, 17987 },
    { MODRM_SPLITRM, 17989 },
    { MODRM_SPLITRM, 17991 },
    { MODRM_SPLITRM, 17993 },
    { MODRM_SPLITRM, 17995 },
    { MODRM_SPLITRM, 17997 },
    { MODRM_SPLITRM, 17999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18001 },
    { MODRM_SPLITRM, 18003 },
    { MODRM_SPLITRM, 18005 },
    { MODRM_SPLITRM, 18007 },
    { MODRM_SPLITRM, 18009 },
    { MODRM_SPLITRM, 18011 },
    { MODRM_SPLITRM, 18013 },
    { MODRM_SPLITRM, 18015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18017 },
    { MODRM_SPLITRM, 18019 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 17957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18021 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18023 },
    { MODRM_SPLITRM, 18025 },
    { MODRM_SPLITRM, 18027 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18029 },
    { MODRM_SPLITRM, 18031 },
    { MODRM_SPLITRM, 17855 },
    { MODRM_SPLITRM, 17857 },
    { MODRM_SPLITRM, 18033 },
    { MODRM_SPLITRM, 18035 },
    { MODRM_SPLITRM, 18037 },
    { MODRM_SPLITRM, 18039 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18041 },
    { MODRM_SPLITRM, 18043 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18045 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18047 },
    { MODRM_SPLITRM, 18049 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18055 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18059 },
    { MODRM_SPLITRM, 18061 },
    { MODRM_SPLITRM, 18063 },
    { MODRM_SPLITRM, 18065 },
    { MODRM_SPLITRM, 18067 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18069 },
    { MODRM_SPLITRM, 18071 },
    { MODRM_SPLITRM, 18073 },
    { MODRM_SPLITRM, 18075 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18077 },
    { MODRM_SPLITRM, 18079 },
    { MODRM_SPLITRM, 17929 },
    { MODRM_SPLITRM, 17931 },
    { MODRM_SPLITRM, 18081 },
    { MODRM_SPLITRM, 18083 },
    { MODRM_SPLITRM, 17937 },
    { MODRM_SPLITRM, 17939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18085 },
    { MODRM_SPLITRM, 18087 },
    { MODRM_SPLITRM, 17945 },
    { MODRM_SPLITRM, 17947 },
    { MODRM_SPLITRM, 18089 },
    { MODRM_SPLITRM, 18091 },
    { MODRM_SPLITRM, 17953 },
    { MODRM_SPLITRM, 17955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 18093 },
    { MODRM_SPLITRM, 18095 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18029 },
    { MODRM_SPLITRM, 18031 },
    { MODRM_SPLITRM, 17855 },
    { MODRM_SPLITRM, 17857 },
    { MODRM_SPLITRM, 18033 },
    { MODRM_SPLITRM, 18035 },
    { MODRM_SPLITRM, 18037 },
    { MODRM_SPLITRM, 18039 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18053 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18055 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18097 },
    { MODRM_SPLITRM, 18099 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18101 },
    { MODRM_SPLITRM, 18103 },
    { MODRM_SPLITRM, 18105 },
    { MODRM_SPLITRM, 18107 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18109 },
    { MODRM_SPLITRM, 18111 },
    { MODRM_SPLITRM, 17989 },
    { MODRM_SPLITRM, 17991 },
    { MODRM_SPLITRM, 18113 },
    { MODRM_SPLITRM, 18115 },
    { MODRM_SPLITRM, 17997 },
    { MODRM_SPLITRM, 17999 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18117 },
    { MODRM_SPLITRM, 18119 },
    { MODRM_SPLITRM, 18005 },
    { MODRM_SPLITRM, 18007 },
    { MODRM_SPLITRM, 18121 },
    { MODRM_SPLITRM, 18123 },
    { MODRM_SPLITRM, 18013 },
    { MODRM_SPLITRM, 18015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18125 },
    { MODRM_SPLITRM, 18127 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18129 },
    { MODRM_SPLITRM, 18131 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18133 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18135 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18137 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18139 },
    { MODRM_SPLITRM, 18141 },
    { MODRM_SPLITRM, 18143 },
    { MODRM_SPLITRM, 18145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18147 },
    { MODRM_SPLITRM, 18149 },
    { MODRM_SPLITRM, 18151 },
    { MODRM_SPLITRM, 18153 },
    { MODRM_SPLITRM, 18155 },
    { MODRM_SPLITRM, 18157 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18159 },
    { MODRM_SPLITRM, 18161 },
    { MODRM_SPLITRM, 18163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18165 },
    { MODRM_SPLITRM, 18167 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18169 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18171 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18173 },
    { MODRM_SPLITRM, 18175 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18177 },
    { MODRM_SPLITRM, 18179 },
    { MODRM_SPLITRM, 18181 },
    { MODRM_SPLITRM, 18183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18185 },
    { MODRM_SPLITRM, 18187 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18189 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18191 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18195 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18197 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18199 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18139 },
    { MODRM_SPLITRM, 18141 },
    { MODRM_SPLITRM, 18201 },
    { MODRM_SPLITRM, 18145 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18203 },
    { MODRM_SPLITRM, 18205 },
    { MODRM_SPLITRM, 18153 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18209 },
    { MODRM_SPLITRM, 18211 },
    { MODRM_SPLITRM, 18213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18215 },
    { MODRM_SPLITRM, 18217 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18171 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18219 },
    { MODRM_SPLITRM, 18221 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18223 },
    { MODRM_SPLITRM, 18225 },
    { MODRM_SPLITRM, 18227 },
    { MODRM_SPLITRM, 18229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18231 },
    { MODRM_SPLITRM, 18233 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18235 },
    { MODRM_SPLITRM, 18237 },
    { MODRM_SPLITRM, 18239 },
    { MODRM_SPLITRM, 18241 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18243 },
    { MODRM_SPLITRM, 18245 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18247 },
    { MODRM_SPLITRM, 18249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18251 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18253 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18255 },
    { MODRM_SPLITRM, 18257 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18259 },
    { MODRM_SPLITRM, 18261 },
    { MODRM_SPLITRM, 18263 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18265 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18267 },
    { MODRM_SPLITRM, 18269 },
    { MODRM_SPLITRM, 18163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18271 },
    { MODRM_SPLITRM, 18273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18275 },
    { MODRM_SPLITRM, 18277 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18279 },
    { MODRM_SPLITRM, 18281 },
    { MODRM_SPLITRM, 18283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18285 },
    { MODRM_SPLITRM, 18175 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18287 },
    { MODRM_SPLITRM, 18179 },
    { MODRM_SPLITRM, 18289 },
    { MODRM_SPLITRM, 18183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18291 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18293 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18295 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 18297 },
    { MODRM_SPLITRM, 18299 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18301 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18307 },
    { MODRM_SPLITRM, 18309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18311 },
    { MODRM_SPLITRM, 18313 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18315 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18317 },
    { MODRM_SPLITRM, 18319 },
    { MODRM_SPLITRM, 18213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18321 },
    { MODRM_SPLITRM, 18323 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18325 },
    { MODRM_SPLITRM, 18327 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18329 },
    { MODRM_SPLITRM, 18283 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18331 },
    { MODRM_SPLITRM, 18221 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18333 },
    { MODRM_SPLITRM, 18225 },
    { MODRM_SPLITRM, 18335 },
    { MODRM_SPLITRM, 18229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18337 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18339 },
    { MODRM_SPLITRM, 18341 },
    { MODRM_SPLITRM, 18343 },
    { MODRM_SPLITRM, 18345 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18347 },
    { MODRM_SPLITRM, 18349 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18351 },
    { MODRM_SPLITRM, 18353 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18355 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18357 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18359 },
    { MODRM_SPLITRM, 18361 },
    { MODRM_SPLITRM, 18363 },
    { MODRM_SPLITRM, 18365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18367 },
    { MODRM_SPLITRM, 18369 },
    { MODRM_SPLITRM, 18371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18373 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18375 },
    { MODRM_SPLITRM, 18377 },
    { MODRM_SPLITRM, 18163 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18379 },
    { MODRM_SPLITRM, 18381 },
    { MODRM_SPLITRM, 18383 },
    { MODRM_SPLITRM, 18385 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18387 },
    { MODRM_SPLITRM, 18389 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18391 },
    { MODRM_SPLITRM, 18393 },
    { MODRM_SPLITRM, 18395 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18397 },
    { MODRM_SPLITRM, 18175 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18399 },
    { MODRM_SPLITRM, 18179 },
    { MODRM_SPLITRM, 18401 },
    { MODRM_SPLITRM, 18183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18405 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18407 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 18409 },
    { MODRM_SPLITRM, 18411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18413 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18415 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18419 },
    { MODRM_SPLITRM, 18421 },
    { MODRM_SPLITRM, 18423 },
    { MODRM_SPLITRM, 18425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18427 },
    { MODRM_SPLITRM, 18429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18431 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18433 },
    { MODRM_SPLITRM, 18435 },
    { MODRM_SPLITRM, 18213 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18437 },
    { MODRM_SPLITRM, 18439 },
    { MODRM_SPLITRM, 18441 },
    { MODRM_SPLITRM, 18443 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18445 },
    { MODRM_SPLITRM, 18447 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18449 },
    { MODRM_SPLITRM, 18395 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18451 },
    { MODRM_SPLITRM, 18221 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18453 },
    { MODRM_SPLITRM, 18225 },
    { MODRM_SPLITRM, 18455 },
    { MODRM_SPLITRM, 18229 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18457 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18459 },
    { MODRM_SPLITRM, 18461 },
    { MODRM_SPLITRM, 18463 },
    { MODRM_SPLITRM, 18465 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18467 },
    { MODRM_SPLITRM, 18469 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18471 },
    { MODRM_SPLITRM, 18473 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18475 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18477 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18481 },
    { MODRM_SPLITRM, 18483 },
    { MODRM_SPLITRM, 18485 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18487 },
    { MODRM_SPLITRM, 18489 },
    { MODRM_SPLITRM, 18491 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18493 },
    { MODRM_SPLITRM, 18495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18497 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18499 },
    { MODRM_SPLITRM, 18501 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18503 },
    { MODRM_SPLITRM, 18505 },
    { MODRM_SPLITRM, 18507 },
    { MODRM_SPLITRM, 18509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18511 },
    { MODRM_SPLITRM, 18513 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18517 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18519 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18521 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18523 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18525 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18527 },
    { MODRM_SPLITRM, 18529 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18531 },
    { MODRM_SPLITRM, 18533 },
    { MODRM_SPLITRM, 18535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18537 },
    { MODRM_SPLITRM, 18539 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18541 },
    { MODRM_SPLITRM, 18543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18545 },
    { MODRM_SPLITRM, 18547 },
    { MODRM_SPLITRM, 18549 },
    { MODRM_SPLITRM, 18551 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18553 },
    { MODRM_SPLITRM, 18555 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18557 },
    { MODRM_SPLITRM, 18559 },
    { MODRM_SPLITRM, 18561 },
    { MODRM_SPLITRM, 18563 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18565 },
    { MODRM_SPLITRM, 18567 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18569 },
    { MODRM_SPLITRM, 18571 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18573 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18575 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18577 },
    { MODRM_SPLITRM, 18579 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18581 },
    { MODRM_SPLITRM, 18583 },
    { MODRM_SPLITRM, 18585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18587 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18589 },
    { MODRM_SPLITRM, 18591 },
    { MODRM_SPLITRM, 18491 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18593 },
    { MODRM_SPLITRM, 18595 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18597 },
    { MODRM_SPLITRM, 18599 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18601 },
    { MODRM_SPLITRM, 18603 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18605 },
    { MODRM_SPLITRM, 18501 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18607 },
    { MODRM_SPLITRM, 18505 },
    { MODRM_SPLITRM, 18609 },
    { MODRM_SPLITRM, 18509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18611 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18613 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18615 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 18617 },
    { MODRM_SPLITRM, 18619 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18621 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18623 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18625 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18627 },
    { MODRM_SPLITRM, 18629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18631 },
    { MODRM_SPLITRM, 18633 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18635 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18637 },
    { MODRM_SPLITRM, 18639 },
    { MODRM_SPLITRM, 18535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18641 },
    { MODRM_SPLITRM, 18643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18645 },
    { MODRM_SPLITRM, 18647 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18649 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18651 },
    { MODRM_SPLITRM, 18543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18653 },
    { MODRM_SPLITRM, 18547 },
    { MODRM_SPLITRM, 18655 },
    { MODRM_SPLITRM, 18551 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18657 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18659 },
    { MODRM_SPLITRM, 18661 },
    { MODRM_SPLITRM, 18663 },
    { MODRM_SPLITRM, 18665 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18667 },
    { MODRM_SPLITRM, 18669 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18671 },
    { MODRM_SPLITRM, 18673 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18675 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18677 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18679 },
    { MODRM_SPLITRM, 18681 },
    { MODRM_SPLITRM, 18683 },
    { MODRM_SPLITRM, 18685 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18687 },
    { MODRM_SPLITRM, 18689 },
    { MODRM_SPLITRM, 18691 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18693 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18695 },
    { MODRM_SPLITRM, 18697 },
    { MODRM_SPLITRM, 18491 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18699 },
    { MODRM_SPLITRM, 18701 },
    { MODRM_SPLITRM, 18703 },
    { MODRM_SPLITRM, 18705 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18707 },
    { MODRM_SPLITRM, 18709 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18711 },
    { MODRM_SPLITRM, 18713 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18715 },
    { MODRM_SPLITRM, 18501 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18717 },
    { MODRM_SPLITRM, 18505 },
    { MODRM_SPLITRM, 18719 },
    { MODRM_SPLITRM, 18509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18721 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18723 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18725 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 18727 },
    { MODRM_SPLITRM, 18729 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18731 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18733 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18735 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18737 },
    { MODRM_SPLITRM, 18739 },
    { MODRM_SPLITRM, 18741 },
    { MODRM_SPLITRM, 18743 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18745 },
    { MODRM_SPLITRM, 18747 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18749 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18751 },
    { MODRM_SPLITRM, 18753 },
    { MODRM_SPLITRM, 18535 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18755 },
    { MODRM_SPLITRM, 18757 },
    { MODRM_SPLITRM, 18759 },
    { MODRM_SPLITRM, 18761 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18763 },
    { MODRM_SPLITRM, 18765 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18767 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18769 },
    { MODRM_SPLITRM, 18543 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18771 },
    { MODRM_SPLITRM, 18547 },
    { MODRM_SPLITRM, 18773 },
    { MODRM_SPLITRM, 18551 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18775 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18777 },
    { MODRM_SPLITRM, 18779 },
    { MODRM_SPLITRM, 18781 },
    { MODRM_SPLITRM, 18783 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18785 },
    { MODRM_SPLITRM, 18787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18789 },
    { MODRM_SPLITRM, 18791 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18793 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18795 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18797 },
    { MODRM_SPLITRM, 18799 },
    { MODRM_SPLITRM, 18801 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18803 },
    { MODRM_SPLITRM, 18805 },
    { MODRM_SPLITRM, 18807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18809 },
    { MODRM_SPLITRM, 18811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18813 },
    { MODRM_SPLITRM, 18815 },
    { MODRM_SPLITRM, 18817 },
    { MODRM_SPLITRM, 18819 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18821 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18823 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18825 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18827 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18829 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18831 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18835 },
    { MODRM_SPLITRM, 18837 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18839 },
    { MODRM_SPLITRM, 18841 },
    { MODRM_SPLITRM, 18843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18845 },
    { MODRM_SPLITRM, 18847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18849 },
    { MODRM_SPLITRM, 18851 },
    { MODRM_SPLITRM, 18853 },
    { MODRM_SPLITRM, 18855 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18857 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18859 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18861 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18863 },
    { MODRM_SPLITRM, 18865 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18867 },
    { MODRM_SPLITRM, 18869 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18871 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18795 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18797 },
    { MODRM_SPLITRM, 18873 },
    { MODRM_SPLITRM, 18875 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18877 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18879 },
    { MODRM_SPLITRM, 18881 },
    { MODRM_SPLITRM, 18807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18883 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18885 },
    { MODRM_SPLITRM, 18811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18887 },
    { MODRM_SPLITRM, 18815 },
    { MODRM_SPLITRM, 18889 },
    { MODRM_SPLITRM, 18819 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18891 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18893 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 18897 },
    { MODRM_SPLITRM, 18899 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18901 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18903 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18905 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18907 },
    { MODRM_SPLITRM, 18909 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18911 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18913 },
    { MODRM_SPLITRM, 18915 },
    { MODRM_SPLITRM, 18843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18917 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18919 },
    { MODRM_SPLITRM, 18847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18921 },
    { MODRM_SPLITRM, 18851 },
    { MODRM_SPLITRM, 18923 },
    { MODRM_SPLITRM, 18855 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18925 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18927 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18929 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18931 },
    { MODRM_SPLITRM, 18933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18935 },
    { MODRM_SPLITRM, 18937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18795 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18797 },
    { MODRM_SPLITRM, 18941 },
    { MODRM_SPLITRM, 18943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18947 },
    { MODRM_SPLITRM, 18949 },
    { MODRM_SPLITRM, 18807 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18953 },
    { MODRM_SPLITRM, 18811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18955 },
    { MODRM_SPLITRM, 18815 },
    { MODRM_SPLITRM, 18957 },
    { MODRM_SPLITRM, 18819 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18959 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 18965 },
    { MODRM_SPLITRM, 18967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18971 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18833 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18975 },
    { MODRM_SPLITRM, 18977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18979 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18981 },
    { MODRM_SPLITRM, 18983 },
    { MODRM_SPLITRM, 18843 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18985 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18987 },
    { MODRM_SPLITRM, 18847 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18989 },
    { MODRM_SPLITRM, 18851 },
    { MODRM_SPLITRM, 18991 },
    { MODRM_SPLITRM, 18855 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18993 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18995 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18997 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 18999 },
    { MODRM_SPLITRM, 19001 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19003 },
    { MODRM_SPLITRM, 19005 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19007 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19011 },
    { MODRM_SPLITRM, 19013 },
    { MODRM_SPLITRM, 19015 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19017 },
    { MODRM_SPLITRM, 19019 },
    { MODRM_SPLITRM, 19021 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19023 },
    { MODRM_SPLITRM, 19025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19027 },
    { MODRM_SPLITRM, 19029 },
    { MODRM_SPLITRM, 19031 },
    { MODRM_SPLITRM, 19033 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19035 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19037 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19039 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19041 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19043 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19045 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19049 },
    { MODRM_SPLITRM, 19051 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19053 },
    { MODRM_SPLITRM, 19055 },
    { MODRM_SPLITRM, 19057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19059 },
    { MODRM_SPLITRM, 19061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19063 },
    { MODRM_SPLITRM, 19065 },
    { MODRM_SPLITRM, 19067 },
    { MODRM_SPLITRM, 19069 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19071 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19073 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19075 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19077 },
    { MODRM_SPLITRM, 19079 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19081 },
    { MODRM_SPLITRM, 19083 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19085 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19011 },
    { MODRM_SPLITRM, 19087 },
    { MODRM_SPLITRM, 19089 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19091 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19093 },
    { MODRM_SPLITRM, 19095 },
    { MODRM_SPLITRM, 19021 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19097 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19099 },
    { MODRM_SPLITRM, 19025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19101 },
    { MODRM_SPLITRM, 19029 },
    { MODRM_SPLITRM, 19103 },
    { MODRM_SPLITRM, 19033 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19105 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19107 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19109 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 19111 },
    { MODRM_SPLITRM, 19113 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19115 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19117 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19119 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19121 },
    { MODRM_SPLITRM, 19123 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19125 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19127 },
    { MODRM_SPLITRM, 19129 },
    { MODRM_SPLITRM, 19057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19131 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19133 },
    { MODRM_SPLITRM, 19061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19135 },
    { MODRM_SPLITRM, 19065 },
    { MODRM_SPLITRM, 19137 },
    { MODRM_SPLITRM, 19069 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19139 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19141 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19143 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19145 },
    { MODRM_SPLITRM, 19147 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19149 },
    { MODRM_SPLITRM, 19151 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19153 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19009 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19011 },
    { MODRM_SPLITRM, 19155 },
    { MODRM_SPLITRM, 19157 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19159 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19161 },
    { MODRM_SPLITRM, 19163 },
    { MODRM_SPLITRM, 19021 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19165 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19167 },
    { MODRM_SPLITRM, 19025 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19169 },
    { MODRM_SPLITRM, 19029 },
    { MODRM_SPLITRM, 19171 },
    { MODRM_SPLITRM, 19033 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19173 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19175 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19177 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 19179 },
    { MODRM_SPLITRM, 19181 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19183 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19185 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19187 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19047 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19189 },
    { MODRM_SPLITRM, 19191 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19193 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19195 },
    { MODRM_SPLITRM, 19197 },
    { MODRM_SPLITRM, 19057 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19199 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19201 },
    { MODRM_SPLITRM, 19061 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19203 },
    { MODRM_SPLITRM, 19065 },
    { MODRM_SPLITRM, 19205 },
    { MODRM_SPLITRM, 19069 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19207 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19209 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19211 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19213 },
    { MODRM_SPLITRM, 19215 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19217 },
    { MODRM_SPLITRM, 19219 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19221 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19223 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19225 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19227 },
    { MODRM_SPLITRM, 19229 },
    { MODRM_SPLITRM, 19231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19233 },
    { MODRM_SPLITRM, 19235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19237 },
    { MODRM_SPLITRM, 19239 },
    { MODRM_SPLITRM, 19241 },
    { MODRM_SPLITRM, 19243 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19245 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19247 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19249 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19251 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19253 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19257 },
    { MODRM_SPLITRM, 19259 },
    { MODRM_SPLITRM, 19261 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19263 },
    { MODRM_SPLITRM, 19265 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19267 },
    { MODRM_SPLITRM, 19269 },
    { MODRM_SPLITRM, 19271 },
    { MODRM_SPLITRM, 19273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19275 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19277 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19279 },
    { MODRM_SPLITRM, 19281 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19283 },
    { MODRM_SPLITRM, 19285 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19287 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19223 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19225 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19289 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19291 },
    { MODRM_SPLITRM, 19293 },
    { MODRM_SPLITRM, 19231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19295 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19297 },
    { MODRM_SPLITRM, 19235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19299 },
    { MODRM_SPLITRM, 19239 },
    { MODRM_SPLITRM, 19301 },
    { MODRM_SPLITRM, 19243 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19303 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19305 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 19307 },
    { MODRM_SPLITRM, 19309 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19311 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19313 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19315 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19317 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19319 },
    { MODRM_SPLITRM, 19321 },
    { MODRM_SPLITRM, 19261 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19323 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19325 },
    { MODRM_SPLITRM, 19265 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19327 },
    { MODRM_SPLITRM, 19269 },
    { MODRM_SPLITRM, 19329 },
    { MODRM_SPLITRM, 19273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19331 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19333 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19335 },
    { MODRM_SPLITRM, 19337 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19339 },
    { MODRM_SPLITRM, 19341 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19343 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19223 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19225 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19345 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19347 },
    { MODRM_SPLITRM, 19349 },
    { MODRM_SPLITRM, 19231 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19351 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19353 },
    { MODRM_SPLITRM, 19235 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19355 },
    { MODRM_SPLITRM, 19239 },
    { MODRM_SPLITRM, 19357 },
    { MODRM_SPLITRM, 19243 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19359 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19361 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 19363 },
    { MODRM_SPLITRM, 19365 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19367 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19369 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19371 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19255 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19373 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19375 },
    { MODRM_SPLITRM, 19377 },
    { MODRM_SPLITRM, 19261 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19379 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19381 },
    { MODRM_SPLITRM, 19265 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19383 },
    { MODRM_SPLITRM, 19269 },
    { MODRM_SPLITRM, 19385 },
    { MODRM_SPLITRM, 19273 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19387 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19389 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19391 },
    { MODRM_SPLITRM, 19393 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19395 },
    { MODRM_SPLITRM, 19397 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19399 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19401 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19403 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19405 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19407 },
    { MODRM_SPLITRM, 19409 },
    { MODRM_SPLITRM, 19411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19413 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19415 },
    { MODRM_SPLITRM, 19417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19419 },
    { MODRM_SPLITRM, 19421 },
    { MODRM_SPLITRM, 19423 },
    { MODRM_SPLITRM, 19425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19427 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19429 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19431 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19433 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19435 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19437 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19439 },
    { MODRM_SPLITRM, 19441 },
    { MODRM_SPLITRM, 19443 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19445 },
    { MODRM_SPLITRM, 19447 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19449 },
    { MODRM_SPLITRM, 19451 },
    { MODRM_SPLITRM, 19453 },
    { MODRM_SPLITRM, 19455 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19457 },
    { MODRM_SPLITRM, 19459 },
    { MODRM_SPLITRM, 19461 },
    { MODRM_SPLITRM, 19463 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19465 },
    { MODRM_SPLITRM, 19467 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19469 },
    { MODRM_SPLITRM, 19471 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19473 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19475 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19477 },
    { MODRM_SPLITRM, 19479 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19481 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19483 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19485 },
    { MODRM_SPLITRM, 19487 },
    { MODRM_SPLITRM, 19411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19489 },
    { MODRM_SPLITRM, 19491 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19493 },
    { MODRM_SPLITRM, 19495 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19497 },
    { MODRM_SPLITRM, 19417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19499 },
    { MODRM_SPLITRM, 19421 },
    { MODRM_SPLITRM, 19501 },
    { MODRM_SPLITRM, 19425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19503 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19505 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 19507 },
    { MODRM_SPLITRM, 19509 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19511 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19513 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19515 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19517 },
    { MODRM_SPLITRM, 19519 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19521 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19523 },
    { MODRM_SPLITRM, 19525 },
    { MODRM_SPLITRM, 19443 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19527 },
    { MODRM_SPLITRM, 19529 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19531 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19533 },
    { MODRM_SPLITRM, 19447 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19535 },
    { MODRM_SPLITRM, 19451 },
    { MODRM_SPLITRM, 19537 },
    { MODRM_SPLITRM, 19455 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19539 },
    { MODRM_SPLITRM, 19541 },
    { MODRM_SPLITRM, 19543 },
    { MODRM_SPLITRM, 19545 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19547 },
    { MODRM_SPLITRM, 19549 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19551 },
    { MODRM_SPLITRM, 19553 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19555 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19557 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19559 },
    { MODRM_SPLITRM, 19561 },
    { MODRM_SPLITRM, 19563 },
    { MODRM_SPLITRM, 19565 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19567 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19569 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19571 },
    { MODRM_SPLITRM, 19573 },
    { MODRM_SPLITRM, 19411 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19575 },
    { MODRM_SPLITRM, 19577 },
    { MODRM_SPLITRM, 19579 },
    { MODRM_SPLITRM, 19581 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19583 },
    { MODRM_SPLITRM, 19585 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19587 },
    { MODRM_SPLITRM, 19417 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19589 },
    { MODRM_SPLITRM, 19421 },
    { MODRM_SPLITRM, 19591 },
    { MODRM_SPLITRM, 19425 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19593 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19595 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_SPLITRM, 19597 },
    { MODRM_SPLITRM, 19599 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19601 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19603 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19605 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19607 },
    { MODRM_SPLITRM, 19609 },
    { MODRM_SPLITRM, 19611 },
    { MODRM_SPLITRM, 19613 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19615 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19617 },
    { MODRM_SPLITRM, 19619 },
    { MODRM_SPLITRM, 19443 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19621 },
    { MODRM_SPLITRM, 19623 },
    { MODRM_SPLITRM, 19625 },
    { MODRM_SPLITRM, 19627 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19629 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19631 },
    { MODRM_SPLITRM, 19447 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19633 },
    { MODRM_SPLITRM, 19451 },
    { MODRM_SPLITRM, 19635 },
    { MODRM_SPLITRM, 19455 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19637 },
    { MODRM_SPLITRM, 19639 },
    { MODRM_SPLITRM, 19641 },
    { MODRM_SPLITRM, 19643 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19645 },
    { MODRM_SPLITRM, 19647 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

static const unsigned char index_x86DisassemblerXOP8Opcodes[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  0,
  0,
  0,
  2,
  0,
  0,
  0,
  3,
  0,
  0,
  0,
  4,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86DisassemblerXOP8Opcodes[] = {
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19649 },
    { MODRM_SPLITRM, 19651 },
    { MODRM_SPLITRM, 19653 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19655 },
    { MODRM_SPLITRM, 19657 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19659 },
    { MODRM_SPLITRM, 19661 },
    { MODRM_SPLITRM, 19663 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19665 },
    { MODRM_SPLITRM, 19667 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19669 },
    { MODRM_SPLITRM, 19671 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19673 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19675 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19677 },
    { MODRM_SPLITRM, 19679 },
    { MODRM_SPLITRM, 19681 },
    { MODRM_SPLITRM, 19683 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19685 },
    { MODRM_SPLITRM, 19687 },
    { MODRM_SPLITRM, 19689 },
    { MODRM_SPLITRM, 19691 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19693 },
    { MODRM_SPLITRM, 19695 },
    { MODRM_SPLITRM, 19697 },
    { MODRM_SPLITRM, 19699 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19701 },
    { MODRM_SPLITRM, 19703 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19705 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19707 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

static const unsigned char index_x86DisassemblerXOP9Opcodes[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  0,
  0,
  0,
  2,
  0,
  0,
  0,
  3,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86DisassemblerXOP9Opcodes[] = {
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 19709 },
    { MODRM_SPLITREG, 19725 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 19741 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19757 },
    { MODRM_SPLITRM, 19759 },
    { MODRM_SPLITRM, 19761 },
    { MODRM_SPLITRM, 19763 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19765 },
    { MODRM_SPLITRM, 19767 },
    { MODRM_SPLITRM, 19769 },
    { MODRM_SPLITRM, 19771 },
    { MODRM_SPLITRM, 19773 },
    { MODRM_SPLITRM, 19775 },
    { MODRM_SPLITRM, 19777 },
    { MODRM_SPLITRM, 19779 },
    { MODRM_SPLITRM, 19781 },
    { MODRM_SPLITRM, 19783 },
    { MODRM_SPLITRM, 19785 },
    { MODRM_SPLITRM, 19787 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19789 },
    { MODRM_SPLITRM, 19791 },
    { MODRM_SPLITRM, 19793 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19795 },
    { MODRM_SPLITRM, 19797 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19799 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19801 },
    { MODRM_SPLITRM, 19803 },
    { MODRM_SPLITRM, 19805 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19807 },
    { MODRM_SPLITRM, 19809 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19811 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19813 },
    { MODRM_SPLITRM, 19815 },
    { MODRM_SPLITRM, 19817 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 19819 },
    { MODRM_SPLITREG, 19835 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 19851 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19867 },
    { MODRM_SPLITRM, 19869 },
    { MODRM_SPLITRM, 19871 },
    { MODRM_SPLITRM, 19873 },
    { MODRM_SPLITRM, 19875 },
    { MODRM_SPLITRM, 19877 },
    { MODRM_SPLITRM, 19879 },
    { MODRM_SPLITRM, 19881 },
    { MODRM_SPLITRM, 19883 },
    { MODRM_SPLITRM, 19885 },
    { MODRM_SPLITRM, 19887 },
    { MODRM_SPLITRM, 19889 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19891 },
    { MODRM_SPLITRM, 19893 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

static const unsigned char index_x86DisassemblerXOPAOpcodes[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  0,
  0,
  0,
  2,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86DisassemblerXOPAOpcodes[] = {
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19895 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 19897 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19913 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITREG, 19915 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

static const unsigned char index_x86Disassembler3DNowOpcodes[] = {
  1,
  2,
  3,
  4,
  5,
  6,
  7,
  0,
  0,
  0,
  0,
  8,
  9,
  10,
  11,
  12,
  13,
  14,
  0,
  0,
  15,
  16,
  17,
  18,
  19,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
};

static const struct OpcodeDecision x86Disassembler3DNowOpcodes[] = {
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
  { {
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19931 },
    { MODRM_SPLITRM, 19933 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19935 },
    { MODRM_SPLITRM, 19937 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19939 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19941 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19943 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19945 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19947 },
    { MODRM_SPLITRM, 19949 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19951 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19953 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19955 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19957 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19959 },
    { MODRM_SPLITRM, 19961 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19963 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19965 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19967 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19969 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19971 },
    { MODRM_SPLITRM, 19973 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19975 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_SPLITRM, 19977 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
    { MODRM_ONEENTRY, 0 },
  } },
};

